// This file is part of the bwip-js project available at:
//
// 	  http://metafloor.github.io/bwip-js
//
// Copyright (c) 2011-2022 Mark Warren
//
// This file contains code automatically generated from:
// Barcode Writer in Pure PostScript - Version 2022-10-19
// Copyright (c) 2004-2022 Terry Burton
//
// The MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
"use strict";

// bwip-js // Barcode Writer in Pure JavaScript
// https://github.com/metafloor/bwip-js
//
// This code was automatically generated from:
// Barcode Writer in Pure PostScript - Version 2022-10-19
//
// Copyright (c) 2011-2022 Mark Warren
// Copyright (c) 2004-2022 Terry Burton
//
// Licensed MIT. See the LICENSE file in the bwip-js root directory.
// bwip-js/barcode-hdr.js
//
// This code is injected above the cross-compiled barcode.js.

// The BWIPJS object (graphics interface)
var $$ = null;
var $j = 0; // stack pointer
var $k = []; // operand stack

// Global state defined at runtime
var $0 = {
    $error: new Map,
};

// Array ctor
//	$a()	: Build a new array up to the Infinity-marker on the stack.
//	$a(arr)	: Convert native array to a "view" of the array.
//	$a(len)	: Create a new array of length `len`
function $a(a) {
    if (!arguments.length) {
        for (var i = $j - 1; i >= 0 && $k[i] !== Infinity; i--);
        if (i < 0) {
            throw new Error('array-marker-not-found');
        }
        a = $k.splice(i + 1, $j - 1 - i);
        $j = i;
    } else if (!(a instanceof Array)) {
        a = new Array(+arguments[0]);
        for (var i = 0, l = a.length; i < l; i++) {
            a[i] = null;
        }
    }
    a.b = a; // base array
    a.o = 0; // offset into base
    return a;
}

// dict ctor
//	$d() : look for the Infinity marker on the stack
function $d() {
    // Build the dictionary in the order the keys/values were pushed so enumeration
    // occurs in the correct sequence.
    for (var mark = $j - 1; mark >= 0 && $k[mark] !== Infinity; mark -= 2) {
        if ($k[mark - 1] === Infinity) {
            throw new Error('dict-malformed-stack');
        }
    }
    if (mark < 0) {
        throw 'dict-marker-not-found';
    }
    var d = new Map;
    for (var i = mark + 1; i < $j; i += 2) {
        // Unlike javascript, postscript dict keys differentiate between
        // numbers and the string representation of a number.
        var k = $k[i]; // "key" into the dict entry
        var t = typeof k;
        if (t == 'number' || t == 'string') {
            d.set(k, $k[i + 1]);
        } else if (k instanceof Uint8Array) {
            d.set($z(k), $k[i + 1]);
        } else {
            throw 'dict-not-a-valid-key(' + k + ')';
        }
    }
    $j = mark;
    return d;
}

// string ctor
//	s(number)	: create zero-filled string of number-length
//	s(string)	: make a copy of the string
//	s(uint8[])	: make a copy of the string
//
// Returns a Uint8Array-string.
function $s(v) {
    var t = typeof v;
    if (t === 'number') {
        return new Uint8Array(v);
    }
    if (t !== 'string') {
        v = '' + v;
    }
    var s = new Uint8Array(v.length);
    for (var i = 0; i < v.length; i++) {
        s[i] = v.charCodeAt(i);
    }
    return s;
}

// ... n c roll
function $r(n, c) {
    if ($j < n) {
        throw 'roll: --stack-underflow--';
    }
    if (!c) {
        return;
    }
    if (c < 0) {
        var t = $k.splice($j - n, -c);
    } else {
        var t = $k.splice($j - n, n - c);
    }
    $k.splice.apply($k, [$j - t.length, 0].concat(t));
}

// Primarily designed to convert uint8-string to string, but will call the
// the toString() method on any value.
function $z(s) {
    if (s instanceof Uint8Array) {
        return String.fromCharCode.apply(null, s);
    }
    return '' + s;
}

// Copies source to dest and returns a view of just the copied characters
function $strcpy(dst, src) {
    if (typeof dst === 'string') {
        dst = $s(dst);
    }
    if (src instanceof Uint8Array) {
        for (var i = 0, l = src.length; i < l; i++) {
            dst[i] = src[i];
        }
    } else {
        for (var i = 0, l = src.length; i < l; i++) {
            dst[i] = src.charCodeAt(i);
        }
    }
    return src.length < dst.length ? dst.subarray(0, src.length) : dst;
}

// Copies source to dest and should (but doesn't) return a view of just the copied elements
function $arrcpy(dst, src) {
    for (var i = 0, l = src.length; i < l; i++) {
        dst[i] = src[i];
    }
    dst.length = src.length;
    return dst;
}

// cvs operator - convert a value to its string representation
//	s : string to store into
//	v : any value
function $cvs(s, v) {
    var t = typeof v;
    if (t == 'number' || t == 'boolean' || v === null) {
        v = '' + v;
    } else if (t !== 'string') {
        v = '--nostringval--';
    }
    for (var i = 0, l = v.length; i < l; i++) {
        s[i] = v.charCodeAt(i);
    }
    $k[$j++] = i < s.length ? s.subarray(0, i) : s;
}
// cvi operator - converts a numeric string value to integer.
function $cvi(s) {
    if (s instanceof Uint8Array) {
        // nul-chars on the end of a string are ignored by postscript but cause javascript
        // to return a zero result.
        return String.fromCharCode.apply(null, s).replace(/\0+$/, '') | 0;
    }
    return ('' + s) | 0;
}

// cvrs operator - convert a number to a radix string
//	s : string to store into
//	n : number
//	r : radix
function $cvrs(s, n, r) {
    return $strcpy(s, (~~n).toString(r).toUpperCase());
}

// cvx - convert to executable.
// This is only used by BWIPP to convert <XX> string literals.
function $cvx(s) {
    s = $z(s)
    var m = /^\s*<((?:[0-9a-fA-F]{2})+)>\s*$/.exec(s);
    if (!m) {
        throw 'cvx: not a <HH> hex string literal';
    }
    var h = m[1];
    var l = h.length >> 1;
    var u = new Uint8Array(l);
    for (var i = 0, j = 0; i < l; i++) {
        var c0 = h.charCodeAt(j++);
        var c1 = h.charCodeAt(j++);
        u[i] = ((c0 < 58 ? c0 - 48 : (c0 & 15) + 9) << 4) +
            (c1 < 58 ? c1 - 48 : (c1 & 15) + 9);
    }
    return u;
}

// get operator
//	s : source
//	k : key
function $get(s, k) {
    if (s instanceof Uint8Array) {
        return s[k];
    }
    if (typeof s === 'string') {
        return s.charCodeAt(k);
    }
    if (s instanceof Array) {
        return s.b[s.o + k];
    }
    if (k instanceof Uint8Array) {
        return s.get($z(k));
    }
    return s.get(k);
}

// put operator
//	d : dest
//	k : key
//	v : value
function $put(d, k, v) {
    if (d instanceof Uint8Array) {
        d[k] = v;
    } else if (d instanceof Array) {
        d.b[d.o + k] = v;
    } else if (typeof d == 'object') {
        if (k instanceof Uint8Array) {
            d.set($z(k), v);
        } else {
            d.set(k, v);
        }
    } else {
        throw 'put-not-writable-' + (typeof d);
    }
}

// getinterval operator
//	s : src
//	o : offset
//	l : length
function $geti(s, o, l) {
    if (s instanceof Uint8Array) {
        return s.subarray(o, o + l);
    }
    if (s instanceof Array) {
        var a = new Array(l);
        a.b = s.b; // base array
        a.o = s.o + o; // offset into base
        return a;
    }
    // Must be a string
    return s.substr(o, l);
}

// putinterval operator
//	d : dst
//	o : offset
//	s : src
function $puti(d, o, s) {
    if (d instanceof Uint8Array) {
        if (typeof s == 'string') {
            for (var i = 0, l = s.length; i < l; i++) {
                d[o + i] = s.charCodeAt(i);
            }
        } else {
            // When both d and s are the same, we want to copy
            // backwards, which works for the general case as well.
            for (var i = s.length - 1; i >= 0; i--) {
                d[o + i] = s[i];
            }
        }
    } else if (d instanceof Array) {
        // Operate on the base arrays
        var darr = d.b;
        var doff = o + d.o;
        var sarr = s.b;
        var soff = s.o;

        for (var i = 0, l = s.length; i < l; i++) {
            darr[doff + i] = sarr[soff + i];
        }
    } else {
        throw 'putinterval-not-writable-' + (typeof d);
    }
}

// type operator
function $type(v) {
    // null can be mis-typed - get it out of the way
    if (v == null) {
        return 'nulltype';
    }
    var t = typeof v;
    if (t == 'number') {
        return v % 1 ? 'realtype' : 'integertype';
    }
    if (t == 'boolean') {
        return 'booleantype';
    }
    if (t == 'string' || v instanceof Uint8Array) {
        return 'stringtype';
    }
    if (t == 'function') {
        return 'operatortype';
    }
    if (v instanceof Array) {
        return 'arraytype';
    }
    return 'dicttype';
    // filetype
    // fonttype
    // gstatetype
    // marktype	(v === Infinity)
    // nametype
    // savetype
}

// anchorsearch operator
//		string seek anchorsearch suffix seek true %if-found
//						         string false	  %if-not-found
function $anchorsearch(str, seek) {
    if (!(str instanceof Uint8Array)) {
        str = $s(str);
    }
    var i = 0,
        ls = str.length,
        lk = seek.length;

    // Optimize for single characters.
    if (lk == 1) {
        var cd = seek instanceof Uint8Array ? seek[0] : seek.charCodeAt(0);
        i = str[0] == cd ? 1 : ls;
    } else if (seek.length <= ls) {
        // Slow path, 
        if (!(seek instanceof Uint8Array)) {
            seek = $s(seek);
        }
        for (; i < lk && str[i] == seek[i]; i++);
    }
    if (i == lk) {
        $k[$j++] = str.subarray(lk);
        $k[$j++] = str.subarray(0, lk);
        $k[$j++] = true;
    } else {
        $k[$j++] = str;
        $k[$j++] = false;
    }
}

// search operator
//		string seek search suffix match prefix true %if-found
//						   string false				%if-not-found
function $search(str, seek) {
    if (!(str instanceof Uint8Array)) {
        str = $s(str);
    }
    var ls = str.length;

    // Virtually all uses of search in BWIPP are for single-characters.
    // Optimize for that case.
    if (seek.length == 1) {
        var lk = 1;
        var cd = seek instanceof Uint8Array ? seek[0] : seek.charCodeAt(0);
        for (var i = 0; i < ls && str[i] != cd; i++);
    } else {
        // Slow path, 
        if (!(seek instanceof Uint8Array)) {
            seek = $s(seek);
        }
        var lk = seek.length;
        var cd = seek[0];
        for (var i = 0; i < ls && str[i] != cd; i++);
        while (i < ls) {
            for (var j = 1; j < lk && str[i + j] === seek[j]; j++);
            if (j === lk) {
                break;
            }
            for (i++; i < ls && str[i] != cd; i++);
        }
    }
    if (i < ls) {
        $k[$j++] = str.subarray(i + lk);
        $k[$j++] = str.subarray(i, i + lk);
        $k[$j++] = str.subarray(0, i);
        $k[$j++] = true;
    } else {
        $k[$j++] = str;
        $k[$j++] = false;
    }
}

// The callback is omitted when forall is being used just to push onto the
// stack.  The callback normally returns undefined.  A return of true means break.
function $forall(o, cb) {
    if (o instanceof Uint8Array) {
        for (var i = 0, l = o.length; i < l; i++) {
            $k[$j++] = o[i];
            if (cb && cb()) break;
        }
    } else if (o instanceof Array) {
        // The array may be a view.
        for (var a = o.b, i = o.o, l = o.o + o.length; i < l; i++) {
            $k[$j++] = a[i];
            if (cb && cb()) break;
        }
    } else if (typeof o === 'string') {
        for (var i = 0, l = o.length; i < l; i++) {
            $k[$j++] = o.charCodeAt(i);
            if (cb && cb()) break;
        }
    } else if (o instanceof Map) {
        for (var keys = o.keys(), i = 0, l = o.size; i < l; i++) {
            var id = keys.next().value;
            $k[$j++] = id;
            $k[$j++] = o.get(id);
            if (cb && cb()) break;
        }
    } else {
        for (var id in o) {
            $k[$j++] = id;
            $k[$j++] = o[id];
            if (cb && cb()) break;
        }
    }
}

function $cleartomark() {
    while ($j > 0 && $k[--$j] !== Infinity);
}

function $counttomark() {
    for (var i = $j - 1; i >= 0 && $k[i] !== Infinity; i--);
    return $j - i - 1;
}

function $aload(a) {
    for (var i = 0, l = a.length, b = a.b, o = a.o; i < l; i++) {
        $k[$j++] = b[o + i];
    }
    // This push has been optimized out.  See $.aload() in psc.js.
    //$k[$j++] = a;
}

function $astore(a) {
    for (var i = 0, l = a.length, b = a.b, o = a.o + l - 1; i < l; i++) {
        b[o - i] = $k[--$j];
    }
    $k[$j++] = a;
}

function $eq(a, b) {
    if (typeof a === 'string' && typeof b === 'string') {
        return a == b;
    }
    if (a instanceof Uint8Array && b instanceof Uint8Array) {
        if (a.length != b.length) {
            return false;
        }
        for (var i = 0, l = a.length; i < l; i++) {
            if (a[i] != b[i]) {
                return false;
            }
        }
        return true;
    }
    if (a instanceof Uint8Array && typeof b === 'string' ||
        b instanceof Uint8Array && typeof a === 'string') {
        if (a instanceof Uint8Array) {
            a = $z(a);
        } else {
            b = $z(b);
        }
        return a == b;
    }
    return a == b;
}

function $ne(a, b) {
    return !$eq(a, b);
}

function $lt(a, b) {
    if (a instanceof Uint8Array) {
        a = $z(a);
    }
    if (b instanceof Uint8Array) {
        b = $z(b);
    }
    return a < b;
}

function $le(a, b) {
    if (a instanceof Uint8Array) {
        a = $z(a);
    }
    if (b instanceof Uint8Array) {
        b = $z(b);
    }
    return a <= b;
}

function $gt(a, b) {
    if (a instanceof Uint8Array) {
        a = $z(a);
    }
    if (b instanceof Uint8Array) {
        b = $z(b);
    }
    return a > b;
}

function $ge(a, b) {
    if (a instanceof Uint8Array) {
        a = $z(a);
    }
    if (b instanceof Uint8Array) {
        b = $z(b);
    }
    return a >= b;
}

function $an(a, b) { // and
    return (typeof a === 'boolean') ? a && b : a & b;
}

function $or(a, b) { // or
    return (typeof a === 'boolean') ? a || b : a | b;
}

function $xo(a, b) { // xor
    return (typeof a === 'boolean') ? !a && b || a && !b : a ^ b;
}

function $nt(a) {
    return typeof a == 'boolean' ? !a : ~a;
}
// emulate single-precision floating-point (pseudo-polyfill for Math.fround)
var $f = (function(fa) {
    return function(v) {
        return Number.isInteger(v) ? v : (fa[0] = v, fa[0]);
    };
})(new Float32Array(1));

// This is a replacement for the BWIPP processoptions function.
// We cannot use the BWIPP version due to two reasons:
// - legacy code allows strings to be numbers and numbers to be strings
// - in javascript, there is no way to tell the difference between a real
//   number that is an integer, and an actual integer.
//
// options currentdict processoptions exec -> options
function bwipp_processoptions() {
    var dict = $k[--$j];
    var opts = $k[$j - 1];
    var map = opts instanceof Map;
    for (var id in dict) {
        var val;
        if (map) {
            if (!opts.has(id)) {
                continue;
            }
            val = opts.get(id);
        } else {
            if (!opts.hasOwnProperty(id)) {
                continue;
            }
            val = opts[id];
        }
        var def = dict[id];
        var typ = typeof def;

        // null is a placeholder for realtype
        if (def == null || typ == 'number') {
            // This allows for numeric strings
            if (!isFinite(+val)) {
                throw new ReferenceError('/bwipp.invalidOptionType: ' + id +
                    ': not a realtype: ' + val);
            }
            if (typeof val == 'string') {
                val = +val;
                map ? opts.set(id, val) : (opts[id] = val);
            }
        } else if (typ == 'boolean') {
            if (val !== true && val !== false) {
                throw new ReferenceError('/bwipp.invalidOptionType: ' + id +
                    ': not a booleantype: ' + val);
            }
        } else if (typ == 'string' || def instanceof Uint8Array) {
            // This allows numbers to be strings
            if (typeof val == 'number') {
                val = '' + val;
                map ? opts.set(id, val) : (opts[id] = val);
            } else if (typeof val != 'string' && !(val instanceof Uint8Array)) {
                throw new ReferenceError('/bwipp.invalidOptionType: ' + id +
                    ': not a stringtype: ' + val);
            }
        }
        // Set the option into the dictionary
        dict[id] = val;
    }
}

// DEBUG-BEGIN
function $stack() {
    console.log('[[[');
    for (var i = $j - 1; i >= 0; i--) {
        console.log(tostring($k[i]));
    }
    console.log(']]]');

    function tostring(v) {
        // null can be mis-typed - get it out of the way
        if (v === null) {
            return 'null';
        } else if (v === undefined) {
            return '<undefined>';
        } else if (v instanceof Array) {
            var s = '<array,' + v.o + ',' + v.length + '>[';
            for (var j = v.o, a = v.b, l = v.length + v.o; j < l; j++) {
                s += (j == v.o ? '' : ',') + tostring(a[j]);
            }
            return s + ']';
        } else if (v instanceof Uint8Array) {
            return '(' + $z[v] + ')';
        } else if (v instanceof Map) {
            var s = '<<';
            for (var elt of v) {
                s += (s.length == 2 ? '' : ',') + elt[0] + ':' + tostring(elt[1]);
            }
            return s + '>>';
        } else if (typeof v === 'object') {
            var s = '<<';
            for (var id in v) {
                s += (s.length == 2 ? '' : ',') + id + ':' + tostring(v[id]);
            }
            return s + '>>';
        } else if (typeof v === 'string') {
            return '"' + v + '"';
        } else {
            return '' + v;
        }
    }
}
// DEBUG-END
function bwipp_raiseerror() {
    $put($0.$error, 'errorinfo', $k[--$j]); //#115
    $put($0.$error, 'errorname', $k[--$j]); //#116
    $put($0.$error, 'command', null); //#117
    $put($0.$error, 'newerror', true); //#118
    throw new Error($z($0.$error.get("errorname")) + ": " + $z($0.$error.get("errorinfo"))); //#119
}

function bwipp_parseinput() {
    var $1 = {}; //#200
    $1.fncvals = $k[--$j]; //#204
    $1.barcode = $k[--$j]; //#205
    var _2 = 'parse'; //#207
    $1[_2] = $get($1.fncvals, _2); //#207
    delete $1.fncvals[_2]; //#207
    var _6 = 'parsefnc'; //#208
    $1[_6] = $get($1.fncvals, _6); //#208
    delete $1.fncvals[_6]; //#208
    var _A = 'parseonly'; //#209
    var _C = $get($1.fncvals, _A) !== undefined; //#209
    $1[_A] = _C; //#209
    delete $1.fncvals[_A]; //#209
    var _E = 'eci'; //#210
    var _G = $get($1.fncvals, _E) !== undefined; //#210
    $1[_E] = _G; //#210
    delete $1.fncvals[_E]; //#210
    $k[$j++] = Infinity; //#223
    var _I = $a(['NUL', 'SOH', 'STX', 'ETX', 'EOT', 'ENQ', 'ACK', 'BEL', 'BS', 'TAB', 'LF', 'VT', 'FF', 'CR', "", "", 'DLE', 'DC1', 'DC2', 'DC3', 'DC4', 'NAK', 'SYN', 'ETB', 'CAN', 'EM', 'SUB', 'ESC', 'FS', 'GS', 'RS', 'US']); //#219
    $k[$j++] = 0; //#223
    for (var _J = 0, _K = _I.length; _J < _K; _J++) { //#223
        var _M = $k[--$j]; //#222
        $k[$j++] = $get(_I, _J); //#222
        $k[$j++] = _M; //#222
        $k[$j++] = $f(_M + 1); //#222
    } //#222
    $j--; //#223
    $1.ctrl = $d(); //#224
    $1.msg = $a($1.barcode.length); //#227
    $1.j = 0; //#228
    $k[$j++] = $1.barcode; //#347
    for (;;) { //#347
        $search($k[--$j], "^"); //#230
        var _S = $k[--$j]; //#230
        var _T = $k[--$j]; //#230
        $k[$j++] = _S; //#233
        $k[$j++] = _T.length; //#233
        $k[$j++] = $1.msg; //#233
        $k[$j++] = $1.j; //#233
        $k[$j++] = _T; //#233
        $k[$j++] = Infinity; //#233
        var _W = $k[--$j]; //#233
        var _X = $k[--$j]; //#233
        $k[$j++] = _W; //#233
        $forall(_X); //#233
        var _Y = $a(); //#233
        var _Z = $k[--$j]; //#233
        $puti($k[--$j], _Z, _Y); //#233
        $1.j = $f($k[--$j] + $1.j); //#234
        if ($k[--$j]) { //#345
            $j--; //#236
            for (var _e = 0, _f = 1; _e < _f; _e++) { //#343
                if ($an($nt($1.parse), $nt($1.parsefnc))) { //#243
                    $put($1.msg, $1.j, 94); //#240
                    $1.j = $f($1.j + 1); //#241
                    break; //#242
                } //#242
                $put($1.msg, $1.j, 94); //#246
                $1.j = $f($1.j + 1); //#247
                if ($1.parse) { //#290
                    var _p = $k[--$j]; //#251
                    $k[$j++] = _p; //#262
                    if (_p.length >= 3) { //#262
                        var _q = $k[--$j]; //#252
                        var _r = $geti(_q, 0, 3); //#252
                        var _s = $1.ctrl; //#252
                        var _t = $get(_s, _r) !== undefined; //#253
                        $k[$j++] = _q; //#261
                        $k[$j++] = _s; //#261
                        $k[$j++] = _r; //#261
                        if (_t) { //#260
                            $1.j = $f($1.j - 1); //#254
                            var _v = $k[--$j]; //#255
                            $put($1.msg, $1.j, $get($k[--$j], _v)); //#255
                            $1.j = $f($1.j + 1); //#256
                            var _11 = $k[--$j]; //#257
                            $k[$j++] = $geti(_11, 3, _11.length - 3); //#258
                            break; //#258
                        } else { //#260
                            $j -= 2; //#260
                        } //#260
                    } //#260
                    var _13 = $k[--$j]; //#263
                    $k[$j++] = _13; //#274
                    if (_13.length >= 2) { //#274
                        var _14 = $k[--$j]; //#264
                        var _15 = $geti(_14, 0, 2); //#264
                        var _16 = $1.ctrl; //#264
                        var _17 = $get(_16, _15) !== undefined; //#265
                        $k[$j++] = _14; //#273
                        $k[$j++] = _16; //#273
                        $k[$j++] = _15; //#273
                        if (_17) { //#272
                            $1.j = $f($1.j - 1); //#266
                            var _19 = $k[--$j]; //#267
                            $put($1.msg, $1.j, $get($k[--$j], _19)); //#267
                            $1.j = $f($1.j + 1); //#268
                            var _1F = $k[--$j]; //#269
                            $k[$j++] = $geti(_1F, 2, _1F.length - 2); //#270
                            break; //#270
                        } else { //#272
                            $j -= 2; //#272
                        } //#272
                    } //#272
                    var _1H = $k[--$j]; //#275
                    $k[$j++] = _1H; //#289
                    if (_1H.length >= 3) { //#289
                        var _1I = $k[--$j]; //#276
                        var _1J = $geti(_1I, 0, 3); //#276
                        $k[$j++] = _1I; //#278
                        $k[$j++] = true; //#278
                        for (var _1K = 0, _1L = _1J.length; _1K < _1L; _1K++) { //#278
                            var _1M = $get(_1J, _1K); //#278
                            if ((_1M < 48) || (_1M > 57)) { //#277
                                $j--; //#277
                                $k[$j++] = false; //#277
                            } //#277
                        } //#277
                        if ($k[--$j]) { //#288
                            var _1O = $k[--$j]; //#280
                            var _1Q = $cvi($geti(_1O, 0, 3)); //#280
                            $k[$j++] = _1O; //#283
                            $k[$j++] = _1Q; //#283
                            if (_1Q > 255) { //#283
                                $j -= 2; //#281
                                $k[$j++] = 'bwipp.invalidOrdinal'; //#282
                                $k[$j++] = "Ordinal must be 000 to 255"; //#282
                                bwipp_raiseerror(); //#282
                            } //#282
                            $1.j = $f($1.j - 1); //#284
                            $put($1.msg, $1.j, $k[--$j]); //#285
                            $1.j = $f($1.j + 1); //#286
                            var _1W = $k[--$j]; //#287
                            $k[$j++] = $geti(_1W, 3, _1W.length - 3); //#287
                        } //#287
                    } //#287
                } //#287
                if (($or($1.parseonly, $nt($1.parsefnc))) || ($get($1.msg, $f($1.j - 1)) != 94)) { //#295
                    break; //#295
                } //#295
                $1.j = $f($1.j - 1); //#298
                var _1e = $k[--$j]; //#299
                $k[$j++] = _1e; //#302
                if (_1e.length < 3) { //#302
                    $j--; //#300
                    $k[$j++] = 'bwipp.truncatedFNC'; //#301
                    $k[$j++] = "Function character truncated"; //#301
                    bwipp_raiseerror(); //#301
                } //#301
                var _1f = $k[--$j]; //#303
                $k[$j++] = _1f; //#308
                if ($get(_1f, 0) == 94) { //#308
                    $put($1.msg, $1.j, 94); //#304
                    $1.j = $f($1.j + 1); //#305
                    var _1k = $k[--$j]; //#306
                    $k[$j++] = $geti(_1k, 1, _1k.length - 1); //#307
                    break; //#307
                } //#307
                var _1m = $k[--$j]; //#309
                $k[$j++] = _1m; //#326
                if ($eq($geti(_1m, 0, 3), "ECI") && $1.eci) { //#326
                    var _1p = $k[--$j]; //#310
                    $k[$j++] = _1p; //#313
                    if (_1p.length < 9) { //#313
                        $j--; //#311
                        $k[$j++] = 'bwipp.truncatedECI'; //#312
                        $k[$j++] = "ECI truncated"; //#312
                        bwipp_raiseerror(); //#312
                    } //#312
                    var _1q = $k[--$j]; //#314
                    var _1r = $geti(_1q, 3, 6); //#314
                    $k[$j++] = _1q; //#320
                    $k[$j++] = _1r; //#320
                    for (var _1s = 0, _1t = _1r.length; _1s < _1t; _1s++) { //#320
                        var _1u = $get(_1r, _1s); //#320
                        if ((_1u < 48) || (_1u > 57)) { //#319
                            $j -= 2; //#317
                            $k[$j++] = 'bwipp.invalidECI'; //#318
                            $k[$j++] = "ECI must be 000000 to 999999"; //#318
                            bwipp_raiseerror(); //#318
                        } //#318
                    } //#318
                    var _1v = $k[--$j]; //#321
                    $k[$j++] = 0; //#321
                    $forall(_1v, function() { //#321
                        var _1w = $k[--$j]; //#321
                        var _1x = $k[--$j]; //#321
                        $k[$j++] = ($f(_1x - $f(_1w - 48))) * 10; //#321
                    }); //#321
                    $put($1.msg, $1.j, (~~($k[--$j] / 10)) - 1000000); //#322
                    $1.j = $f($1.j + 1); //#323
                    var _22 = $k[--$j]; //#324
                    $k[$j++] = $geti(_22, 9, _22.length - 9); //#325
                    break; //#325
                } //#325
                var _24 = $k[--$j]; //#327
                $k[$j++] = _24; //#330
                if (_24.length < 4) { //#330
                    $j--; //#328
                    $k[$j++] = 'bwipp.truncatedFNC'; //#329
                    $k[$j++] = "Function character truncated"; //#329
                    bwipp_raiseerror(); //#329
                } //#329
                var _25 = $k[--$j]; //#331
                var _26 = $geti(_25, 0, 4); //#331
                var _28 = $get($1.fncvals, _26) !== undefined; //#331
                $k[$j++] = _25; //#336
                $k[$j++] = _26; //#336
                if (!_28) { //#336
                    var _29 = $k[--$j]; //#332
                    var _2A = $s(_29.length + 28); //#332
                    $puti(_2A, 28, _29); //#332
                    $puti(_2A, 0, "Unknown function character: "); //#333
                    var _2B = $k[--$j]; //#334
                    $k[$j++] = _2A; //#334
                    $k[$j++] = _2B; //#334
                    $j--; //#334
                    var _2C = $k[--$j]; //#335
                    $k[$j++] = 'bwipp.unknownFNC'; //#335
                    $k[$j++] = _2C; //#335
                    bwipp_raiseerror(); //#335
                } //#335
                $put($1.msg, $1.j, $get($1.fncvals, $k[--$j])); //#338
                $1.j = $f($1.j + 1); //#339
                var _2J = $k[--$j]; //#340
                $k[$j++] = $geti(_2J, 4, _2J.length - 4); //#341
                break; //#341
            } //#341
        } else { //#345
            break; //#345
        } //#345
    } //#345
    if ($nt($1.parseonly)) { //#353
        $k[$j++] = $geti($1.msg, 0, $1.j); //#350
    } else { //#353
        $k[$j++] = $s($1.j); //#353
        for (var _2T = 0, _2S = $f($1.j - 1); _2T <= _2S; _2T += 1) { //#353
            var _2U = $k[--$j]; //#353
            $put(_2U, _2T, $get($1.msg, _2T)); //#353
            $k[$j++] = _2U; //#353
        } //#353
    } //#353
}

function bwipp_gs1process() {
    var $1 = {}; //#383
    var _1 = new Map([
        ["cset", 'N'],
        ["min", 18],
        ["max", 18],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#393
    var _2 = $a([_1]); //#393
    var _3 = $a([]); //#395
    var _4 = new Map([
        ["parts", _2],
        ["dlpkey", _3]
    ]); //#395
    var _5 = $a(['lintcsum', 'lintkey']); //#402
    var _6 = new Map([
        ["cset", 'N'],
        ["min", 14],
        ["max", 14],
        ["opt", false],
        ["linters", _5]
    ]); //#402
    var _7 = $a([_6]); //#402
    var _8 = $a(["02", "255", "37"]); //#404
    var _9 = $a(["22", "10", "21"]); //#405
    var _A = $a(["235"]); //#405
    var _B = $a([_9, _A]); //#405
    var _C = new Map([
        ["parts", _7],
        ["ex", _8],
        ["dlpkey", _B]
    ]); //#405
    var _D = $a(['lintcsum', 'lintkey']); //#412
    var _E = new Map([
        ["cset", 'N'],
        ["min", 14],
        ["max", 14],
        ["opt", false],
        ["linters", _D]
    ]); //#412
    var _F = $a([_E]); //#412
    var _G = $a(["37"]); //#414
    var _H = $a([_G]); //#414
    var _I = new Map([
        ["parts", _F],
        ["req", _H]
    ]); //#414
    var _K = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#421
    var _O = new Map([
        ["parts", $a([_K])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#423
    var _Q = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmd0'])]
    ]); //#430
    var _U = new Map([
        ["parts", $a([_Q])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#432
    var _W = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmd0'])]
    ]); //#439
    var _a = new Map([
        ["parts", $a([_W])],
        ["req", $a([$a(["8020"])])]
    ]); //#441
    var _c = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmd0'])]
    ]); //#448
    var _g = new Map([
        ["parts", $a([_c])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#450
    var _i = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmd0'])]
    ]); //#459
    var _m = new Map([
        ["parts", $a([_i])],
        ["req", $a([$a(["01", "02", "255", "8006", "8026"])])]
    ]); //#461
    var _o = new Map([
        ["cset", 'N'],
        ["min", 2],
        ["max", 2],
        ["opt", false],
        ["linters", $a([])]
    ]); //#468
    var _r = $a([$a(["01", "02", "8006", "8026"])]); //#470
    var _s = new Map([
        ["parts", $a([_o])],
        ["req", _r]
    ]); //#470
    var _u = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#477
    var _z = new Map([
        ["parts", $a([_u])],
        ["ex", $a(["235"])],
        ["req", $a([$a(["01", "8006"])])]
    ]); //#480
    var _11 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#487
    var _15 = new Map([
        ["parts", $a([_11])],
        ["req", $a([$a(["01"])])]
    ]); //#489
    var _17 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 28],
        ["opt", false],
        ["linters", $a([])]
    ]); //#496
    var _1B = new Map([
        ["parts", $a([_17])],
        ["req", $a([$a(["01"])])]
    ]); //#498
    var _1D = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#505
    var _1H = new Map([
        ["parts", $a([_1D])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#507
    var _1J = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#515
    var _1N = new Map([
        ["parts", $a([_1J])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#517
    var _1P = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#524
    var _1T = new Map([
        ["parts", $a([_1P])],
        ["req", $a([$a(["01"])])]
    ]); //#526
    var _1V = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#533
    var _1a = new Map([
        ["parts", $a([_1V])],
        ["req", $a([$a(["01", "8006"]), $a(["21"])])]
    ]); //#535
    var _1c = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#542
    var _1g = new Map([
        ["parts", $a([_1c])],
        ["req", $a([$a(["01", "8006"])])]
    ]); //#544
    var _1i = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#551
    var _1k = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 17],
        ["opt", true],
        ["linters", $a([])]
    ]); //#552
    var _1n = new Map([
        ["parts", $a([_1i, _1k])],
        ["dlpkey", $a([])]
    ]); //#554
    var _1p = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#561
    var _1t = new Map([
        ["parts", $a([_1p])],
        ["req", $a([$a(["414"])])]
    ]); //#563
    var _1v = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#570
    var _1x = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 12],
        ["opt", true],
        ["linters", $a([])]
    ]); //#571
    var _21 = new Map([
        ["parts", $a([_1v, _1x])],
        ["ex", $a(["01", "02", "415", "8006", "8020", "8026"])],
        ["dlpkey", $a([])]
    ]); //#574
    var _23 = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 8],
        ["opt", false],
        ["linters", $a([])]
    ]); //#581
    var _27 = new Map([
        ["parts", $a([_23])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#583
    var _29 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#590
    var _2E = new Map([
        ["parts", $a([_29])],
        ["ex", $a(["310n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#593
    var _2G = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#605
    var _2L = new Map([
        ["parts", $a([_2G])],
        ["ex", $a(["311n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#608
    var _2N = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#620
    var _2S = new Map([
        ["parts", $a([_2N])],
        ["ex", $a(["312n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#623
    var _2U = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#635
    var _2Z = new Map([
        ["parts", $a([_2U])],
        ["ex", $a(["313n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#638
    var _2b = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#650
    var _2g = new Map([
        ["parts", $a([_2b])],
        ["ex", $a(["314n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#653
    var _2i = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#665
    var _2n = new Map([
        ["parts", $a([_2i])],
        ["ex", $a(["315n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#668
    var _2p = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#680
    var _2u = new Map([
        ["parts", $a([_2p])],
        ["ex", $a(["316n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#683
    var _2w = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#695
    var _31 = new Map([
        ["parts", $a([_2w])],
        ["ex", $a(["320n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#698
    var _33 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#710
    var _38 = new Map([
        ["parts", $a([_33])],
        ["ex", $a(["321n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#713
    var _3A = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#725
    var _3F = new Map([
        ["parts", $a([_3A])],
        ["ex", $a(["322n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#728
    var _3H = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#740
    var _3M = new Map([
        ["parts", $a([_3H])],
        ["ex", $a(["323n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#743
    var _3O = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#755
    var _3T = new Map([
        ["parts", $a([_3O])],
        ["ex", $a(["324n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#758
    var _3V = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#770
    var _3a = new Map([
        ["parts", $a([_3V])],
        ["ex", $a(["325n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#773
    var _3c = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#785
    var _3h = new Map([
        ["parts", $a([_3c])],
        ["ex", $a(["326n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#788
    var _3j = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#800
    var _3o = new Map([
        ["parts", $a([_3j])],
        ["ex", $a(["327n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#803
    var _3q = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#815
    var _3v = new Map([
        ["parts", $a([_3q])],
        ["ex", $a(["328n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#818
    var _3x = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#830
    var _42 = new Map([
        ["parts", $a([_3x])],
        ["ex", $a(["329n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#833
    var _44 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#845
    var _49 = new Map([
        ["parts", $a([_44])],
        ["ex", $a(["330n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#848
    var _4B = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#860
    var _4G = new Map([
        ["parts", $a([_4B])],
        ["ex", $a(["331n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#863
    var _4I = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#875
    var _4N = new Map([
        ["parts", $a([_4I])],
        ["ex", $a(["332n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#878
    var _4P = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#890
    var _4U = new Map([
        ["parts", $a([_4P])],
        ["ex", $a(["333n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#893
    var _4W = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#905
    var _4b = new Map([
        ["parts", $a([_4W])],
        ["ex", $a(["334n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#908
    var _4d = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#920
    var _4i = new Map([
        ["parts", $a([_4d])],
        ["ex", $a(["335n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#923
    var _4k = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#935
    var _4p = new Map([
        ["parts", $a([_4k])],
        ["ex", $a(["336n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#938
    var _4r = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#950
    var _4w = new Map([
        ["parts", $a([_4r])],
        ["ex", $a(["337n"])],
        ["req", $a([$a(["01"])])]
    ]); //#953
    var _4y = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#965
    var _53 = new Map([
        ["parts", $a([_4y])],
        ["ex", $a(["340n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#968
    var _55 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#980
    var _5A = new Map([
        ["parts", $a([_55])],
        ["ex", $a(["341n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#983
    var _5C = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#995
    var _5H = new Map([
        ["parts", $a([_5C])],
        ["ex", $a(["342n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#998
    var _5J = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1010
    var _5O = new Map([
        ["parts", $a([_5J])],
        ["ex", $a(["343n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1013
    var _5Q = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1025
    var _5V = new Map([
        ["parts", $a([_5Q])],
        ["ex", $a(["344n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1028
    var _5X = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1040
    var _5c = new Map([
        ["parts", $a([_5X])],
        ["ex", $a(["345n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1043
    var _5e = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1055
    var _5j = new Map([
        ["parts", $a([_5e])],
        ["ex", $a(["346n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1058
    var _5l = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1070
    var _5q = new Map([
        ["parts", $a([_5l])],
        ["ex", $a(["347n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1073
    var _5s = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1085
    var _5x = new Map([
        ["parts", $a([_5s])],
        ["ex", $a(["348n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1088
    var _5z = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1100
    var _64 = new Map([
        ["parts", $a([_5z])],
        ["ex", $a(["349n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1103
    var _66 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1115
    var _6B = new Map([
        ["parts", $a([_66])],
        ["ex", $a(["350n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1118
    var _6D = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1130
    var _6I = new Map([
        ["parts", $a([_6D])],
        ["ex", $a(["351n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1133
    var _6K = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1145
    var _6P = new Map([
        ["parts", $a([_6K])],
        ["ex", $a(["352n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1148
    var _6R = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1160
    var _6W = new Map([
        ["parts", $a([_6R])],
        ["ex", $a(["353n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1163
    var _6Y = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1175
    var _6d = new Map([
        ["parts", $a([_6Y])],
        ["ex", $a(["354n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1178
    var _6f = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1190
    var _6k = new Map([
        ["parts", $a([_6f])],
        ["ex", $a(["355n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1193
    var _6m = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1205
    var _6r = new Map([
        ["parts", $a([_6m])],
        ["ex", $a(["356n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1208
    var _6t = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1220
    var _6y = new Map([
        ["parts", $a([_6t])],
        ["ex", $a(["357n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1223
    var _70 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1235
    var _75 = new Map([
        ["parts", $a([_70])],
        ["ex", $a(["360n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1238
    var _77 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1250
    var _7C = new Map([
        ["parts", $a([_77])],
        ["ex", $a(["361n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1253
    var _7E = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1265
    var _7J = new Map([
        ["parts", $a([_7E])],
        ["ex", $a(["362n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1268
    var _7L = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1280
    var _7Q = new Map([
        ["parts", $a([_7L])],
        ["ex", $a(["363n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1283
    var _7S = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1295
    var _7X = new Map([
        ["parts", $a([_7S])],
        ["ex", $a(["364n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1298
    var _7Z = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1310
    var _7e = new Map([
        ["parts", $a([_7Z])],
        ["ex", $a(["365n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1313
    var _7g = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1325
    var _7l = new Map([
        ["parts", $a([_7g])],
        ["ex", $a(["366n"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1328
    var _7n = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1340
    var _7s = new Map([
        ["parts", $a([_7n])],
        ["ex", $a(["367n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1343
    var _7u = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1355
    var _7z = new Map([
        ["parts", $a([_7u])],
        ["ex", $a(["368n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1358
    var _81 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1370
    var _86 = new Map([
        ["parts", $a([_81])],
        ["ex", $a(["369n"])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#1373
    var _88 = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 8],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1385
    var _8D = new Map([
        ["parts", $a([_88])],
        ["req", $a([$a(["00"]), $a(["02", "8026"])])]
    ]); //#1387
    var _8F = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1394
    var _8K = new Map([
        ["parts", $a([_8F])],
        ["ex", $a(["390n", "391n", "394n", "8111"])],
        ["req", $a([$a(["255", "8020"])])]
    ]); //#1397
    var _8M = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso4217'])]
    ]); //#1413
    var _8O = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1414
    var _8T = new Map([
        ["parts", $a([_8M, _8O])],
        ["ex", $a(["391n"])],
        ["req", $a([$a(["8020"])])]
    ]); //#1417
    var _8V = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1433
    var _8b = new Map([
        ["parts", $a([_8V])],
        ["ex", $a(["392n", "393n"])],
        ["req", $a([$a(["01"]), $a(["30", "31nn", "32nn", "35nn", "36nn"])])]
    ]); //#1436
    var _8d = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso4217'])]
    ]); //#1452
    var _8f = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1453
    var _8k = new Map([
        ["parts", $a([_8d, _8f])],
        ["ex", $a(["393n"])],
        ["req", $a([$a(["30", "31nn", "32nn", "35nn", "36nn"])])]
    ]); //#1456
    var _8m = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1472
    var _8r = new Map([
        ["parts", $a([_8m])],
        ["ex", $a(["394n", "8111"])],
        ["req", $a([$a(["255"])])]
    ]); //#1475
    var _8t = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1485
    var _8y = new Map([
        ["parts", $a([_8t])],
        ["ex", $a(["392n", "393n", "395n", "8005"])],
        ["req", $a([$a(["30", "31nn", "32nn", "35nn", "36nn"])])]
    ]); //#1488
    var _90 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1500
    var _92 = new Map([
        ["parts", $a([_90])]
    ]); //#1500
    var _94 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a(['lintkey'])]
    ]); //#1508
    var _97 = new Map([
        ["parts", $a([_94])],
        ["dlpkey", $a([])]
    ]); //#1510
    var _99 = new Map([
        ["cset", 'N'],
        ["min", 17],
        ["max", 17],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1517
    var _9C = new Map([
        ["parts", $a([_99])],
        ["dlpkey", $a([])]
    ]); //#1519
    var _9E = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1526
    var _9I = new Map([
        ["parts", $a([_9E])],
        ["req", $a([$a(["00"])])]
    ]); //#1528
    var _9K = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1535
    var _9M = new Map([
        ["parts", $a([_9K])]
    ]); //#1535
    var _9O = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1546
    var _9T = new Map([
        ["parts", $a([_9O])],
        ["dlpkey", $a([$a(["254"]), $a(["7040"])])]
    ]); //#1548
    var _9V = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1555
    var _9Z = new Map([
        ["parts", $a([_9V])],
        ["req", $a([$a(["8020"])])]
    ]); //#1557
    var _9b = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1564
    var _9d = new Map([
        ["parts", $a([_9b])]
    ]); //#1564
    var _9f = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#1572
    var _9j = new Map([
        ["parts", $a([_9f])],
        ["dlpkey", $a([$a(["7040"])])]
    ]); //#1574
    var _9l = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1581
    var _9o = new Map([
        ["parts", $a([_9l])],
        ["ex", $a(["421"])]
    ]); //#1583
    var _9q = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso3166'])]
    ]); //#1590
    var _9s = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 9],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1591
    var _9v = new Map([
        ["parts", $a([_9q, _9s])],
        ["ex", $a(["4307"])]
    ]); //#1593
    var _9x = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso3166'])]
    ]); //#1600
    var _A2 = new Map([
        ["parts", $a([_9x])],
        ["ex", $a(["426"])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#1603
    var _A4 = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a(['lintiso3166list'])]
    ]); //#1610
    var _A9 = new Map([
        ["parts", $a([_A4])],
        ["ex", $a(["426"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1613
    var _AB = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso3166'])]
    ]); //#1620
    var _AG = new Map([
        ["parts", $a([_AB])],
        ["ex", $a(["426"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1623
    var _AI = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 15],
        ["opt", false],
        ["linters", $a(['lintiso3166list'])]
    ]); //#1630
    var _AN = new Map([
        ["parts", $a([_AI])],
        ["ex", $a(["426"])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1633
    var _AP = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso3166'])]
    ]); //#1640
    var _AT = new Map([
        ["parts", $a([_AP])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1642
    var _AV = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 3],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1649
    var _Aa = new Map([
        ["parts", $a([_AV])],
        ["req", $a([$a(["01", "02"]), $a(["422"])])]
    ]); //#1651
    var _Ac = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 35],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1658
    var _Ag = new Map([
        ["parts", $a([_Ac])],
        ["req", $a([$a(["00"])])]
    ]); //#1660
    var _Ai = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1668
    var _Am = new Map([
        ["parts", $a([_Ai])],
        ["req", $a([$a(["00"])])]
    ]); //#1670
    var _Ao = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1677
    var _As = new Map([
        ["parts", $a([_Ao])],
        ["req", $a([$a(["4302"])])]
    ]); //#1679
    var _Au = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1686
    var _Ay = new Map([
        ["parts", $a([_Au])],
        ["req", $a([$a(["00"])])]
    ]); //#1688
    var _B0 = new Map([
        ["cset", 'X'],
        ["min", 2],
        ["max", 2],
        ["opt", false],
        ["linters", $a(['lintiso3166alpha2'])]
    ]); //#1697
    var _B4 = new Map([
        ["parts", $a([_B0])],
        ["req", $a([$a(["00"])])]
    ]); //#1699
    var _B6 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1706
    var _BA = new Map([
        ["parts", $a([_B6])],
        ["req", $a([$a(["00"])])]
    ]); //#1708
    var _BC = new Map([
        ["cset", 'N'],
        ["min", 20],
        ["max", 20],
        ["opt", false],
        ["linters", $a(['lintlatlong'])]
    ]); //#1715
    var _BG = new Map([
        ["parts", $a([_BC])],
        ["req", $a([$a(["00"])])]
    ]); //#1717
    var _BI = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 35],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1724
    var _BM = new Map([
        ["parts", $a([_BI])],
        ["req", $a([$a(["00"])])]
    ]); //#1726
    var _BO = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1734
    var _BS = new Map([
        ["parts", $a([_BO])],
        ["req", $a([$a(["00"])])]
    ]); //#1736
    var _BU = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1743
    var _BY = new Map([
        ["parts", $a([_BU])],
        ["req", $a([$a(["4312"])])]
    ]); //#1745
    var _Ba = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1752
    var _Be = new Map([
        ["parts", $a([_Ba])],
        ["req", $a([$a(["00"])])]
    ]); //#1754
    var _Bg = new Map([
        ["cset", 'X'],
        ["min", 2],
        ["max", 2],
        ["opt", false],
        ["linters", $a(['lintiso3166alpha2'])]
    ]); //#1763
    var _Bk = new Map([
        ["parts", $a([_Bg])],
        ["req", $a([$a(["00"])])]
    ]); //#1765
    var _Bm = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1772
    var _Bq = new Map([
        ["parts", $a([_Bm])],
        ["req", $a([$a(["00"])])]
    ]); //#1774
    var _Bs = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1781
    var _Bw = new Map([
        ["parts", $a([_Bs])],
        ["req", $a([$a(["00"])])]
    ]); //#1783
    var _By = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 35],
        ["opt", false],
        ["linters", $a(['lintpcenc'])]
    ]); //#1790
    var _C2 = new Map([
        ["parts", $a([_By])],
        ["req", $a([$a(["00"])])]
    ]); //#1792
    var _C4 = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a(['lintyesno'])]
    ]); //#1799
    var _C8 = new Map([
        ["parts", $a([_C4])],
        ["req", $a([$a(["00"])])]
    ]); //#1801
    var _CA = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmd0'])]
    ]); //#1810
    var _CC = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a(['linthhmm'])]
    ]); //#1811
    var _CG = new Map([
        ["parts", $a([_CA, _CC])],
        ["req", $a([$a(["00"])])]
    ]); //#1813
    var _CI = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1821
    var _CM = new Map([
        ["parts", $a([_CI])],
        ["req", $a([$a(["00"])])]
    ]); //#1823
    var _CO = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1830
    var _CS = new Map([
        ["parts", $a([_CO])],
        ["req", $a([$a(["01", "02", "8006", "8026"])])]
    ]); //#1832
    var _CU = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1839
    var _CY = new Map([
        ["parts", $a([_CU])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1841
    var _Ca = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1848
    var _Cc = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a(['linthhmm'])]
    ]); //#1849
    var _Cg = new Map([
        ["parts", $a([_Ca, _Cc])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1851
    var _Ci = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 4],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1858
    var _Cn = new Map([
        ["parts", $a([_Ci])],
        ["req", $a([$a(["01"]), $a(["10"])])]
    ]); //#1860
    var _Cp = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 12],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1867
    var _Ct = new Map([
        ["parts", $a([_Cp])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1869
    var _Cv = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1876
    var _Cz = new Map([
        ["parts", $a([_Cv])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1878
    var _D1 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1885
    var _D3 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", true],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1886
    var _D7 = new Map([
        ["parts", $a([_D1, _D3])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1888
    var _D9 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 3],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1895
    var _DD = new Map([
        ["parts", $a([_D9])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1897
    var _DF = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 10],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1904
    var _DJ = new Map([
        ["parts", $a([_DF])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1906
    var _DL = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 2],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1913
    var _DP = new Map([
        ["parts", $a([_DL])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1915
    var _DR = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a(['lintyymmdd'])]
    ]); //#1922
    var _DT = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", true],
        ["linters", $a(['linthhmm'])]
    ]); //#1923
    var _DX = new Map([
        ["parts", $a([_DR, _DT])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1925
    var _DZ = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1932
    var _De = new Map([
        ["parts", $a([_DZ])],
        ["req", $a([$a(["01", "8006"]), $a(["416"])])]
    ]); //#1934
    var _Dg = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1941
    var _Dk = new Map([
        ["parts", $a([_Dg])],
        ["req", $a([$a(["01", "8006"])])]
    ]); //#1943
    var _Dm = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1950
    var _Dq = new Map([
        ["parts", $a([_Dm])],
        ["req", $a([$a(["7021"])])]
    ]); //#1952
    var _Ds = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a(['lintkey'])]
    ]); //#1959
    var _Du = new Map([
        ["parts", $a([_Ds])]
    ]); //#1959
    var _Dw = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintiso3166999'])]
    ]); //#1967
    var _Dy = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 27],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1968
    var _E2 = new Map([
        ["parts", $a([_Dw, _Dy])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#1970
    var _E4 = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1986
    var _E6 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1987
    var _E8 = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1988
    var _EA = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a(['lintimporteridx'])]
    ]); //#1989
    var _EC = new Map([
        ["parts", $a([_E4, _E6, _E8, _EA])]
    ]); //#1989
    var _EE = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#1997
    var _EI = new Map([
        ["parts", $a([_EE])],
        ["req", $a([$a(["01"])])]
    ]); //#1999
    var _EK = new Map([
        ["cset", 'X'],
        ["min", 2],
        ["max", 2],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2011
    var _EM = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 28],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2012
    var _EQ = new Map([
        ["parts", $a([_EK, _EM])],
        ["req", $a([$a(["01", "8004"])])]
    ]); //#2014
    var _ES = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2030
    var _EW = new Map([
        ["parts", $a([_ES])],
        ["req", $a([$a(["01", "8006"])])]
    ]); //#2032
    var _EY = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a(['lintnonzero'])]
    ]); //#2039
    var _Ea = new Map([
        ["cset", 'N'],
        ["min", 5],
        ["max", 5],
        ["opt", false],
        ["linters", $a(['lintnonzero'])]
    ]); //#2040
    var _Ec = new Map([
        ["cset", 'N'],
        ["min", 3],
        ["max", 3],
        ["opt", false],
        ["linters", $a(['lintnonzero'])]
    ]); //#2041
    var _Ee = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a(['lintwinding'])]
    ]); //#2042
    var _Eg = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2043
    var _Ek = new Map([
        ["parts", $a([_EY, _Ea, _Ec, _Ee, _Eg])],
        ["req", $a([$a(["01"])])]
    ]); //#2045
    var _Em = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2052
    var _Eo = new Map([
        ["parts", $a([_Em])]
    ]); //#2052
    var _Eq = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 1],
        ["opt", false],
        ["linters", $a(['lintzero'])]
    ]); //#2060
    var _Es = new Map([
        ["cset", 'N'],
        ["min", 13],
        ["max", 13],
        ["opt", false],
        ["linters", $a(['lintcsum', 'lintkey'])]
    ]); //#2061
    var _Eu = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 16],
        ["opt", true],
        ["linters", $a([])]
    ]); //#2062
    var _Ex = new Map([
        ["parts", $a([_Eq, _Es, _Eu])],
        ["dlpkey", $a([])]
    ]); //#2064
    var _Ez = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a(['lintkey'])]
    ]); //#2071
    var _F3 = new Map([
        ["parts", $a([_Ez])],
        ["dlpkey", $a([$a(["7040"])])]
    ]); //#2073
    var _F5 = new Map([
        ["cset", 'N'],
        ["min", 6],
        ["max", 6],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2080
    var _F9 = new Map([
        ["parts", $a([_F5])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#2082
    var _FB = new Map([
        ["cset", 'N'],
        ["min", 14],
        ["max", 14],
        ["opt", false],
        ["linters", $a(['lintcsum'])]
    ]); //#2089
    var _FD = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a(['lintpieceoftotal'])]
    ]); //#2090
    var _FI = new Map([
        ["parts", $a([_FB, _FD])],
        ["ex", $a(["01", "37"])],
        ["dlpkey", $a([$a(["22", "10", "21"])])]
    ]); //#2093
    var _FK = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 34],
        ["opt", false],
        ["linters", $a(['lintiban'])]
    ]); //#2100
    var _FO = new Map([
        ["parts", $a([_FK])],
        ["req", $a([$a(["415"])])]
    ]); //#2102
    var _FQ = new Map([
        ["cset", 'N'],
        ["min", 8],
        ["max", 8],
        ["opt", false],
        ["linters", $a(['lintyymmddhh'])]
    ]); //#2109
    var _FS = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 4],
        ["opt", true],
        ["linters", $a(['lintmmoptss'])]
    ]); //#2110
    var _FW = new Map([
        ["parts", $a([_FQ, _FS])],
        ["req", $a([$a(["01", "02"])])]
    ]); //#2112
    var _FY = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 50],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2119
    var _Fc = new Map([
        ["parts", $a([_FY])],
        ["req", $a([$a(["00", "01"])])]
    ]); //#2121
    var _Fe = new Map([
        ["cset", 'Y'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a(['lintkey'])]
    ]); //#2128
    var _Fi = new Map([
        ["parts", $a([_Fe])],
        ["dlpkey", $a([$a(["8011"])])]
    ]); //#2130
    var _Fk = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 12],
        ["opt", false],
        ["linters", $a(['lintnozeroprefix'])]
    ]); //#2137
    var _Fo = new Map([
        ["parts", $a([_Fk])],
        ["req", $a([$a(["8010"])])]
    ]); //#2139
    var _Fq = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 20],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2146
    var _Fu = new Map([
        ["parts", $a([_Fq])],
        ["req", $a([$a(["01", "8006"])])]
    ]); //#2148
    var _Fw = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 25],
        ["opt", false],
        ["linters", $a(['lintcsumalpha', 'lintkey'])]
    ]); //#2155
    var _Fz = new Map([
        ["parts", $a([_Fw])],
        ["dlpkey", $a([])]
    ]); //#2157
    var _G1 = new Map([
        ["cset", 'N'],
        ["min", 18],
        ["max", 18],
        ["opt", false],
        ["linters", $a(['lintcsum'])]
    ]); //#2164
    var _G5 = new Map([
        ["parts", $a([_G1])],
        ["dlpkey", $a([$a(["8019"])])]
    ]); //#2166
    var _G7 = new Map([
        ["cset", 'N'],
        ["min", 18],
        ["max", 18],
        ["opt", false],
        ["linters", $a(['lintcsum'])]
    ]); //#2173
    var _GC = new Map([
        ["parts", $a([_G7])],
        ["ex", $a(["8017"])],
        ["dlpkey", $a([$a(["8019"])])]
    ]); //#2176
    var _GE = new Map([
        ["cset", 'N'],
        ["min", 1],
        ["max", 10],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2183
    var _GI = new Map([
        ["parts", $a([_GE])],
        ["req", $a([$a(["8017", "8018"])])]
    ]); //#2185
    var _GK = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 25],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2192
    var _GO = new Map([
        ["parts", $a([_GK])],
        ["req", $a([$a(["415"])])]
    ]); //#2194
    var _GQ = new Map([
        ["cset", 'N'],
        ["min", 14],
        ["max", 14],
        ["opt", false],
        ["linters", $a(['lintcsum'])]
    ]); //#2201
    var _GS = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a(['lintpieceoftotal'])]
    ]); //#2202
    var _GX = new Map([
        ["parts", $a([_GQ, _GS])],
        ["ex", $a(["02", "8006"])],
        ["req", $a([$a(["37"])])]
    ]); //#2205
    var _GZ = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintcouponcode'])]
    ]); //#2212
    var _Gb = new Map([
        ["parts", $a([_GZ])]
    ]); //#2212
    var _Gd = new Map([
        ["cset", 'N'],
        ["min", 4],
        ["max", 4],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2220
    var _Gh = new Map([
        ["parts", $a([_Gd])],
        ["req", $a([$a(["255"])])]
    ]); //#2222
    var _Gj = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a(['lintcouponposoffer'])]
    ]); //#2229
    var _Gl = new Map([
        ["parts", $a([_Gj])]
    ]); //#2229
    var _Gn = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 70],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2237
    var _Gr = new Map([
        ["parts", $a([_Gn])],
        ["req", $a([$a(["01"])])]
    ]); //#2239
    var _Gt = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 30],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2246
    var _Gv = new Map([
        ["parts", $a([_Gt])]
    ]); //#2246
    var _Gx = new Map([
        ["cset", 'X'],
        ["min", 1],
        ["max", 90],
        ["opt", false],
        ["linters", $a([])]
    ]); //#2254
    var _Gz = new Map([
        ["parts", $a([_Gx])]
    ]); //#2254
    var _H0 = new Map([
        ["00", _4],
        ["01", _C],
        ["02", _I],
        ["10", _O],
        ["11", _U],
        ["12", _a],
        ["13", _g],
        ["15", _g],
        ["16", _g],
        ["17", _m],
        ["20", _s],
        ["21", _z],
        ["22", _15],
        ["235", _1B],
        ["240", _1H],
        ["241", _1H],
        ["242", _1N],
        ["243", _1T],
        ["250", _1a],
        ["251", _1g],
        ["253", _1n],
        ["254", _1t],
        ["255", _21],
        ["30", _27],
        ["3100", _2E],
        ["3101", _2E],
        ["3102", _2E],
        ["3103", _2E],
        ["3104", _2E],
        ["3105", _2E],
        ["3110", _2L],
        ["3111", _2L],
        ["3112", _2L],
        ["3113", _2L],
        ["3114", _2L],
        ["3115", _2L],
        ["3120", _2S],
        ["3121", _2S],
        ["3122", _2S],
        ["3123", _2S],
        ["3124", _2S],
        ["3125", _2S],
        ["3130", _2Z],
        ["3131", _2Z],
        ["3132", _2Z],
        ["3133", _2Z],
        ["3134", _2Z],
        ["3135", _2Z],
        ["3140", _2g],
        ["3141", _2g],
        ["3142", _2g],
        ["3143", _2g],
        ["3144", _2g],
        ["3145", _2g],
        ["3150", _2n],
        ["3151", _2n],
        ["3152", _2n],
        ["3153", _2n],
        ["3154", _2n],
        ["3155", _2n],
        ["3160", _2u],
        ["3161", _2u],
        ["3162", _2u],
        ["3163", _2u],
        ["3164", _2u],
        ["3165", _2u],
        ["3200", _31],
        ["3201", _31],
        ["3202", _31],
        ["3203", _31],
        ["3204", _31],
        ["3205", _31],
        ["3210", _38],
        ["3211", _38],
        ["3212", _38],
        ["3213", _38],
        ["3214", _38],
        ["3215", _38],
        ["3220", _3F],
        ["3221", _3F],
        ["3222", _3F],
        ["3223", _3F],
        ["3224", _3F],
        ["3225", _3F],
        ["3230", _3M],
        ["3231", _3M],
        ["3232", _3M],
        ["3233", _3M],
        ["3234", _3M],
        ["3235", _3M],
        ["3240", _3T],
        ["3241", _3T],
        ["3242", _3T],
        ["3243", _3T],
        ["3244", _3T],
        ["3245", _3T],
        ["3250", _3a],
        ["3251", _3a],
        ["3252", _3a],
        ["3253", _3a],
        ["3254", _3a],
        ["3255", _3a],
        ["3260", _3h],
        ["3261", _3h],
        ["3262", _3h],
        ["3263", _3h],
        ["3264", _3h],
        ["3265", _3h],
        ["3270", _3o],
        ["3271", _3o],
        ["3272", _3o],
        ["3273", _3o],
        ["3274", _3o],
        ["3275", _3o],
        ["3280", _3v],
        ["3281", _3v],
        ["3282", _3v],
        ["3283", _3v],
        ["3284", _3v],
        ["3285", _3v],
        ["3290", _42],
        ["3291", _42],
        ["3292", _42],
        ["3293", _42],
        ["3294", _42],
        ["3295", _42],
        ["3300", _49],
        ["3301", _49],
        ["3302", _49],
        ["3303", _49],
        ["3304", _49],
        ["3305", _49],
        ["3310", _4G],
        ["3311", _4G],
        ["3312", _4G],
        ["3313", _4G],
        ["3314", _4G],
        ["3315", _4G],
        ["3320", _4N],
        ["3321", _4N],
        ["3322", _4N],
        ["3323", _4N],
        ["3324", _4N],
        ["3325", _4N],
        ["3330", _4U],
        ["3331", _4U],
        ["3332", _4U],
        ["3333", _4U],
        ["3334", _4U],
        ["3335", _4U],
        ["3340", _4b],
        ["3341", _4b],
        ["3342", _4b],
        ["3343", _4b],
        ["3344", _4b],
        ["3345", _4b],
        ["3350", _4i],
        ["3351", _4i],
        ["3352", _4i],
        ["3353", _4i],
        ["3354", _4i],
        ["3355", _4i],
        ["3360", _4p],
        ["3361", _4p],
        ["3362", _4p],
        ["3363", _4p],
        ["3364", _4p],
        ["3365", _4p],
        ["3370", _4w],
        ["3371", _4w],
        ["3372", _4w],
        ["3373", _4w],
        ["3374", _4w],
        ["3375", _4w],
        ["3400", _53],
        ["3401", _53],
        ["3402", _53],
        ["3403", _53],
        ["3404", _53],
        ["3405", _53],
        ["3410", _5A],
        ["3411", _5A],
        ["3412", _5A],
        ["3413", _5A],
        ["3414", _5A],
        ["3415", _5A],
        ["3420", _5H],
        ["3421", _5H],
        ["3422", _5H],
        ["3423", _5H],
        ["3424", _5H],
        ["3425", _5H],
        ["3430", _5O],
        ["3431", _5O],
        ["3432", _5O],
        ["3433", _5O],
        ["3434", _5O],
        ["3435", _5O],
        ["3440", _5V],
        ["3441", _5V],
        ["3442", _5V],
        ["3443", _5V],
        ["3444", _5V],
        ["3445", _5V],
        ["3450", _5c],
        ["3451", _5c],
        ["3452", _5c],
        ["3453", _5c],
        ["3454", _5c],
        ["3455", _5c],
        ["3460", _5j],
        ["3461", _5j],
        ["3462", _5j],
        ["3463", _5j],
        ["3464", _5j],
        ["3465", _5j],
        ["3470", _5q],
        ["3471", _5q],
        ["3472", _5q],
        ["3473", _5q],
        ["3474", _5q],
        ["3475", _5q],
        ["3480", _5x],
        ["3481", _5x],
        ["3482", _5x],
        ["3483", _5x],
        ["3484", _5x],
        ["3485", _5x],
        ["3490", _64],
        ["3491", _64],
        ["3492", _64],
        ["3493", _64],
        ["3494", _64],
        ["3495", _64],
        ["3500", _6B],
        ["3501", _6B],
        ["3502", _6B],
        ["3503", _6B],
        ["3504", _6B],
        ["3505", _6B],
        ["3510", _6I],
        ["3511", _6I],
        ["3512", _6I],
        ["3513", _6I],
        ["3514", _6I],
        ["3515", _6I],
        ["3520", _6P],
        ["3521", _6P],
        ["3522", _6P],
        ["3523", _6P],
        ["3524", _6P],
        ["3525", _6P],
        ["3530", _6W],
        ["3531", _6W],
        ["3532", _6W],
        ["3533", _6W],
        ["3534", _6W],
        ["3535", _6W],
        ["3540", _6d],
        ["3541", _6d],
        ["3542", _6d],
        ["3543", _6d],
        ["3544", _6d],
        ["3545", _6d],
        ["3550", _6k],
        ["3551", _6k],
        ["3552", _6k],
        ["3553", _6k],
        ["3554", _6k],
        ["3555", _6k],
        ["3560", _6r],
        ["3561", _6r],
        ["3562", _6r],
        ["3563", _6r],
        ["3564", _6r],
        ["3565", _6r],
        ["3570", _6y],
        ["3571", _6y],
        ["3572", _6y],
        ["3573", _6y],
        ["3574", _6y],
        ["3575", _6y],
        ["3600", _75],
        ["3601", _75],
        ["3602", _75],
        ["3603", _75],
        ["3604", _75],
        ["3605", _75],
        ["3610", _7C],
        ["3611", _7C],
        ["3612", _7C],
        ["3613", _7C],
        ["3614", _7C],
        ["3615", _7C],
        ["3620", _7J],
        ["3621", _7J],
        ["3622", _7J],
        ["3623", _7J],
        ["3624", _7J],
        ["3625", _7J],
        ["3630", _7Q],
        ["3631", _7Q],
        ["3632", _7Q],
        ["3633", _7Q],
        ["3634", _7Q],
        ["3635", _7Q],
        ["3640", _7X],
        ["3641", _7X],
        ["3642", _7X],
        ["3643", _7X],
        ["3644", _7X],
        ["3645", _7X],
        ["3650", _7e],
        ["3651", _7e],
        ["3652", _7e],
        ["3653", _7e],
        ["3654", _7e],
        ["3655", _7e],
        ["3660", _7l],
        ["3661", _7l],
        ["3662", _7l],
        ["3663", _7l],
        ["3664", _7l],
        ["3665", _7l],
        ["3670", _7s],
        ["3671", _7s],
        ["3672", _7s],
        ["3673", _7s],
        ["3674", _7s],
        ["3675", _7s],
        ["3680", _7z],
        ["3681", _7z],
        ["3682", _7z],
        ["3683", _7z],
        ["3684", _7z],
        ["3685", _7z],
        ["3690", _86],
        ["3691", _86],
        ["3692", _86],
        ["3693", _86],
        ["3694", _86],
        ["3695", _86],
        ["37", _8D],
        ["3900", _8K],
        ["3901", _8K],
        ["3902", _8K],
        ["3903", _8K],
        ["3904", _8K],
        ["3905", _8K],
        ["3906", _8K],
        ["3907", _8K],
        ["3908", _8K],
        ["3909", _8K],
        ["3910", _8T],
        ["3911", _8T],
        ["3912", _8T],
        ["3913", _8T],
        ["3914", _8T],
        ["3915", _8T],
        ["3916", _8T],
        ["3917", _8T],
        ["3918", _8T],
        ["3919", _8T],
        ["3920", _8b],
        ["3921", _8b],
        ["3922", _8b],
        ["3923", _8b],
        ["3924", _8b],
        ["3925", _8b],
        ["3926", _8b],
        ["3927", _8b],
        ["3928", _8b],
        ["3929", _8b],
        ["3930", _8k],
        ["3931", _8k],
        ["3932", _8k],
        ["3933", _8k],
        ["3934", _8k],
        ["3935", _8k],
        ["3936", _8k],
        ["3937", _8k],
        ["3938", _8k],
        ["3939", _8k],
        ["3940", _8r],
        ["3941", _8r],
        ["3942", _8r],
        ["3943", _8r],
        ["3950", _8y],
        ["3951", _8y],
        ["3952", _8y],
        ["3953", _8y],
        ["3954", _8y],
        ["3955", _8y],
        ["400", _92],
        ["401", _97],
        ["402", _9C],
        ["403", _9I],
        ["410", _9M],
        ["411", _9M],
        ["412", _9M],
        ["413", _9M],
        ["414", _9T],
        ["415", _9Z],
        ["416", _9d],
        ["417", _9j],
        ["420", _9o],
        ["421", _9v],
        ["422", _A2],
        ["423", _A9],
        ["424", _AG],
        ["425", _AN],
        ["426", _AT],
        ["427", _Aa],
        ["4300", _Ag],
        ["4301", _Ag],
        ["4302", _Am],
        ["4303", _As],
        ["4304", _Ay],
        ["4305", _Ay],
        ["4306", _Ay],
        ["4307", _B4],
        ["4308", _BA],
        ["4309", _BG],
        ["4310", _BM],
        ["4311", _BM],
        ["4312", _BS],
        ["4313", _BY],
        ["4314", _Be],
        ["4315", _Be],
        ["4316", _Be],
        ["4317", _Bk],
        ["4318", _Bq],
        ["4319", _Bw],
        ["4320", _C2],
        ["4321", _C8],
        ["4322", _C8],
        ["4323", _C8],
        ["4324", _CG],
        ["4325", _CG],
        ["4326", _CM],
        ["7001", _CS],
        ["7002", _CY],
        ["7003", _Cg],
        ["7004", _Cn],
        ["7005", _Ct],
        ["7006", _Cz],
        ["7007", _D7],
        ["7008", _DD],
        ["7009", _DJ],
        ["7010", _DP],
        ["7011", _DX],
        ["7020", _De],
        ["7021", _Dk],
        ["7022", _Dq],
        ["7023", _Du],
        ["7030", _E2],
        ["7031", _E2],
        ["7032", _E2],
        ["7033", _E2],
        ["7034", _E2],
        ["7035", _E2],
        ["7036", _E2],
        ["7037", _E2],
        ["7038", _E2],
        ["7039", _E2],
        ["7040", _EC],
        ["710", _EI],
        ["711", _EI],
        ["712", _EI],
        ["713", _EI],
        ["714", _EI],
        ["715", _EI],
        ["7230", _EQ],
        ["7231", _EQ],
        ["7232", _EQ],
        ["7233", _EQ],
        ["7234", _EQ],
        ["7235", _EQ],
        ["7236", _EQ],
        ["7237", _EQ],
        ["7238", _EQ],
        ["7239", _EQ],
        ["7240", _EW],
        ["8001", _Ek],
        ["8002", _Eo],
        ["8003", _Ex],
        ["8004", _F3],
        ["8005", _F9],
        ["8006", _FI],
        ["8007", _FO],
        ["8008", _FW],
        ["8009", _Fc],
        ["8010", _Fi],
        ["8011", _Fo],
        ["8012", _Fu],
        ["8013", _Fz],
        ["8017", _G5],
        ["8018", _GC],
        ["8019", _GI],
        ["8020", _GO],
        ["8026", _GX],
        ["8110", _Gb],
        ["8111", _Gh],
        ["8112", _Gl],
        ["8200", _Gr],
        ["90", _Gv],
        ["91", _Gz],
        ["92", _Gz],
        ["93", _Gz],
        ["94", _Gz],
        ["95", _Gz],
        ["96", _Gz],
        ["97", _Gz],
        ["98", _Gz],
        ["99", _Gz]
    ]); //#2266
    $1.gs1syntax = _H0; //#2268
    if ($eq($k[--$j], 'ai')) { //#2453
        $anchorsearch($k[--$j], "("); //#2276
        if ($nt($k[--$j])) { //#2278
            $j--; //#2277
            $k[$j++] = 'bwipp.GS1aiMissingOpenParen'; //#2277
            $k[$j++] = "AIs must start with '('"; //#2277
            bwipp_raiseerror(); //#2277
        } //#2277
        $j--; //#2279
        $k[$j++] = Infinity; //#2280
        var _H4 = $k[--$j]; //#2280
        var _H5 = $k[--$j]; //#2280
        $k[$j++] = _H4; //#2287
        $k[$j++] = _H5; //#2287
        for (;;) { //#2287
            var _H6 = $k[--$j]; //#2281
            $k[$j++] = _H6; //#2281
            if ($eq(_H6, "")) { //#2281
                $j--; //#2281
                break; //#2281
            } //#2281
            $search($k[--$j], ")"); //#2282
            if ($nt($k[--$j])) { //#2284
                $cleartomark(); //#2283
                $k[$j++] = 'bwipp.GS1aiMissingCloseParen'; //#2283
                $k[$j++] = "AIs must end with ')'"; //#2283
                bwipp_raiseerror(); //#2283
            } //#2283
            var _H9 = $k[--$j]; //#2285
            var _HA = $k[--$j]; //#2285
            $k[$j++] = _H9; //#2285
            $k[$j++] = _HA; //#2285
            $j--; //#2285
            var _HB = $k[--$j]; //#2285
            var _HC = $k[--$j]; //#2285
            $k[$j++] = _HB; //#2286
            $search(_HC, "("); //#2286
            if ($k[--$j]) { //#2286
                var _HE = $k[--$j]; //#2286
                var _HF = $k[--$j]; //#2286
                $k[$j++] = _HE; //#2286
                $k[$j++] = _HF; //#2286
                $j--; //#2286
                var _HG = $k[--$j]; //#2286
                var _HH = $k[--$j]; //#2286
                $k[$j++] = _HG; //#2286
                $k[$j++] = _HH; //#2286
            } else { //#2286
                $k[$j++] = ""; //#2286
            } //#2286
        } //#2286
        var _HI = $counttomark(); //#2288
        $k[$j++] = _HI; //#2288
        if (_HI > 0) { //#2288
            var _HJ = $k[--$j]; //#2288
            for (var _HL = _HJ, _HK = (~~(_HJ / 2)) + 1; _HL >= _HK; _HL -= 1) { //#2288
                $r(_HL, -1); //#2288
            } //#2288
        } else { //#2288
            $j--; //#2288
        } //#2288
        $astore($a(~~($counttomark() / 2))); //#2289
        $1.ais = $k[--$j]; //#2289
        $astore($a($counttomark())); //#2290
        $k[$j++] = Infinity; //#2291
        var _HR = $k[--$j]; //#2290
        var _HS = $k[--$j]; //#2290
        $k[$j++] = _HR; //#2292
        $forall(_HS, function() { //#2292
            var _HU = new Map([
                ["parse", $1.parse],
                ["parseonly", true],
                ["parsefnc", false]
            ]); //#2291
            $k[$j++] = _HU; //#2291
            bwipp_parseinput(); //#2291
        }); //#2291
        $1.vals = $a(); //#2292
        $j--; //#2293
    } else { //#2453
        $anchorsearch($k[--$j], "http://"); //#2298
        if ($nt($k[--$j])) { //#2301
            $anchorsearch($k[--$j], "https://"); //#2299
            if ($nt($k[--$j])) { //#2301
                $j--; //#2300
                $k[$j++] = 'bwipp.GS1dlURIbadScheme'; //#2300
                $k[$j++] = "Scheme must be http:// or https://"; //#2300
                bwipp_raiseerror(); //#2300
            } //#2300
        } //#2300
        $j--; //#2302
        $search($k[--$j], "/"); //#2305
        if ($nt($k[--$j])) { //#2307
            $j--; //#2306
            $k[$j++] = 'bwipp.GS1dlMissingDomainOrPathInfo'; //#2306
            $k[$j++] = "URI must contain a domain and path info"; //#2306
            bwipp_raiseerror(); //#2306
        } //#2306
        $j -= 2; //#2308
        $search($k[--$j], "#"); //#2311
        if ($k[--$j]) { //#2313
            var _He = $k[--$j]; //#2312
            var _Hf = $k[--$j]; //#2312
            $k[$j++] = _He; //#2312
            $k[$j++] = _Hf; //#2312
            $j--; //#2312
            var _Hg = $k[--$j]; //#2312
            var _Hh = $k[--$j]; //#2312
            $k[$j++] = _Hg; //#2312
            $k[$j++] = _Hh; //#2312
            $j--; //#2312
        } //#2312
        $search($k[--$j], "?"); //#2316
        if ($nt($k[--$j])) { //#2318
            var _Hk = $k[--$j]; //#2317
            $k[$j++] = ""; //#2317
            $k[$j++] = null; //#2317
            $k[$j++] = _Hk; //#2317
        } //#2317
        $1.pp = $k[--$j]; //#2319
        $j--; //#2320
        $1.qp = $k[--$j]; //#2321
        $k[$j++] = Infinity; //#2324
        $k[$j++] = 0; //#2328
        $k[$j++] = 0; //#2328
        $k[$j++] = $1.pp; //#2328
        for (;;) { //#2328
            $search($k[--$j], "/"); //#2326
            if ($nt($k[--$j])) { //#2326
                $j--; //#2326
                break; //#2326
            } //#2326
            var _Hq = $k[--$j]; //#2327
            var _Hr = $k[--$j]; //#2327
            $k[$j++] = _Hq.length + 1; //#2327
            $k[$j++] = _Hr; //#2327
            $j--; //#2327
            var _Hs = $k[--$j]; //#2327
            var _Ht = $k[--$j]; //#2327
            var _Hu = $k[--$j]; //#2327
            $k[$j++] = _Hu; //#2327
            $k[$j++] = $f(_Hs + _Hu); //#2327
            $k[$j++] = _Ht; //#2327
        } //#2327
        $astore($a($counttomark() - 1)); //#2329
        $1.pipos = $k[--$j]; //#2329
        $j -= 2; //#2329
        if ($1.pipos.length <= 1) { //#2332
            $k[$j++] = 'bwipp.GS1dlNoAIinfo'; //#2331
            $k[$j++] = "The path was too short to contain AI info"; //#2331
            bwipp_raiseerror(); //#2331
        } //#2331
        $k[$j++] = false; //#2348
        for (var _I0 = $1.pipos.length - 2; _I0 >= 0; _I0 -= 2) { //#2348
            var _I2 = $get($1.pipos, _I0); //#2338
            var _I6 = $geti($1.pp, _I2, $f($f($get($1.pipos, _I0 + 1) - _I2) - 1)); //#2339
            var _I8 = $get($1.gs1syntax, _I6) !== undefined; //#2340
            $k[$j++] = _I0; //#2346
            $k[$j++] = _I6; //#2346
            if (_I8) { //#2345
                var _IC = $get($get($1.gs1syntax, $k[--$j]), 'dlpkey') !== undefined; //#2341
                if (_IC) { //#2343
                    var _ID = $k[--$j]; //#2342
                    var _IE = $k[--$j]; //#2342
                    $k[$j++] = _ID; //#2342
                    $k[$j++] = _IE; //#2342
                    $j--; //#2342
                    $k[$j++] = true; //#2342
                    break; //#2342
                } //#2342
            } else { //#2345
                $j--; //#2345
            } //#2345
            $j--; //#2347
        } //#2347
        if ($nt($k[--$j])) { //#2351
            $k[$j++] = 'bwipp.GS1dlNoAIinfo'; //#2350
            $k[$j++] = "The path does not contain a valid primary key"; //#2350
            bwipp_raiseerror(); //#2350
        } //#2350
        var _II = $get($1.pipos, $k[--$j]); //#2352
        $1.pp = $geti($1.pp, _II, $f($1.pp.length - _II)); //#2352
        $1.uriunescape = function() {
            $1.in = $k[--$j]; //#2355
            $1.out = $s($1.in.length); //#2356
            $k[$j++] = 0; //#2376
            $k[$j++] = 0; //#2376
            for (;;) { //#2376
                var _IP = $k[--$j]; //#2358
                var _IQ = $k[--$j]; //#2358
                $k[$j++] = _IQ; //#2358
                $k[$j++] = _IP; //#2358
                if (_IQ >= $1.in.length) { //#2358
                    break; //#2358
                } //#2358
                var _IT = $k[--$j]; //#2359
                var _IU = $k[--$j]; //#2359
                var _IV = $get($1.in, _IU); //#2359
                $k[$j++] = _IU; //#2375
                $k[$j++] = _IT; //#2375
                $k[$j++] = _IV; //#2375
                if (_IV == 43) { //#2374
                    $j--; //#2361
                    var _IX = $k[--$j]; //#2361
                    $put($1.out, _IX, 32); //#2361
                    var _IY = $k[--$j]; //#2362
                    $k[$j++] = $f(_IY + 1); //#2362
                    $k[$j++] = $f(_IX + 1); //#2362
                } else { //#2374
                    var _IZ = $k[--$j]; //#2364
                    var _Ia = $k[--$j]; //#2364
                    var _Ib = $k[--$j]; //#2364
                    $k[$j++] = _Ib; //#2375
                    $k[$j++] = _Ia; //#2375
                    $k[$j++] = _IZ; //#2375
                    if ((_IZ == 37) && (_Ib < ($1.in.length - 2))) { //#2374
                        $j--; //#2365
                        var _Ie = $strcpy($s(4), "<  >"); //#2366
                        var _Ig = $k[--$j]; //#2366
                        var _Ih = $k[--$j]; //#2366
                        $puti(_Ie, 1, $geti($1.in, $f(_Ih + 1), 2)); //#2366
                        try { //#2367
                            $k[$j++] = _Ih; //#2367
                            $k[$j++] = _Ig; //#2367
                            $k[$j++] = $cvx(_Ie); //#2367
                            $k[$j++] = false
                        } catch (e) {
                            $k[$j++] = true
                        } //#2367
                        if ($k[--$j]) { //#2369
                            $j -= 2; //#2368
                            $k[$j++] = 'bwipp.GS1dlBadHexCharacter'; //#2368
                            $k[$j++] = "Invalid hex character"; //#2368
                            bwipp_raiseerror(); //#2368
                        } //#2368
                        var _Il = $get($k[--$j], 0); //#2370
                        var _In = $k[--$j]; //#2370
                        $put($1.out, _In, _Il); //#2370
                        var _Io = $k[--$j]; //#2371
                        $k[$j++] = $f(_Io + 3); //#2371
                        $k[$j++] = $f(_In + 1); //#2371
                    } else { //#2374
                        var _Iq = $k[--$j]; //#2373
                        var _Ir = $k[--$j]; //#2373
                        $put($1.out, _Ir, _Iq); //#2373
                        var _Is = $k[--$j]; //#2374
                        $k[$j++] = $f(_Is + 1); //#2374
                        $k[$j++] = $f(_Ir + 1); //#2374
                    } //#2374
                } //#2374
            } //#2374
            $1.out = $geti($1.out, 0, $k[--$j]); //#2377
            $j--; //#2378
            $k[$j++] = $1.out; //#2379
        }; //#2379
        $1.ais = $a(99); //#2382
        $1.vals = $a(99); //#2383
        $k[$j++] = 0; //#2397
        $k[$j++] = $1.pp; //#2397
        for (;;) { //#2397
            $search($k[--$j], "/"); //#2388
            if ($k[--$j]) { //#2394
                var _J3 = $k[--$j]; //#2389
                var _J4 = $k[--$j]; //#2389
                var _J5 = $k[--$j]; //#2389
                var _J6 = $k[--$j]; //#2389
                $put($1.ais, _J6, _J3); //#2389
                $k[$j++] = _J6; //#2391
                $search(_J5, "/"); //#2391
                if ($k[--$j]) { //#2391
                    var _J8 = $k[--$j]; //#2391
                    var _J9 = $k[--$j]; //#2391
                    $k[$j++] = _J8; //#2391
                    $k[$j++] = _J9; //#2391
                    $j--; //#2391
                } else { //#2391
                    var _JA = $k[--$j]; //#2391
                    $k[$j++] = ""; //#2391
                    $k[$j++] = _JA; //#2391
                } //#2391
                var _JC = $k[--$j]; //#2392
                var _JD = $k[--$j]; //#2392
                var _JE = $k[--$j]; //#2392
                $k[$j++] = _JE; //#2392
                $k[$j++] = _JD; //#2392
                $k[$j++] = $1.vals; //#2392
                $k[$j++] = _JE; //#2392
                $k[$j++] = _JC; //#2392
                $1.uriunescape(); //#2392
                var _JF = $k[--$j]; //#2392
                var _JG = $k[--$j]; //#2392
                $put($k[--$j], _JG, _JF); //#2392
            } else { //#2394
                $j--; //#2394
                break; //#2394
            } //#2394
            var _JI = $k[--$j]; //#2396
            var _JJ = $k[--$j]; //#2396
            $k[$j++] = $f(_JJ + 1); //#2396
            $k[$j++] = _JI; //#2396
        } //#2396
        var _JK = $k[--$j]; //#2400
        $k[$j++] = _JK; //#2418
        if (_JK > 1) { //#2418
            $k[$j++] = false; //#2414
            $forall($get($get($1.gs1syntax, $get($1.ais, 0)), 'dlpkey'), function() { //#2414
                $1.seq = $k[--$j]; //#2403
                $1.i = 1; //#2404
                $1.j = 0; //#2404
                for (;;) { //#2412
                    if ($1.i >= $1.ais.length) { //#2406
                        break; //#2406
                    } //#2406
                    if ($1.j >= $1.seq.length) { //#2407
                        break; //#2407
                    } //#2407
                    if ($eq($get($1.ais, $1.i), $get($1.seq, $1.j))) { //#2410
                        $1.i = $1.i + 1; //#2409
                    } //#2409
                    $1.j = $1.j + 1; //#2411
                } //#2411
                var _Je = $k[--$j]; //#2413
                var _Jf = $k[--$j]; //#2413
                $k[$j++] = _Jf; //#2413
                $k[$j++] = _Je; //#2413
                if ($1.i == _Jf) { //#2413
                    $j--; //#2413
                    $k[$j++] = true; //#2413
                    return true; //#2413
                } //#2413
            }); //#2413
            if ($nt($k[--$j])) { //#2417
                $j--; //#2416
                $k[$j++] = 'bwipp.GS1dlBadPathInfo'; //#2416
                $k[$j++] = "The AIs in the path are not a valid key-qualifier sequence for the key"; //#2416
                bwipp_raiseerror(); //#2416
            } //#2416
        } //#2416
        $k[$j++] = $1.qp; //#2436
        for (;;) { //#2436
            var _Ji = $k[--$j]; //#2422
            $k[$j++] = _Ji; //#2422
            if ($eq(_Ji, "")) { //#2422
                $j--; //#2422
                break; //#2422
            } //#2422
            $search($k[--$j], "&"); //#2423
            if ($k[--$j]) { //#2423
                var _Jl = $k[--$j]; //#2423
                var _Jm = $k[--$j]; //#2423
                $k[$j++] = _Jl; //#2423
                $k[$j++] = _Jm; //#2423
                $j--; //#2423
            } else { //#2423
                var _Jn = $k[--$j]; //#2423
                $k[$j++] = ""; //#2423
                $k[$j++] = _Jn; //#2423
            } //#2423
            $search($k[--$j], "="); //#2424
            if ($k[--$j]) { //#2434
                var _Jq = $k[--$j]; //#2425
                $k[$j++] = _Jq; //#2425
                $k[$j++] = true; //#2425
                $forall(_Jq, function() { //#2425
                    var _Jr = $k[--$j]; //#2425
                    var _Js = $k[--$j]; //#2425
                    $k[$j++] = _Js && ((_Jr >= 48) && (_Jr <= 57)); //#2425
                }); //#2425
                if ($k[--$j]) { //#2431
                    var _Jv = $k[--$j]; //#2426
                    var _Jw = $k[--$j]; //#2426
                    var _Jx = $k[--$j]; //#2426
                    var _Jy = $k[--$j]; //#2426
                    var _Jz = $k[--$j]; //#2426
                    $put($1.ais, _Jz, _Jv); //#2426
                    $k[$j++] = _Jz; //#2428
                    $k[$j++] = _Jy; //#2428
                    $k[$j++] = $1.vals; //#2428
                    $k[$j++] = _Jz; //#2428
                    $k[$j++] = _Jx; //#2428
                    $1.uriunescape(); //#2428
                    var _K1 = $k[--$j]; //#2428
                    var _K2 = $k[--$j]; //#2428
                    $put($k[--$j], _K2, _K1); //#2428
                    var _K4 = $k[--$j]; //#2429
                    var _K5 = $k[--$j]; //#2429
                    $k[$j++] = $f(_K5 + 1); //#2429
                    $k[$j++] = _K4; //#2429
                } else { //#2431
                    $j -= 3; //#2431
                } //#2431
            } else { //#2434
                $j--; //#2434
            } //#2434
        } //#2434
        var _K7 = $k[--$j]; //#2438
        $1.ais = $geti($1.ais, 0, _K7); //#2438
        $1.vals = $geti($1.vals, 0, _K7); //#2439
        for (var _KD = 0, _KC = $1.ais.length - 1; _KD <= _KC; _KD += 1) { //#2454
            $k[$j++] = _KD; //#2452
            if ($eq($get($1.ais, _KD), "01")) { //#2452
                var _KG = $k[--$j]; //#2445
                var _KI = $get($1.vals, _KG); //#2445
                var _KJ = _KI.length; //#2446
                $k[$j++] = _KG; //#2451
                $k[$j++] = _KI; //#2451
                if ((_KJ == 8) || ((_KJ == 12) || (_KJ == 13))) { //#2450
                    var _KL = $strcpy($s(14), "00000000000000"); //#2447
                    var _KM = $k[--$j]; //#2447
                    $puti(_KL, 14 - _KM.length, _KM); //#2447
                    var _KO = $k[--$j]; //#2448
                    $put($1.vals, _KO, _KL); //#2448
                    $k[$j++] = _KO; //#2448
                } else { //#2450
                    $j--; //#2450
                } //#2450
            } //#2450
            $j--; //#2453
        } //#2453
    } //#2453
    $k[$j++] = Infinity; //#2466
    var _KP = $a(["00", "01", "02", "03", "04", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "31", "32", "33", "34", "35", "36", "41"]); //#2465
    for (var _KQ = 0, _KR = _KP.length; _KQ < _KR; _KQ++) { //#2466
        var _KS = $get(_KP, _KQ); //#2466
        $k[$j++] = _KS; //#2466
        $k[$j++] = _KS; //#2466
    } //#2466
    $1.aifixed = $d(); //#2466
    $k[$j++] = Infinity; //#2475
    var _KU = $1.ais; //#2470
    for (var _KV = 0, _KW = _KU.length; _KV < _KW; _KV++) { //#2477
        var _KX = $get(_KU, _KV); //#2477
        $k[$j++] = true; //#2476
        $k[$j++] = _KX; //#2476
        if (_KX.length >= 2) { //#2475
            var _Kb = $get($1.aifixed, $geti($k[--$j], 0, 2)) !== undefined; //#2473
            if (_Kb) { //#2473
                $j--; //#2473
                $k[$j++] = false; //#2473
            } //#2473
        } else { //#2475
            $j--; //#2475
        } //#2475
    } //#2475
    $1.fncs = $a(); //#2475
    $1.lintnumeric = function() {
        var _Kd = $k[--$j]; //#2484
        $k[$j++] = true; //#2486
        $forall(_Kd, function() { //#2486
            var _Ke = $k[--$j]; //#2485
            if ((_Ke < 48) || (_Ke > 57)) { //#2485
                $j--; //#2485
                $k[$j++] = false; //#2485
                return true; //#2485
            } //#2485
        }); //#2485
        if ($nt($k[--$j])) { //#2487
            $j--; //#2487
            $k[$j++] = 'bwipp.GS1notNumeric'; //#2487
            $k[$j++] = "Not numeric"; //#2487
            $k[$j++] = false; //#2487
            return true; //#2487
        } //#2487
    }; //#2487
    $1.lintcset82 = function() {
        var _Kg = $k[--$j]; //#2491
        $k[$j++] = true; //#2496
        $forall(_Kg, function() { //#2496
            var _Kh = $s(1); //#2492
            $put(_Kh, 0, $k[--$j]); //#2492
            $search("!\"%&'()*+,-./0123456789:;<=>?ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz", _Kh); //#2494
            if ($nt($k[--$j])) { //#2494
                $j -= 2; //#2494
                $k[$j++] = false; //#2494
                return true; //#2494
            } //#2494
            $j -= 3; //#2495
        }); //#2495
        if ($nt($k[--$j])) { //#2497
            $j--; //#2497
            $k[$j++] = 'bwipp.GS1badCSET82character'; //#2497
            $k[$j++] = "Invalid CSET 82 character"; //#2497
            $k[$j++] = false; //#2497
            return true; //#2497
        } //#2497
    }; //#2497
    $1.lintcset39 = function() {
        var _Kl = $k[--$j]; //#2501
        $k[$j++] = true; //#2506
        $forall(_Kl, function() { //#2506
            var _Km = $s(1); //#2502
            $put(_Km, 0, $k[--$j]); //#2502
            $search("#-/0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ", _Km); //#2504
            if ($nt($k[--$j])) { //#2504
                $j -= 2; //#2504
                $k[$j++] = false; //#2504
                return true; //#2504
            } //#2504
            $j -= 3; //#2505
        }); //#2505
        if ($nt($k[--$j])) { //#2507
            $j--; //#2507
            $k[$j++] = 'bwipp.GS1badCSET39character'; //#2507
            $k[$j++] = "Invalid CSET 39 character"; //#2507
            $k[$j++] = false; //#2507
            return true; //#2507
        } //#2507
    }; //#2507
    $1.lintkey = function() {
        var _Kq = $k[--$j]; //#2511
        $k[$j++] = _Kq; //#2511
        if (_Kq.length < 2) { //#2511
            $j -= 2; //#2511
            $k[$j++] = 'bwipp.GS1keyTooShort'; //#2511
            $k[$j++] = "Key is too short"; //#2511
            $k[$j++] = false; //#2511
            return true; //#2511
        } //#2511
        var _Kr = $k[--$j]; //#2512
        var _Ks = $get(_Kr, 0); //#2512
        var _Kt = $get(_Kr, 1); //#2513
        if (((_Ks < 48) || (_Ks > 57)) || ((_Kt < 48) || (_Kt > 57))) { //#2515
            $j--; //#2514
            $k[$j++] = 'bwipp.GS1badGCP'; //#2514
            $k[$j++] = "Non-numeric company prefix"; //#2514
            $k[$j++] = false; //#2514
            return true; //#2514
        } //#2514
    }; //#2514
    $1.lintimporteridx = function() {
        $search("-0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz", $k[--$j]); //#2520
        if ($nt($k[--$j])) { //#2520
            $j -= 2; //#2520
            $k[$j++] = 'bwipp.GS1badImporterIndex'; //#2520
            $k[$j++] = "Invalid importer index"; //#2520
            $k[$j++] = false; //#2520
            return true; //#2520
        } //#2520
        $j -= 3; //#2521
    }; //#2521
    $1.lintcsum = function() {
        $k[$j++] = Infinity; //#2525
        var _Kw = $k[--$j]; //#2525
        var _Kx = $k[--$j]; //#2525
        var _Ky = ((_Kx.length % 2) == 0) ? 3 : 1; //#2526
        $k[$j++] = _Kw; //#2527
        $k[$j++] = _Ky; //#2527
        $forall(_Kx, function() { //#2527
            var _Kz = $k[--$j]; //#2527
            var _L0 = $k[--$j]; //#2527
            $k[$j++] = $f(_Kz - 48) * _L0; //#2527
            $k[$j++] = $f(4 - _L0); //#2527
        }); //#2527
        $j--; //#2527
        var _L1 = $counttomark() + 1; //#2528
        $k[$j++] = 0; //#2528
        for (var _L2 = 0, _L3 = _L1 - 1; _L2 < _L3; _L2++) { //#2528
            var _L4 = $k[--$j]; //#2528
            var _L5 = $k[--$j]; //#2528
            $k[$j++] = $f(_L5 + _L4); //#2528
        } //#2528
        var _L6 = $k[--$j]; //#2528
        var _L7 = $k[--$j]; //#2528
        $k[$j++] = _L6; //#2528
        $k[$j++] = _L7; //#2528
        $j--; //#2528
        if (($k[--$j] % 10) != 0) { //#2529
            $j--; //#2529
            $k[$j++] = 'bwipp.GS1badChecksum'; //#2529
            $k[$j++] = "Bad checksum"; //#2529
            $k[$j++] = false; //#2529
            return true; //#2529
        } //#2529
    }; //#2529
    $k[$j++] = Infinity; //#2535
    $k[$j++] = 0; //#2535
    for (var _L9 = 0, _LA = "!\"%&'()*+,-./0123456789:;<=>?ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz".length; _L9 < _LA; _L9++) { //#2535
        var _LC = $k[--$j]; //#2535
        $k[$j++] = $get("!\"%&'()*+,-./0123456789:;<=>?ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz", _L9); //#2535
        $k[$j++] = _LC; //#2535
        $k[$j++] = $f(_LC + 1); //#2535
    } //#2535
    $j--; //#2535
    $1.cset82 = $d(); //#2536
    $k[$j++] = Infinity; //#2540
    $k[$j++] = 0; //#2540
    for (var _LE = 0, _LF = "23456789ABCDEFGHJKLMNPQRSTUVWXYZ".length; _LE < _LF; _LE++) { //#2540
        var _LH = $k[--$j]; //#2540
        $k[$j++] = $get("23456789ABCDEFGHJKLMNPQRSTUVWXYZ", _LE); //#2540
        $k[$j++] = _LH; //#2540
        $k[$j++] = $f(_LH + 1); //#2540
    } //#2540
    $j--; //#2540
    $1.cset32 = $d(); //#2541
    $1.lintcsumalpha = function() {
        var _LJ = $k[--$j]; //#2545
        $k[$j++] = _LJ; //#2545
        if (_LJ.length < 2) { //#2545
            $j -= 2; //#2545
            $k[$j++] = 'bwipp.GS1alphaTooShort'; //#2545
            $k[$j++] = "Alphanumeric string is too short to check"; //#2545
            $k[$j++] = false; //#2545
            return true; //#2545
        } //#2545
        var _LK = $k[--$j]; //#2546
        $k[$j++] = _LK; //#2548
        $k[$j++] = _LK.length - 2; //#2548
        $k[$j++] = $geti(_LK, 0, _LK.length - 2); //#2548
        $k[$j++] = Infinity; //#2548
        var _LM = $k[--$j]; //#2548
        var _LN = $k[--$j]; //#2548
        $k[$j++] = _LM; //#2550
        $forall(_LN, function() { //#2550
            var _LO = $k[--$j]; //#2549
            var _LQ = $get($1.cset82, _LO) !== undefined; //#2549
            $k[$j++] = _LO; //#2549
            if (_LQ) { //#2549
                var _LT = $get($1.cset82, $k[--$j]); //#2549
                $k[$j++] = _LT; //#2549
            } else { //#2549
                $k[$j++] = -1; //#2549
                return true; //#2549
            } //#2549
        }); //#2549
        var _LU = $k[--$j]; //#2551
        $k[$j++] = _LU; //#2551
        if (_LU == -1) { //#2551
            $cleartomark(); //#2551
            $j -= 3; //#2551
            $k[$j++] = 'bwipp.GS1UnknownCSET82Character'; //#2551
            $k[$j++] = "Unknown CSET 82 character"; //#2551
            $k[$j++] = false; //#2551
            return true; //#2551
        } //#2551
        $astore($a($counttomark())); //#2552
        var _LX = $k[--$j]; //#2552
        var _LY = $k[--$j]; //#2552
        $k[$j++] = _LX; //#2552
        $k[$j++] = _LY; //#2552
        $j--; //#2552
        var _LZ = $k[--$j]; //#2553
        var _La = $k[--$j]; //#2553
        var _Lc = $geti($k[--$j], _La, 2); //#2554
        $k[$j++] = _LZ; //#2554
        $k[$j++] = _Lc; //#2554
        $k[$j++] = Infinity; //#2554
        var _Ld = $k[--$j]; //#2554
        var _Le = $k[--$j]; //#2554
        $k[$j++] = _Ld; //#2556
        $forall(_Le, function() { //#2556
            var _Lf = $k[--$j]; //#2555
            var _Lh = $get($1.cset32, _Lf) !== undefined; //#2555
            $k[$j++] = _Lf; //#2555
            if (_Lh) { //#2555
                var _Lk = $get($1.cset32, $k[--$j]); //#2555
                $k[$j++] = _Lk; //#2555
            } else { //#2555
                $k[$j++] = -1; //#2555
                return true; //#2555
            } //#2555
        }); //#2555
        var _Ll = $k[--$j]; //#2557
        $k[$j++] = _Ll; //#2557
        if (_Ll == -1) { //#2557
            $cleartomark(); //#2557
            $j -= 2; //#2557
            $k[$j++] = 'bwipp.GS1UnknownCSET32Character'; //#2557
            $k[$j++] = "Unknown CSET 32 character"; //#2557
            $k[$j++] = false; //#2557
            return true; //#2557
        } //#2557
        $astore($a($counttomark())); //#2558
        var _Lo = $k[--$j]; //#2558
        var _Lp = $k[--$j]; //#2558
        $k[$j++] = _Lo; //#2558
        $k[$j++] = _Lp; //#2558
        $j--; //#2558
        var _Lq = $k[--$j]; //#2559
        var _Lt = $k[--$j]; //#2559
        var _Lu = $a([2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 79, 83]); //#2560
        var _Lv = _Lt.length; //#2562
        $k[$j++] = $f(($get(_Lq, 0) << 5) + $get(_Lq, 1)); //#2562
        $k[$j++] = _Lt; //#2562
        $k[$j++] = _Lu; //#2562
        $k[$j++] = _Lv; //#2562
        if (_Lv > _Lu.length) { //#2562
            $j -= 5; //#2562
            $k[$j++] = 'bwipp.GS1alphaTooLong'; //#2562
            $k[$j++] = "Alphanumeric string is too long to check"; //#2562
            $k[$j++] = false; //#2562
            return true; //#2562
        } //#2562
        var _Lw = $k[--$j]; //#2563
        var _Ly = $geti($k[--$j], 0, _Lw); //#2563
        for (var _Lz = 0, _M0 = _Ly.length; _Lz < _M0; _Lz++) { //#2563
            var _M2 = $k[--$j]; //#2563
            $k[$j++] = $get(_Ly, _Lz); //#2563
            $k[$j++] = _M2; //#2563
        } //#2563
        var _M3 = $k[--$j]; //#2564
        $k[$j++] = 0; //#2564
        $forall(_M3, function() { //#2564
            var _M4 = $k[--$j]; //#2564
            var _M5 = $k[--$j]; //#2564
            var _M6 = $k[--$j]; //#2564
            $k[$j++] = $f(_M5 + (_M6 * _M4)); //#2564
        }); //#2564
        var _M7 = $k[--$j]; //#2564
        if ($k[--$j] != (_M7 % 1021)) { //#2565
            $j--; //#2565
            $k[$j++] = 'bwipp.GS1badAlphaCheckCharacters'; //#2565
            $k[$j++] = "Bad alphanumeric check characters"; //#2565
            $k[$j++] = false; //#2565
            return true; //#2565
        } //#2565
    }; //#2565
    $k[$j++] = Infinity; //#2588
    var _M9 = $a(['004', '008', '010', '012', '016', '020', '024', '028', '031', '032', '036', '040', '044', '048', '050', '051', '052', '056', '060', '064', '068', '070', '072', '074', '076', '084', '086', '090', '092', '096', '100', '104', '108', '112', '116', '120', '124', '132', '136', '140', '144', '148', '152', '156', '158', '162', '166', '170', '174', '175', '178', '180', '184', '188', '191', '192', '196', '203', '204', '208', '212', '214', '218', '222', '226', '231', '232', '233', '234', '238', '239', '242', '246', '248', '250', '254', '258', '260', '262', '266', '268', '270', '275', '276', '288', '292', '296', '300', '304', '308', '312', '316', '320', '324', '328', '332', '334', '336', '340', '344', '348', '352', '356', '360', '364', '368', '372', '376', '380', '384', '388', '392', '398', '400', '404', '408', '410', '414', '417', '418', '422', '426', '428', '430', '434', '438', '440', '442', '446', '450', '454', '458', '462', '466', '470', '474', '478', '480', '484', '492', '496', '498', '499', '500', '504', '508', '512', '516', '520', '524', '528', '531', '533', '534', '535', '540', '548', '554', '558', '562', '566', '570', '574', '578', '580', '581', '583', '584', '585', '586', '591', '598', '600', '604', '608', '612', '616', '620', '624', '626', '630', '634', '638', '642', '643', '646', '652', '654', '659', '660', '662', '663', '666', '670', '674', '678', '682', '686', '688', '690', '694', '702', '703', '704', '705', '706', '710', '716', '724', '728', '729', '732', '740', '744', '748', '752', '756', '760', '762', '764', '768', '772', '776', '780', '784', '788', '792', '795', '796', '798', '800', '804', '807', '818', '826', '831', '832', '833', '834', '840', '850', '854', '858', '860', '862', '876', '882', '887', '894']); //#2587
    for (var _MA = 0, _MB = _M9.length; _MA < _MB; _MA++) { //#2588
        var _MC = $get(_M9, _MA); //#2588
        $k[$j++] = _MC; //#2588
        $k[$j++] = _MC; //#2588
    } //#2588
    $1.iso3166 = $d(); //#2588
    $1.lintiso3166 = function() {
        var _MG = $get($1.iso3166, $k[--$j]) !== undefined; //#2592
        if (!_MG) { //#2592
            $j--; //#2592
            $k[$j++] = 'bwipp.GS1UnknownCountry'; //#2592
            $k[$j++] = "Unknown country code"; //#2592
            $k[$j++] = false; //#2592
            return true; //#2592
        } //#2592
    }; //#2592
    $1.lintiso3166999 = function() {
        var _MH = $k[--$j]; //#2596
        $k[$j++] = _MH; //#2600
        if ($ne(_MH, '999')) { //#2599
            var _MK = $get($1.iso3166, $k[--$j]) !== undefined; //#2597
            if (!_MK) { //#2597
                $j--; //#2597
                $k[$j++] = 'bwipp.GS1UnknownCountryOr999'; //#2597
                $k[$j++] = "Unknown country code or not 999"; //#2597
                $k[$j++] = false; //#2597
                return true; //#2597
            } //#2597
        } else { //#2599
            $j--; //#2599
        } //#2599
    }; //#2599
    $1.lintiso3166list = function() {
        var _ML = $k[--$j]; //#2604
        $k[$j++] = _ML; //#2606
        if ((_ML.length % 3) != 0) { //#2606
            $j -= 2; //#2605
            $k[$j++] = 'bwipp.GS1BadCountryListLength'; //#2605
            $k[$j++] = "Not a group of three-digit country codes"; //#2605
            $k[$j++] = false; //#2605
            return true; //#2605
        } //#2605
        var _MM = $k[--$j]; //#2608
        $k[$j++] = _MM; //#2611
        $k[$j++] = true; //#2611
        for (var _MO = 0, _MN = _MM.length - 1; _MO <= _MN; _MO += 3) { //#2611
            var _MP = $k[--$j]; //#2609
            var _MQ = $k[--$j]; //#2609
            var _MT = $get($1.iso3166, $geti(_MQ, _MO, 3)) !== undefined; //#2610
            $k[$j++] = _MQ; //#2610
            $k[$j++] = _MP; //#2610
            if (!_MT) { //#2610
                $j -= 2; //#2610
                $k[$j++] = false; //#2610
                break; //#2610
            } //#2610
        } //#2610
        if ($nt($k[--$j])) { //#2612
            $j--; //#2612
            $k[$j++] = 'bwipp.GS1UnknownCountry'; //#2612
            $k[$j++] = "Unknown country code"; //#2612
            $k[$j++] = false; //#2612
            return true; //#2612
        } //#2612
        $j--; //#2613
    }; //#2613
    $k[$j++] = Infinity; //#2642
    var _MV = $a(['AD', 'AE', 'AF', 'AG', 'AI', 'AL', 'AM', 'AO', 'AQ', 'AR', 'AS', 'AT', 'AU', 'AW', 'AX', 'AZ', 'BA', 'BB', 'BD', 'BE', 'BF', 'BG', 'BH', 'BI', 'BJ', 'BL', 'BM', 'BN', 'BO', 'BQ', 'BR', 'BS', 'BT', 'BV', 'BW', 'BY', 'BZ', 'CA', 'CC', 'CD', 'CF', 'CG', 'CH', 'CI', 'CK', 'CL', 'CM', 'CN', 'CO', 'CR', 'CU', 'CV', 'CW', 'CX', 'CY', 'CZ', 'DE', 'DJ', 'DK', 'DM', 'DO', 'DZ', 'EC', 'EE', 'EG', 'EH', 'ER', 'ES', 'ET', 'FI', 'FJ', 'FK', 'FM', 'FO', 'FR', 'GA', 'GB', 'GD', 'GE', 'GF', 'GG', 'GH', 'GI', 'GL', 'GM', 'GN', 'GP', 'GQ', 'GR', 'GS', 'GT', 'GU', 'GW', 'GY', 'HK', 'HM', 'HN', 'HR', 'HT', 'HU', 'ID', 'IE', 'IL', 'IM', 'IN', 'IO', 'IQ', 'IR', 'IS', 'IT', 'JE', 'JM', 'JO', 'JP', 'KE', 'KG', 'KH', 'KI', 'KM', 'KN', 'KP', 'KR', 'KW', 'KY', 'KZ', 'LA', 'LB', 'LC', 'LI', 'LK', 'LR', 'LS', 'LT', 'LU', 'LV', 'LY', 'MA', 'MC', 'MD', 'ME', 'MF', 'MG', 'MH', 'MK', 'ML', 'MM', 'MN', 'MO', 'MP', 'MQ', 'MR', 'MS', 'MT', 'MU', 'MV', 'MW', 'MX', 'MY', 'MZ', 'NA', 'NC', 'NE', 'NF', 'NG', 'NI', 'NL', 'NO', 'NP', 'NR', 'NU', 'NZ', 'OM', 'PA', 'PE', 'PF', 'PG', 'PH', 'PK', 'PL', 'PM', 'PN', 'PR', 'PS', 'PT', 'PW', 'PY', 'QA', 'RE', 'RO', 'RS', 'RU', 'RW', 'SA', 'SB', 'SC', 'SD', 'SE', 'SG', 'SH', 'SI', 'SJ', 'SK', 'SL', 'SM', 'SN', 'SO', 'SR', 'SS', 'ST', 'SV', 'SX', 'SY', 'SZ', 'TC', 'TD', 'TF', 'TG', 'TH', 'TJ', 'TK', 'TL', 'TM', 'TN', 'TO', 'TR', 'TT', 'TV', 'TW', 'TZ', 'UA', 'UG', 'UM', 'US', 'UY', 'UZ', 'VA', 'VC', 'VE', 'VG', 'VI', 'VN', 'VU', 'WF', 'WS', 'YE', 'YT', 'ZA', 'ZM', 'ZW']); //#2641
    for (var _MW = 0, _MX = _MV.length; _MW < _MX; _MW++) { //#2642
        var _MY = $get(_MV, _MW); //#2642
        $k[$j++] = _MY; //#2642
        $k[$j++] = _MY; //#2642
    } //#2642
    $1.iso3166alpha2 = $d(); //#2642
    $1.lintiso3166alpha2 = function() {
        var _Mc = $get($1.iso3166alpha2, $k[--$j]) !== undefined; //#2646
        if (!_Mc) { //#2646
            $j--; //#2646
            $k[$j++] = 'bwipp.GS1UnknownCountryAlpha'; //#2646
            $k[$j++] = "Unknown country alpha code"; //#2646
            $k[$j++] = false; //#2646
            return true; //#2646
        } //#2646
    }; //#2646
    $k[$j++] = Infinity; //#2673
    var _Md = $a(['008', '012', '032', '036', '044', '048', '050', '051', '052', '060', '064', '068', '072', '084', '090', '096', '104', '108', '116', '124', '132', '136', '144', '152', '156', '170', '174', '188', '191', '192', '203', '208', '214', '222', '230', '232', '238', '242', '262', '270', '292', '320', '324', '328', '332', '340', '344', '348', '352', '356', '360', '364', '368', '376', '388', '392', '398', '400', '404', '408', '410', '414', '417', '418', '422', '426', '430', '434', '446', '454', '458', '462', '480', '484', '496', '498', '504', '512', '516', '524', '532', '533', '548', '554', '558', '566', '578', '586', '590', '598', '600', '604', '608', '634', '643', '646', '654', '682', '690', '694', '702', '704', '706', '710', '728', '748', '752', '756', '760', '764', '776', '780', '784', '788', '800', '807', '818', '826', '834', '840', '858', '860', '882', '886', '901', '925', '927', '928', '929', '930', '931', '932', '933', '934', '936', '938', '940', '941', '943', '944', '946', '947', '948', '949', '950', '951', '952', '953', '955', '956', '957', '958', '959', '960', '961', '962', '963', '964', '965', '967', '968', '969', '970', '971', '972', '973', '975', '976', '977', '978', '979', '980', '981', '984', '985', '986', '990', '994', '997', '999']); //#2672
    for (var _Me = 0, _Mf = _Md.length; _Me < _Mf; _Me++) { //#2673
        var _Mg = $get(_Md, _Me); //#2673
        $k[$j++] = _Mg; //#2673
        $k[$j++] = _Mg; //#2673
    } //#2673
    $1.iso4217 = $d(); //#2673
    $1.lintiso4217 = function() {
        var _Mk = $get($1.iso4217, $k[--$j]) !== undefined; //#2677
        if (!_Mk) { //#2677
            $j--; //#2677
            $k[$j++] = 'bwipp.GS1UnknownCurrency'; //#2677
            $k[$j++] = "Unknown currency code"; //#2677
            $k[$j++] = false; //#2677
            return true; //#2677
        } //#2677
    }; //#2677
    $1.lintiban = function() {
        var _Ml = $k[--$j]; //#2681
        $k[$j++] = _Ml; //#2681
        if (_Ml.length <= 4) { //#2681
            $j -= 2; //#2681
            $k[$j++] = 'bwipp.GS1tooShort'; //#2681
            $k[$j++] = "IBAN too short"; //#2681
            $k[$j++] = false; //#2681
            return true; //#2681
        } //#2681
        var _Mm = $k[--$j]; //#2682
        $k[$j++] = _Mm; //#2687
        $k[$j++] = true; //#2687
        $forall(_Mm, function() { //#2687
            var _Mn = $s(1); //#2683
            $put(_Mn, 0, $k[--$j]); //#2683
            $search("0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ", _Mn); //#2685
            if ($nt($k[--$j])) { //#2685
                $j -= 2; //#2685
                $k[$j++] = false; //#2685
                return true; //#2685
            } //#2685
            $j -= 3; //#2686
        }); //#2686
        if ($nt($k[--$j])) { //#2688
            $j--; //#2688
            $k[$j++] = 'bwipp.GS1badIBANcharacter'; //#2688
            $k[$j++] = "Invalid IBAN character"; //#2688
            $k[$j++] = false; //#2688
            return true; //#2688
        } //#2688
        var _Mr = $k[--$j]; //#2689
        $k[$j++] = _Mr; //#2689
        $k[$j++] = _Mr; //#2689
        $k[$j++] = Infinity; //#2689
        var _Ms = $k[--$j]; //#2689
        var _Mt = $k[--$j]; //#2689
        $k[$j++] = _Ms; //#2689
        $k[$j++] = _Mt; //#2689
        $k[$j++] = Infinity; //#2689
        var _Mu = $k[--$j]; //#2689
        var _Mv = $k[--$j]; //#2689
        $k[$j++] = _Mu; //#2689
        $forall(_Mv); //#2689
        $r($counttomark(), -4); //#2689
        $astore($a($counttomark())); //#2689
        var _Mz = $k[--$j]; //#2689
        var _N0 = $k[--$j]; //#2689
        $k[$j++] = _Mz; //#2689
        $k[$j++] = _N0; //#2689
        $j--; //#2689
        $forall($k[--$j], function() { //#2691
            var _N3 = $f($k[--$j] - 48); //#2690
            $k[$j++] = _N3; //#2690
            if (_N3 > 9) { //#2690
                var _N5 = $f($k[--$j] - 7); //#2690
                $k[$j++] = ~~(_N5 / 10); //#2690
                $k[$j++] = _N5 % 10; //#2690
            } //#2690
        }); //#2690
        $astore($a($counttomark())); //#2691
        var _N8 = $k[--$j]; //#2691
        var _N9 = $k[--$j]; //#2691
        $k[$j++] = _N8; //#2691
        $k[$j++] = _N9; //#2691
        $j--; //#2691
        var _NA = $k[--$j]; //#2692
        $k[$j++] = 0; //#2692
        $forall(_NA, function() { //#2692
            var _NB = $k[--$j]; //#2692
            var _NC = $k[--$j]; //#2692
            $k[$j++] = ($f(_NB + (_NC * 10))) % 97; //#2692
        }); //#2692
        if ($k[--$j] != 1) { //#2693
            $j -= 2; //#2693
            $k[$j++] = 'bwipp.GS1badIBANchecksum'; //#2693
            $k[$j++] = "IBAN checksum incorrect"; //#2693
            $k[$j++] = false; //#2693
            return true; //#2693
        } //#2693
        var _NF = $geti($k[--$j], 0, 2); //#2694
        $k[$j++] = _NF; //#2694
        $1.lintiso3166alpha2(); //#2694
    }; //#2694
    $1.lintzero = function() {
        if ($ne($k[--$j], "0")) { //#2698
            $j--; //#2698
            $k[$j++] = 'bwipp.GS1zeroRequired'; //#2698
            $k[$j++] = "Zero is required"; //#2698
            $k[$j++] = false; //#2698
            return true; //#2698
        } //#2698
    }; //#2698
    $1.lintnonzero = function() {
        var _NH = $k[--$j]; //#2702
        $k[$j++] = false; //#2702
        $forall(_NH, function() { //#2702
            if ($k[--$j] != 48) { //#2702
                $j--; //#2702
                $k[$j++] = true; //#2702
            } //#2702
        }); //#2702
        if ($nt($k[--$j])) { //#2703
            $j--; //#2703
            $k[$j++] = 'bwipp.GS1zeroNotPermitted'; //#2703
            $k[$j++] = "Zero not permitted"; //#2703
            $k[$j++] = false; //#2703
            return true; //#2703
        } //#2703
    }; //#2703
    $1.lintnozeroprefix = function() {
        var _NK = $k[--$j]; //#2707
        if ((_NK.length > 1) && ($get(_NK, 0) == 48)) { //#2709
            $j--; //#2708
            $k[$j++] = 'bwipp.GS1badZeroPrefix'; //#2708
            $k[$j++] = "Zero prefix is not permitted"; //#2708
            $k[$j++] = false; //#2708
            return true; //#2708
        } //#2708
    }; //#2708
    $1.lintyymmd0 = function() {
        var _NM = $k[--$j]; //#2713
        var _NO = $cvi($geti(_NM, 2, 2)); //#2713
        $k[$j++] = _NM; //#2713
        if ((_NO < 1) || (_NO > 12)) { //#2713
            $j--; //#2713
            $k[$j++] = 'bwipp.GS1badMonth'; //#2713
            $k[$j++] = "Invalid month"; //#2713
            $k[$j++] = false; //#2713
            return true; //#2713
        } //#2713
        var _NP = $k[--$j]; //#2714
        var _NR = $cvi($geti(_NP, 0, 2)); //#2714
        var _NS = _NR - 21; //#2715
        $k[$j++] = _NP; //#2715
        $k[$j++] = _NR; //#2715
        $k[$j++] = _NS; //#2715
        if (_NS >= 51) { //#2715
            $j--; //#2715
            var _NT = $k[--$j]; //#2715
            $k[$j++] = $f(_NT + 1900); //#2715
        } else { //#2715
            if ($k[--$j] <= -50) { //#2715
                var _NV = $k[--$j]; //#2715
                $k[$j++] = $f(_NV + 2100); //#2715
            } else { //#2715
                var _NW = $k[--$j]; //#2715
                $k[$j++] = $f(_NW + 2000); //#2715
            } //#2715
        } //#2715
        var _NX = $k[--$j]; //#2716
        $k[$j++] = ((_NX % 400) == 0) || (((_NX % 4) == 0) && ((_NX % 100) != 0)); //#2717
        $k[$j++] = Infinity; //#2717
        var _NY = $k[--$j]; //#2717
        var _Na = $k[--$j] ? 29 : 28; //#2717
        $k[$j++] = _NY; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = _Na; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = 30; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = 30; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = 30; //#2717
        $k[$j++] = 31; //#2717
        $k[$j++] = 30; //#2717
        $k[$j++] = 31; //#2717
        var _Nb = $a(); //#2717
        var _Nc = $k[--$j]; //#2718
        if ($get(_Nb, $cvi($geti(_Nc, 2, 2)) - 1) < $cvi($geti(_Nc, 4, 2))) { //#2719
            $j--; //#2719
            $k[$j++] = 'bwipp.GS1badDay'; //#2719
            $k[$j++] = "Invalid day of month"; //#2719
            $k[$j++] = false; //#2719
            return true; //#2719
        } //#2719
    }; //#2719
    $1.lintyymmdd = function() {
        var _Ng = $k[--$j]; //#2723
        $k[$j++] = _Ng; //#2723
        if (_Ng.length != 6) { //#2723
            $j--; //#2723
            $k[$j++] = 'bwipp.GS1badDateLength'; //#2723
            $k[$j++] = "Invalid length for date"; //#2723
            $k[$j++] = false; //#2723
            return true; //#2723
        } //#2723
        var _Nh = $k[--$j]; //#2724
        $k[$j++] = _Nh; //#2724
        if ($cvi($geti(_Nh, 4, 2)) < 1) { //#2724
            $j--; //#2724
            $k[$j++] = 'bwipp.GS1badDay'; //#2724
            $k[$j++] = "Invalid day of month"; //#2724
            $k[$j++] = false; //#2724
            return true; //#2724
        } //#2724
        $1.lintyymmd0(); //#2725
    }; //#2725
    $1.lintyymmddhh = function() {
        var _Nj = $k[--$j]; //#2729
        $k[$j++] = _Nj; //#2729
        if (_Nj.length != 8) { //#2729
            $j--; //#2729
            $k[$j++] = 'bwipp.GS1badYYMMDDHHLength'; //#2729
            $k[$j++] = "Invalid length for date with hour"; //#2729
            $k[$j++] = false; //#2729
            return true; //#2729
        } //#2729
        var _Nk = $k[--$j]; //#2730
        $k[$j++] = _Nk; //#2730
        if ($cvi($geti(_Nk, 6, 2)) > 23) { //#2730
            $j -= 2; //#2730
            $k[$j++] = 'bwipp.GS1badHour'; //#2730
            $k[$j++] = "Invalid hour of day"; //#2730
            $k[$j++] = false; //#2730
            return true; //#2730
        } //#2730
        var _Nn = $geti($k[--$j], 0, 6); //#2731
        $k[$j++] = _Nn; //#2731
        $1.lintyymmdd(); //#2731
    }; //#2731
    $1.linthhmm = function() {
        var _No = $k[--$j]; //#2735
        $k[$j++] = _No; //#2735
        if ($cvi($geti(_No, 0, 2)) > 23) { //#2735
            $j -= 2; //#2735
            $k[$j++] = 'bwipp.GS1badHour'; //#2735
            $k[$j++] = "Invalid hour of day"; //#2735
            $k[$j++] = false; //#2735
            return true; //#2735
        } //#2735
        if ($cvi($geti($k[--$j], 2, 2)) > 59) { //#2736
            $j--; //#2736
            $k[$j++] = 'bwipp.GS1badMinute'; //#2736
            $k[$j++] = "Invalid minute in the hour"; //#2736
            $k[$j++] = false; //#2736
            return true; //#2736
        } //#2736
    }; //#2736
    $1.lintmmoptss = function() {
        var _Ns = $k[--$j]; //#2740
        var _Nt = _Ns.length; //#2740
        $k[$j++] = _Ns; //#2742
        if ((_Nt != 2) && (_Nt != 4)) { //#2742
            $j--; //#2741
            $k[$j++] = 'bwipp.GS1badTimeLength'; //#2741
            $k[$j++] = "Invalid length for optional minutes and seconds"; //#2741
            $k[$j++] = false; //#2741
            return true; //#2741
        } //#2741
        var _Nu = $k[--$j]; //#2743
        $k[$j++] = _Nu; //#2743
        if ($cvi($geti(_Nu, 0, 2)) > 59) { //#2743
            $j -= 2; //#2743
            $k[$j++] = 'bwipp.GS1badMinute'; //#2743
            $k[$j++] = "Invalid minute in the hour"; //#2743
            $k[$j++] = false; //#2743
            return true; //#2743
        } //#2743
        var _Nw = $k[--$j]; //#2744
        $k[$j++] = _Nw; //#2746
        if (_Nw.length >= 4) { //#2746
            var _Nx = $k[--$j]; //#2745
            $k[$j++] = _Nx; //#2745
            if ($cvi($geti(_Nx, 2, 2)) > 59) { //#2745
                $j -= 2; //#2745
                $k[$j++] = 'bwipp.GS1badSecond'; //#2745
                $k[$j++] = "Invalid second in the minute"; //#2745
                $k[$j++] = false; //#2745
                return true; //#2745
            } //#2745
        } //#2745
        $j--; //#2747
    }; //#2747
    $1.lintyesno = function() {
        var _Nz = $k[--$j]; //#2751
        if ($ne(_Nz, "0") && $ne(_Nz, "1")) { //#2753
            $j--; //#2752
            $k[$j++] = 'bwipp.GS1badBoolean'; //#2752
            $k[$j++] = "Neither 0 nor 1 for yes or no"; //#2752
            $k[$j++] = false; //#2752
            return true; //#2752
        } //#2752
    }; //#2752
    $1.lintwinding = function() {
        var _O0 = $k[--$j]; //#2757
        if ($ne(_O0, "0") && ($ne(_O0, "1") && $ne(_O0, "9"))) { //#2759
            $j--; //#2758
            $k[$j++] = 'bwipp.GS1badWinding'; //#2758
            $k[$j++] = "Invalid winding direction"; //#2758
            $k[$j++] = false; //#2758
            return true; //#2758
        } //#2758
    }; //#2758
    $1.lintpieceoftotal = function() {
        var _O1 = $k[--$j]; //#2763
        $k[$j++] = _O1; //#2763
        if ((_O1.length % 2) != 0) { //#2763
            $j -= 2; //#2763
            $k[$j++] = 'bwipp.GS1badPieceTotalLength'; //#2763
            $k[$j++] = "Invalid piece/total length"; //#2763
            $k[$j++] = false; //#2763
            return true; //#2763
        } //#2763
        var _O2 = $k[--$j]; //#2764
        var _O4 = $cvi($geti(_O2, 0, ~~(_O2.length / 2))); //#2765
        $k[$j++] = _O2; //#2765
        $k[$j++] = _O4; //#2765
        if (_O4 == 0) { //#2765
            $j -= 3; //#2765
            $k[$j++] = 'bwipp.GS1badPieceNumber'; //#2765
            $k[$j++] = "Invalid piece number"; //#2765
            $k[$j++] = false; //#2765
            return true; //#2765
        } //#2765
        var _O5 = $k[--$j]; //#2766
        var _O6 = $k[--$j]; //#2766
        var _O7 = ~~(_O6.length / 2); //#2766
        var _O9 = $cvi($geti(_O6, _O7, _O7)); //#2767
        $k[$j++] = _O5; //#2767
        $k[$j++] = _O9; //#2767
        if (_O9 == 0) { //#2767
            $j -= 3; //#2767
            $k[$j++] = 'bwipp.GS1badPieceTotal'; //#2767
            $k[$j++] = "Invalid total number"; //#2767
            $k[$j++] = false; //#2767
            return true; //#2767
        } //#2767
        var _OA = $k[--$j]; //#2768
        if ($gt($k[--$j], _OA)) { //#2768
            $j--; //#2768
            $k[$j++] = 'bwipp.GS1pieceExceedsTotal'; //#2768
            $k[$j++] = "Piece number exceeds total"; //#2768
            $k[$j++] = false; //#2768
            return true; //#2768
        } //#2768
    }; //#2768
    $1.lintpcenc = function() {
        for (;;) { //#2782
            $search($k[--$j], "%"); //#2773
            if ($nt($k[--$j])) { //#2773
                $j--; //#2773
                break; //#2773
            } //#2773
            $j -= 2; //#2774
            var _OE = $k[--$j]; //#2774
            $k[$j++] = _OE; //#2774
            if (_OE.length < 2) { //#2774
                $j -= 2; //#2774
                $k[$j++] = 'bwipp.GS1badPercentEscape'; //#2774
                $k[$j++] = "Invalid % escape"; //#2774
                $k[$j++] = false; //#2774
                break; //#2774
            } //#2774
            var _OF = $k[--$j]; //#2775
            var _OG = $geti(_OF, 0, 2); //#2775
            $k[$j++] = _OF; //#2780
            $k[$j++] = true; //#2780
            for (var _OH = 0, _OI = _OG.length; _OH < _OI; _OH++) { //#2780
                var _OK = $s(1); //#2776
                $put(_OK, 0, $get(_OG, _OH)); //#2776
                $search("0123456789ABCDEFabcdef", _OK); //#2778
                if ($nt($k[--$j])) { //#2778
                    $j -= 2; //#2778
                    $k[$j++] = false; //#2778
                    return true; //#2778
                } //#2778
                $j -= 3; //#2779
            } //#2779
            if ($nt($k[--$j])) { //#2781
                $j -= 2; //#2781
                $k[$j++] = 'bwipp.GS1badPercentChars'; //#2781
                $k[$j++] = "Invalid characters for percent encoding"; //#2781
                $k[$j++] = false; //#2781
                break; //#2781
            } //#2781
        } //#2781
    }; //#2781
    $1.lintcouponcode = function() {
        var _ON = $k[--$j]; //#2786
        $k[$j++] = _ON; //#2788
        $k[$j++] = true; //#2788
        $forall(_ON, function() { //#2788
            var _OO = $k[--$j]; //#2787
            if ((_OO < 48) || (_OO > 57)) { //#2787
                $j--; //#2787
                $k[$j++] = false; //#2787
                return true; //#2787
            } //#2787
        }); //#2787
        if ($nt($k[--$j])) { //#2789
            $j -= 2; //#2789
            $k[$j++] = 'bwipp.GS1couponNotNumeric'; //#2789
            $k[$j++] = "Coupon not numeric"; //#2789
            $k[$j++] = false; //#2789
            return true; //#2789
        } //#2789
        var _OQ = $k[--$j]; //#2792
        $k[$j++] = _OQ; //#2794
        if (_OQ.length < 1) { //#2794
            $j -= 2; //#2793
            $k[$j++] = 'bwipp.GS1couponTooShortGCPVLI'; //#2793
            $k[$j++] = "Coupon too short: Missing GCP VLI"; //#2793
            $k[$j++] = false; //#2793
            return true; //#2793
        } //#2793
        var _OR = $k[--$j]; //#2795
        var _OT = $cvi($geti(_OR, 0, 1)); //#2795
        $k[$j++] = _OR; //#2797
        $k[$j++] = _OT; //#2797
        if (_OT > 6) { //#2797
            $j -= 2; //#2796
            $k[$j++] = 'bwipp.GS1couponBadGCPVLI'; //#2796
            $k[$j++] = "Coupon GCP length indicator must be 0-6"; //#2796
            $k[$j++] = false; //#2796
            return true; //#2796
        } //#2796
        var _OU = $k[--$j]; //#2798
        var _OV = $k[--$j]; //#2799
        $k[$j++] = _OV; //#2801
        $k[$j++] = $f($f(_OU + 6) + 1); //#2801
        if (($f($f(_OU + 6) + 1)) > _OV.length) { //#2801
            $j -= 3; //#2800
            $k[$j++] = 'bwipp.GS1couponTooShortGCP'; //#2800
            $k[$j++] = "Coupon too short: GCP truncated"; //#2800
            $k[$j++] = false; //#2800
            return true; //#2800
        } //#2800
        var _OW = $k[--$j]; //#2802
        var _OX = $k[--$j]; //#2802
        var _OY = $geti(_OX, _OW, $f(_OX.length - _OW)); //#2802
        $k[$j++] = _OY; //#2807
        if (_OY.length < 6) { //#2807
            $j -= 2; //#2806
            $k[$j++] = 'bwipp.GS1couponTooShortOfferCode'; //#2806
            $k[$j++] = "Coupon too short: Offer Code truncated"; //#2806
            $k[$j++] = false; //#2806
            return true; //#2806
        } //#2806
        var _OZ = $k[--$j]; //#2808
        var _Oa = $geti(_OZ, 6, _OZ.length - 6); //#2808
        $k[$j++] = _Oa; //#2813
        if (_Oa.length < 1) { //#2813
            $j -= 2; //#2812
            $k[$j++] = 'bwipp.GS1couponTooShortSaveValueVLI'; //#2812
            $k[$j++] = "Coupon too short: Missing Save Value VLI"; //#2812
            $k[$j++] = false; //#2812
            return true; //#2812
        } //#2812
        var _Ob = $k[--$j]; //#2814
        var _Od = $cvi($geti(_Ob, 0, 1)); //#2814
        $k[$j++] = _Ob; //#2816
        $k[$j++] = _Od; //#2816
        if ((_Od < 1) || (_Od > 5)) { //#2816
            $j -= 2; //#2815
            $k[$j++] = 'bwipp.GS1couponBadSaveValueVLI'; //#2815
            $k[$j++] = "Coupon Save Value length indicator must be 1-5"; //#2815
            $k[$j++] = false; //#2815
            return true; //#2815
        } //#2815
        var _Oe = $k[--$j]; //#2817
        var _Of = $k[--$j]; //#2818
        $k[$j++] = _Of; //#2820
        $k[$j++] = $f(_Oe + 1); //#2820
        if ($f(_Oe + 1) > _Of.length) { //#2820
            $j -= 3; //#2819
            $k[$j++] = 'bwipp.GS1couponTooShortSaveValue'; //#2819
            $k[$j++] = "Coupon too short: Save Value truncated"; //#2819
            $k[$j++] = false; //#2819
            return true; //#2819
        } //#2819
        var _Og = $k[--$j]; //#2821
        var _Oh = $k[--$j]; //#2821
        var _Oi = $geti(_Oh, _Og, $f(_Oh.length - _Og)); //#2821
        $k[$j++] = _Oi; //#2826
        if (_Oi.length < 1) { //#2826
            $j -= 2; //#2825
            $k[$j++] = 'bwipp.GS1couponTooShort1stPurchaseRequirementVLI'; //#2825
            $k[$j++] = "Coupon too short: Missing 1st Purchase Requirement VLI"; //#2825
            $k[$j++] = false; //#2825
            return true; //#2825
        } //#2825
        var _Oj = $k[--$j]; //#2827
        var _Ol = $cvi($geti(_Oj, 0, 1)); //#2827
        $k[$j++] = _Oj; //#2829
        $k[$j++] = _Ol; //#2829
        if ((_Ol < 1) || (_Ol > 5)) { //#2829
            $j -= 2; //#2828
            $k[$j++] = 'bwipp.GS1couponBad1stPurchaseRequirementVLI'; //#2828
            $k[$j++] = "Coupon 1st Purchase Requirement length indicator must be 1-5"; //#2828
            $k[$j++] = false; //#2828
            return true; //#2828
        } //#2828
        var _Om = $k[--$j]; //#2830
        var _On = $k[--$j]; //#2831
        $k[$j++] = _On; //#2833
        $k[$j++] = $f(_Om + 1); //#2833
        if ($f(_Om + 1) > _On.length) { //#2833
            $j -= 3; //#2832
            $k[$j++] = 'bwipp.GS1couponTooShort1stPurchaseRequirement'; //#2832
            $k[$j++] = "Coupon too short: 1st Purchase Requirement truncated"; //#2832
            $k[$j++] = false; //#2832
            return true; //#2832
        } //#2832
        var _Oo = $k[--$j]; //#2834
        var _Op = $k[--$j]; //#2834
        var _Oq = $geti(_Op, _Oo, $f(_Op.length - _Oo)); //#2834
        $k[$j++] = _Oq; //#2839
        if (_Oq.length < 1) { //#2839
            $j -= 2; //#2838
            $k[$j++] = 'bwipp.GS1couponTooShort1stPurchaseRequirementCode'; //#2838
            $k[$j++] = "Coupon too short: Missing 1st Purchase Requirement Code"; //#2838
            $k[$j++] = false; //#2838
            return true; //#2838
        } //#2838
        var _Or = $k[--$j]; //#2840
        var _Ot = $cvi($geti(_Or, 0, 1)); //#2840
        $k[$j++] = _Or; //#2842
        if ((_Ot > 4) && (_Ot != 9)) { //#2842
            $j -= 2; //#2841
            $k[$j++] = 'bwipp.GS1couponBad1stPurchaseRequirementCode'; //#2841
            $k[$j++] = "Coupon 1st Purchase Requirement Code must be 0-4 or 9"; //#2841
            $k[$j++] = false; //#2841
            return true; //#2841
        } //#2841
        var _Ou = $k[--$j]; //#2843
        var _Ov = $geti(_Ou, 1, _Ou.length - 1); //#2843
        $k[$j++] = _Ov; //#2848
        if (_Ov.length < 3) { //#2848
            $j -= 2; //#2847
            $k[$j++] = 'bwipp.GS1couponTooShort1stPurchaseFamilyCode'; //#2847
            $k[$j++] = "Coupon too short: 1st Purchase Family Code truncated"; //#2847
            $k[$j++] = false; //#2847
            return true; //#2847
        } //#2847
        var _Ow = $k[--$j]; //#2849
        var _Ox = $geti(_Ow, 3, _Ow.length - 3); //#2849
        $k[$j++] = _Ox; //#2905
        if (_Ox.length >= 1) { //#2905
            var _Oy = $k[--$j]; //#2852
            $k[$j++] = _Oy; //#2905
            if ($cvi($geti(_Oy, 0, 1)) == 1) { //#2905
                var _P0 = $k[--$j]; //#2853
                var _P1 = $geti(_P0, 1, _P0.length - 1); //#2853
                $k[$j++] = _P1; //#2858
                if (_P1.length < 1) { //#2858
                    $j -= 2; //#2857
                    $k[$j++] = 'bwipp.GS1couponTooShortAdditionalPurchaseRulesCode'; //#2857
                    $k[$j++] = "Coupon too short: Missing Additional Purchase Rules Code"; //#2857
                    $k[$j++] = false; //#2857
                    return true; //#2857
                } //#2857
                var _P2 = $k[--$j]; //#2859
                $k[$j++] = _P2; //#2861
                if ($cvi($geti(_P2, 0, 1)) > 3) { //#2861
                    $j -= 2; //#2860
                    $k[$j++] = 'bwipp.GS1couponBadAdditionalPurchaseRulesCode'; //#2860
                    $k[$j++] = "Coupon Additional Purchase Rules Code must be 0-3"; //#2860
                    $k[$j++] = false; //#2860
                    return true; //#2860
                } //#2860
                var _P4 = $k[--$j]; //#2862
                var _P5 = $geti(_P4, 1, _P4.length - 1); //#2862
                $k[$j++] = _P5; //#2867
                if (_P5.length < 1) { //#2867
                    $j -= 2; //#2866
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseRequirementVLI'; //#2866
                    $k[$j++] = "Coupon too short: Missing 2nd Purchase Requirement VLI"; //#2866
                    $k[$j++] = false; //#2866
                    return true; //#2866
                } //#2866
                var _P6 = $k[--$j]; //#2868
                var _P8 = $cvi($geti(_P6, 0, 1)); //#2868
                $k[$j++] = _P6; //#2870
                $k[$j++] = _P8; //#2870
                if ((_P8 < 1) || (_P8 > 5)) { //#2870
                    $j -= 2; //#2869
                    $k[$j++] = 'bwipp.GS1couponBad2ndPurchaseRequirementVLI'; //#2869
                    $k[$j++] = "Coupon 2nd Purchase Requirement length indicator must be 1-5"; //#2869
                    $k[$j++] = false; //#2869
                    return true; //#2869
                } //#2869
                var _P9 = $k[--$j]; //#2871
                var _PA = $k[--$j]; //#2872
                $k[$j++] = _PA; //#2874
                $k[$j++] = $f(_P9 + 1); //#2874
                if ($f(_P9 + 1) > _PA.length) { //#2874
                    $j -= 3; //#2873
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseRequirement'; //#2873
                    $k[$j++] = "Coupon too short: 2nd Purchase Requirement truncated"; //#2873
                    $k[$j++] = false; //#2873
                    return true; //#2873
                } //#2873
                var _PB = $k[--$j]; //#2875
                var _PC = $k[--$j]; //#2875
                var _PD = $geti(_PC, _PB, $f(_PC.length - _PB)); //#2875
                $k[$j++] = _PD; //#2880
                if (_PD.length < 1) { //#2880
                    $j -= 2; //#2879
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseRequirementCode'; //#2879
                    $k[$j++] = "Coupon too short: Missing 2nd Purchase Requirement Code"; //#2879
                    $k[$j++] = false; //#2879
                    return true; //#2879
                } //#2879
                var _PE = $k[--$j]; //#2881
                var _PG = $cvi($geti(_PE, 0, 1)); //#2881
                $k[$j++] = _PE; //#2883
                if ((_PG > 4) && (_PG != 9)) { //#2883
                    $j -= 2; //#2882
                    $k[$j++] = 'bwipp.GS1couponBad2ndPurchaseRequirementCode'; //#2882
                    $k[$j++] = "Coupon 2nd Purchase Requirement Code must be 0-4 or 9"; //#2882
                    $k[$j++] = false; //#2882
                    return true; //#2882
                } //#2882
                var _PH = $k[--$j]; //#2884
                var _PI = $geti(_PH, 1, _PH.length - 1); //#2884
                $k[$j++] = _PI; //#2889
                if (_PI.length < 3) { //#2889
                    $j -= 2; //#2888
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseFamilyCode'; //#2888
                    $k[$j++] = "Coupon too short: 2nd Purchase Family Code truncated"; //#2888
                    $k[$j++] = false; //#2888
                    return true; //#2888
                } //#2888
                var _PJ = $k[--$j]; //#2890
                var _PK = $geti(_PJ, 3, _PJ.length - 3); //#2890
                $k[$j++] = _PK; //#2895
                if (_PK.length < 1) { //#2895
                    $j -= 2; //#2894
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseGCPVLI'; //#2894
                    $k[$j++] = "Coupon too short: Missing 2nd Purchase GCP VLI"; //#2894
                    $k[$j++] = false; //#2894
                    return true; //#2894
                } //#2894
                var _PL = $k[--$j]; //#2896
                var _PN = $cvi($geti(_PL, 0, 1)); //#2896
                $k[$j++] = _PL; //#2898
                $k[$j++] = _PN; //#2898
                if ((_PN > 6) && (_PN != 9)) { //#2898
                    $j -= 2; //#2897
                    $k[$j++] = 'bwipp.GS1couponBad2ndPurchaseGCPVLI'; //#2897
                    $k[$j++] = "Coupon 2nd Purchase GCP length indicator must be 0-6 or 9"; //#2897
                    $k[$j++] = false; //#2897
                    return true; //#2897
                } //#2897
                var _PO = $k[--$j]; //#2899
                $k[$j++] = _PO; //#2899
                if (_PO != 9) { //#2899
                    var _PP = $k[--$j]; //#2899
                    $k[$j++] = $f(_PP + 6); //#2899
                } else { //#2899
                    $j--; //#2899
                    $k[$j++] = 0; //#2899
                } //#2899
                var _PQ = $k[--$j]; //#2899
                var _PR = $k[--$j]; //#2900
                $k[$j++] = _PR; //#2902
                $k[$j++] = $f(_PQ + 1); //#2902
                if ($f(_PQ + 1) > _PR.length) { //#2902
                    $j -= 3; //#2901
                    $k[$j++] = 'bwipp.GS1couponTooShort2ndPurchaseGCP'; //#2901
                    $k[$j++] = "Coupon too short: 2nd Purchase GCP truncated"; //#2901
                    $k[$j++] = false; //#2901
                    return true; //#2901
                } //#2901
                var _PS = $k[--$j]; //#2903
                var _PT = $k[--$j]; //#2903
                $k[$j++] = $geti(_PT, _PS, $f(_PT.length - _PS)); //#2903
            } //#2903
        } //#2903
        var _PV = $k[--$j]; //#2908
        $k[$j++] = _PV; //#2952
        if (_PV.length >= 1) { //#2952
            var _PW = $k[--$j]; //#2908
            $k[$j++] = _PW; //#2952
            if ($cvi($geti(_PW, 0, 1)) == 2) { //#2952
                var _PY = $k[--$j]; //#2909
                var _PZ = $geti(_PY, 1, _PY.length - 1); //#2909
                $k[$j++] = _PZ; //#2914
                if (_PZ.length < 1) { //#2914
                    $j -= 2; //#2913
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseRequirementVLI'; //#2913
                    $k[$j++] = "Coupon too short: Missing 3rd Purchase Requirement VLI"; //#2913
                    $k[$j++] = false; //#2913
                    return true; //#2913
                } //#2913
                var _Pa = $k[--$j]; //#2915
                var _Pc = $cvi($geti(_Pa, 0, 1)); //#2915
                $k[$j++] = _Pa; //#2917
                $k[$j++] = _Pc; //#2917
                if ((_Pc < 1) || (_Pc > 5)) { //#2917
                    $j -= 2; //#2916
                    $k[$j++] = 'bwipp.GS1couponBad3rdPurchaseRequirementVLI'; //#2916
                    $k[$j++] = "Coupon 3rd Purchase Requirement length indicator must be 1-5"; //#2916
                    $k[$j++] = false; //#2916
                    return true; //#2916
                } //#2916
                var _Pd = $k[--$j]; //#2918
                var _Pe = $k[--$j]; //#2919
                $k[$j++] = _Pe; //#2921
                $k[$j++] = $f(_Pd + 1); //#2921
                if ($f(_Pd + 1) > _Pe.length) { //#2921
                    $j -= 3; //#2920
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseRequirement'; //#2920
                    $k[$j++] = "Coupon too short: 3rd Purchase Requirement truncated"; //#2920
                    $k[$j++] = false; //#2920
                    return true; //#2920
                } //#2920
                var _Pf = $k[--$j]; //#2922
                var _Pg = $k[--$j]; //#2922
                var _Ph = $geti(_Pg, _Pf, $f(_Pg.length - _Pf)); //#2922
                $k[$j++] = _Ph; //#2927
                if (_Ph.length < 1) { //#2927
                    $j -= 2; //#2926
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseRequirementCode'; //#2926
                    $k[$j++] = "Coupon too short: Missing 3rd Purchase Requirement Code"; //#2926
                    $k[$j++] = false; //#2926
                    return true; //#2926
                } //#2926
                var _Pi = $k[--$j]; //#2928
                var _Pk = $cvi($geti(_Pi, 0, 1)); //#2928
                $k[$j++] = _Pi; //#2930
                if ((_Pk > 4) && (_Pk != 9)) { //#2930
                    $j -= 2; //#2929
                    $k[$j++] = 'bwipp.GS1couponBad3rdPurchaseRequirementCode'; //#2929
                    $k[$j++] = "Coupon 3rd Purchase Requirement Code must be 0-4 or 9"; //#2929
                    $k[$j++] = false; //#2929
                    return true; //#2929
                } //#2929
                var _Pl = $k[--$j]; //#2931
                var _Pm = $geti(_Pl, 1, _Pl.length - 1); //#2931
                $k[$j++] = _Pm; //#2936
                if (_Pm.length < 3) { //#2936
                    $j -= 2; //#2935
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseFamilyCode'; //#2935
                    $k[$j++] = "Coupon too short: 3rd Purchase Family Code truncated"; //#2935
                    $k[$j++] = false; //#2935
                    return true; //#2935
                } //#2935
                var _Pn = $k[--$j]; //#2937
                var _Po = $geti(_Pn, 3, _Pn.length - 3); //#2937
                $k[$j++] = _Po; //#2942
                if (_Po.length < 1) { //#2942
                    $j -= 2; //#2941
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseGCPVLI'; //#2941
                    $k[$j++] = "Coupon too short: Missing 3rd Purchase GCP VLI"; //#2941
                    $k[$j++] = false; //#2941
                    return true; //#2941
                } //#2941
                var _Pp = $k[--$j]; //#2943
                var _Pr = $cvi($geti(_Pp, 0, 1)); //#2943
                $k[$j++] = _Pp; //#2945
                $k[$j++] = _Pr; //#2945
                if ((_Pr > 6) && (_Pr != 9)) { //#2945
                    $j -= 2; //#2944
                    $k[$j++] = 'bwipp.GS1couponBad3rdPurchaseGCPVLI'; //#2944
                    $k[$j++] = "Coupon 3rd Purchase GCP length indicator must be 0-6 or 9"; //#2944
                    $k[$j++] = false; //#2944
                    return true; //#2944
                } //#2944
                var _Ps = $k[--$j]; //#2946
                $k[$j++] = _Ps; //#2946
                if (_Ps != 9) { //#2946
                    var _Pt = $k[--$j]; //#2946
                    $k[$j++] = $f(_Pt + 6); //#2946
                } else { //#2946
                    $j--; //#2946
                    $k[$j++] = 0; //#2946
                } //#2946
                var _Pu = $k[--$j]; //#2946
                var _Pv = $k[--$j]; //#2947
                $k[$j++] = _Pv; //#2949
                $k[$j++] = $f(_Pu + 1); //#2949
                if ($f(_Pu + 1) > _Pv.length) { //#2949
                    $j -= 3; //#2948
                    $k[$j++] = 'bwipp.GS1couponTooShort3rdPurchaseGCP'; //#2948
                    $k[$j++] = "Coupon too short: 3rd Purchase GCP truncated"; //#2948
                    $k[$j++] = false; //#2948
                    return true; //#2948
                } //#2948
                var _Pw = $k[--$j]; //#2950
                var _Px = $k[--$j]; //#2950
                $k[$j++] = $geti(_Px, _Pw, $f(_Px.length - _Pw)); //#2950
            } //#2950
        } //#2950
        $1.couponexpire = -1; //#2955
        var _Pz = $k[--$j]; //#2956
        $k[$j++] = _Pz; //#2974
        if (_Pz.length >= 1) { //#2974
            var _Q0 = $k[--$j]; //#2956
            $k[$j++] = _Q0; //#2974
            if ($cvi($geti(_Q0, 0, 1)) == 3) { //#2974
                var _Q2 = $k[--$j]; //#2957
                var _Q3 = $geti(_Q2, 1, _Q2.length - 1); //#2957
                $k[$j++] = _Q3; //#2962
                if (_Q3.length < 6) { //#2962
                    $j -= 2; //#2961
                    $k[$j++] = 'bwipp.GS1couponTooShortExpirationDate'; //#2961
                    $k[$j++] = "Coupon too short: Expiration date"; //#2961
                    $k[$j++] = false; //#2961
                    return true; //#2961
                } //#2961
                var _Q4 = $k[--$j]; //#2963
                var _Q6 = $cvi($geti(_Q4, 2, 2)); //#2963
                $k[$j++] = _Q4; //#2963
                if ((_Q6 < 1) || (_Q6 > 12)) { //#2963
                    $j -= 2; //#2963
                    $k[$j++] = 'bwipp.GS1couponExpirationDateBadMonth'; //#2963
                    $k[$j++] = "Invalid month in expiration date"; //#2963
                    $k[$j++] = false; //#2963
                    return true; //#2963
                } //#2963
                var _Q7 = $k[--$j]; //#2964
                var _Q9 = $cvi($geti(_Q7, 0, 2)); //#2964
                var _QA = _Q9 - 21; //#2965
                $k[$j++] = _Q7; //#2965
                $k[$j++] = _Q9; //#2965
                $k[$j++] = _QA; //#2965
                if (_QA >= 51) { //#2965
                    $j--; //#2965
                    var _QB = $k[--$j]; //#2965
                    $k[$j++] = $f(_QB + 1900); //#2965
                } else { //#2965
                    if ($k[--$j] <= -50) { //#2965
                        var _QD = $k[--$j]; //#2965
                        $k[$j++] = $f(_QD + 2100); //#2965
                    } else { //#2965
                        var _QE = $k[--$j]; //#2965
                        $k[$j++] = $f(_QE + 2000); //#2965
                    } //#2965
                } //#2965
                var _QF = $k[--$j]; //#2966
                $k[$j++] = ((_QF % 400) == 0) || (((_QF % 4) == 0) && ((_QF % 100) != 0)); //#2967
                $k[$j++] = Infinity; //#2967
                var _QG = $k[--$j]; //#2967
                var _QI = $k[--$j] ? 29 : 28; //#2967
                $k[$j++] = _QG; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = _QI; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = 30; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = 30; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = 30; //#2967
                $k[$j++] = 31; //#2967
                $k[$j++] = 30; //#2967
                $k[$j++] = 31; //#2967
                var _QJ = $a(); //#2967
                var _QK = $k[--$j]; //#2968
                var _QO = $cvi($geti(_QK, 4, 2)); //#2969
                $k[$j++] = _QK; //#2970
                if (($get(_QJ, $cvi($geti(_QK, 2, 2)) - 1) < _QO) || (_QO < 1)) { //#2970
                    $j -= 2; //#2970
                    $k[$j++] = 'bwipp.GS1couponExpirationDateBadDay'; //#2970
                    $k[$j++] = "Invalid day of month in expiration date"; //#2970
                    $k[$j++] = false; //#2970
                    return true; //#2970
                } //#2970
                var _QP = $k[--$j]; //#2971
                $1.couponexpire = $cvi($geti(_QP, 0, 6)); //#2971
                $k[$j++] = $geti(_QP, 6, _QP.length - 6); //#2972
            } //#2972
        } //#2972
        var _QS = $k[--$j]; //#2977
        $k[$j++] = _QS; //#2998
        if (_QS.length >= 1) { //#2998
            var _QT = $k[--$j]; //#2977
            $k[$j++] = _QT; //#2998
            if ($cvi($geti(_QT, 0, 1)) == 4) { //#2998
                var _QV = $k[--$j]; //#2978
                var _QW = $geti(_QV, 1, _QV.length - 1); //#2978
                $k[$j++] = _QW; //#2983
                if (_QW.length < 6) { //#2983
                    $j -= 2; //#2982
                    $k[$j++] = 'bwipp.GS1couponTooShortStartDate'; //#2982
                    $k[$j++] = "Coupon too short: Start date"; //#2982
                    $k[$j++] = false; //#2982
                    return true; //#2982
                } //#2982
                var _QX = $k[--$j]; //#2984
                var _QZ = $cvi($geti(_QX, 2, 2)); //#2984
                $k[$j++] = _QX; //#2984
                if ((_QZ < 1) || (_QZ > 12)) { //#2984
                    $j -= 2; //#2984
                    $k[$j++] = 'bwipp.GS1couponStartDateBadMonth'; //#2984
                    $k[$j++] = "Invalid month in start date"; //#2984
                    $k[$j++] = false; //#2984
                    return true; //#2984
                } //#2984
                var _Qa = $k[--$j]; //#2985
                var _Qc = $cvi($geti(_Qa, 0, 2)); //#2985
                var _Qd = _Qc - 21; //#2986
                $k[$j++] = _Qa; //#2986
                $k[$j++] = _Qc; //#2986
                $k[$j++] = _Qd; //#2986
                if (_Qd >= 51) { //#2986
                    $j--; //#2986
                    var _Qe = $k[--$j]; //#2986
                    $k[$j++] = $f(_Qe + 1900); //#2986
                } else { //#2986
                    if ($k[--$j] <= -50) { //#2986
                        var _Qg = $k[--$j]; //#2986
                        $k[$j++] = $f(_Qg + 2100); //#2986
                    } else { //#2986
                        var _Qh = $k[--$j]; //#2986
                        $k[$j++] = $f(_Qh + 2000); //#2986
                    } //#2986
                } //#2986
                var _Qi = $k[--$j]; //#2987
                $k[$j++] = ((_Qi % 400) == 0) || (((_Qi % 4) == 0) && ((_Qi % 100) != 0)); //#2988
                $k[$j++] = Infinity; //#2988
                var _Qj = $k[--$j]; //#2988
                var _Ql = $k[--$j] ? 29 : 28; //#2988
                $k[$j++] = _Qj; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = _Ql; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = 30; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = 30; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = 30; //#2988
                $k[$j++] = 31; //#2988
                $k[$j++] = 30; //#2988
                $k[$j++] = 31; //#2988
                var _Qm = $a(); //#2988
                var _Qn = $k[--$j]; //#2989
                var _Qr = $cvi($geti(_Qn, 4, 2)); //#2990
                $k[$j++] = _Qn; //#2991
                if (($get(_Qm, $cvi($geti(_Qn, 2, 2)) - 1) < _Qr) || (_Qr < 1)) { //#2991
                    $j -= 2; //#2991
                    $k[$j++] = 'bwipp.GS1couponStartDateBadDay'; //#2991
                    $k[$j++] = "Invalid day of month in start date"; //#2991
                    $k[$j++] = false; //#2991
                    return true; //#2991
                } //#2991
                var _Qs = $k[--$j]; //#2992
                $1.couponstart = $cvi($geti(_Qs, 0, 6)); //#2992
                $k[$j++] = _Qs; //#2995
                if (($1.couponexpire != -1) && ($1.couponexpire < $1.couponstart)) { //#2995
                    $j -= 2; //#2994
                    $k[$j++] = 'bwipp.GS1couponExpireDateBeforeStartDate'; //#2994
                    $k[$j++] = "Coupon expires before it starts"; //#2994
                    $k[$j++] = false; //#2994
                    return true; //#2994
                } //#2994
                var _Qx = $k[--$j]; //#2996
                $k[$j++] = $geti(_Qx, 6, _Qx.length - 6); //#2996
            } //#2996
        } //#2996
        var _Qz = $k[--$j]; //#3001
        $k[$j++] = _Qz; //#3014
        if (_Qz.length >= 1) { //#3014
            var _R0 = $k[--$j]; //#3001
            $k[$j++] = _R0; //#3014
            if ($cvi($geti(_R0, 0, 1)) == 5) { //#3014
                var _R2 = $k[--$j]; //#3002
                var _R3 = $geti(_R2, 1, _R2.length - 1); //#3002
                $k[$j++] = _R3; //#3007
                if (_R3.length < 1) { //#3007
                    $j -= 2; //#3006
                    $k[$j++] = 'bwipp.GS1couponTooShortSerialNumberVLI'; //#3006
                    $k[$j++] = "Coupon too short: Missing Serial Number VLI"; //#3006
                    $k[$j++] = false; //#3006
                    return true; //#3006
                } //#3006
                var _R4 = $k[--$j]; //#3008
                var _R5 = $geti(_R4, 0, 1); //#3008
                $k[$j++] = _R4; //#3011
                $k[$j++] = ($cvi(_R5) + 6) + 1; //#3011
                if ((($cvi(_R5) + 6) + 1) > _R4.length) { //#3011
                    $j -= 3; //#3010
                    $k[$j++] = 'bwipp.GS1couponTooShortSerialNumber'; //#3010
                    $k[$j++] = "Coupon too short: Serial Number truncated"; //#3010
                    $k[$j++] = false; //#3010
                    return true; //#3010
                } //#3010
                var _R6 = $k[--$j]; //#3012
                var _R7 = $k[--$j]; //#3012
                $k[$j++] = $geti(_R7, _R6, $f(_R7.length - _R6)); //#3012
            } //#3012
        } //#3012
        var _R9 = $k[--$j]; //#3017
        $k[$j++] = _R9; //#3033
        if (_R9.length >= 1) { //#3033
            var _RA = $k[--$j]; //#3017
            $k[$j++] = _RA; //#3033
            if ($cvi($geti(_RA, 0, 1)) == 6) { //#3033
                var _RC = $k[--$j]; //#3018
                var _RD = $geti(_RC, 1, _RC.length - 1); //#3018
                $k[$j++] = _RD; //#3023
                if (_RD.length < 1) { //#3023
                    $j -= 2; //#3022
                    $k[$j++] = 'bwipp.GS1couponTooShortRetailerGCPGLNVLI'; //#3022
                    $k[$j++] = "Coupon too short: Missing Retailer GCP/GLN VLI"; //#3022
                    $k[$j++] = false; //#3022
                    return true; //#3022
                } //#3022
                var _RE = $k[--$j]; //#3024
                var _RG = $cvi($geti(_RE, 0, 1)); //#3024
                $k[$j++] = _RE; //#3026
                $k[$j++] = _RG; //#3026
                if ((_RG < 1) || (_RG > 7)) { //#3026
                    $j -= 2; //#3025
                    $k[$j++] = 'bwipp.GS1couponBadRetailerGCPGLNVLI'; //#3025
                    $k[$j++] = "Coupon Retailer GCP/GLN length indicator must be 1-7"; //#3025
                    $k[$j++] = false; //#3025
                    return true; //#3025
                } //#3025
                var _RH = $k[--$j]; //#3027
                var _RI = $k[--$j]; //#3028
                $k[$j++] = _RI; //#3030
                $k[$j++] = $f($f(_RH + 6) + 1); //#3030
                if (($f($f(_RH + 6) + 1)) > _RI.length) { //#3030
                    $j -= 3; //#3029
                    $k[$j++] = 'bwipp.GS1couponTooShortRetailerGCPGLN'; //#3029
                    $k[$j++] = "Coupon too short: Retailer GCP/GLN truncated"; //#3029
                    $k[$j++] = false; //#3029
                    return true; //#3029
                } //#3029
                var _RJ = $k[--$j]; //#3031
                var _RK = $k[--$j]; //#3031
                $k[$j++] = $geti(_RK, _RJ, $f(_RK.length - _RJ)); //#3031
            } //#3031
        } //#3031
        var _RM = $k[--$j]; //#3036
        $k[$j++] = _RM; //#3072
        if (_RM.length >= 1) { //#3072
            var _RN = $k[--$j]; //#3036
            $k[$j++] = _RN; //#3072
            if ($cvi($geti(_RN, 0, 1)) == 9) { //#3072
                var _RP = $k[--$j]; //#3037
                var _RQ = $geti(_RP, 1, _RP.length - 1); //#3037
                $k[$j++] = _RQ; //#3042
                if (_RQ.length < 1) { //#3042
                    $j -= 2; //#3041
                    $k[$j++] = 'bwipp.GS1couponTooShortSaveValueCode'; //#3041
                    $k[$j++] = "Coupon too short: Missing Save Value Code"; //#3041
                    $k[$j++] = false; //#3041
                    return true; //#3041
                } //#3041
                var _RR = $k[--$j]; //#3043
                var _RT = $cvi($geti(_RR, 0, 1)); //#3043
                $k[$j++] = _RR; //#3045
                if ((_RT > 6) || ((_RT == 3) || (_RT == 4))) { //#3045
                    $j -= 2; //#3044
                    $k[$j++] = 'bwipp.GS1couponBadSaveValueCode'; //#3044
                    $k[$j++] = "Coupon Save Value Code must be 0,1,2,5 or 6"; //#3044
                    $k[$j++] = false; //#3044
                    return true; //#3044
                } //#3044
                var _RU = $k[--$j]; //#3046
                var _RV = $geti(_RU, 1, _RU.length - 1); //#3046
                $k[$j++] = _RV; //#3051
                if (_RV.length < 1) { //#3051
                    $j -= 2; //#3050
                    $k[$j++] = 'bwipp.GS1couponTooShortSaveValueAppliesToItem'; //#3050
                    $k[$j++] = "Coupon too short: Missing Save Value Applies to Item"; //#3050
                    $k[$j++] = false; //#3050
                    return true; //#3050
                } //#3050
                var _RW = $k[--$j]; //#3052
                $k[$j++] = _RW; //#3054
                if ($cvi($geti(_RW, 0, 1)) > 2) { //#3054
                    $j -= 2; //#3053
                    $k[$j++] = 'bwipp.GS1couponBadSaveValueAppliesToItem'; //#3053
                    $k[$j++] = "Coupon Save Value Applies to Item must be 0-2"; //#3053
                    $k[$j++] = false; //#3053
                    return true; //#3053
                } //#3053
                var _RY = $k[--$j]; //#3055
                var _RZ = $geti(_RY, 1, _RY.length - 1); //#3055
                $k[$j++] = _RZ; //#3060
                if (_RZ.length < 1) { //#3060
                    $j -= 2; //#3059
                    $k[$j++] = 'bwipp.GS1couponTooShortStoreCouponFlag'; //#3059
                    $k[$j++] = "Coupon too short: Missing Store Coupon Flag"; //#3059
                    $k[$j++] = false; //#3059
                    return true; //#3059
                } //#3059
                var _Ra = $k[--$j]; //#3061
                var _Rb = $geti(_Ra, 1, _Ra.length - 1); //#3061
                $k[$j++] = _Rb; //#3066
                if (_Rb.length < 1) { //#3066
                    $j -= 2; //#3065
                    $k[$j++] = 'bwipp.GS1couponTooShortDontMultiplyFlag'; //#3065
                    $k[$j++] = "Coupon too short: Missing Don't Multiply Flag"; //#3065
                    $k[$j++] = false; //#3065
                    return true; //#3065
                } //#3065
                var _Rc = $k[--$j]; //#3067
                $k[$j++] = _Rc; //#3069
                if ($cvi($geti(_Rc, 0, 1)) > 1) { //#3069
                    $j -= 2; //#3068
                    $k[$j++] = 'bwipp.GS1couponBadDontMultiplyFlag'; //#3068
                    $k[$j++] = "Don't Multiply Flag must be 0 or 1"; //#3068
                    $k[$j++] = false; //#3068
                    return true; //#3068
                } //#3068
                var _Re = $k[--$j]; //#3070
                $k[$j++] = $geti(_Re, 1, _Re.length - 1); //#3070
            } //#3070
        } //#3070
        var _Rg = $k[--$j]; //#3074
        $k[$j++] = _Rg; //#3076
        if (_Rg.length != 0) { //#3076
            $j -= 2; //#3075
            $k[$j++] = 'bwipp.GS1couponUnrecognisedOptionalField'; //#3075
            $k[$j++] = "Coupon fields must be 1,2,3,4,5,6 or 9, increasing order"; //#3075
            $k[$j++] = false; //#3075
            return true; //#3075
        } //#3075
        $j--; //#3077
    }; //#3077
    $1.lintcouponposoffer = function() {
        var _Rh = $k[--$j]; //#3081
        $k[$j++] = _Rh; //#3083
        $k[$j++] = true; //#3083
        $forall(_Rh, function() { //#3083
            var _Ri = $k[--$j]; //#3082
            if ((_Ri < 48) || (_Ri > 57)) { //#3082
                $j--; //#3082
                $k[$j++] = false; //#3082
                return true; //#3082
            } //#3082
        }); //#3082
        if ($nt($k[--$j])) { //#3084
            $j -= 2; //#3084
            $k[$j++] = 'bwipp.GS1couponNotNumeric'; //#3084
            $k[$j++] = "Coupon not numeric"; //#3084
            $k[$j++] = false; //#3084
            return true; //#3084
        } //#3084
        var _Rk = $k[--$j]; //#3086
        $k[$j++] = _Rk; //#3088
        if (_Rk.length < 1) { //#3088
            $j -= 2; //#3087
            $k[$j++] = 'bwipp.GS1couponTooShortFormatCode'; //#3087
            $k[$j++] = "Coupon too short: Missing Format Code"; //#3087
            $k[$j++] = false; //#3087
            return true; //#3087
        } //#3087
        var _Rl = $k[--$j]; //#3089
        var _Rm = $geti(_Rl, 0, 1); //#3089
        $k[$j++] = _Rl; //#3091
        if ($ne(_Rm, "0") && $ne(_Rm, "1")) { //#3091
            $j -= 2; //#3090
            $k[$j++] = 'bwipp.GS1couponBadFormatCode'; //#3090
            $k[$j++] = "Coupon format must be 0 or 1"; //#3090
            $k[$j++] = false; //#3090
            return true; //#3090
        } //#3090
        var _Rn = $k[--$j]; //#3092
        var _Ro = $geti(_Rn, 1, _Rn.length - 1); //#3092
        $k[$j++] = _Ro; //#3096
        if (_Ro.length < 1) { //#3096
            $j -= 2; //#3095
            $k[$j++] = 'bwipp.GS1couponTooShortFunderVLI'; //#3095
            $k[$j++] = "Coupon too short: Missing Funder VLI"; //#3095
            $k[$j++] = false; //#3095
            return true; //#3095
        } //#3095
        var _Rp = $k[--$j]; //#3097
        var _Rr = $cvi($geti(_Rp, 0, 1)); //#3097
        $k[$j++] = _Rp; //#3099
        $k[$j++] = _Rr; //#3099
        if (_Rr > 6) { //#3099
            $j -= 3; //#3098
            $k[$j++] = 'bwipp.GS1couponBadFunderVLI'; //#3098
            $k[$j++] = "Coupon Funder length indicator must be 0-6"; //#3098
            $k[$j++] = false; //#3098
            return true; //#3098
        } //#3098
        var _Rs = $k[--$j]; //#3100
        var _Rt = $k[--$j]; //#3101
        $k[$j++] = _Rt; //#3103
        $k[$j++] = $f($f(_Rs + 6) + 1); //#3103
        if (($f($f(_Rs + 6) + 1)) > _Rt.length) { //#3103
            $j -= 3; //#3102
            $k[$j++] = 'bwipp.GS1couponTooShortFunder'; //#3102
            $k[$j++] = "Coupon too short: Truncated Funder ID"; //#3102
            $k[$j++] = false; //#3102
            return true; //#3102
        } //#3102
        var _Ru = $k[--$j]; //#3104
        var _Rv = $k[--$j]; //#3104
        var _Rw = $geti(_Rv, _Ru, $f(_Rv.length - _Ru)); //#3104
        $k[$j++] = _Rw; //#3108
        if (_Rw.length < 6) { //#3108
            $j -= 2; //#3107
            $k[$j++] = 'bwipp.GS1couponTooShortOfferCode'; //#3107
            $k[$j++] = "Coupon too short: Truncated Offer Code"; //#3107
            $k[$j++] = false; //#3107
            return true; //#3107
        } //#3107
        var _Rx = $k[--$j]; //#3109
        var _Ry = $geti(_Rx, 6, _Rx.length - 6); //#3109
        $k[$j++] = _Ry; //#3113
        if (_Ry.length < 1) { //#3113
            $j -= 2; //#3112
            $k[$j++] = 'bwipp.GS1couponTooShortSnVLI'; //#3112
            $k[$j++] = "Coupon too short: Missing SN VLI"; //#3112
            $k[$j++] = false; //#3112
            return true; //#3112
        } //#3112
        var _Rz = $k[--$j]; //#3114
        var _S0 = $geti(_Rz, 0, 1); //#3114
        $k[$j++] = _Rz; //#3118
        $k[$j++] = ($cvi(_S0) + 6) + 1; //#3118
        if ((($cvi(_S0) + 6) + 1) > _Rz.length) { //#3118
            $j -= 3; //#3117
            $k[$j++] = 'bwipp.GS1couponTooShortSn'; //#3117
            $k[$j++] = "Coupon too short: Truncated SN"; //#3117
            $k[$j++] = false; //#3117
            return true; //#3117
        } //#3117
        var _S1 = $k[--$j]; //#3119
        var _S2 = $k[--$j]; //#3119
        var _S3 = $geti(_S2, _S1, $f(_S2.length - _S1)); //#3119
        $k[$j++] = _S3; //#3122
        if (_S3.length != 0) { //#3122
            $j -= 2; //#3121
            $k[$j++] = 'bwipp.GS1couponTooLong'; //#3121
            $k[$j++] = "Coupon too long"; //#3121
            $k[$j++] = false; //#3121
            return true; //#3121
        } //#3121
        $j--; //#3123
    }; //#3123
    $1.lintlatlong = function() {
        var _S4 = $k[--$j]; //#3127
        $k[$j++] = _S4; //#3129
        if (_S4.length != 20) { //#3129
            $j--; //#3128
            $k[$j++] = 'bwipp.GS1badGeoLength'; //#3128
            $k[$j++] = "Invalid length for a geo-location"; //#3128
            $k[$j++] = false; //#3128
            return true; //#3128
        } //#3128
        var _S5 = $k[--$j]; //#3130
        $k[$j++] = _S5; //#3130
        if ($cvi($geti(_S5, 0, 10)) > 1800000000) { //#3130
            $j--; //#3130
            $k[$j++] = 'bwipp.GS1badLatitude'; //#3130
            $k[$j++] = "Invalid value for latitude"; //#3130
            $k[$j++] = false; //#3130
            return true; //#3130
        } //#3130
        var _S7 = $k[--$j]; //#3131
        $k[$j++] = _S7; //#3131
        if ($cvi($geti(_S7, 10, 10)) > 3600000000) { //#3131
            $j--; //#3131
            $k[$j++] = 'bwipp.GS1badLongitude'; //#3131
            $k[$j++] = "Invalid value for longitude"; //#3131
            $k[$j++] = false; //#3131
            return true; //#3131
        } //#3131
        $j--; //#3132
    }; //#3132
    if (!$1.dontlint) { //#3269
        $k[$j++] = true; //#3175
        for (var _SC = 0, _SB = $1.vals.length - 1; _SC <= _SB; _SC += 1) { //#3175
            $1.ai = $get($1.ais, _SC); //#3140
            $1.val = $get($1.vals, _SC); //#3141
            var _SJ = $get($1.gs1syntax, $1.ai) !== undefined; //#3142
            if (_SJ) { //#3173
                var _SN = $get($get($1.gs1syntax, $1.ai), 'parts'); //#3143
                $k[$j++] = _SN; //#3145
                $k[$j++] = 0; //#3145
                $forall(_SN, function() { //#3145
                    var _SO = $k[--$j]; //#3145
                    $k[$j++] = _SO; //#3145
                    if ($get(_SO, 'opt')) { //#3145
                        $j--; //#3145
                        $k[$j++] = 0; //#3145
                    } else { //#3145
                        var _SR = $get($k[--$j], 'min'); //#3145
                        $k[$j++] = _SR; //#3145
                    } //#3145
                    var _SS = $k[--$j]; //#3145
                    var _ST = $k[--$j]; //#3145
                    $k[$j++] = $f(_ST + _SS); //#3145
                }); //#3145
                if ($k[--$j] > $1.val.length) { //#3147
                    $j--; //#3146
                    $k[$j++] = 'bwipp.GS1valueTooShort'; //#3146
                    $k[$j++] = "Too short"; //#3146
                    $k[$j++] = false; //#3146
                    break; //#3146
                } //#3146
                var _SW = $k[--$j]; //#3148
                $k[$j++] = _SW; //#3148
                $k[$j++] = 0; //#3148
                $forall(_SW, function() { //#3148
                    var _SY = $get($k[--$j], 'max'); //#3148
                    var _SZ = $k[--$j]; //#3148
                    $k[$j++] = $f(_SZ + _SY); //#3148
                }); //#3148
                if ($k[--$j] < $1.val.length) { //#3150
                    $j--; //#3149
                    $k[$j++] = 'bwipp.GS1valueTooLong'; //#3149
                    $k[$j++] = "Too long"; //#3149
                    $k[$j++] = false; //#3149
                    break; //#3149
                } //#3149
                $forall($k[--$j], function() { //#3167
                    $1.props = $k[--$j]; //#3152
                    var _Sf = $get($1.props, 'max'); //#3153
                    var _Sg = $1.val; //#3153
                    var _Sh = _Sg.length; //#3153
                    if (_Sf > _Sg.length) { //#3153
                        var _ = _Sh; //#3153
                        _Sh = _Sf; //#3153
                        _Sf = _; //#3153
                    } //#3153
                    $1.eval = $geti($1.val, 0, _Sf); //#3154
                    var _Sm = $1.eval.length; //#3155
                    $1.val = $geti($1.val, _Sm, $1.val.length - _Sm); //#3155
                    if ($1.eval.length == 0) { //#3165
                        if ($nt($get($1.props, 'opt'))) { //#3159
                            $j--; //#3158
                            $k[$j++] = 'bwipp.GS1valueTooShort'; //#3158
                            $k[$j++] = "Too short"; //#3158
                            $k[$j++] = false; //#3158
                            return true; //#3158
                        } //#3158
                    } else { //#3165
                        if ($1.eval.length < $get($1.props, 'min')) { //#3163
                            $j--; //#3162
                            $k[$j++] = 'bwipp.GS1valueTooShort'; //#3162
                            $k[$j++] = "Too short"; //#3162
                            $k[$j++] = false; //#3162
                            return true; //#3162
                        } //#3162
                        var _Sv = new Map([
                            ["N", 'lintnumeric'],
                            ["X", 'lintcset82'],
                            ["Y", 'lintcset39']
                        ]); //#3164
                        $k[$j++] = $1.eval; //#3164
                        if ($1[$get(_Sv, $get($1.props, 'cset'))]() === true) {
                            return true;
                        } //#3164
                        $forall($get($1.props, 'linters'), function() { //#3165
                            var _T5 = $1[$k[--$j]]; //#3165
                            $k[$j++] = $1.eval; //#3165
                            if (_T5() === true) {
                                return true;
                            } //#3165
                        }); //#3165
                    } //#3165
                }); //#3165
                var _T6 = $k[--$j]; //#3168
                $k[$j++] = _T6; //#3168
                if ($nt(_T6)) { //#3168
                    break; //#3168
                } //#3168
                if ($1.val.length != 0) { //#3171
                    $j--; //#3170
                    $k[$j++] = 'bwipp.GS1valueTooLong'; //#3170
                    $k[$j++] = "Too long"; //#3170
                    $k[$j++] = false; //#3170
                    break; //#3170
                } //#3170
            } else { //#3173
                $j--; //#3173
                $k[$j++] = 'bwipp.GS1unknownAI'; //#3173
                $k[$j++] = "Unrecognised AI"; //#3173
                $k[$j++] = false; //#3173
                break; //#3173
            } //#3173
        } //#3173
        if ($nt($k[--$j])) { //#3183
            var _T9 = $k[--$j]; //#3177
            var _TB = $s((_T9.length + $1.ai.length) + 5); //#3177
            $puti(_TB, 0, "AI "); //#3178
            $puti(_TB, 3, $1.ai); //#3179
            $puti(_TB, 3 + $1.ai.length, ": "); //#3180
            $puti(_TB, 5 + $1.ai.length, _T9); //#3181
            $k[$j++] = _TB; //#3182
            bwipp_raiseerror(); //#3182
        } //#3182
        $1.aiexists = function() {
            $1.this = $k[--$j]; //#3187
            $1.patt = $k[--$j]; //#3188
            for (var _TH = 0, _TI = 1; _TH < _TI; _TH++) { //#3209
                var _TL = $get($1.aivals, $1.patt) !== undefined; //#3190
                if (_TL) { //#3190
                    $k[$j++] = true; //#3190
                    break; //#3190
                } //#3190
                if ($1.patt.length == 4) { //#3207
                    if ($eq($geti($1.patt, 3, 1), "n")) { //#3205
                        var _TR = $eq($geti($1.patt, 2, 1), "n") ? 2 : 3; //#3193
                        $1.pfxlen = _TR; //#3193
                        var _TS = $1.ais; //#3195
                        $k[$j++] = false; //#3203
                        for (var _TT = 0, _TU = _TS.length; _TT < _TU; _TT++) { //#3203
                            var _TV = $get(_TS, _TT); //#3203
                            $k[$j++] = _TV; //#3202
                            if ($ne(_TV, $1.this) && (_TV.length == 4)) { //#3201
                                if ($eq($geti($k[--$j], 0, $1.pfxlen), $geti($1.patt, 0, $1.pfxlen))) { //#3199
                                    $j--; //#3198
                                    $k[$j++] = true; //#3198
                                } //#3198
                            } else { //#3201
                                $j--; //#3201
                            } //#3201
                        } //#3201
                        break; //#3204
                    } //#3204
                    $k[$j++] = false; //#3206
                    break; //#3206
                } //#3206
                $k[$j++] = false; //#3208
                break; //#3208
            } //#3208
        }; //#3208
        var _Td = $1.vals; //#3213
        $1.aivals = new Map; //#3213
        for (var _Tg = 0, _Tf = $1.vals.length - 1; _Tg <= _Tf; _Tg += 1) { //#3228
            $1.ai = $get($1.ais, _Tg); //#3215
            $1.val = $get($1.vals, _Tg); //#3216
            var _Tn = $get($1.aivals, $1.ai) !== undefined; //#3217
            if (_Tn) { //#3226
                if ($ne($get($1.aivals, $1.ai), $1.val)) { //#3224
                    var _Tt = $s($1.ai.length + 40); //#3219
                    $puti(_Tt, 0, "Repeated AIs ("); //#3220
                    $puti(_Tt, 14, $1.ai); //#3221
                    $puti(_Tt, 14 + $1.ai.length, ") must have the same value"); //#3222
                    $k[$j++] = 'bwipp.GS1repeatedDifferingAIs'; //#3223
                    $k[$j++] = _Tt; //#3223
                    bwipp_raiseerror(); //#3223
                } //#3223
            } else { //#3226
                $put($1.aivals, $1.ai, $1.val); //#3226
            } //#3226
        } //#3226
        for (var _U1 = 0, _U0 = $1.vals.length - 1; _U1 <= _U0; _U1 += 1) { //#3267
            $1.ai = $get($1.ais, _U1); //#3232
            var _U6 = $get($1.gs1syntax, $1.ai); //#3233
            var _U7 = $get(_U6, 'ex') !== undefined; //#3233
            $k[$j++] = _U6; //#3248
            $k[$j++] = 'ex'; //#3248
            if (_U7) { //#3247
                var _U8 = $k[--$j]; //#3234
                $forall($get($k[--$j], _U8), function() { //#3245
                    $1.patt = $k[--$j]; //#3235
                    $k[$j++] = $1.patt; //#3236
                    $k[$j++] = $1.ai; //#3236
                    $1.aiexists(); //#3236
                    if ($k[--$j]) { //#3244
                        var _UH = $s(($1.ai.length + $1.patt.length) + 36); //#3237
                        $puti(_UH, 0, "AIs ("); //#3238
                        $puti(_UH, 5, $1.ai); //#3239
                        $puti(_UH, 5 + $1.ai.length, ") and ("); //#3240
                        $puti(_UH, 12 + $1.ai.length, $1.patt); //#3241
                        $puti(_UH, (12 + $1.ai.length) + $1.patt.length, ") are mutually exclusive"); //#3242
                        $k[$j++] = 'bwipp.GS1exclusiveAIs'; //#3243
                        $k[$j++] = _UH; //#3243
                        bwipp_raiseerror(); //#3243
                    } //#3243
                }); //#3243
            } else { //#3247
                $j -= 2; //#3247
            } //#3247
            if ($1.lintreqs) { //#3266
                var _UR = $get($1.gs1syntax, $1.ai); //#3250
                var _US = $get(_UR, 'req') !== undefined; //#3250
                $k[$j++] = _UR; //#3265
                $k[$j++] = 'req'; //#3265
                if (_US) { //#3264
                    var _UT = $k[--$j]; //#3251
                    $forall($get($k[--$j], _UT), function() { //#3262
                        var _UW = $k[--$j]; //#3252
                        $k[$j++] = false; //#3254
                        $forall(_UW, function() { //#3254
                            $k[$j++] = $1.ai; //#3253
                            $1.aiexists(); //#3253
                            if ($k[--$j]) { //#3253
                                $j--; //#3253
                                $k[$j++] = true; //#3253
                            } //#3253
                        }); //#3253
                        if ($nt($k[--$j])) { //#3261
                            var _Ub = $s($1.ai.length + 47); //#3256
                            $puti(_Ub, 0, "One of more requisite AIs for AI ("); //#3257
                            $puti(_Ub, 34, $1.ai); //#3258
                            $puti(_Ub, 34 + $1.ai.length, ") are missing"); //#3259
                            $k[$j++] = 'bwipp.GS1missingAIs'; //#3260
                            $k[$j++] = _Ub; //#3260
                            bwipp_raiseerror(); //#3260
                        } //#3260
                    }); //#3260
                } else { //#3264
                    $j -= 2; //#3264
                } //#3264
            } //#3264
        } //#3264
    } //#3264
    $k[$j++] = $1.ais; //#3275
    $k[$j++] = $1.vals; //#3275
    $k[$j++] = $1.fncs; //#3275
}

function bwipp_renmatrix() {
    if ($0.bwipjs_dontdraw) { //#3521
        return; //#3521
    } //#3521
    var $1 = {}; //#3523
    $1.width = 1; //#3526
    $1.height = 1; //#3527
    $1.barcolor = "unset"; //#3528
    $1.backgroundcolor = "unset"; //#3529
    $1.colormap = "unset"; //#3530
    $1.dotty = false; //#3531
    $1.inkspread = 0; //#3532
    $1.inkspreadh = 0; //#3533
    $1.inkspreadv = 0; //#3534
    $1.includetext = false; //#3535
    $1.txt = $a([]); //#3536
    $1.textcolor = "unset"; //#3537
    $1.textxalign = "unset"; //#3538
    $1.textyalign = "unset"; //#3539
    $1.textfont = "OCR-B"; //#3540
    $1.textsize = 10; //#3541
    $1.textxoffset = 0; //#3542
    $1.textyoffset = 0; //#3543
    $1.textgaps = 0; //#3544
    $1.alttext = ""; //#3545
    $forall($k[--$j], function() { //#3547
        var _3 = $k[--$j]; //#3547
        $1[$k[--$j]] = _3; //#3547
    }); //#3547
    $k[$j++] = $1.opt; //#3548
    delete $1['opt']; //#3548
    $k[$j++] = $1; //#3548
    bwipp_processoptions(); //#3548
    $j--; //#3548
    if ($1.inkspread != 0) { //#3550
        $1.inkspreadh = $1.inkspread; //#3550
    } //#3550
    if ($1.inkspread != 0) { //#3551
        $1.inkspreadv = $1.inkspread; //#3551
    } //#3551
    $1.xyget = function() {
        var _B = $k[--$j]; //#3553
        var _E = $get($1.pixs, $f($k[--$j] + (_B * $1.pixx))); //#3553
        $k[$j++] = _E; //#3553
    }; //#3553
    $1.cget = function() {
        var _G = $k[--$j]; //#3554
        var _J = $get($1.cache, $f($k[--$j] + (_G * $1.pixx))); //#3554
        var _K = $k[--$j]; //#3554
        $k[$j++] = $an(_K, _J); //#3554
    }; //#3554
    $1.cput = function() {
        var _L = $k[--$j]; //#3556
        $k[$j++] = _L; //#3560
        if ((_L % 4) == 0) { //#3559
            var _M = $k[--$j]; //#3557
            var _N = $k[--$j]; //#3557
            var _O = $k[--$j]; //#3557
            var _P = $1.pixx; //#3557
            var _Q = $1.cache; //#3557
            $put(_Q, $f(_O + (_N * _P)), $or($get(_Q, $f(_O + (_N * _P))), _M)); //#3557
        } else { //#3559
            $j -= 3; //#3559
        } //#3559
    }; //#3559
    $1.abcd = function() {
        $k[$j++] = $s(4); //#3568
        $k[$j++] = 0; //#3568
        $k[$j++] = Infinity; //#3568
        var _T = $k[--$j]; //#3565
        var _U = $k[--$j]; //#3565
        var _V = $k[--$j]; //#3565
        var _W = $k[--$j]; //#3565
        var _Z = $f($k[--$j] + (_W * $1.pixx)); //#3566
        $k[$j++] = _V; //#3567
        $k[$j++] = _U; //#3567
        $k[$j++] = _T; //#3567
        $k[$j++] = _Z; //#3567
        $aload($geti($1.pixs, _Z, 2)); //#3567
        var _c = $k[--$j]; //#3567
        var _d = $k[--$j]; //#3567
        var _h = $geti($1.pixs, $f($k[--$j] + $1.pixx), 2); //#3568
        $k[$j++] = _d; //#3568
        $k[$j++] = _c; //#3568
        $aload(_h); //#3568
        var _i = $a(); //#3568
        for (var _j = 0, _k = _i.length; _j < _k; _j++) { //#3569
            var _m = $k[--$j]; //#3569
            var _n = $k[--$j]; //#3569
            $put(_n, _m, $f($get(_i, _j) + 48)); //#3569
            $k[$j++] = _n; //#3569
            $k[$j++] = $f(_m + 1); //#3569
        } //#3569
        $j--; //#3569
    }; //#3569
    $1.right = function() {
        if ($1.dir != 1) { //#3572
            $k[$j++] = $1.x; //#3572
            $k[$j++] = $1.y; //#3572
            $k[$j++] = $1.dir; //#3572
            $1.cput(); //#3572
            $k[$j++] = $a([$1.x, $1.y]); //#3572
        } //#3572
        $1.x = $1.x + 1; //#3572
        $1.dir = 1; //#3572
    }; //#3572
    $1.down = function() {
        if ($1.dir != 2) { //#3573
            $k[$j++] = $1.x; //#3573
            $k[$j++] = $1.y; //#3573
            $k[$j++] = $1.dir; //#3573
            $1.cput(); //#3573
            $k[$j++] = $a([$1.x, $1.y]); //#3573
        } //#3573
        $1.y = $1.y + 1; //#3573
        $1.dir = 2; //#3573
    }; //#3573
    $1.left = function() {
        if ($1.dir != 4) { //#3574
            $k[$j++] = $1.x; //#3574
            $k[$j++] = $1.y; //#3574
            $k[$j++] = $1.dir; //#3574
            $1.cput(); //#3574
            $k[$j++] = $a([$1.x, $1.y]); //#3574
        } //#3574
        $1.x = $1.x - 1; //#3574
        $1.dir = 4; //#3574
    }; //#3574
    $1.up = function() {
        if ($1.dir != 8) { //#3575
            $k[$j++] = $1.x; //#3575
            $k[$j++] = $1.y; //#3575
            $k[$j++] = $1.dir; //#3575
            $1.cput(); //#3575
            $k[$j++] = $a([$1.x, $1.y]); //#3575
        } //#3575
        $1.y = $1.y - 1; //#3575
        $1.dir = 8; //#3575
    }; //#3575
    $1.trace = function() {
        $1.y = $k[--$j]; //#3579
        $1.x = $k[--$j]; //#3579
        $k[$j++] = 'dir'; //#3581
        $k[$j++] = $f($1.x + 1); //#3581
        $k[$j++] = $f($1.y + 1); //#3581
        $1.xyget(); //#3581
        var _1P = ($k[--$j] == 1) ? 8 : 4; //#3581
        $1[$k[--$j]] = _1P; //#3581
        $1.sx = $1.x; //#3582
        $1.sy = $1.y; //#3582
        $1.sdir = $1.dir; //#3582
        $k[$j++] = Infinity; //#3586
        for (;;) { //#3600
            $k[$j++] = $1.x; //#3587
            $k[$j++] = $1.y; //#3587
            $1.abcd(); //#3587
            for (var _1W = 0, _1X = 1; _1W < _1X; _1W++) { //#3598
                var _1Y = $k[--$j]; //#3589
                $k[$j++] = _1Y; //#3589
                if ($eq(_1Y, "0001") || ($eq(_1Y, "0011") || $eq(_1Y, "1011"))) { //#3589
                    $j--; //#3589
                    $1.right(); //#3589
                    break; //#3589
                } //#3589
                var _1Z = $k[--$j]; //#3590
                $k[$j++] = _1Z; //#3590
                if ($eq(_1Z, "0010") || ($eq(_1Z, "1010") || $eq(_1Z, "1110"))) { //#3590
                    $j--; //#3590
                    $1.down(); //#3590
                    break; //#3590
                } //#3590
                var _1a = $k[--$j]; //#3591
                $k[$j++] = _1a; //#3591
                if ($eq(_1a, "1000") || ($eq(_1a, "1100") || $eq(_1a, "1101"))) { //#3591
                    $j--; //#3591
                    $1.left(); //#3591
                    break; //#3591
                } //#3591
                var _1b = $k[--$j]; //#3592
                $k[$j++] = _1b; //#3592
                if ($eq(_1b, "0100") || ($eq(_1b, "0101") || $eq(_1b, "0111"))) { //#3592
                    $j--; //#3592
                    $1.up(); //#3592
                    break; //#3592
                } //#3592
                var _1c = $k[--$j]; //#3593
                $k[$j++] = _1c; //#3597
                if ($eq(_1c, "1001")) { //#3596
                    if ($1.dir == 2) { //#3594
                        $j--; //#3594
                        $1.left(); //#3594
                        break; //#3594
                    } else { //#3594
                        $j--; //#3594
                        $1.right(); //#3594
                        break; //#3594
                    } //#3594
                } else { //#3596
                    if ($1.dir == 1) { //#3596
                        $j--; //#3596
                        $1.down(); //#3596
                        break; //#3596
                    } else { //#3596
                        $j--; //#3596
                        $1.up(); //#3596
                        break; //#3596
                    } //#3596
                } //#3596
            } //#3596
            if (($eq($1.x, $1.sx) && $eq($1.y, $1.sy)) && ($1.dir == $1.sdir)) { //#3599
                break; //#3599
            } //#3599
        } //#3599
        $astore($a($counttomark())); //#3601
        var _1n = $k[--$j]; //#3601
        var _1o = $k[--$j]; //#3601
        $k[$j++] = _1n; //#3601
        $k[$j++] = _1o; //#3601
        $j--; //#3601
    }; //#3601
    $1.drawlayer = function() {
        $1.pixsorig = $1.pixs; //#3619
        $1.pixs = $k[--$j]; //#3620
        $k[$j++] = Infinity; //#3630
        for (var _1s = 0, _1t = $1.pixx + 2; _1s < _1t; _1s++) { //#3624
            $k[$j++] = 0; //#3624
        } //#3624
        for (var _1x = 0, _1y = $1.pixx, _1w = $1.pixs.length - 1; _1y < 0 ? _1x >= _1w : _1x <= _1w; _1x += _1y) { //#3629
            $k[$j++] = 0; //#3627
            $aload($geti($1.pixs, _1x, $1.pixx)); //#3627
            $k[$j++] = 0; //#3628
        } //#3628
        for (var _23 = 0, _24 = $1.pixx + 2; _23 < _24; _23++) { //#3630
            $k[$j++] = 0; //#3630
        } //#3630
        $1.pixs = $a(); //#3630
        $1.pixx = $1.pixx + 2; //#3632
        $1.pixy = $1.pixy + 2; //#3633
        $k[$j++] = Infinity; //#3636
        for (var _29 = 0, _2A = $1.pixs.length; _29 < _2A; _29++) { //#3636
            $k[$j++] = 0; //#3636
        } //#3636
        $1.cache = $a(); //#3636
        $k[$j++] = Infinity; //#3652
        for (var _2E = 0, _2D = $1.pixy - 2; _2E <= _2D; _2E += 1) { //#3656
            $1.j = _2E; //#3641
            for (var _2H = 0, _2G = $1.pixx - 2; _2H <= _2G; _2H += 1) { //#3655
                $1.i = _2H; //#3643
                $k[$j++] = 'k'; //#3644
                $k[$j++] = $1.i; //#3644
                $k[$j++] = $1.j; //#3644
                $1.abcd(); //#3644
                var _2K = $k[--$j]; //#3644
                $1[$k[--$j]] = _2K; //#3644
                if ($eq($1.k, "0001") || $eq($1.k, "1001")) { //#3649
                    $k[$j++] = 8; //#3646
                    $k[$j++] = $1.i; //#3646
                    $k[$j++] = $1.j; //#3646
                    $1.cget(); //#3646
                    if ($k[--$j] == 0) { //#3648
                        $k[$j++] = $1.i; //#3647
                        $k[$j++] = $1.j; //#3647
                        $1.trace(); //#3647
                    } //#3647
                } //#3647
                if ($eq($1.k, "1110")) { //#3654
                    $k[$j++] = 4; //#3651
                    $k[$j++] = $1.i; //#3651
                    $k[$j++] = $1.j; //#3651
                    $1.cget(); //#3651
                    if ($k[--$j] == 0) { //#3653
                        $k[$j++] = $1.i; //#3652
                        $k[$j++] = $1.j; //#3652
                        $1.trace(); //#3652
                    } //#3652
                } //#3652
            } //#3652
        } //#3652
        $1.paths = $a(); //#3652
        $1.pixx = $1.pixx - 2; //#3660
        $1.pixy = $1.pixy - 2; //#3661
        $$.newpath(); //#3664
        var _2c = $1.paths; //#3665
        for (var _2d = 0, _2e = _2c.length; _2d < _2e; _2d++) { //#3683
            $1.p = $get(_2c, _2d); //#3666
            $1.len = $1.p.length; //#3667
            $aload($get($1.p, $1.len - 1)); //#3668
            $aload($get($1.p, 0)); //#3669
            for (var _2o = 0, _2n = $1.len - 1; _2o <= _2n; _2o += 1) { //#3680
                $1.i = _2o; //#3671
                $aload($get($1.p, ($1.i + 1) % $1.len)); //#3672
                var _2t = $k[--$j]; //#3672
                var _2u = $k[--$j]; //#3672
                var _2v = $k[--$j]; //#3672
                var _2w = $k[--$j]; //#3672
                var _2x = $k[--$j]; //#3672
                var _2y = $k[--$j]; //#3672
                $k[$j++] = _2w; //#3674
                $k[$j++] = _2v; //#3674
                $k[$j++] = _2u; //#3674
                $k[$j++] = _2t; //#3674
                $k[$j++] = _2y; //#3674
                $k[$j++] = _2w; //#3674
                $k[$j++] = $1.inkspreadh; //#3674
                if ($lt(_2t, _2x)) { //#3674
                    var _30 = $k[--$j]; //#3674
                    var _31 = $k[--$j]; //#3674
                    $k[$j++] = $f(_31 + _30); //#3674
                } else { //#3674
                    var _32 = $k[--$j]; //#3674
                    var _33 = $k[--$j]; //#3674
                    $k[$j++] = $f(_33 - _32); //#3674
                } //#3674
                var _34 = $k[--$j]; //#3675
                var _35 = $k[--$j]; //#3675
                var _36 = $k[--$j]; //#3675
                var _37 = $k[--$j]; //#3675
                var _38 = $k[--$j]; //#3676
                $k[$j++] = _38; //#3677
                $k[$j++] = _34; //#3677
                $k[$j++] = _37; //#3677
                $k[$j++] = _36; //#3677
                $k[$j++] = _38; //#3677
                $k[$j++] = $1.inkspreadv; //#3677
                if ($gt(_37, _35)) { //#3677
                    var _3A = $k[--$j]; //#3677
                    var _3B = $k[--$j]; //#3677
                    $k[$j++] = $f(_3B + _3A); //#3677
                } else { //#3677
                    var _3C = $k[--$j]; //#3677
                    var _3D = $k[--$j]; //#3677
                    $k[$j++] = $f(_3D - _3C); //#3677
                } //#3677
                var _3E = $k[--$j]; //#3678
                var _3F = $k[--$j]; //#3678
                var _3G = $k[--$j]; //#3678
                var _3H = $k[--$j]; //#3678
                $k[$j++] = _3G; //#3679
                $k[$j++] = _3F; //#3679
                $k[$j++] = _3H; //#3679
                $k[$j++] = $f($1.pixy - _3E); //#3679
                if ($1.i == 0) { //#3679
                    var _3K = $k[--$j]; //#3679
                    $$.moveto($k[--$j], _3K); //#3679
                } else { //#3679
                    var _3M = $k[--$j]; //#3679
                    $$.lineto($k[--$j], _3M); //#3679
                } //#3679
            } //#3679
            $$.closepath(); //#3681
            $j -= 4; //#3682
        } //#3682
        $$.fill(); //#3684
        $1.pixs = $1.pixsorig; //#3686
    }; //#3686
    $1.drawlayerdots = function() {
        $1.pixsorig = $1.pixs; //#3692
        $1.pixs = $k[--$j]; //#3693
        $$.newpath(); //#3695
        for (var _3T = 0, _3S = $1.pixs.length - 1; _3T <= _3S; _3T += 1) { //#3703
            $1.x = _3T % $1.pixx; //#3697
            $1.y = ~~(_3T / $1.pixx); //#3698
            $k[$j++] = $1.x; //#3699
            $k[$j++] = $1.y; //#3699
            $1.xyget(); //#3699
            if ($k[--$j] == 1) { //#3702
                $$.moveto($f($1.x + 0.5), $f(($1.pixy - $1.y) - 0.5)); //#3700
                $$.arc($f($1.x + 0.5), $f(($1.pixy - $1.y) - 0.5), $f(0.5 - $1.inkspread), 0, 360, 1); //#3701
            } //#3701
        } //#3701
        $$.fill(); //#3704
        $1.pixs = $1.pixsorig; //#3706
    }; //#3706
    $$.save(); //#3710
    $1.inkspread = $1.inkspread / 2; //#3713
    $1.inkspreadh = $1.inkspreadh / 2; //#3714
    $1.inkspreadv = $1.inkspreadv / 2; //#3715
    var _3k = $$.currpos(); //#3716
    $$.translate(_3k.x, _3k.y); //#3716
    $$.scale(($1.width / $1.pixx) * 72, ($1.height / $1.pixy) * 72); //#3717
    $$.moveto(0, 0); //#3718
    $$.lineto($1.pixx, 0); //#3718
    $$.lineto($1.pixx, $1.pixy); //#3718
    $$.lineto(0, $1.pixy); //#3718
    $$.closepath(); //#3718
    if ($eq($1.colormap, "unset")) { //#3723
        var _3v = new Map([
            [1, $1.barcolor]
        ]); //#3722
        $1.colormap = _3v; //#3722
    } //#3722
    var _3w = $1.colormap; //#3725
    for (var _41 = _3w.size, _40 = _3w.keys(), _3z = 0; _3z < _41; _3z++) { //#3731
        var _3x = _40.next().value; //#3731
        $$.setcolor(_3w.get(_3x)); //#3726
        $1.key = _3x; //#3727
        $k[$j++] = Infinity; //#3729
        var _42 = $1.pixs; //#3729
        for (var _43 = 0, _44 = _42.length; _43 < _44; _43++) { //#3729
            var _47 = $eq($get(_42, _43), $1.key) ? 1 : 0; //#3729
            $k[$j++] = _47; //#3729
        } //#3729
        var _48 = $a(); //#3729
        $k[$j++] = _48; //#3730
        if ($1.dotty) { //#3730
            $1.drawlayerdots(); //#3730
        } else { //#3730
            $1.drawlayer(); //#3730
        } //#3730
    } //#3730
    if ($ne($1.textcolor, "unset")) { //#3734
        $$.setcolor($1.textcolor); //#3734
    } //#3734
    if ($1.includetext) { //#3791
        if (($eq($1.textxalign, "unset") && $eq($1.textyalign, "unset")) && $eq($1.alttext, "")) { //#3789
            $1.s = 0; //#3737
            $1.fn = ""; //#3737
            var _4G = $1.txt; //#3738
            for (var _4H = 0, _4I = _4G.length; _4H < _4I; _4H++) { //#3747
                $forall($get(_4G, _4H)); //#3739
                var _4K = $k[--$j]; //#3740
                var _4L = $k[--$j]; //#3740
                $k[$j++] = _4L; //#3745
                $k[$j++] = _4K; //#3745
                if ((_4K != $1.s) || $ne(_4L, $1.fn)) { //#3744
                    var _4O = $k[--$j]; //#3741
                    var _4P = $k[--$j]; //#3741
                    $1.s = _4O; //#3741
                    $1.fn = _4P; //#3741
                    $$.selectfont(_4P, _4O); //#3742
                } else { //#3744
                    $j -= 2; //#3744
                } //#3744
                var _4Q = $k[--$j]; //#3746
                $$.moveto($k[--$j], _4Q); //#3746
                $$.show($k[--$j], 0, 0); //#3746
            } //#3746
        } else { //#3789
            $$.selectfont($1.textfont, $1.textsize); //#3749
            if ($eq($1.alttext, "")) { //#3755
                $k[$j++] = Infinity; //#3751
                var _4W = $1.txt; //#3751
                for (var _4X = 0, _4Y = _4W.length; _4X < _4Y; _4X++) { //#3751
                    $forall($get($get(_4W, _4X), 0)); //#3751
                } //#3751
                $1.txt = $a(); //#3751
                $1.tstr = $s($1.txt.length); //#3752
                for (var _4g = 0, _4f = $1.txt.length - 1; _4g <= _4f; _4g += 1) { //#3753
                    $put($1.tstr, _4g, $get($1.txt, _4g)); //#3753
                } //#3753
            } else { //#3755
                $1.tstr = $1.alttext; //#3755
            } //#3755
            if ($1.tstr.length == 0) { //#3765
                $k[$j++] = 0; //#3760
            } else { //#3765
                $$.save(); //#3762
                $$.newpath(); //#3763
                $$.moveto(0, 0); //#3763
                $$.charpath("0", false); //#3763
                var _4m = $$.pathbbox(); //#3763
                $$.restore(); //#3765
                $k[$j++] = _4m.ury; //#3765
            } //#3765
            $1.textascent = $k[--$j]; //#3774
            var _4p = $$.stringwidth($1.tstr); //#3775
            $1.textwidth = $f(_4p.w + (($1.tstr.length - 1) * $1.textgaps)); //#3775
            $1.textxpos = $f($1.textxoffset + ($f($1.pixx - $1.textwidth) / 2)); //#3777
            if ($eq($1.textxalign, "left")) { //#3778
                $1.textxpos = $1.textxoffset; //#3778
            } //#3778
            if ($eq($1.textxalign, "right")) { //#3779
                $1.textxpos = $f(($1.pixx - $1.textxoffset) - $1.textwidth); //#3779
            } //#3779
            if ($eq($1.textxalign, "offleft")) { //#3780
                $1.textxpos = -$f($1.textwidth + $1.textxoffset); //#3780
            } //#3780
            if ($eq($1.textxalign, "offright")) { //#3781
                $1.textxpos = $1.pixx + $1.textxoffset; //#3781
            } //#3781
            if ($eq($1.textxalign, "justify") && ($1.textwidth < $1.pixx)) { //#3785
                $1.textxpos = 0; //#3783
                $1.textgaps = $f($1.pixx - $1.textwidth) / ($1.tstr.length - 1); //#3784
            } //#3784
            $1.textypos = -($f($f($1.textyoffset + $1.textascent) + 1)); //#3786
            if ($eq($1.textyalign, "above")) { //#3787
                $1.textypos = ($1.textyoffset + $1.pixy) + 1; //#3787
            } //#3787
            if ($eq($1.textyalign, "center")) { //#3788
                $1.textypos = $f($1.textyoffset + ($f($1.pixy - $1.textascent) / 2)); //#3788
            } //#3788
            $$.moveto($1.textxpos, $1.textypos); //#3789
            $$.show($1.tstr, $1.textgaps, 0); //#3789
        } //#3789
    } //#3789
    $$.restore(); //#3793
}

function bwipp_ean5() {
    var $1 = {}; //#3909
    $1.ctx = null; //#3911
    $1.dontdraw = false; //#3912
    $1.includetext = false; //#3913
    $1.textfont = "OCR-B"; //#3914
    $1.textsize = 12; //#3915
    $1.textxoffset = 0; //#3916
    $1.textyoffset = null; //#3917
    $1.height = 0.7; //#3918
    $k[$j++] = $1; //#3920
    bwipp_processoptions(); //#3920
    $1.options = $k[--$j]; //#3920
    $1.barcode = $k[--$j]; //#3921
    if ($eq($1.textyoffset, null)) { //#3925
        $1.textyoffset = $f(($1.height * 72) + 1); //#3924
    } //#3924
    if ($1.barcode.length != 5) { //#3932
        $k[$j++] = 'bwipp.ean5badLength'; //#3931
        $k[$j++] = "EAN-5 add-on must be 5 digits"; //#3931
        bwipp_raiseerror(); //#3931
    } //#3931
    $forall($1.barcode, function() { //#3937
        var _6 = $k[--$j]; //#3934
        if ((_6 < 48) || (_6 > 57)) { //#3936
            $k[$j++] = 'bwipp.ean5badCharacter'; //#3935
            $k[$j++] = "EAN-5 add-on must contain only digits"; //#3935
            bwipp_raiseerror(); //#3935
        } //#3935
    }); //#3935
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "112", "11"]); //#3945
    $1.barchars = "0123456789"; //#3948
    $1.mirrormaps = $a(["11000", "10100", "10010", "10001", "01100", "00110", "00011", "01010", "01001", "00101"]); //#3954
    $1.checksum = 0; //#3957
    for (var _9 = 0; _9 <= 4; _9 += 1) { //#3966
        $1.i = _9; //#3959
        $1.barchar = $f($get($1.barcode, $1.i) - 48); //#3960
        if (($1.i % 2) == 0) { //#3964
            $1.checksum = $f(($1.barchar * 3) + $1.checksum); //#3962
        } else { //#3964
            $1.checksum = $f(($1.barchar * 9) + $1.checksum); //#3964
        } //#3964
    } //#3964
    $1.checksum = $1.checksum % 10; //#3967
    $1.mirrormap = $get($1.mirrormaps, $1.checksum); //#3968
    $1.sbs = $s(31); //#3970
    $1.txt = $a(5); //#3971
    for (var _O = 0; _O <= 4; _O += 1) { //#4001
        $1.i = _O; //#3974
        if ($1.i == 0) { //#3980
            $puti($1.sbs, 0, $get($1.encs, 10)); //#3978
        } else { //#3980
            $puti($1.sbs, (($1.i - 1) * 6) + 7, $get($1.encs, 11)); //#3980
        } //#3980
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#3984
        $j--; //#3985
        $1.indx = $k[--$j].length; //#3986
        $j -= 2; //#3987
        $1.enc = $get($1.encs, $1.indx); //#3988
        if ($get($1.mirrormap, $1.i) == 49) { //#3998
            $1.enclen = $1.enc.length; //#3990
            $1.revenc = $s($1.enclen); //#3991
            for (var _n = 0, _m = $1.enclen - 1; _n <= _m; _n += 1) { //#3996
                $1.j = _n; //#3993
                $1.char = $get($1.enc, $1.j); //#3994
                $put($1.revenc, ($1.enclen - $1.j) - 1, $1.char); //#3995
            } //#3995
            $1.enc = $1.revenc; //#3997
        } //#3997
        $puti($1.sbs, ($1.i * 6) + 3, $1.enc); //#3999
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 1) * 9) + 13) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4000
    } //#4000
    $k[$j++] = Infinity; //#4015
    $k[$j++] = Infinity; //#4006
    var _1A = $1.sbs; //#4006
    for (var _1B = 0, _1C = _1A.length; _1B < _1C; _1B++) { //#4006
        $k[$j++] = $get(_1A, _1B) - 48; //#4006
    } //#4006
    var _1E = $a(); //#4006
    $k[$j++] = Infinity; //#4007
    for (var _1F = 0, _1G = 16; _1F < _1G; _1F++) { //#4007
        $k[$j++] = $1.height; //#4007
    } //#4007
    var _1I = $a(); //#4007
    $k[$j++] = Infinity; //#4008
    for (var _1J = 0, _1K = 16; _1J < _1K; _1J++) { //#4008
        $k[$j++] = 0; //#4008
    } //#4008
    var _1L = $a(); //#4008
    $k[$j++] = 'ren'; //#4011
    $k[$j++] = bwipp_renlinear; //#4011
    $k[$j++] = 'sbs'; //#4011
    $k[$j++] = _1E; //#4011
    $k[$j++] = 'bhs'; //#4011
    $k[$j++] = _1I; //#4011
    $k[$j++] = 'bbs'; //#4011
    $k[$j++] = _1L; //#4011
    if ($1.includetext) { //#4011
        $k[$j++] = 'txt'; //#4010
        $k[$j++] = $1.txt; //#4010
    } //#4010
    $k[$j++] = 'opt'; //#4015
    $k[$j++] = $1.options; //#4015
    $k[$j++] = 'guardrightpos'; //#4015
    $k[$j++] = 10; //#4015
    $k[$j++] = 'guardrightypos'; //#4015
    $k[$j++] = $f($1.textyoffset + 4); //#4015
    $k[$j++] = 'bordertop'; //#4015
    $k[$j++] = 10; //#4015
    var _1Q = $d(); //#4015
    $k[$j++] = _1Q; //#4018
    if (!$1.dontdraw) { //#4018
        bwipp_renlinear(); //#4018
    } //#4018
}

function bwipp_ean2() {
    var $1 = {}; //#4052
    $1.ctx = null; //#4054
    $1.dontdraw = false; //#4055
    $1.includetext = false; //#4056
    $1.textfont = "OCR-B"; //#4057
    $1.textsize = 12; //#4058
    $1.textxoffset = 0; //#4059
    $1.textyoffset = null; //#4060
    $1.height = 0.7; //#4061
    $k[$j++] = $1; //#4063
    bwipp_processoptions(); //#4063
    $1.options = $k[--$j]; //#4063
    $1.barcode = $k[--$j]; //#4064
    if ($eq($1.textyoffset, null)) { //#4068
        $1.textyoffset = $f(($1.height * 72) + 1); //#4067
    } //#4067
    if ($1.barcode.length != 2) { //#4075
        $k[$j++] = 'bwipp.ean2badLength'; //#4074
        $k[$j++] = "EAN-2 add-on must be 2 digits"; //#4074
        bwipp_raiseerror(); //#4074
    } //#4074
    $forall($1.barcode, function() { //#4080
        var _6 = $k[--$j]; //#4077
        if ((_6 < 48) || (_6 > 57)) { //#4079
            $k[$j++] = 'bwipp.ean2badCharacter'; //#4078
            $k[$j++] = "EAN-2 add-on must contain only digits"; //#4078
            bwipp_raiseerror(); //#4078
        } //#4078
    }); //#4078
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "112", "11"]); //#4088
    $1.barchars = "0123456789"; //#4091
    $1.mirrormaps = $a(["00", "01", "10", "11"]); //#4094
    $1.mirrormap = $get($1.mirrormaps, $cvi($geti($1.barcode, 0, 2)) % 4); //#4097
    $1.sbs = $s(13); //#4099
    $1.txt = $a(2); //#4100
    for (var _F = 0; _F <= 1; _F += 1) { //#4130
        $1.i = _F; //#4103
        if ($1.i == 0) { //#4109
            $puti($1.sbs, 0, $get($1.encs, 10)); //#4107
        } else { //#4109
            $puti($1.sbs, (($1.i - 1) * 6) + 7, $get($1.encs, 11)); //#4109
        } //#4109
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4113
        $j--; //#4114
        $1.indx = $k[--$j].length; //#4115
        $j -= 2; //#4116
        $1.enc = $get($1.encs, $1.indx); //#4117
        if ($get($1.mirrormap, $1.i) == 49) { //#4127
            $1.enclen = $1.enc.length; //#4119
            $1.revenc = $s($1.enclen); //#4120
            for (var _e = 0, _d = $1.enclen - 1; _e <= _d; _e += 1) { //#4125
                $1.j = _e; //#4122
                $1.char = $get($1.enc, $1.j); //#4123
                $put($1.revenc, ($1.enclen - $1.j) - 1, $1.char); //#4124
            } //#4124
            $1.enc = $1.revenc; //#4126
        } //#4126
        $puti($1.sbs, ($1.i * 6) + 3, $1.enc); //#4128
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 1) * 9) + 13) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4129
    } //#4129
    $k[$j++] = Infinity; //#4144
    $k[$j++] = Infinity; //#4135
    var _11 = $1.sbs; //#4135
    for (var _12 = 0, _13 = _11.length; _12 < _13; _12++) { //#4135
        $k[$j++] = $get(_11, _12) - 48; //#4135
    } //#4135
    var _15 = $a(); //#4135
    $k[$j++] = Infinity; //#4136
    for (var _16 = 0, _17 = 12; _16 < _17; _16++) { //#4136
        $k[$j++] = $1.height; //#4136
    } //#4136
    var _19 = $a(); //#4136
    $k[$j++] = Infinity; //#4137
    for (var _1A = 0, _1B = 12; _1A < _1B; _1A++) { //#4137
        $k[$j++] = 0; //#4137
    } //#4137
    var _1C = $a(); //#4137
    $k[$j++] = 'ren'; //#4140
    $k[$j++] = bwipp_renlinear; //#4140
    $k[$j++] = 'sbs'; //#4140
    $k[$j++] = _15; //#4140
    $k[$j++] = 'bhs'; //#4140
    $k[$j++] = _19; //#4140
    $k[$j++] = 'bbs'; //#4140
    $k[$j++] = _1C; //#4140
    if ($1.includetext) { //#4140
        $k[$j++] = 'txt'; //#4139
        $k[$j++] = $1.txt; //#4139
    } //#4139
    $k[$j++] = 'opt'; //#4144
    $k[$j++] = $1.options; //#4144
    $k[$j++] = 'guardrightpos'; //#4144
    $k[$j++] = 10; //#4144
    $k[$j++] = 'guardrightypos'; //#4144
    $k[$j++] = $f($1.textyoffset + 4); //#4144
    $k[$j++] = 'bordertop'; //#4144
    $k[$j++] = 10; //#4144
    var _1H = $d(); //#4144
    $k[$j++] = _1H; //#4147
    if (!$1.dontdraw) { //#4147
        bwipp_renlinear(); //#4147
    } //#4147
}

function bwipp_ean13() {
    var $1 = {}; //#4183
    $1.ctx = null; //#4185
    $1.dontdraw = false; //#4186
    $1.includetext = false; //#4187
    $1.textfont = "OCR-B"; //#4188
    $1.textsize = 12; //#4189
    $1.textxoffset = -10; //#4190
    $1.textyoffset = -4; //#4191
    $1.height = 1; //#4192
    $1.addongap = 12; //#4193
    $1.addontextfont = "unset"; //#4194
    $1.addontextsize = null; //#4195
    $1.addontextxoffset = null; //#4196
    $1.addontextyoffset = null; //#4197
    $k[$j++] = $1; //#4199
    bwipp_processoptions(); //#4199
    $1.options = $k[--$j]; //#4199
    $1.barcode = $k[--$j]; //#4200
    $search($1.barcode, " "); //#4205
    if ($k[--$j]) { //#4211
        $1.barcode = $k[--$j]; //#4206
        $j--; //#4207
        $1.addon = $k[--$j]; //#4208
    } else { //#4211
        $j--; //#4210
        $1.addon = ""; //#4211
    } //#4211
    if (($1.barcode.length != 12) && ($1.barcode.length != 13)) { //#4217
        $k[$j++] = 'bwipp.ean13badLength'; //#4216
        $k[$j++] = "EAN-13 must be 12 or 13 digits"; //#4216
        bwipp_raiseerror(); //#4216
    } //#4216
    $forall($1.barcode, function() { //#4222
        var _9 = $k[--$j]; //#4219
        if ((_9 < 48) || (_9 > 57)) { //#4221
            $k[$j++] = 'bwipp.ean13badCharacter'; //#4220
            $k[$j++] = "EAN-13 must contain only digits"; //#4220
            bwipp_raiseerror(); //#4220
        } //#4220
    }); //#4220
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#4225
        $k[$j++] = 'bwipp.ean13badAddOnLength'; //#4224
        $k[$j++] = "Add-on for EAN-13 must be 2 or 5 digits"; //#4224
        bwipp_raiseerror(); //#4224
    } //#4224
    $1.pad = $s(13); //#4228
    $1.checksum = 0; //#4229
    for (var _E = 0; _E <= 11; _E += 1) { //#4238
        $1.i = _E; //#4231
        $1.barchar = $f($get($1.barcode, $1.i) - 48); //#4232
        if (($1.i % 2) == 0) { //#4236
            $1.checksum = $f($1.barchar + $1.checksum); //#4234
        } else { //#4236
            $1.checksum = $f(($1.barchar * 3) + $1.checksum); //#4236
        } //#4236
    } //#4236
    $1.checksum = ($f(10 - ($1.checksum % 10))) % 10; //#4239
    if ($1.barcode.length == 13) { //#4244
        if ($get($1.barcode, 12) != $f($1.checksum + 48)) { //#4243
            $k[$j++] = 'bwipp.ean13badCheckDigit'; //#4242
            $k[$j++] = "Incorrect EAN-13 check digit provided"; //#4242
            bwipp_raiseerror(); //#4242
        } //#4242
    } //#4242
    $puti($1.pad, 0, $1.barcode); //#4245
    $put($1.pad, 12, $f($1.checksum + 48)); //#4246
    $1.barcode = $1.pad; //#4247
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "111", "11111", "111"]); //#4255
    $1.barchars = "0123456789"; //#4258
    $1.mirrormaps = $a(["000000", "001011", "001101", "001110", "010011", "011001", "011100", "010101", "010110", "011010"]); //#4264
    $1.sbs = $s(59); //#4267
    $1.txt = $a(13); //#4268
    $puti($1.sbs, 0, $get($1.encs, 10)); //#4271
    $1.mirrormap = $get($1.mirrormaps, $get($1.barcode, 0) - 48); //#4274
    $put($1.txt, 0, $a([$geti($1.barcode, 0, 1), $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4275
    for (var _q = 1; _q <= 6; _q += 1) { //#4298
        $1.i = _q; //#4280
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4281
        $j--; //#4282
        $1.indx = $k[--$j].length; //#4283
        $j -= 2; //#4284
        $1.enc = $get($1.encs, $1.indx); //#4285
        if ($get($1.mirrormap, $1.i - 1) == 49) { //#4295
            $1.enclen = $1.enc.length; //#4287
            $1.revenc = $s($1.enclen); //#4288
            for (var _17 = 0, _16 = $1.enclen - 1; _17 <= _16; _17 += 1) { //#4293
                $1.j = _17; //#4290
                $1.char = $get($1.enc, $1.j); //#4291
                $put($1.revenc, ($1.enclen - $1.j) - 1, $1.char); //#4292
            } //#4292
            $1.enc = $1.revenc; //#4294
        } //#4294
        $puti($1.sbs, (($1.i - 1) * 4) + 3, $1.enc); //#4296
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 1) * 7) + 14) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4297
    } //#4297
    $puti($1.sbs, ((7 - 1) * 4) + 3, $get($1.encs, 11)); //#4301
    for (var _1X = 7; _1X <= 12; _1X += 1) { //#4314
        $1.i = _1X; //#4306
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4307
        $j--; //#4308
        $1.indx = $k[--$j].length; //#4309
        $j -= 2; //#4310
        $1.enc = $get($1.encs, $1.indx); //#4311
        $puti($1.sbs, (($1.i - 1) * 4) + 8, $1.enc); //#4312
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 1) * 7) + 18) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4313
    } //#4313
    $puti($1.sbs, 56, $get($1.encs, 12)); //#4317
    $k[$j++] = Infinity; //#4319
    var _1x = $1.sbs; //#4319
    for (var _1y = 0, _1z = _1x.length; _1y < _1z; _1y++) { //#4319
        $k[$j++] = $get(_1x, _1y) - 48; //#4319
    } //#4319
    $1.sbs = $a(); //#4319
    if ($1.includetext) { //#4326
        $k[$j++] = Infinity; //#4321
        $k[$j++] = $1.height; //#4321
        $k[$j++] = $1.height; //#4321
        for (var _25 = 0, _26 = 12; _25 < _26; _25++) { //#4321
            $k[$j++] = $f($1.height - 0.075); //#4321
        } //#4321
        $k[$j++] = $1.height; //#4321
        $k[$j++] = $1.height; //#4321
        for (var _2A = 0, _2B = 12; _2A < _2B; _2A++) { //#4321
            $k[$j++] = $f($1.height - 0.075); //#4321
        } //#4321
        $k[$j++] = $1.height; //#4321
        $k[$j++] = $1.height; //#4321
        $1.bhs = $a(); //#4321
        $k[$j++] = Infinity; //#4322
        $k[$j++] = 0; //#4322
        $k[$j++] = 0; //#4322
        for (var _2G = 0, _2H = 12; _2G < _2H; _2G++) { //#4322
            $k[$j++] = 0.075; //#4322
        } //#4322
        $k[$j++] = 0; //#4322
        $k[$j++] = 0; //#4322
        for (var _2I = 0, _2J = 12; _2I < _2J; _2I++) { //#4322
            $k[$j++] = 0.075; //#4322
        } //#4322
        $k[$j++] = 0; //#4322
        $k[$j++] = 0; //#4322
        $1.bbs = $a(); //#4322
    } else { //#4326
        $k[$j++] = Infinity; //#4324
        for (var _2L = 0, _2M = 30; _2L < _2M; _2L++) { //#4324
            $k[$j++] = $1.height; //#4324
        } //#4324
        $1.bhs = $a(); //#4324
        $k[$j++] = Infinity; //#4325
        for (var _2P = 0, _2Q = 30; _2P < _2Q; _2P++) { //#4325
            $k[$j++] = 0; //#4325
        } //#4325
        $1.bbs = $a(); //#4325
        $1.txt = $a([]); //#4326
    } //#4326
    $1.guardrightypos = 0; //#4328
    if ($ne($1.addon, "")) { //#4349
        $k[$j++] = Infinity; //#4339
        $k[$j++] = 'dontdraw'; //#4336
        $k[$j++] = true; //#4336
        $k[$j++] = 'includetext'; //#4336
        $k[$j++] = true; //#4336
        $k[$j++] = 'height'; //#4336
        $k[$j++] = $f($1.height - 0.15); //#4336
        $k[$j++] = 'textxoffset'; //#4336
        if ($ne($1.addontextxoffset, null)) { //#4336
            $k[$j++] = $1.addontextxoffset; //#4336
        } else { //#4336
            $k[$j++] = 95 + $1.addongap; //#4336
        } //#4336
        if ($ne($1.addontextyoffset, null)) { //#4337
            $k[$j++] = 'textyoffset'; //#4337
            $k[$j++] = $1.addontextyoffset; //#4337
        } //#4337
        $k[$j++] = 'textsize'; //#4338
        if ($ne($1.addontextsize, null)) { //#4338
            $k[$j++] = $1.addontextsize; //#4338
        } else { //#4338
            $k[$j++] = $1.textsize; //#4338
        } //#4338
        var _2e = $ne($1.addontextfont, "unset") ? $1.addontextfont : $1.textfont; //#4339
        $k[$j++] = 'textfont'; //#4339
        $k[$j++] = _2e; //#4339
        $1.addopts = $d(); //#4340
        if ($1.addon.length == 2) { //#4341
            $k[$j++] = $1.addon; //#4341
            $k[$j++] = $1.addopts; //#4341
            bwipp_ean2(); //#4341
        } //#4341
        if ($1.addon.length == 5) { //#4342
            $k[$j++] = $1.addon; //#4342
            $k[$j++] = $1.addopts; //#4342
            bwipp_ean5(); //#4342
        } //#4342
        $1.addcode = $k[--$j]; //#4343
        $k[$j++] = Infinity; //#4344
        $aload($1.sbs); //#4344
        $k[$j++] = $1.addongap; //#4344
        $aload($get($1.addcode, "sbs")); //#4344
        $1.sbs = $a(); //#4344
        $k[$j++] = Infinity; //#4345
        $aload($1.bhs); //#4345
        $forall($get($1.addcode, "bhs"), function() { //#4345
            var _2v = $k[--$j]; //#4345
            $k[$j++] = $f(_2v - 0.075); //#4345
        }); //#4345
        $1.bhs = $a(); //#4345
        $k[$j++] = Infinity; //#4346
        $aload($1.bbs); //#4346
        $forall($get($1.addcode, "bbs"), function() { //#4346
            var _30 = $k[--$j]; //#4346
            $k[$j++] = $f(_30 + 0.075); //#4346
        }); //#4346
        $1.bbs = $a(); //#4346
        $k[$j++] = Infinity; //#4347
        $aload($1.txt); //#4347
        $aload($get($1.addcode, "txt")); //#4347
        $1.txt = $a(); //#4347
        $1.guardrightypos = ($1.height * 72) - 6; //#4348
    } //#4348
    var _3D = new Map([
        ["ren", bwipp_renlinear],
        ["sbs", $1.sbs],
        ["bhs", $1.bhs],
        ["bbs", $1.bbs],
        ["txt", $1.txt],
        ["opt", $1.options],
        ["guardrightpos", 10],
        ["guardrightypos", $1.guardrightypos],
        ["borderbottom", 5]
    ]); //#4361
    $k[$j++] = _3D; //#4364
    if (!$1.dontdraw) { //#4364
        bwipp_renlinear(); //#4364
    } //#4364
}

function bwipp_ean8() {
    var $1 = {}; //#4400
    $1.ctx = null; //#4402
    $1.dontdraw = false; //#4403
    $1.includetext = false; //#4404
    $1.textfont = "OCR-B"; //#4405
    $1.textsize = 12; //#4406
    $1.textxoffset = 4; //#4407
    $1.textyoffset = -4; //#4408
    $1.height = 1; //#4409
    $1.addongap = 12; //#4410
    $1.addontextfont = "unset"; //#4411
    $1.addontextsize = null; //#4412
    $1.addontextxoffset = null; //#4413
    $1.addontextyoffset = null; //#4414
    $k[$j++] = $1; //#4416
    bwipp_processoptions(); //#4416
    $1.options = $k[--$j]; //#4416
    $1.barcode = $k[--$j]; //#4417
    $search($1.barcode, " "); //#4422
    if ($k[--$j]) { //#4428
        $1.barcode = $k[--$j]; //#4423
        $j--; //#4424
        $1.addon = $k[--$j]; //#4425
    } else { //#4428
        $j--; //#4427
        $1.addon = ""; //#4428
    } //#4428
    if (($1.barcode.length != 7) && ($1.barcode.length != 8)) { //#4434
        $k[$j++] = 'bwipp.ean8badLength'; //#4433
        $k[$j++] = "EAN-8 must be 7 or 8 digits"; //#4433
        bwipp_raiseerror(); //#4433
    } //#4433
    $forall($1.barcode, function() { //#4439
        var _9 = $k[--$j]; //#4436
        if ((_9 < 48) || (_9 > 57)) { //#4438
            $k[$j++] = 'bwipp.ean8badCharacter'; //#4437
            $k[$j++] = "EAN-8 must contain only digits"; //#4437
            bwipp_raiseerror(); //#4437
        } //#4437
    }); //#4437
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#4442
        $k[$j++] = 'bwipp.ean8badAddOnLength'; //#4441
        $k[$j++] = "Add-on for EAN-8 must be 2 or 5 digits"; //#4441
        bwipp_raiseerror(); //#4441
    } //#4441
    $1.pad = $s(8); //#4445
    $1.checksum = 0; //#4446
    for (var _E = 0; _E <= 6; _E += 1) { //#4455
        $1.i = _E; //#4448
        $1.barchar = $f($get($1.barcode, $1.i) - 48); //#4449
        if (($1.i % 2) != 0) { //#4453
            $1.checksum = $f($1.barchar + $1.checksum); //#4451
        } else { //#4453
            $1.checksum = $f(($1.barchar * 3) + $1.checksum); //#4453
        } //#4453
    } //#4453
    $1.checksum = ($f(10 - ($1.checksum % 10))) % 10; //#4456
    if ($1.barcode.length == 8) { //#4461
        if ($get($1.barcode, 7) != $f($1.checksum + 48)) { //#4460
            $k[$j++] = 'bwipp.ean8badCheckDigit'; //#4459
            $k[$j++] = "Incorrect EAN-8 check digit provided"; //#4459
            bwipp_raiseerror(); //#4459
        } //#4459
    } //#4459
    $puti($1.pad, 0, $1.barcode); //#4462
    $put($1.pad, 7, $f($1.checksum + 48)); //#4463
    $1.barcode = $1.pad; //#4464
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "111", "11111", "111"]); //#4472
    $1.barchars = "0123456789"; //#4475
    $1.sbs = $s(43); //#4478
    $1.txt = $a(8); //#4479
    $puti($1.sbs, 0, $get($1.encs, 10)); //#4482
    for (var _d = 0; _d <= 3; _d += 1) { //#4495
        $1.i = _d; //#4487
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4488
        $j--; //#4489
        $1.indx = $k[--$j].length; //#4490
        $j -= 2; //#4491
        $1.enc = $get($1.encs, $1.indx); //#4492
        $puti($1.sbs, ($1.i * 4) + 3, $1.enc); //#4493
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 7) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4494
    } //#4494
    $puti($1.sbs, (4 * 4) + 3, $get($1.encs, 11)); //#4498
    for (var _13 = 4; _13 <= 7; _13 += 1) { //#4511
        $1.i = _13; //#4503
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4504
        $j--; //#4505
        $1.indx = $k[--$j].length; //#4506
        $j -= 2; //#4507
        $1.enc = $get($1.encs, $1.indx); //#4508
        $puti($1.sbs, ($1.i * 4) + 8, $1.enc); //#4509
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 7) + $1.textxoffset) + 4, $1.textyoffset, $1.textfont, $1.textsize])); //#4510
    } //#4510
    $puti($1.sbs, 40, $get($1.encs, 12)); //#4514
    $k[$j++] = Infinity; //#4516
    var _1T = $1.sbs; //#4516
    for (var _1U = 0, _1V = _1T.length; _1U < _1V; _1U++) { //#4516
        $k[$j++] = $get(_1T, _1U) - 48; //#4516
    } //#4516
    $1.sbs = $a(); //#4516
    if ($1.includetext) { //#4523
        $k[$j++] = Infinity; //#4518
        $k[$j++] = $1.height; //#4518
        $k[$j++] = $1.height; //#4518
        for (var _1b = 0, _1c = 8; _1b < _1c; _1b++) { //#4518
            $k[$j++] = $f($1.height - 0.075); //#4518
        } //#4518
        $k[$j++] = $1.height; //#4518
        $k[$j++] = $1.height; //#4518
        for (var _1g = 0, _1h = 8; _1g < _1h; _1g++) { //#4518
            $k[$j++] = $f($1.height - 0.075); //#4518
        } //#4518
        $k[$j++] = $1.height; //#4518
        $k[$j++] = $1.height; //#4518
        $1.bhs = $a(); //#4518
        $k[$j++] = Infinity; //#4519
        $k[$j++] = 0; //#4519
        $k[$j++] = 0; //#4519
        for (var _1m = 0, _1n = 8; _1m < _1n; _1m++) { //#4519
            $k[$j++] = 0.075; //#4519
        } //#4519
        $k[$j++] = 0; //#4519
        $k[$j++] = 0; //#4519
        for (var _1o = 0, _1p = 8; _1o < _1p; _1o++) { //#4519
            $k[$j++] = 0.075; //#4519
        } //#4519
        $k[$j++] = 0; //#4519
        $k[$j++] = 0; //#4519
        $1.bbs = $a(); //#4519
    } else { //#4523
        $k[$j++] = Infinity; //#4521
        for (var _1r = 0, _1s = 22; _1r < _1s; _1r++) { //#4521
            $k[$j++] = $1.height; //#4521
        } //#4521
        $1.bhs = $a(); //#4521
        $k[$j++] = Infinity; //#4522
        for (var _1v = 0, _1w = 22; _1v < _1w; _1v++) { //#4522
            $k[$j++] = 0; //#4522
        } //#4522
        $1.bbs = $a(); //#4522
        $1.txt = $a([]); //#4523
    } //#4523
    $1.guardrightypos = 0; //#4525
    if ($ne($1.addon, "")) { //#4546
        $k[$j++] = Infinity; //#4536
        $k[$j++] = 'dontdraw'; //#4533
        $k[$j++] = true; //#4533
        $k[$j++] = 'includetext'; //#4533
        $k[$j++] = true; //#4533
        $k[$j++] = 'height'; //#4533
        $k[$j++] = $f($1.height - 0.15); //#4533
        $k[$j++] = 'textxoffset'; //#4533
        if ($ne($1.addontextxoffset, null)) { //#4533
            $k[$j++] = $1.addontextxoffset; //#4533
        } else { //#4533
            $k[$j++] = 67 + $1.addongap; //#4533
        } //#4533
        if ($ne($1.addontextyoffset, null)) { //#4534
            $k[$j++] = 'textyoffset'; //#4534
            $k[$j++] = $1.addontextyoffset; //#4534
        } //#4534
        $k[$j++] = 'textsize'; //#4535
        if ($ne($1.addontextsize, null)) { //#4535
            $k[$j++] = $1.addontextsize; //#4535
        } else { //#4535
            $k[$j++] = $1.textsize; //#4535
        } //#4535
        var _2A = $ne($1.addontextfont, "unset") ? $1.addontextfont : $1.textfont; //#4536
        $k[$j++] = 'textfont'; //#4536
        $k[$j++] = _2A; //#4536
        $1.addopts = $d(); //#4537
        if ($1.addon.length == 2) { //#4538
            $k[$j++] = $1.addon; //#4538
            $k[$j++] = $1.addopts; //#4538
            bwipp_ean2(); //#4538
        } //#4538
        if ($1.addon.length == 5) { //#4539
            $k[$j++] = $1.addon; //#4539
            $k[$j++] = $1.addopts; //#4539
            bwipp_ean5(); //#4539
        } //#4539
        $1.addcode = $k[--$j]; //#4540
        $k[$j++] = Infinity; //#4541
        $aload($1.sbs); //#4541
        $k[$j++] = $1.addongap; //#4541
        $aload($get($1.addcode, "sbs")); //#4541
        $1.sbs = $a(); //#4541
        $k[$j++] = Infinity; //#4542
        $aload($1.bhs); //#4542
        $forall($get($1.addcode, "bhs"), function() { //#4542
            var _2R = $k[--$j]; //#4542
            $k[$j++] = $f(_2R - 0.075); //#4542
        }); //#4542
        $1.bhs = $a(); //#4542
        $k[$j++] = Infinity; //#4543
        $aload($1.bbs); //#4543
        $forall($get($1.addcode, "bbs"), function() { //#4543
            var _2W = $k[--$j]; //#4543
            $k[$j++] = $f(_2W + 0.075); //#4543
        }); //#4543
        $1.bbs = $a(); //#4543
        $k[$j++] = Infinity; //#4544
        $aload($1.txt); //#4544
        $aload($get($1.addcode, "txt")); //#4544
        $1.txt = $a(); //#4544
        $1.guardrightypos = ($1.height * 72) - 6; //#4545
    } //#4545
    var _2j = new Map([
        ["ren", bwipp_renlinear],
        ["sbs", $1.sbs],
        ["bhs", $1.bhs],
        ["bbs", $1.bbs],
        ["txt", $1.txt],
        ["opt", $1.options],
        ["guardleftpos", 10],
        ["guardrightpos", 10],
        ["guardrightypos", $1.guardrightypos],
        ["borderbottom", 5]
    ]); //#4559
    $k[$j++] = _2j; //#4562
    if (!$1.dontdraw) { //#4562
        bwipp_renlinear(); //#4562
    } //#4562
}

function bwipp_upca() {
    var $1 = {}; //#4598
    $1.ctx = null; //#4600
    $1.dontdraw = false; //#4601
    $1.includetext = false; //#4602
    $1.textfont = "OCR-B"; //#4603
    $1.textsize = 12; //#4604
    $1.textxoffset = -7; //#4605
    $1.textyoffset = -4; //#4606
    $1.height = 1; //#4607
    $1.addongap = 12; //#4608
    $1.addontextfont = "unset"; //#4609
    $1.addontextsize = null; //#4610
    $1.addontextxoffset = null; //#4611
    $1.addontextyoffset = null; //#4612
    $k[$j++] = $1; //#4614
    bwipp_processoptions(); //#4614
    $1.options = $k[--$j]; //#4614
    $1.barcode = $k[--$j]; //#4615
    $search($1.barcode, " "); //#4620
    if ($k[--$j]) { //#4626
        $1.barcode = $k[--$j]; //#4621
        $j--; //#4622
        $1.addon = $k[--$j]; //#4623
    } else { //#4626
        $j--; //#4625
        $1.addon = ""; //#4626
    } //#4626
    if (($1.barcode.length == 7) || ($1.barcode.length == 8)) { //#4672
        $forall($1.barcode, function() { //#4636
            var _9 = $k[--$j]; //#4633
            if ((_9 < 48) || (_9 > 57)) { //#4635
                $k[$j++] = 'bwipp.upcAupcEbadCharacter'; //#4634
                $k[$j++] = "UPC-E must contain only digits"; //#4634
                bwipp_raiseerror(); //#4634
            } //#4634
        }); //#4634
        var _B = $get($1.barcode, 0); //#4637
        if ((_B != 48) && (_B != 49)) { //#4639
            $k[$j++] = 'bwipp.upcAupcEbadNumberSystem'; //#4638
            $k[$j++] = "UPC-E must have number system 0 or 1"; //#4638
            bwipp_raiseerror(); //#4638
        } //#4638
        for (var _C = 0, _D = 1; _C < _D; _C++) { //#4667
            var _F = ($1.barcode.length == 8) ? 12 : 11; //#4641
            $1.upcacode = $s(_F); //#4641
            if ($f($get($1.barcode, 6) - 48) <= 2) { //#4648
                $puti($1.upcacode, 0, $geti($1.barcode, 0, 3)); //#4643
                $puti($1.upcacode, 3, $geti($1.barcode, 6, 1)); //#4644
                $puti($1.upcacode, 4, "0000"); //#4645
                $puti($1.upcacode, 8, $geti($1.barcode, 3, 3)); //#4646
                break; //#4647
            } //#4647
            if ($f($get($1.barcode, 6) - 48) == 3) { //#4654
                $puti($1.upcacode, 0, $geti($1.barcode, 0, 4)); //#4650
                $puti($1.upcacode, 4, "00000"); //#4651
                $puti($1.upcacode, 9, $geti($1.barcode, 4, 2)); //#4652
                break; //#4653
            } //#4653
            if ($f($get($1.barcode, 6) - 48) == 4) { //#4660
                $puti($1.upcacode, 0, $geti($1.barcode, 0, 5)); //#4656
                $puti($1.upcacode, 5, "00000"); //#4657
                $puti($1.upcacode, 10, $geti($1.barcode, 5, 1)); //#4658
                break; //#4659
            } //#4659
            if ($f($get($1.barcode, 6) - 48) >= 5) { //#4666
                $puti($1.upcacode, 0, $geti($1.barcode, 0, 6)); //#4662
                $puti($1.upcacode, 6, "0000"); //#4663
                $puti($1.upcacode, 10, $geti($1.barcode, 6, 1)); //#4664
                break; //#4665
            } //#4665
        } //#4665
        if ($1.barcode.length == 8) { //#4670
            $puti($1.upcacode, 11, $geti($1.barcode, 7, 1)); //#4669
        } //#4669
        $1.barcode = $1.upcacode; //#4671
    } //#4671
    if (($1.barcode.length != 11) && ($1.barcode.length != 12)) { //#4677
        $k[$j++] = 'bwipp.upcAbadLength'; //#4676
        $k[$j++] = "UPC-A must be 11 or 12 digits"; //#4676
        bwipp_raiseerror(); //#4676
    } //#4676
    var _11 = $1.barcode; //#4678
    for (var _12 = 0, _13 = _11.length; _12 < _13; _12++) { //#4682
        var _14 = $get(_11, _12); //#4682
        if ((_14 < 48) || (_14 > 57)) { //#4681
            $k[$j++] = 'bwipp.upcAbadCharacter'; //#4680
            $k[$j++] = "UPC-A must contain only digits"; //#4680
            bwipp_raiseerror(); //#4680
        } //#4680
    } //#4680
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#4685
        $k[$j++] = 'bwipp.upcAbadAddOnLength'; //#4684
        $k[$j++] = "Add-on for UPC-A must be 2 or 5 digits"; //#4684
        bwipp_raiseerror(); //#4684
    } //#4684
    $1.pad = $s(12); //#4688
    $1.checksum = 0; //#4689
    for (var _19 = 0; _19 <= 10; _19 += 1) { //#4698
        $1.i = _19; //#4691
        $1.barchar = $get($1.barcode, $1.i) - 48; //#4692
        if (($1.i % 2) != 0) { //#4696
            $1.checksum = $1.checksum + $1.barchar; //#4694
        } else { //#4696
            $1.checksum = $1.checksum + ($1.barchar * 3); //#4696
        } //#4696
    } //#4696
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#4699
    if ($1.barcode.length == 12) { //#4704
        if ($get($1.barcode, 11) != ($1.checksum + 48)) { //#4703
            $k[$j++] = 'bwipp.upcAbadCheckDigit'; //#4702
            $k[$j++] = "Incorrect UPC check digit provided"; //#4702
            bwipp_raiseerror(); //#4702
        } //#4702
    } //#4702
    $puti($1.pad, 0, $1.barcode); //#4705
    $put($1.pad, 11, $1.checksum + 48); //#4706
    $1.barcode = $1.pad; //#4707
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "111", "11111", "111"]); //#4715
    $1.barchars = "0123456789"; //#4718
    $1.sbs = $s(59); //#4721
    $1.txt = $a(12); //#4722
    $puti($1.sbs, 0, $get($1.encs, 10)); //#4725
    for (var _1Y = 0; _1Y <= 5; _1Y += 1) { //#4742
        $1.i = _1Y; //#4730
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4731
        $j--; //#4732
        $1.indx = $k[--$j].length; //#4733
        $j -= 2; //#4734
        $1.enc = $get($1.encs, $1.indx); //#4735
        $puti($1.sbs, ($1.i * 4) + 3, $1.enc); //#4736
        if ($1.i == 0) { //#4740
            $put($1.txt, 0, $a([$geti($1.barcode, 0, 1), $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize - 2])); //#4738
        } else { //#4740
            $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 7) + 11) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#4740
        } //#4740
    } //#4740
    $puti($1.sbs, (6 * 4) + 3, $get($1.encs, 11)); //#4745
    for (var _27 = 6; _27 <= 11; _27 += 1) { //#4762
        $1.i = _27; //#4750
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#4751
        $j--; //#4752
        $1.indx = $k[--$j].length; //#4753
        $j -= 2; //#4754
        $1.enc = $get($1.encs, $1.indx); //#4755
        $puti($1.sbs, ($1.i * 4) + 8, $1.enc); //#4756
        if ($1.i == 11) { //#4760
            $put($1.txt, 11, $a([$geti($1.barcode, 11, 1), $1.textxoffset + 104, $1.textyoffset, $1.textfont, $1.textsize - 2])); //#4758
        } else { //#4760
            $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 7) + $1.textxoffset) + 15, $1.textyoffset, $1.textfont, $1.textsize])); //#4760
        } //#4760
    } //#4760
    $puti($1.sbs, 56, $get($1.encs, 12)); //#4765
    $k[$j++] = Infinity; //#4767
    var _2g = $1.sbs; //#4767
    for (var _2h = 0, _2i = _2g.length; _2h < _2i; _2h++) { //#4767
        $k[$j++] = $get(_2g, _2h) - 48; //#4767
    } //#4767
    $1.sbs = $a(); //#4767
    if ($1.includetext) { //#4774
        $k[$j++] = Infinity; //#4769
        for (var _2m = 0, _2n = 4; _2m < _2n; _2m++) { //#4769
            $k[$j++] = $1.height; //#4769
        } //#4769
        for (var _2p = 0, _2q = 10; _2p < _2q; _2p++) { //#4769
            $k[$j++] = $f($1.height - 0.075); //#4769
        } //#4769
        $k[$j++] = $1.height; //#4769
        $k[$j++] = $1.height; //#4769
        for (var _2u = 0, _2v = 10; _2u < _2v; _2u++) { //#4769
            $k[$j++] = $f($1.height - 0.075); //#4769
        } //#4769
        for (var _2x = 0, _2y = 4; _2x < _2y; _2x++) { //#4769
            $k[$j++] = $1.height; //#4769
        } //#4769
        $1.bhs = $a(); //#4769
        $k[$j++] = Infinity; //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        for (var _31 = 0, _32 = 10; _31 < _32; _31++) { //#4770
            $k[$j++] = 0.075; //#4770
        } //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        for (var _33 = 0, _34 = 10; _33 < _34; _33++) { //#4770
            $k[$j++] = 0.075; //#4770
        } //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        $k[$j++] = 0; //#4770
        $1.bbs = $a(); //#4770
    } else { //#4774
        $k[$j++] = Infinity; //#4772
        for (var _36 = 0, _37 = 30; _36 < _37; _36++) { //#4772
            $k[$j++] = $1.height; //#4772
        } //#4772
        $1.bhs = $a(); //#4772
        $k[$j++] = Infinity; //#4773
        for (var _3A = 0, _3B = 30; _3A < _3B; _3A++) { //#4773
            $k[$j++] = 0; //#4773
        } //#4773
        $1.bbs = $a(); //#4773
        $1.txt = $a([]); //#4774
    } //#4774
    $1.guardrightypos = 0; //#4776
    if ($ne($1.addon, "")) { //#4797
        $k[$j++] = Infinity; //#4787
        $k[$j++] = 'dontdraw'; //#4784
        $k[$j++] = true; //#4784
        $k[$j++] = 'includetext'; //#4784
        $k[$j++] = true; //#4784
        $k[$j++] = 'height'; //#4784
        $k[$j++] = $f($1.height - 0.15); //#4784
        $k[$j++] = 'textxoffset'; //#4784
        if ($ne($1.addontextxoffset, null)) { //#4784
            $k[$j++] = $1.addontextxoffset; //#4784
        } else { //#4784
            $k[$j++] = 95 + $1.addongap; //#4784
        } //#4784
        if ($ne($1.addontextyoffset, null)) { //#4785
            $k[$j++] = 'textyoffset'; //#4785
            $k[$j++] = $1.addontextyoffset; //#4785
        } //#4785
        $k[$j++] = 'textsize'; //#4786
        if ($ne($1.addontextsize, null)) { //#4786
            $k[$j++] = $1.addontextsize; //#4786
        } else { //#4786
            $k[$j++] = $1.textsize; //#4786
        } //#4786
        var _3P = $ne($1.addontextfont, "unset") ? $1.addontextfont : $1.textfont; //#4787
        $k[$j++] = 'textfont'; //#4787
        $k[$j++] = _3P; //#4787
        $1.addopts = $d(); //#4788
        if ($1.addon.length == 2) { //#4789
            $k[$j++] = $1.addon; //#4789
            $k[$j++] = $1.addopts; //#4789
            bwipp_ean2(); //#4789
        } //#4789
        if ($1.addon.length == 5) { //#4790
            $k[$j++] = $1.addon; //#4790
            $k[$j++] = $1.addopts; //#4790
            bwipp_ean5(); //#4790
        } //#4790
        $1.addcode = $k[--$j]; //#4791
        $k[$j++] = Infinity; //#4792
        $aload($1.sbs); //#4792
        $k[$j++] = $1.addongap; //#4792
        $aload($get($1.addcode, "sbs")); //#4792
        $1.sbs = $a(); //#4792
        $k[$j++] = Infinity; //#4793
        $aload($1.bhs); //#4793
        $forall($get($1.addcode, "bhs"), function() { //#4793
            var _3g = $k[--$j]; //#4793
            $k[$j++] = $f(_3g - 0.075); //#4793
        }); //#4793
        $1.bhs = $a(); //#4793
        $k[$j++] = Infinity; //#4794
        $aload($1.bbs); //#4794
        $forall($get($1.addcode, "bbs"), function() { //#4794
            var _3l = $k[--$j]; //#4794
            $k[$j++] = $f(_3l + 0.075); //#4794
        }); //#4794
        $1.bbs = $a(); //#4794
        $k[$j++] = Infinity; //#4795
        $aload($1.txt); //#4795
        $aload($get($1.addcode, "txt")); //#4795
        $1.txt = $a(); //#4795
        $1.guardrightypos = ($1.height * 72) - 6; //#4796
    } //#4796
    var _3y = new Map([
        ["ren", bwipp_renlinear],
        ["sbs", $1.sbs],
        ["bhs", $1.bhs],
        ["bbs", $1.bbs],
        ["txt", $1.txt],
        ["opt", $1.options],
        ["guardrightpos", 10],
        ["guardrightypos", $1.guardrightypos],
        ["borderbottom", 5]
    ]); //#4809
    $k[$j++] = _3y; //#4812
    if (!$1.dontdraw) { //#4812
        bwipp_renlinear(); //#4812
    } //#4812
}

function bwipp_upce() {
    var $1 = {}; //#4848
    $1.ctx = null; //#4850
    $1.dontdraw = false; //#4851
    $1.includetext = false; //#4852
    $1.textfont = "OCR-B"; //#4853
    $1.textsize = 12; //#4854
    $1.textxoffset = -7; //#4855
    $1.textyoffset = -4; //#4856
    $1.height = 1; //#4857
    $1.addongap = 12; //#4858
    $1.addontextfont = "unset"; //#4859
    $1.addontextsize = null; //#4860
    $1.addontextxoffset = null; //#4861
    $1.addontextyoffset = null; //#4862
    $k[$j++] = $1; //#4864
    bwipp_processoptions(); //#4864
    $1.options = $k[--$j]; //#4864
    $1.barcode = $k[--$j]; //#4865
    $search($1.barcode, " "); //#4870
    if ($k[--$j]) { //#4876
        $1.barcode = $k[--$j]; //#4871
        $j--; //#4872
        $1.addon = $k[--$j]; //#4873
    } else { //#4876
        $j--; //#4875
        $1.addon = ""; //#4876
    } //#4876
    if (($1.barcode.length == 11) || ($1.barcode.length == 12)) { //#4918
        $forall($1.barcode, function() { //#4886
            var _9 = $k[--$j]; //#4883
            if ((_9 < 48) || (_9 > 57)) { //#4885
                $k[$j++] = 'bwipp.upcEupcAbadCharacter'; //#4884
                $k[$j++] = "UPC-A must contain only digits"; //#4884
                bwipp_raiseerror(); //#4884
            } //#4884
        }); //#4884
        for (var _A = 0, _B = 1; _A < _B; _A++) { //#4913
            var _D = ($1.barcode.length == 12) ? 8 : 7; //#4888
            $1.upcecode = $s(_D); //#4888
            if (($f($get($1.barcode, 3) - 48) <= 2) && $eq($geti($1.barcode, 4, 4), "0000")) { //#4894
                $puti($1.upcecode, 0, $geti($1.barcode, 0, 3)); //#4890
                $puti($1.upcecode, 3, $geti($1.barcode, 8, 3)); //#4891
                $puti($1.upcecode, 6, $geti($1.barcode, 3, 1)); //#4892
                break; //#4893
            } //#4893
            if ($eq($geti($1.barcode, 4, 5), "00000")) { //#4900
                $puti($1.upcecode, 0, $geti($1.barcode, 0, 4)); //#4896
                $puti($1.upcecode, 4, $geti($1.barcode, 9, 2)); //#4897
                $puti($1.upcecode, 6, "3"); //#4898
                break; //#4899
            } //#4899
            if ($eq($geti($1.barcode, 5, 5), "00000")) { //#4906
                $puti($1.upcecode, 0, $geti($1.barcode, 0, 5)); //#4902
                $puti($1.upcecode, 5, $geti($1.barcode, 10, 1)); //#4903
                $puti($1.upcecode, 6, "4"); //#4904
                break; //#4905
            } //#4905
            if (($f($get($1.barcode, 10) - 48) >= 5) && $eq($geti($1.barcode, 6, 4), "0000")) { //#4911
                $puti($1.upcecode, 0, $geti($1.barcode, 0, 6)); //#4908
                $puti($1.upcecode, 6, $geti($1.barcode, 10, 1)); //#4909
                break; //#4910
            } //#4910
            $k[$j++] = 'bwipp.upcEupcAnotCompressible'; //#4912
            $k[$j++] = "UPC-A cannot be converted to a UPC-E"; //#4912
            bwipp_raiseerror(); //#4912
        } //#4912
        if ($1.barcode.length == 12) { //#4916
            $puti($1.upcecode, 7, $geti($1.barcode, 11, 1)); //#4915
        } //#4915
        $1.barcode = $1.upcecode; //#4917
    } //#4917
    if (($1.barcode.length != 7) && ($1.barcode.length != 8)) { //#4923
        $k[$j++] = 'bwipp.upcEbadLength'; //#4922
        $k[$j++] = "UPC-E must be 7 or 8 digits"; //#4922
        bwipp_raiseerror(); //#4922
    } //#4922
    var _11 = $1.barcode; //#4924
    for (var _12 = 0, _13 = _11.length; _12 < _13; _12++) { //#4928
        var _14 = $get(_11, _12); //#4928
        if ((_14 < 48) || (_14 > 57)) { //#4927
            $k[$j++] = 'bwipp.upcEbadCharacter'; //#4926
            $k[$j++] = "UPC-E must contain only digits"; //#4926
            bwipp_raiseerror(); //#4926
        } //#4926
    } //#4926
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#4931
        $k[$j++] = 'bwipp.upcEbadAddOnLength'; //#4930
        $k[$j++] = "Add-on for UPC-E must be 2 or 5 digits"; //#4930
        bwipp_raiseerror(); //#4930
    } //#4930
    var _19 = $get($1.barcode, 0); //#4934
    if ((_19 != 48) && (_19 != 49)) { //#4936
        $k[$j++] = 'bwipp.upcEbadNumberSystem'; //#4935
        $k[$j++] = "UPC-E must have number system 0 or 1"; //#4935
        bwipp_raiseerror(); //#4935
    } //#4935
    $1.encs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "1312", "1213", "3112", "111", "111111"]); //#4944
    $1.barchars = "0123456789"; //#4947
    $1.mirrormaps = $a(["000111", "001011", "001101", "001110", "010011", "011001", "011100", "010101", "010110", "011010"]); //#4952
    for (var _1C = 0, _1D = 1; _1C < _1D; _1C++) { //#4983
        $1.upcacode = $s(11); //#4957
        if (($get($1.barcode, 6) - 48) <= 2) { //#4964
            $puti($1.upcacode, 0, $geti($1.barcode, 0, 3)); //#4959
            $puti($1.upcacode, 3, $geti($1.barcode, 6, 1)); //#4960
            $puti($1.upcacode, 4, "0000"); //#4961
            $puti($1.upcacode, 8, $geti($1.barcode, 3, 3)); //#4962
            break; //#4963
        } //#4963
        if (($get($1.barcode, 6) - 48) == 3) { //#4970
            $puti($1.upcacode, 0, $geti($1.barcode, 0, 4)); //#4966
            $puti($1.upcacode, 4, "00000"); //#4967
            $puti($1.upcacode, 9, $geti($1.barcode, 4, 2)); //#4968
            break; //#4969
        } //#4969
        if (($get($1.barcode, 6) - 48) == 4) { //#4976
            $puti($1.upcacode, 0, $geti($1.barcode, 0, 5)); //#4972
            $puti($1.upcacode, 5, "00000"); //#4973
            $puti($1.upcacode, 10, $geti($1.barcode, 5, 1)); //#4974
            break; //#4975
        } //#4975
        if (($get($1.barcode, 6) - 48) >= 5) { //#4982
            $puti($1.upcacode, 0, $geti($1.barcode, 0, 6)); //#4978
            $puti($1.upcacode, 6, "0000"); //#4979
            $puti($1.upcacode, 10, $geti($1.barcode, 6, 1)); //#4980
            break; //#4981
        } //#4981
    } //#4981
    $1.checksum = 0; //#4984
    for (var _1s = 0; _1s <= 10; _1s += 1) { //#4993
        $1.i = _1s; //#4986
        $1.barchar = $get($1.upcacode, $1.i) - 48; //#4987
        if (($1.i % 2) != 0) { //#4991
            $1.checksum = $1.checksum + $1.barchar; //#4989
        } else { //#4991
            $1.checksum = $1.checksum + ($1.barchar * 3); //#4991
        } //#4991
    } //#4991
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#4994
    if ($1.barcode.length == 8) { //#4999
        if ($get($1.barcode, 7) != ($1.checksum + 48)) { //#4998
            $k[$j++] = 'bwipp.upcEbadCheckDigit'; //#4997
            $k[$j++] = "Incorrect UPC check digit provided"; //#4997
            bwipp_raiseerror(); //#4997
        } //#4997
    } //#4997
    $1.pad = $s(8); //#5000
    $puti($1.pad, 0, $1.barcode); //#5001
    $put($1.pad, 7, $1.checksum + 48); //#5002
    $1.barcode = $1.pad; //#5003
    $1.txt = $a(8); //#5004
    $put($1.txt, 0, $a([$geti($1.barcode, 0, 1), $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize - 2])); //#5005
    $1.mirrormap = $get($1.mirrormaps, $1.checksum); //#5008
    if ($get($1.barcode, 0) == 48) { //#5022
        $1.invt = $s($1.mirrormap.length); //#5012
        for (var _2U = 0, _2T = $1.mirrormap.length - 1; _2U <= _2T; _2U += 1) { //#5020
            $1.i = _2U; //#5014
            if ($get($1.mirrormap, $1.i) == 48) { //#5018
                $put($1.invt, $1.i, 49); //#5016
            } else { //#5018
                $put($1.invt, $1.i, 48); //#5018
            } //#5018
        } //#5018
        $1.mirrormap = $1.invt; //#5021
    } //#5021
    $1.sbs = $s(33); //#5024
    $puti($1.sbs, 0, $get($1.encs, 10)); //#5027
    for (var _2h = 1; _2h <= 6; _2h += 1) { //#5049
        $1.i = _2h; //#5030
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#5032
        $j--; //#5033
        $1.indx = $k[--$j].length; //#5034
        $j -= 2; //#5035
        $1.enc = $get($1.encs, $1.indx); //#5036
        if ($get($1.mirrormap, $1.i - 1) == 49) { //#5046
            $1.enclen = $1.enc.length; //#5038
            $1.revenc = $s($1.enclen); //#5039
            for (var _2y = 0, _2x = $1.enclen - 1; _2y <= _2x; _2y += 1) { //#5044
                $1.j = _2y; //#5041
                $1.char = $get($1.enc, $1.j); //#5042
                $put($1.revenc, ($1.enclen - $1.j) - 1, $1.char); //#5043
            } //#5043
            $1.enc = $1.revenc; //#5045
        } //#5045
        $puti($1.sbs, (($1.i - 1) * 4) + 3, $1.enc); //#5047
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 1) * 7) + 11) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])); //#5048
    } //#5048
    $put($1.txt, 7, $a([$geti($1.barcode, 7, 1), ((6 * 7) + 18) + $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize - 2])); //#5051
    $puti($1.sbs, 27, $get($1.encs, 11)); //#5054
    $k[$j++] = Infinity; //#5056
    var _3W = $1.sbs; //#5056
    for (var _3X = 0, _3Y = _3W.length; _3X < _3Y; _3X++) { //#5056
        $k[$j++] = $get(_3W, _3X) - 48; //#5056
    } //#5056
    $1.sbs = $a(); //#5056
    if ($1.includetext) { //#5063
        $k[$j++] = Infinity; //#5058
        $k[$j++] = $1.height; //#5058
        $k[$j++] = $1.height; //#5058
        for (var _3e = 0, _3f = 12; _3e < _3f; _3e++) { //#5058
            $k[$j++] = $f($1.height - 0.075); //#5058
        } //#5058
        $k[$j++] = $1.height; //#5058
        $k[$j++] = $1.height; //#5058
        $k[$j++] = $1.height; //#5058
        $1.bhs = $a(); //#5058
        $k[$j++] = Infinity; //#5059
        $k[$j++] = 0; //#5059
        $k[$j++] = 0; //#5059
        for (var _3l = 0, _3m = 12; _3l < _3m; _3l++) { //#5059
            $k[$j++] = 0.075; //#5059
        } //#5059
        $k[$j++] = 0; //#5059
        $k[$j++] = 0; //#5059
        $k[$j++] = 0; //#5059
        $1.bbs = $a(); //#5059
    } else { //#5063
        $k[$j++] = Infinity; //#5061
        for (var _3o = 0, _3p = 17; _3o < _3p; _3o++) { //#5061
            $k[$j++] = $1.height; //#5061
        } //#5061
        $1.bhs = $a(); //#5061
        $k[$j++] = Infinity; //#5062
        for (var _3s = 0, _3t = 17; _3s < _3t; _3s++) { //#5062
            $k[$j++] = 0; //#5062
        } //#5062
        $1.bbs = $a(); //#5062
        $1.txt = $a([]); //#5063
    } //#5063
    $1.guardrightypos = 0; //#5065
    if ($ne($1.addon, "")) { //#5086
        $k[$j++] = Infinity; //#5076
        $k[$j++] = 'dontdraw'; //#5073
        $k[$j++] = true; //#5073
        $k[$j++] = 'includetext'; //#5073
        $k[$j++] = true; //#5073
        $k[$j++] = 'height'; //#5073
        $k[$j++] = $f($1.height - 0.15); //#5073
        $k[$j++] = 'textxoffset'; //#5073
        if ($ne($1.addontextxoffset, null)) { //#5073
            $k[$j++] = $1.addontextxoffset; //#5073
        } else { //#5073
            $k[$j++] = 51 + $1.addongap; //#5073
        } //#5073
        if ($ne($1.addontextyoffset, null)) { //#5074
            $k[$j++] = 'textyoffset'; //#5074
            $k[$j++] = $1.addontextyoffset; //#5074
        } //#5074
        $k[$j++] = 'textsize'; //#5075
        if ($ne($1.addontextsize, null)) { //#5075
            $k[$j++] = $1.addontextsize; //#5075
        } else { //#5075
            $k[$j++] = $1.textsize; //#5075
        } //#5075
        var _47 = $ne($1.addontextfont, "unset") ? $1.addontextfont : $1.textfont; //#5076
        $k[$j++] = 'textfont'; //#5076
        $k[$j++] = _47; //#5076
        $1.addopts = $d(); //#5077
        if ($1.addon.length == 2) { //#5078
            $k[$j++] = $1.addon; //#5078
            $k[$j++] = $1.addopts; //#5078
            bwipp_ean2(); //#5078
        } //#5078
        if ($1.addon.length == 5) { //#5079
            $k[$j++] = $1.addon; //#5079
            $k[$j++] = $1.addopts; //#5079
            bwipp_ean5(); //#5079
        } //#5079
        $1.addcode = $k[--$j]; //#5080
        $k[$j++] = Infinity; //#5081
        $aload($1.sbs); //#5081
        $k[$j++] = $1.addongap; //#5081
        $aload($get($1.addcode, "sbs")); //#5081
        $1.sbs = $a(); //#5081
        $k[$j++] = Infinity; //#5082
        $aload($1.bhs); //#5082
        $forall($get($1.addcode, "bhs"), function() { //#5082
            var _4O = $k[--$j]; //#5082
            $k[$j++] = $f(_4O - 0.075); //#5082
        }); //#5082
        $1.bhs = $a(); //#5082
        $k[$j++] = Infinity; //#5083
        $aload($1.bbs); //#5083
        $forall($get($1.addcode, "bbs"), function() { //#5083
            var _4T = $k[--$j]; //#5083
            $k[$j++] = $f(_4T + 0.075); //#5083
        }); //#5083
        $1.bbs = $a(); //#5083
        $k[$j++] = Infinity; //#5084
        $aload($1.txt); //#5084
        $aload($get($1.addcode, "txt")); //#5084
        $1.txt = $a(); //#5084
        $1.guardrightypos = ($1.height * 72) - 6; //#5085
    } //#5085
    var _4g = new Map([
        ["ren", bwipp_renlinear],
        ["sbs", $1.sbs],
        ["bhs", $1.bhs],
        ["bbs", $1.bbs],
        ["txt", $1.txt],
        ["opt", $1.options],
        ["guardrightpos", 10],
        ["guardrightypos", $1.guardrightypos],
        ["borderbottom", 5]
    ]); //#5098
    $k[$j++] = _4g; //#5101
    if (!$1.dontdraw) { //#5101
        bwipp_renlinear(); //#5101
    } //#5101
}

function bwipp_isbn() {
    var $1 = {}; //#5134
    $1.ctx = null; //#5136
    $1.dontdraw = false; //#5137
    $1.includetext = false; //#5138
    $1.isbntextfont = 'OCR-A'; //#5139
    $1.isbntextsize = 8; //#5140
    $1.isbntextxoffset = null; //#5141
    $1.isbntextyoffset = null; //#5142
    $1.height = 1; //#5143
    $1.addongap = 12; //#5144
    $1.legacy = false; //#5145
    $k[$j++] = $1; //#5147
    bwipp_processoptions(); //#5147
    $1.options = $k[--$j]; //#5147
    $1.barcode = $k[--$j]; //#5148
    $search($1.barcode, " "); //#5151
    if ($k[--$j]) { //#5157
        $1.barcode = $k[--$j]; //#5152
        $j--; //#5153
        $1.addon = $k[--$j]; //#5154
    } else { //#5157
        $j--; //#5156
        $1.addon = ""; //#5157
    } //#5157
    if ((($1.barcode.length != 15) && ($1.barcode.length != 17)) && (($1.barcode.length != 11) && ($1.barcode.length != 13))) { //#5164
        $k[$j++] = 'bwipp.isbnBadLength'; //#5163
        $k[$j++] = "ISBN-13 must be 15 or 17 characters including dashes. ISBN-10 must be 11 or 13 characters including dashes"; //#5163
        bwipp_raiseerror(); //#5163
    } //#5163
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#5167
        $k[$j++] = 'bwipp.isbnBadAddOnLength'; //#5166
        $k[$j++] = "Add-on for ISBN must be 2 or 5 digits"; //#5166
        bwipp_raiseerror(); //#5166
    } //#5166
    if ($1.barcode.length >= 15) { //#5231
        var _F = $geti($1.barcode, 0, 4); //#5169
        if ($ne(_F, "978-") && $ne(_F, "979-")) { //#5171
            $k[$j++] = 'bwipp.isbn13badPrefix'; //#5170
            $k[$j++] = "ISBN-13 prefix must be 978- or 979-"; //#5170
            bwipp_raiseerror(); //#5170
        } //#5170
        $1.wasdash = false; //#5172
        $1.numdash = 0; //#5172
        $1.numdigit = 0; //#5172
        var _H = $geti($1.barcode, 5, 9); //#5173
        for (var _I = 0, _J = _H.length; _I < _J; _I++) { //#5186
            var _K = $get(_H, _I); //#5186
            $k[$j++] = _K; //#5181
            if (_K == 45) { //#5181
                if ($1.wasdash) { //#5178
                    $k[$j++] = 'bwipp.isbn13adjacentDashes'; //#5177
                    $k[$j++] = "ISBN-13 does not permit adjacent dashes"; //#5177
                    bwipp_raiseerror(); //#5177
                } //#5177
                $1.wasdash = true; //#5179
                $1.numdash = $1.numdash + 1; //#5180
            } //#5180
            var _N = $k[--$j]; //#5182
            if ((_N >= 48) && (_N <= 57)) { //#5185
                $1.wasdash = false; //#5183
                $1.numdigit = $1.numdigit + 1; //#5184
            } //#5184
        } //#5184
        if (($1.numdash != 2) || ($1.numdigit != 7)) { //#5189
            $k[$j++] = 'bwipp.isbn13numDashesDigits'; //#5188
            $k[$j++] = "Incorrect number of dashes and digits for ISBN-13"; //#5188
            bwipp_raiseerror(); //#5188
        } //#5188
        var _S = $get($1.barcode, 14); //#5190
        if ((_S < 48) || (_S > 57)) { //#5192
            $k[$j++] = 'bwipp.isbn13character15'; //#5191
            $k[$j++] = "ISBN-13 character 15 must be a digit"; //#5191
            bwipp_raiseerror(); //#5191
        } //#5191
        if ($1.barcode.length == 17) { //#5200
            if ($ne($geti($1.barcode, 15, 1), "-")) { //#5196
                $k[$j++] = 'bwipp.isbn13character16'; //#5195
                $k[$j++] = "ISBN-13 penultimate character must be a dash"; //#5195
                bwipp_raiseerror(); //#5195
            } //#5195
            var _X = $get($1.barcode, 16); //#5197
            if ((_X < 48) || (_X > 57)) { //#5199
                $k[$j++] = 'bwipp.isbn13character17'; //#5198
                $k[$j++] = "ISBN-13 final character must be a digit"; //#5198
                bwipp_raiseerror(); //#5198
            } //#5198
        } //#5198
    } else { //#5231
        var _Z = $get($1.barcode, 0); //#5202
        if ((_Z < 48) || (_Z > 57)) { //#5204
            $k[$j++] = 'bwipp.isbn10FirstDigit'; //#5203
            $k[$j++] = "ISBN-10 first character must be a digit"; //#5203
            bwipp_raiseerror(); //#5203
        } //#5203
        $1.wasdash = false; //#5205
        $1.numdash = 0; //#5205
        $1.numdigit = 0; //#5205
        var _b = $geti($1.barcode, 1, 9); //#5206
        for (var _c = 0, _d = _b.length; _c < _d; _c++) { //#5219
            var _e = $get(_b, _c); //#5219
            $k[$j++] = _e; //#5214
            if (_e == 45) { //#5214
                if ($1.wasdash) { //#5211
                    $k[$j++] = 'bwipp.isbn10adjacentDashes'; //#5210
                    $k[$j++] = "ISBN-10 does not permit adjacent dashes"; //#5210
                    bwipp_raiseerror(); //#5210
                } //#5210
                $1.wasdash = true; //#5212
                $1.numdash = $1.numdash + 1; //#5213
            } //#5213
            var _h = $k[--$j]; //#5215
            if ((_h >= 48) && (_h <= 57)) { //#5218
                $1.wasdash = false; //#5216
                $1.numdigit = $1.numdigit + 1; //#5217
            } //#5217
        } //#5217
        if (($1.numdash != 2) || ($1.numdigit != 7)) { //#5222
            $k[$j++] = 'bwipp.isbn10numDashesDigits'; //#5221
            $k[$j++] = "Incorrect number of dashes and digits for ISBN-10"; //#5221
            bwipp_raiseerror(); //#5221
        } //#5221
        var _m = $get($1.barcode, 10); //#5223
        if ((_m < 48) || (_m > 57)) { //#5225
            $k[$j++] = 'bwipp.isbn10character11'; //#5224
            $k[$j++] = "ISBN-10 character 11 must be a digit"; //#5224
            bwipp_raiseerror(); //#5224
        } //#5224
        if ($1.barcode.length == 13) { //#5233
            if ($ne($geti($1.barcode, 11, 1), "-")) { //#5229
                $k[$j++] = 'bwipp.isbn10character12'; //#5228
                $k[$j++] = "ISBN-10 penultimate character must be a dash"; //#5228
                bwipp_raiseerror(); //#5228
            } //#5228
            var _r = $get($1.barcode, 12); //#5230
            if (((_r < 48) || (_r > 57)) && (_r != 88)) { //#5232
                $k[$j++] = 'bwipp.isbn10character13'; //#5231
                $k[$j++] = "ISBN-10 final character must be a digit or X"; //#5231
                bwipp_raiseerror(); //#5231
            } //#5231
        } //#5231
    } //#5231
    $1.isbntxt = $1.barcode; //#5236
    if ($1.isbntxt.length <= 13) { //#5262
        $1.isbn = $s(10); //#5240
        $1.checksum = 0; //#5241
        $1.i = 0; //#5242
        $1.n = 0; //#5242
        for (;;) { //#5254
            $1.isbnchar = $f($get($1.isbntxt, $1.i) - 48); //#5244
            if ($1.isbnchar != -3) { //#5251
                $put($1.isbn, $1.n, $f($1.isbnchar + 48)); //#5246
                if ($1.n < 9) { //#5249
                    $1.checksum = $f($1.checksum + ((10 - $1.n) * $1.isbnchar)); //#5248
                } //#5248
                $1.n = $1.n + 1; //#5250
            } //#5250
            $1.i = $1.i + 1; //#5252
            if ($1.i == $1.isbntxt.length) { //#5253
                break; //#5253
            } //#5253
        } //#5253
        var _1B = ($f(11 - ($1.checksum % 11))) % 11; //#5255
        $k[$j++] = 'checksum'; //#5255
        $k[$j++] = _1B; //#5255
        if (_1B == 10) { //#5255
            $j--; //#5255
            $k[$j++] = 40; //#5255
        } //#5255
        var _1C = $k[--$j]; //#5255
        $1[$k[--$j]] = $f(_1C + 48); //#5255
        $1.isbn = $geti($1.isbn, 0, 9); //#5256
        if ($1.isbntxt.length == 13) { //#5261
            if ($get($1.isbntxt, 12) != $1.checksum) { //#5260
                $k[$j++] = 'bwipp.isbn10badCheckDigit'; //#5259
                $k[$j++] = "Incorrect ISBN-10 check digit provided"; //#5259
                bwipp_raiseerror(); //#5259
            } //#5259
        } //#5259
    } //#5259
    if ((!$1.legacy) || ($1.isbntxt.length >= 15)) { //#5298
        if ($1.isbntxt.length <= 13) { //#5272
            $1.pad = $s(15); //#5268
            $puti($1.pad, 0, "978-"); //#5269
            $puti($1.pad, 4, $geti($1.isbntxt, 0, 11)); //#5270
            $1.isbntxt = $1.pad; //#5271
        } //#5271
        $1.isbn = $s(13); //#5275
        $1.checksum = 0; //#5276
        $1.i = 0; //#5277
        $1.n = 0; //#5277
        for (;;) { //#5289
            $1.isbnchar = $get($1.isbntxt, $1.i) - 48; //#5279
            if ($1.isbnchar != -3) { //#5286
                $put($1.isbn, $1.n, $1.isbnchar + 48); //#5281
                if ($1.n < 12) { //#5284
                    $k[$j++] = 'checksum'; //#5283
                    $k[$j++] = $1.isbnchar; //#5283
                    if (($1.n % 2) != 0) { //#5283
                        var _1e = $k[--$j]; //#5283
                        $k[$j++] = _1e * 3; //#5283
                    } //#5283
                    var _1g = $k[--$j]; //#5283
                    $1[$k[--$j]] = $f(_1g + $1.checksum); //#5283
                } //#5283
                $1.n = $1.n + 1; //#5285
            } //#5285
            $1.i = $1.i + 1; //#5287
            if ($1.i == $1.isbntxt.length) { //#5288
                break; //#5288
            } //#5288
        } //#5288
        $1.checksum = ((10 - ($1.checksum % 10)) % 10) + 48; //#5290
        $1.isbn = $geti($1.isbn, 0, 12); //#5291
        if ($1.isbntxt.length == 17) { //#5296
            if ($get($1.isbntxt, 16) != $1.checksum) { //#5295
                $k[$j++] = 'bwipp.isbn13badCheckDigit'; //#5294
                $k[$j++] = "Incorrect ISBN-13 check digit provided"; //#5294
                bwipp_raiseerror(); //#5294
            } //#5294
        } //#5294
    } //#5294
    var _1u = ($1.isbn.length == 12) ? 22 : 18; //#5301
    $1.pad = $s(_1u); //#5301
    $puti($1.pad, 0, "ISBN "); //#5302
    $puti($1.pad, 5, $1.isbntxt); //#5303
    $put($1.pad, $1.pad.length - 2, 45); //#5304
    $put($1.pad, $1.pad.length - 1, $1.checksum); //#5305
    $1.isbntxt = $1.pad; //#5306
    $1.barcode = $s(12); //#5309
    if ($1.isbn.length == 9) { //#5314
        $puti($1.barcode, 0, "978"); //#5311
        $puti($1.barcode, 3, $1.isbn); //#5312
    } else { //#5314
        $puti($1.barcode, 0, $1.isbn); //#5314
    } //#5314
    if ($ne($1.addon, "")) { //#5324
        var _2E = $s((12 + $1.addon.length) + 1); //#5319
        $puti(_2E, 0, $1.barcode); //#5320
        $puti(_2E, 12, " "); //#5321
        $puti(_2E, 13, $1.addon); //#5322
        $1.barcode = _2E; //#5323
    } //#5323
    $put($1.options, "dontdraw", true); //#5327
    $put($1.options, "addongap", $1.addongap); //#5328
    $k[$j++] = 'args'; //#5329
    $k[$j++] = $1.barcode; //#5329
    $k[$j++] = $1.options; //#5329
    bwipp_ean13(); //#5329
    var _2M = $k[--$j]; //#5329
    $1[$k[--$j]] = _2M; //#5329
    if ($1.includetext) { //#5348
        if ($eq($1.isbntextxoffset, null)) { //#5335
            $k[$j++] = 'isbntextxoffset'; //#5334
            if ($1.isbn.length == 9) { //#5334
                $k[$j++] = -1; //#5334
            } else { //#5334
                $k[$j++] = -12; //#5334
            } //#5334
            var _2R = $k[--$j]; //#5334
            $1[$k[--$j]] = _2R; //#5334
        } //#5334
        if ($eq($1.isbntextyoffset, null)) { //#5338
            $1.isbntextyoffset = ($1.height * 72) + 3; //#5337
        } //#5337
        var _2W = $get($1.args, "txt") !== undefined; //#5339
        if (_2W) { //#5346
            $1.txt = $get($1.args, "txt"); //#5340
            $1.newtxt = $a($1.txt.length + 1); //#5341
            $puti($1.newtxt, 0, $1.txt); //#5342
            $put($1.newtxt, $1.newtxt.length - 1, $a([$1.isbntxt, $1.isbntextxoffset, $1.isbntextyoffset, $1.isbntextfont, $1.isbntextsize])); //#5343
            $put($1.args, "txt", $1.newtxt); //#5344
        } else { //#5346
            $put($1.args, "txt", $a([$a([$1.isbntxt, $1.isbntextxoffset, $1.isbntextyoffset, $1.isbntextfont, $1.isbntextsize])])); //#5346
        } //#5346
    } //#5346
    $put($1.args, "opt", $1.options); //#5350
    $k[$j++] = $1.args; //#5353
    if (!$1.dontdraw) { //#5353
        bwipp_renlinear(); //#5353
    } //#5353
}

function bwipp_ismn() {
    var $1 = {}; //#5384
    $1.ctx = null; //#5386
    $1.dontdraw = false; //#5387
    $1.includetext = false; //#5388
    $1.ismntextfont = 'OCR-A'; //#5389
    $1.ismntextsize = 8; //#5390
    $1.ismntextxoffset = null; //#5391
    $1.ismntextyoffset = null; //#5392
    $1.height = 1; //#5393
    $1.addongap = 12; //#5394
    $1.legacy = false; //#5395
    $k[$j++] = $1; //#5397
    bwipp_processoptions(); //#5397
    $1.options = $k[--$j]; //#5397
    $1.barcode = $k[--$j]; //#5398
    $search($1.barcode, " "); //#5401
    if ($k[--$j]) { //#5407
        $1.barcode = $k[--$j]; //#5402
        $j--; //#5403
        $1.addon = $k[--$j]; //#5404
    } else { //#5407
        $j--; //#5406
        $1.addon = ""; //#5407
    } //#5407
    if ((($1.barcode.length != 15) && ($1.barcode.length != 17)) && (($1.barcode.length != 11) && ($1.barcode.length != 13))) { //#5414
        $k[$j++] = 'bwipp.ismnBadLength'; //#5413
        $k[$j++] = "ISMN-13 must be 15 or 17 characters including dashes. ISMN-10 must be 11 or 13 characters including dashes"; //#5413
        bwipp_raiseerror(); //#5413
    } //#5413
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#5417
        $k[$j++] = 'bwipp.ismnBadAddOnLength'; //#5416
        $k[$j++] = "Add-on for ISMN must be 2 or 5 digits"; //#5416
        bwipp_raiseerror(); //#5416
    } //#5416
    if ($1.barcode.length >= 15) { //#5484
        if ($ne($geti($1.barcode, 0, 4), "979-")) { //#5421
            $k[$j++] = 'bwipp.ismn13badPrefix'; //#5420
            $k[$j++] = "ISMN-13 prefix must be 979-"; //#5420
            bwipp_raiseerror(); //#5420
        } //#5420
        $1.wasdash = false; //#5422
        $1.numdash = 0; //#5422
        $1.numdigit = 0; //#5422
        var _H = $geti($1.barcode, 5, 9); //#5423
        for (var _I = 0, _J = _H.length; _I < _J; _I++) { //#5436
            var _K = $get(_H, _I); //#5436
            $k[$j++] = _K; //#5431
            if (_K == 45) { //#5431
                if ($1.wasdash) { //#5428
                    $k[$j++] = 'bwipp.ismn13adjacentDashes'; //#5427
                    $k[$j++] = "ISMN-13 does not permit adjacent dashes"; //#5427
                    bwipp_raiseerror(); //#5427
                } //#5427
                $1.wasdash = true; //#5429
                $1.numdash = $1.numdash + 1; //#5430
            } //#5430
            var _N = $k[--$j]; //#5432
            if ((_N >= 48) && (_N <= 57)) { //#5435
                $1.wasdash = false; //#5433
                $1.numdigit = $1.numdigit + 1; //#5434
            } //#5434
        } //#5434
        if (($1.numdash != 2) || ($1.numdigit != 7)) { //#5439
            $k[$j++] = 'bwipp.ismn13numDashesDigits'; //#5438
            $k[$j++] = "Incorrect number of dashes and digits for ISMN-13"; //#5438
            bwipp_raiseerror(); //#5438
        } //#5438
        var _S = $get($1.barcode, 14); //#5440
        if ((_S < 48) || (_S > 57)) { //#5442
            $k[$j++] = 'bwipp.ismn13character15'; //#5441
            $k[$j++] = "ISMN-13 character 15 must be a digit"; //#5441
            bwipp_raiseerror(); //#5441
        } //#5441
        if ($1.barcode.length == 17) { //#5450
            if ($ne($geti($1.barcode, 15, 1), "-")) { //#5446
                $k[$j++] = 'bwipp.ismn13character16'; //#5445
                $k[$j++] = "ISMN-13 penultimate character must be a dash"; //#5445
                bwipp_raiseerror(); //#5445
            } //#5445
            var _X = $get($1.barcode, 16); //#5447
            if ((_X < 48) || (_X > 57)) { //#5449
                $k[$j++] = 'bwipp.ismn13character17'; //#5448
                $k[$j++] = "ISMN-13 final character must be a digit"; //#5448
                bwipp_raiseerror(); //#5448
            } //#5448
        } //#5448
    } else { //#5484
        if ($ne($geti($1.barcode, 0, 2), "M-")) { //#5454
            $k[$j++] = 'bwipp.ismn10badPrefix'; //#5453
            $k[$j++] = "ISMN-10 prefix must be M-"; //#5453
            bwipp_raiseerror(); //#5453
        } //#5453
        var _b = $get($1.barcode, 2); //#5455
        if ((_b < 48) || (_b > 57)) { //#5457
            $k[$j++] = 'bwipp.ismn10character3'; //#5456
            $k[$j++] = "ISMN-10 character 3 must be a digit"; //#5456
            bwipp_raiseerror(); //#5456
        } //#5456
        $1.wasdash = false; //#5458
        $1.numdash = 0; //#5458
        $1.numdigit = 0; //#5458
        var _d = $geti($1.barcode, 3, 7); //#5459
        for (var _e = 0, _f = _d.length; _e < _f; _e++) { //#5472
            var _g = $get(_d, _e); //#5472
            $k[$j++] = _g; //#5467
            if (_g == 45) { //#5467
                if ($1.wasdash) { //#5464
                    $k[$j++] = 'bwipp.ismn10adjacentDashes'; //#5463
                    $k[$j++] = "ISMN-10 does not permit adjacent dashes"; //#5463
                    bwipp_raiseerror(); //#5463
                } //#5463
                $1.wasdash = true; //#5465
                $1.numdash = $1.numdash + 1; //#5466
            } //#5466
            var _j = $k[--$j]; //#5468
            if ((_j >= 48) && (_j <= 57)) { //#5471
                $1.wasdash = false; //#5469
                $1.numdigit = $1.numdigit + 1; //#5470
            } //#5470
        } //#5470
        if (($1.numdash != 1) || ($1.numdigit != 6)) { //#5475
            $k[$j++] = 'bwipp.ismn10numDashesDigits'; //#5474
            $k[$j++] = "Incorrect number of dashes and digits for ISMN-10"; //#5474
            bwipp_raiseerror(); //#5474
        } //#5474
        var _o = $get($1.barcode, 10); //#5476
        if ((_o < 48) || (_o > 57)) { //#5478
            $k[$j++] = 'bwipp.ismn10character11'; //#5477
            $k[$j++] = "ISMN-10 character 11 must be a digit"; //#5477
            bwipp_raiseerror(); //#5477
        } //#5477
        if ($1.barcode.length == 13) { //#5486
            var _r = $geti($1.barcode, 11, 1); //#5480
            if ($ne(_r, "-")) { //#5482
                $k[$j++] = 'bwipp.ismn10character12'; //#5481
                $k[$j++] = "ISMN-10 penultimate character must be a dash"; //#5481
                bwipp_raiseerror(); //#5481
            } //#5481
            var _t = $get($1.barcode, 12); //#5483
            if (((_t < 48) || (_t > 57)) && (_t != 88)) { //#5485
                $k[$j++] = 'bwipp.ismn10character13'; //#5484
                $k[$j++] = "ISMN-10 final character must be a digit or X"; //#5484
                bwipp_raiseerror(); //#5484
            } //#5484
        } //#5484
    } //#5484
    $1.ismntxt = $1.barcode; //#5489
    $1.legacytxt = ""; //#5492
    if ($1.ismntxt.length <= 13) { //#5499
        $1.legacytxt = $1.ismntxt; //#5494
        $1.pad = $s($1.ismntxt.length + 4); //#5495
        $puti($1.pad, 0, "979-0-"); //#5496
        $puti($1.pad, 6, $geti($1.ismntxt, 2, $1.ismntxt.length - 2)); //#5497
        $1.ismntxt = $1.pad; //#5498
    } //#5498
    $1.ismn = $s(13); //#5502
    $1.checksum = 0; //#5503
    $1.i = 0; //#5504
    $1.n = 0; //#5504
    for (;;) { //#5520
        $1.ismnchar = $get($1.ismntxt, $1.i) - 48; //#5506
        if ($1.ismnchar != -3) { //#5517
            $put($1.ismn, $1.n, $1.ismnchar + 48); //#5508
            if ($1.n < 12) { //#5515
                if (($1.n % 2) == 0) { //#5513
                    $1.checksum = $1.ismnchar + $1.checksum; //#5511
                } else { //#5513
                    $1.checksum = ($1.ismnchar * 3) + $1.checksum; //#5513
                } //#5513
            } //#5513
            $1.n = $1.n + 1; //#5516
        } //#5516
        $1.i = $1.i + 1; //#5518
        if ($1.i == $1.ismntxt.length) { //#5519
            break; //#5519
        } //#5519
    } //#5519
    $1.checksum = ((10 - ($1.checksum % 10)) % 10) + 48; //#5521
    if (($1.barcode.length == 13) || ($1.barcode.length == 17)) { //#5528
        var _1Q = $1.barcode; //#5525
        if ($get(_1Q, _1Q.length - 1) != $1.checksum) { //#5527
            $k[$j++] = 'bwipp.ismnBadCheckDigit'; //#5526
            $k[$j++] = "Incorrect ISMN check digit provided"; //#5526
            bwipp_raiseerror(); //#5526
        } //#5526
    } //#5526
    if ($1.legacy && $ne($1.legacytxt, "")) { //#5535
        $1.ismntxt = $1.legacytxt; //#5532
        $1.pad = $s(18); //#5533
    } else { //#5535
        $1.pad = $s(22); //#5535
    } //#5535
    $puti($1.pad, 0, "ISMN "); //#5537
    $puti($1.pad, 5, $1.ismntxt); //#5538
    $put($1.pad, $1.pad.length - 2, 45); //#5539
    $put($1.pad, $1.pad.length - 1, $1.checksum); //#5540
    $1.ismntxt = $1.pad; //#5541
    $1.barcode = $geti($1.ismn, 0, 12); //#5544
    if ($ne($1.addon, "")) { //#5553
        var _1l = $s((12 + $1.addon.length) + 1); //#5548
        $puti(_1l, 0, $1.barcode); //#5549
        $puti(_1l, 12, " "); //#5550
        $puti(_1l, 13, $1.addon); //#5551
        $1.barcode = _1l; //#5552
    } //#5552
    $put($1.options, "dontdraw", true); //#5556
    $put($1.options, "addongap", $1.addongap); //#5557
    $k[$j++] = 'args'; //#5558
    $k[$j++] = $1.barcode; //#5558
    $k[$j++] = $1.options; //#5558
    bwipp_ean13(); //#5558
    var _1t = $k[--$j]; //#5558
    $1[$k[--$j]] = _1t; //#5558
    if ($1.includetext) { //#5577
        if ($eq($1.ismntextxoffset, null)) { //#5564
            $k[$j++] = 'ismntextxoffset'; //#5563
            if ($1.ismntxt.length == 18) { //#5563
                $k[$j++] = -1; //#5563
            } else { //#5563
                $k[$j++] = -12; //#5563
            } //#5563
            var _1y = $k[--$j]; //#5563
            $1[$k[--$j]] = _1y; //#5563
        } //#5563
        if ($eq($1.ismntextyoffset, null)) { //#5567
            $1.ismntextyoffset = ($1.height * 72) + 3; //#5566
        } //#5566
        var _23 = $get($1.args, "txt") !== undefined; //#5568
        if (_23) { //#5575
            $1.txt = $get($1.args, "txt"); //#5569
            $1.newtxt = $a($1.txt.length + 1); //#5570
            $puti($1.newtxt, 0, $1.txt); //#5571
            $put($1.newtxt, $1.newtxt.length - 1, $a([$1.ismntxt, $1.ismntextxoffset, $1.ismntextyoffset, $1.ismntextfont, $1.ismntextsize])); //#5572
            $put($1.args, "txt", $1.newtxt); //#5573
        } else { //#5575
            $put($1.args, "txt", $a([$a([$1.ismntxt, $1.ismntextxoffset, $1.ismntextyoffset, $1.ismntextfont, $1.ismntextsize])])); //#5575
        } //#5575
    } //#5575
    $put($1.args, "opt", $1.options); //#5579
    $k[$j++] = $1.args; //#5582
    if (!$1.dontdraw) { //#5582
        bwipp_renlinear(); //#5582
    } //#5582
}

function bwipp_issn() {
    var $1 = {}; //#5613
    $1.ctx = null; //#5615
    $1.dontdraw = false; //#5616
    $1.includetext = false; //#5617
    $1.issntextfont = 'OCR-A'; //#5618
    $1.issntextsize = 8; //#5619
    $1.issntextxoffset = null; //#5620
    $1.issntextyoffset = null; //#5621
    $1.height = 1; //#5622
    $1.addongap = 12; //#5623
    $k[$j++] = $1; //#5625
    bwipp_processoptions(); //#5625
    $1.options = $k[--$j]; //#5625
    $1.issntxt = $k[--$j]; //#5626
    $search($1.issntxt, " "); //#5629
    if ($k[--$j]) { //#5635
        $1.issntxt = $k[--$j]; //#5630
        $j--; //#5631
        $1.seqvar = $k[--$j]; //#5632
    } else { //#5635
        $j--; //#5634
        $1.seqvar = "00"; //#5635
    } //#5635
    $search($1.seqvar, " "); //#5639
    if ($k[--$j]) { //#5645
        $1.seqvar = $k[--$j]; //#5640
        $j--; //#5641
        $1.addon = $k[--$j]; //#5642
    } else { //#5645
        $j--; //#5644
        $1.addon = ""; //#5645
    } //#5645
    if (($1.issntxt.length != 8) && ($1.issntxt.length != 9)) { //#5651
        $k[$j++] = 'bwipp.issnBadLength'; //#5650
        $k[$j++] = "ISSN must be 8 or 9 characters including dash, in the format XXXX-XXXX"; //#5650
        bwipp_raiseerror(); //#5650
    } //#5650
    var _D = $geti($1.issntxt, 0, 4); //#5652
    for (var _E = 0, _F = _D.length; _E < _F; _E++) { //#5656
        var _G = $get(_D, _E); //#5656
        if ((_G < 48) || (_G > 57)) { //#5655
            $k[$j++] = 'bwipp.issnFirstThroughFourthNotNumeric'; //#5654
            $k[$j++] = "ISSN first four characters must be numeral characters"; //#5654
            bwipp_raiseerror(); //#5654
        } //#5654
    } //#5654
    if ($ne($geti($1.issntxt, 4, 1), "-")) { //#5659
        $k[$j++] = 'bwipp.issnNeedsDash'; //#5658
        $k[$j++] = "ISSN fifth character must be a dash"; //#5658
        bwipp_raiseerror(); //#5658
    } //#5658
    var _K = $geti($1.issntxt, 5, 3); //#5660
    for (var _L = 0, _M = _K.length; _L < _M; _L++) { //#5664
        var _N = $get(_K, _L); //#5664
        if ((_N < 48) || (_N > 57)) { //#5663
            $k[$j++] = 'bwipp.issnSixthThroughEighthNotNumeric'; //#5662
            $k[$j++] = "ISSN sixth through eighth characters must be numerals"; //#5662
            bwipp_raiseerror(); //#5662
        } //#5662
    } //#5662
    if ($1.issntxt.length == 9) { //#5669
        var _Q = $get($1.issntxt, 8); //#5666
        if (((_Q < 48) || (_Q > 57)) && (_Q != 88)) { //#5668
            $k[$j++] = 'bwipp.issnNinthCharacterBadFormat'; //#5667
            $k[$j++] = "ISSN ninth character must be a number or the character X"; //#5667
            bwipp_raiseerror(); //#5667
        } //#5667
    } //#5667
    if ($1.seqvar.length != 2) { //#5672
        $k[$j++] = 'bwipp.issnBadSequenceVariantLength'; //#5671
        $k[$j++] = "Sequence variant for ISSN must be 2 digits"; //#5671
        bwipp_raiseerror(); //#5671
    } //#5671
    $forall($1.seqvar, function() { //#5677
        var _T = $k[--$j]; //#5674
        if ((_T < 48) || (_T > 57)) { //#5676
            $k[$j++] = 'bwipp.issnSequenceVariantBadCharacter'; //#5675
            $k[$j++] = "Sequence variant for ISSN must contain only digits"; //#5675
            bwipp_raiseerror(); //#5675
        } //#5675
    }); //#5675
    if ((($1.addon.length != 0) && ($1.addon.length != 2)) && ($1.addon.length != 5)) { //#5680
        $k[$j++] = 'bwipp.issnBadAddOnLength'; //#5679
        $k[$j++] = "Add-on for ISSN must be 2 or 5 digits"; //#5679
        bwipp_raiseerror(); //#5679
    } //#5679
    $1.issn = $s(8); //#5683
    $1.checksum = 0; //#5684
    $1.i = 0; //#5685
    $1.n = 0; //#5685
    for (;;) { //#5697
        $1.issnchar = $f($get($1.issntxt, $1.i) - 48); //#5687
        if ($1.issnchar != -3) { //#5694
            $put($1.issn, $1.n, $f($1.issnchar + 48)); //#5689
            if ($1.n < 7) { //#5692
                $1.checksum = $f($1.checksum + ($1.issnchar * (8 - $1.n))); //#5691
            } //#5691
            $1.n = $1.n + 1; //#5693
        } //#5693
        $1.i = $1.i + 1; //#5695
        if ($1.i == $1.issntxt.length) { //#5696
            break; //#5696
        } //#5696
    } //#5696
    $1.checksum = ($f(11 - ($1.checksum % 11))) % 11; //#5698
    var _p = $f($1.checksum + 48); //#5699
    $k[$j++] = 'checksum'; //#5699
    $k[$j++] = _p; //#5699
    if (_p == 58) { //#5699
        $j--; //#5699
        $k[$j++] = 88; //#5699
    } //#5699
    var _q = $k[--$j]; //#5699
    var _r = $k[--$j]; //#5699
    $1[_r] = _q; //#5699
    if ($1.issntxt.length == 9) { //#5704
        if ($get($1.issntxt, 8) != $1.checksum) { //#5703
            $k[$j++] = 'bwipp.issnBadCheckDigit'; //#5702
            $k[$j++] = "Incorrect ISSN check digit provided"; //#5702
            bwipp_raiseerror(); //#5702
        } //#5702
    } //#5702
    $1.pad = $s(14); //#5707
    $puti($1.pad, 0, "ISSN "); //#5708
    $puti($1.pad, 5, $1.issntxt); //#5709
    $put($1.pad, 13, $1.checksum); //#5710
    $1.issntxt = $1.pad; //#5711
    $1.barcode = $geti($1.issn, 0, 7); //#5714
    $1.barcode = $s(12); //#5717
    $puti($1.barcode, 0, "977"); //#5718
    $puti($1.barcode, 3, $1.issn); //#5719
    $puti($1.barcode, 10, $1.seqvar); //#5720
    if ($ne($1.addon, "")) { //#5729
        var _1D = $s((12 + $1.addon.length) + 1); //#5724
        $puti(_1D, 0, $1.barcode); //#5725
        $puti(_1D, 12, " "); //#5726
        $puti(_1D, 13, $1.addon); //#5727
        $1.barcode = _1D; //#5728
    } //#5728
    $put($1.options, "dontdraw", true); //#5732
    $put($1.options, "addongap", $1.addongap); //#5733
    $k[$j++] = 'args'; //#5734
    $k[$j++] = $1.barcode; //#5734
    $k[$j++] = $1.options; //#5734
    bwipp_ean13(); //#5734
    var _1L = $k[--$j]; //#5734
    $1[$k[--$j]] = _1L; //#5734
    if ($1.includetext) { //#5749
        if ($eq($1.issntextxoffset, null)) { //#5738
            $1.issntextxoffset = 10; //#5738
        } //#5738
        if ($eq($1.issntextyoffset, null)) { //#5739
            $1.issntextyoffset = ($1.height * 72) + 3; //#5739
        } //#5739
        var _1S = $get($1.args, "txt") !== undefined; //#5740
        if (_1S) { //#5747
            $1.txt = $get($1.args, "txt"); //#5741
            $1.newtxt = $a($1.txt.length + 1); //#5742
            $puti($1.newtxt, 0, $1.txt); //#5743
            $put($1.newtxt, $1.newtxt.length - 1, $a([$1.issntxt, $1.issntextxoffset, $1.issntextyoffset, $1.issntextfont, $1.issntextsize])); //#5744
            $put($1.args, "txt", $1.newtxt); //#5745
        } else { //#5747
            $put($1.args, "txt", $a([$a([$1.issntxt, $1.issntextxoffset, $1.issntextyoffset, $1.issntextfont, $1.issntextsize])])); //#5747
        } //#5747
    } //#5747
    $put($1.args, "opt", $1.options); //#5751
    $k[$j++] = $1.args; //#5754
    if (!$1.dontdraw) { //#5754
        bwipp_renlinear(); //#5754
    } //#5754
}

function bwipp_mands() {
    var $1 = {}; //#5785
    $1.ctx = null; //#5787
    $1.dontdraw = false; //#5788
    $1.includetext = false; //#5789
    $k[$j++] = $1; //#5791
    bwipp_processoptions(); //#5791
    $1.options = $k[--$j]; //#5791
    $1.barcode = $k[--$j]; //#5792
    $1.barlen = $1.barcode.length; //#5794
    if (($1.barlen != 7) && ($1.barlen != 8)) { //#5799
        $k[$j++] = 'bwipp.MandSbadLength'; //#5798
        $k[$j++] = "M&S barcode must be 7 or 8 characters"; //#5798
        bwipp_raiseerror(); //#5798
    } //#5798
    if ($1.barlen == 7) { //#5803
        var _7 = $strcpy($s(8), "00000000"); //#5802
        $puti(_7, 1, $1.barcode); //#5802
        $1.barcode = _7; //#5802
    } //#5802
    $put($1.options, "dontdraw", true); //#5806
    $k[$j++] = 'args'; //#5807
    $k[$j++] = $1.barcode; //#5807
    $k[$j++] = $1.options; //#5807
    bwipp_ean8(); //#5807
    var _C = $k[--$j]; //#5807
    $1[$k[--$j]] = _C; //#5807
    var _F = $get($1.args, "bbs"); //#5810
    $put(_F, 10, $get(_F, 2)); //#5811
    $put(_F, 11, $get(_F, 2)); //#5812
    var _J = $get($1.args, "bhs"); //#5813
    $put(_J, 10, $get(_J, 2)); //#5814
    $put(_J, 11, $get(_J, 2)); //#5815
    $1.txt = $get($1.args, "txt"); //#5818
    if ($1.barlen == 7) { //#5826
        for (var _P = 0; _P <= 6; _P += 1) { //#5824
            var _Q = $1.txt; //#5821
            $puti($get($get(_Q, _P), 0), 0, $get($get(_Q, _P + 1), 0)); //#5823
        } //#5823
        $puti($get($get($1.txt, 7), 0), 0, " "); //#5825
    } //#5825
    var _Y = $a(10); //#5829
    $puti(_Y, 0, $1.txt); //#5829
    $1.txt = _Y; //#5829
    var _b = $get($1.txt, 0); //#5830
    $put($1.txt, 8, $arrcpy($a(_b.length), _b)); //#5830
    var _g = $get($1.txt, 0); //#5831
    $put($1.txt, 9, $arrcpy($a(_g.length), _g)); //#5831
    $put($get($1.txt, 8), 0, "M"); //#5832
    $put($get($1.txt, 8), 1, -12); //#5832
    $put($get($1.txt, 9), 0, "S"); //#5833
    var _r = $get($1.txt, 9); //#5833
    $put(_r, 1, 69); //#5833
    $put($1.args, "txt", $1.txt); //#5835
    $put($1.args, "opt", $1.options); //#5836
    $k[$j++] = $1.args; //#5839
    if (!$1.dontdraw) { //#5839
        bwipp_renlinear(); //#5839
    } //#5839
}

function bwipp_code128() {
    var $1 = {}; //#5872
    $1.ctx = null; //#5874
    $1.dontdraw = false; //#5875
    $1.includetext = false; //#5876
    $1.textfont = "OCR-B"; //#5877
    $1.textsize = 10; //#5878
    $1.textxoffset = 0; //#5879
    $1.textyoffset = -8; //#5880
    $1.height = 1; //#5881
    $1.encoding = "auto"; //#5882
    $1.raw = false; //#5883
    $1.parse = false; //#5884
    $1.parsefnc = false; //#5885
    $k[$j++] = $1; //#5887
    bwipp_processoptions(); //#5887
    $1.options = $k[--$j]; //#5887
    var _1 = $k[--$j]; //#5888
    $1.barcode = _1; //#5888
    $1.sta = -1; //#5894
    $1.stb = -2; //#5894
    $1.stc = -3; //#5894
    $1.swa = -4; //#5895
    $1.swb = -5; //#5895
    $1.swc = -6; //#5895
    $1.fn1 = -7; //#5896
    $1.fn2 = -8; //#5896
    $1.fn3 = -9; //#5896
    $1.fn4 = -10; //#5897
    $1.sft = -11; //#5897
    $1.stp = -12; //#5897
    $1.lka = -13; //#5898
    $1.lkc = -14; //#5898
    var _2 = $1.parse; //#5903
    var _A = new Map([
        ["parse", _2],
        ["parsefnc", $1.parsefnc],
        ["FNC1", $1.fn1],
        ["FNC1", $1.fn1],
        ["FNC2", $1.fn2],
        ["FNC3", $1.fn3],
        ["LNKA", $1.lka],
        ["LNKC", $1.lkc]
    ]); //#5911
    $1.fncvals = _A; //#5912
    $k[$j++] = 'msg'; //#5913
    $k[$j++] = $1.barcode; //#5913
    $k[$j++] = $1.fncvals; //#5913
    bwipp_parseinput(); //#5913
    var _D = $k[--$j]; //#5913
    $1[$k[--$j]] = _D; //#5913
    $1.msglen = $1.msg.length; //#5914
    $1.charmaps = $a([$a([32, 32, "00"]), $a(["!", "!", "01"]), $a(["\"", "\"", "02"]), $a(["#", "#", "03"]), $a(["$", "$", "04"]), $a(["%", "%", "05"]), $a(["&", "&", "06"]), $a(["'", "'", "07"]), $a([40, 40, "08"]), $a([41, 41, "09"]), $a(["*", "*", "10"]), $a(["+", "+", "11"]), $a([",", ",", "12"]), $a(["-", "-", "13"]), $a([".", ".", "14"]), $a(["/", "/", "15"]), $a(["0", "0", "16"]), $a(["1", "1", "17"]), $a(["2", "2", "18"]), $a(["3", "3", "19"]), $a(["4", "4", "20"]), $a(["5", "5", "21"]), $a(["6", "6", "22"]), $a(["7", "7", "23"]), $a(["8", "8", "24"]), $a(["9", "9", "25"]), $a([":", ":", "26"]), $a([";", ";", "27"]), $a(["<", "<", "28"]), $a(["=", "=", "29"]), $a([">", ">", "30"]), $a(["?", "?", "31"]), $a(["@", "@", "32"]), $a(["A", "A", "33"]), $a(["B", "B", "34"]), $a(["C", "C", "35"]), $a(["D", "D", "36"]), $a(["E", "E", "37"]), $a(["F", "F", "38"]), $a(["G", "G", "39"]), $a(["H", "H", "40"]), $a(["I", "I", "41"]), $a(["J", "J", "42"]), $a(["K", "K", "43"]), $a(["L", "L", "44"]), $a(["M", "M", "45"]), $a(["N", "N", "46"]), $a(["O", "O", "47"]), $a(["P", "P", "48"]), $a(["Q", "Q", "49"]), $a(["R", "R", "50"]), $a(["S", "S", "51"]), $a(["T", "T", "52"]), $a(["U", "U", "53"]), $a(["V", "V", "54"]), $a(["W", "W", "55"]), $a(["X", "X", "56"]), $a(["Y", "Y", "57"]), $a(["Z", "Z", "58"]), $a(["[", "[", "59"]), $a([92, 92, "60"]), $a(["]", "]", "61"]), $a(["^", "^", "62"]), $a(["_", "_", "63"]), $a([0, "`", "64"]), $a([1, "a", "65"]), $a([2, "b", "66"]), $a([3, "c", "67"]), $a([4, "d", "68"]), $a([5, "e", "69"]), $a([6, "f", "70"]), $a([7, "g", "71"]), $a([8, "h", "72"]), $a([9, "i", "73"]), $a([10, "j", "74"]), $a([11, "k", "75"]), $a([12, "l", "76"]), $a([13, "m", "77"]), $a([14, "n", "78"]), $a([15, "o", "79"]), $a([16, "p", "80"]), $a([17, "q", "81"]), $a([18, "r", "82"]), $a([19, "s", "83"]), $a([20, "t", "84"]), $a([21, "u", "85"]), $a([22, "v", "86"]), $a([23, "w", "87"]), $a([24, "x", "88"]), $a([25, "y", "89"]), $a([26, "z", "90"]), $a([27, "{", "91"]), $a([28, "|", "92"]), $a([29, "}", "93"]), $a([30, "~", "94"]), $a([31, 127, "95"]), $a([$1.fn3, $1.fn3, "96"]), $a([$1.fn2, $1.fn2, "97"]), $a([$1.sft, $1.sft, "98"]), $a([$1.swc, $1.swc, "99"]), $a([$1.swb, $1.fn4, $1.swb]), $a([$1.fn4, $1.swa, $1.swa]), $a([$1.fn1, $1.fn1, $1.fn1]), $a([$1.sta, $1.sta, $1.sta]), $a([$1.stb, $1.stb, $1.stb]), $a([$1.stc, $1.stc, $1.stc]), $a([$1.stp, $1.stp, $1.stp])]); //#5956
    $1.charvals = $a([new Map, new Map, new Map]); //#5959
    for (var _2W = 0, _2V = $1.charmaps.length - 1; _2W <= _2V; _2W += 1) { //#5968
        $1.i = _2W; //#5961
        $1.encs = $get($1.charmaps, $1.i); //#5962
        for (var _2a = 0; _2a <= 2; _2a += 1) { //#5967
            $1.j = _2a; //#5964
            var _2d = $get($1.encs, $1.j); //#5965
            $k[$j++] = _2d; //#5965
            if ($eq($type(_2d), 'stringtype')) { //#5965
                var _2g = $get($k[--$j], 0); //#5965
                $k[$j++] = _2g; //#5965
            } //#5965
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#5966
        } //#5966
    } //#5966
    $1.seta = $get($1.charvals, 0); //#5969
    $1.setb = $get($1.charvals, 1); //#5970
    $1.setc = $get($1.charvals, 2); //#5971
    $put($1.seta, $1.lka, $get($1.seta, $1.swb)); //#5975
    $put($1.seta, $1.lkc, $get($1.seta, $1.swc)); //#5975
    $put($1.setb, $1.lka, $get($1.setb, $1.swc)); //#5976
    $put($1.setb, $1.lkc, $get($1.setb, $1.swa)); //#5976
    $put($1.setc, $1.lka, $get($1.setc, $1.swa)); //#5977
    $put($1.setc, $1.lkc, $get($1.setc, $1.swb)); //#5977
    if ($1.raw) { //#5979
        $1.encoding = "raw"; //#5979
    } //#5979
    if ($eq($1.encoding, "raw")) { //#5993
        $1.cws = $a($1.barcode.length); //#5982
        $1.i = 0; //#5983
        $1.j = 0; //#5983
        for (;;) { //#5990
            if ($1.i == $1.barcode.length) { //#5985
                break; //#5985
            } //#5985
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#5986
            $put($1.cws, $1.j, $1.cw); //#5987
            $1.i = $1.i + 4; //#5988
            $1.j = $1.j + 1; //#5989
        } //#5989
        $1.cws = $geti($1.cws, 0, $1.j); //#5991
        $1.text = ""; //#5992
    } //#5992
    if ($eq($1.encoding, "auto")) { //#6218
        $1.text = $s($1.msglen); //#5997
        for (var _3i = 0, _3h = $1.msglen - 1; _3i <= _3h; _3i += 1) { //#6001
            $1.i = _3i; //#5999
            var _3n = $get($1.msg, $1.i); //#6000
            $k[$j++] = $1.text; //#6000
            $k[$j++] = $1.i; //#6000
            $k[$j++] = _3n; //#6000
            if (_3n < 0) { //#6000
                $j--; //#6000
                $k[$j++] = 32; //#6000
            } //#6000
            var _3o = $k[--$j]; //#6000
            var _3p = $k[--$j]; //#6000
            $put($k[--$j], _3p, _3o); //#6000
        } //#6000
        $k[$j++] = Infinity; //#6004
        for (var _3s = 0, _3t = $1.msglen; _3s < _3t; _3s++) { //#6004
            $k[$j++] = 0; //#6004
        } //#6004
        $k[$j++] = 0; //#6004
        $1.numSA = $a(); //#6004
        $k[$j++] = Infinity; //#6005
        for (var _3w = 0, _3x = $1.msglen; _3w < _3x; _3w++) { //#6005
            $k[$j++] = 0; //#6005
        } //#6005
        $k[$j++] = 0; //#6005
        $1.numEA = $a(); //#6005
        for (var _40 = $1.msglen - 1; _40 >= 0; _40 -= 1) { //#6015
            $1.i = _40; //#6007
            if ($get($1.msg, $1.i) >= 0) { //#6014
                if ($get($1.msg, $1.i) >= 128) { //#6012
                    $put($1.numEA, $1.i, $f($get($1.numEA, $1.i + 1) + 1)); //#6010
                } else { //#6012
                    $put($1.numSA, $1.i, $f($get($1.numSA, $1.i + 1) + 1)); //#6012
                } //#6012
            } //#6012
        } //#6012
        $1.ea = false; //#6018
        $1.msgtmp = $a([]); //#6018
        for (var _4K = 0, _4J = $1.msglen - 1; _4K <= _4J; _4K += 1) { //#6033
            $1.i = _4K; //#6020
            $1.c = $get($1.msg, $1.i); //#6021
            if ((!$xo($1.ea, $1.c < 128)) && ($1.c >= 0)) { //#6031
                if ($1.ea) { //#6023
                    $k[$j++] = $1.numSA; //#6023
                } else { //#6023
                    $k[$j++] = $1.numEA; //#6023
                } //#6023
                var _4W = $get($k[--$j], $1.i); //#6023
                var _4Z = ($f(_4W + $1.i) == $1.msglen) ? 3 : 5; //#6024
                if (_4W < _4Z) { //#6029
                    $k[$j++] = Infinity; //#6026
                    $aload($1.msgtmp); //#6026
                    $k[$j++] = $1.fn4; //#6026
                    $1.msgtmp = $a(); //#6026
                } else { //#6029
                    $k[$j++] = Infinity; //#6028
                    $aload($1.msgtmp); //#6028
                    $k[$j++] = $1.fn4; //#6028
                    $k[$j++] = $1.fn4; //#6028
                    $1.msgtmp = $a(); //#6028
                    $1.ea = !$1.ea; //#6029
                } //#6029
            } //#6029
            $k[$j++] = Infinity; //#6032
            $aload($1.msgtmp); //#6032
            if ($1.c >= 0) { //#6032
                $k[$j++] = $1.c & 127; //#6032
            } else { //#6032
                $k[$j++] = $1.c; //#6032
            } //#6032
            $1.msgtmp = $a(); //#6032
        } //#6032
        $1.msg = $1.msgtmp; //#6034
        $1.msglen = $1.msg.length; //#6035
        $1.numsscr = function() {
            $1.n = 0; //#6039
            $1.s = 0; //#6039
            $1.p = $k[--$j]; //#6040
            for (;;) { //#6053
                if ($1.p >= $1.msglen) { //#6041
                    break; //#6041
                } //#6041
                var _4u = $get($1.msg, $1.p); //#6042
                var _4w = $get($1.setc, _4u) !== undefined; //#6043
                $k[$j++] = _4u; //#6043
                if (!_4w) { //#6043
                    $j--; //#6043
                    break; //#6043
                } //#6043
                var _4x = $k[--$j]; //#6044
                $k[$j++] = _4x; //#6049
                if (_4x <= -1) { //#6048
                    var _4z = $k[--$j]; //#6046
                    if ((_4z == $1.fn1) && (($1.s % 2) == 0)) { //#6046
                        $1.s = $1.s + 1; //#6046
                    } else { //#6046
                        break; //#6046
                    } //#6046
                } else { //#6048
                    $j--; //#6048
                } //#6048
                $1.n = $1.n + 1; //#6050
                $1.s = $1.s + 1; //#6051
                $1.p = $f($1.p + 1); //#6052
            } //#6052
            $k[$j++] = $1.n; //#6054
            $k[$j++] = $1.s; //#6054
        }; //#6054
        $1.enca = function() {
            $put($1.cws, $1.j, $get($1.seta, $k[--$j])); //#6059
            $1.j = $1.j + 1; //#6060
        }; //#6060
        $1.encb = function() {
            $put($1.cws, $1.j, $get($1.setb, $k[--$j])); //#6063
            $1.j = $1.j + 1; //#6064
        }; //#6064
        $1.encc = function() {
            var _5J = $k[--$j]; //#6067
            $k[$j++] = _5J; //#6071
            if ($ne($type(_5J), 'arraytype')) { //#6070
                var _5N = $get($1.setc, $k[--$j]); //#6068
                $k[$j++] = _5N; //#6068
            } else { //#6070
                $aload($k[--$j]); //#6070
                var _5P = $k[--$j]; //#6070
                var _5Q = $k[--$j]; //#6070
                $k[$j++] = $f($f(_5P - 48) + ($f(_5Q - 48) * 10)); //#6070
            } //#6070
            $put($1.cws, $1.j, $k[--$j]); //#6072
            $1.j = $1.j + 1; //#6073
        }; //#6073
        $1.anotb = function() {
            var _5V = $k[--$j]; //#6077
            var _5X = $get($1.seta, _5V) !== undefined; //#6077
            var _5Z = $get($1.setb, _5V) !== undefined; //#6077
            $k[$j++] = _5X && (!_5Z); //#6077
        }; //#6077
        $1.bnota = function() {
            var _5a = $k[--$j]; //#6078
            var _5c = $get($1.setb, _5a) !== undefined; //#6078
            var _5e = $get($1.seta, _5a) !== undefined; //#6078
            $k[$j++] = _5c && (!_5e); //#6078
        }; //#6078
        $k[$j++] = Infinity; //#6081
        for (var _5g = 0, _5h = $1.msg.length; _5g < _5h; _5g++) { //#6081
            $k[$j++] = 0; //#6081
        } //#6081
        $k[$j++] = 9999; //#6081
        $1.nextanotb = $a(); //#6081
        $k[$j++] = Infinity; //#6082
        for (var _5k = 0, _5l = $1.msg.length; _5k < _5l; _5k++) { //#6082
            $k[$j++] = 0; //#6082
        } //#6082
        $k[$j++] = 9999; //#6082
        $1.nextbnota = $a(); //#6082
        for (var _5o = $1.msg.length - 1; _5o >= 0; _5o -= 1) { //#6095
            $1.i = _5o; //#6084
            $k[$j++] = $get($1.msg, $1.i); //#6085
            $1.anotb(); //#6085
            if ($k[--$j]) { //#6088
                $put($1.nextanotb, $1.i, 0); //#6086
            } else { //#6088
                $put($1.nextanotb, $1.i, $f($get($1.nextanotb, $1.i + 1) + 1)); //#6088
            } //#6088
            $k[$j++] = $get($1.msg, $1.i); //#6090
            $1.bnota(); //#6090
            if ($k[--$j]) { //#6093
                $put($1.nextbnota, $1.i, 0); //#6091
            } else { //#6093
                $put($1.nextbnota, $1.i, $f($get($1.nextbnota, $1.i + 1) + 1)); //#6093
            } //#6093
        } //#6093
        $1.abeforeb = function() {
            var _6B = $k[--$j]; //#6098
            $k[$j++] = $lt($get($1.nextanotb, _6B), $get($1.nextbnota, _6B)); //#6098
        }; //#6098
        $1.bbeforea = function() {
            var _6G = $k[--$j]; //#6099
            $k[$j++] = $lt($get($1.nextbnota, _6G), $get($1.nextanotb, _6G)); //#6099
        }; //#6099
        $1.cws = $a(($1.barcode.length * 2) + 3); //#6101
        $1.j = 0; //#6104
        if ($1.msglen > 0) { //#6105
            $k[$j++] = 0; //#6105
            $1.numsscr(); //#6105
        } else { //#6105
            $k[$j++] = -1; //#6105
            $k[$j++] = -1; //#6105
        } //#6105
        $1.nums = $k[--$j]; //#6105
        $1.nchars = $k[--$j]; //#6105
        for (;;) { //#6130
            if ($1.msglen == 0) { //#6111
                $k[$j++] = $1.stb; //#6108
                $1.enca(); //#6108
                $1.cset = "setb"; //#6109
                break; //#6110
            } //#6110
            if (($1.msglen == 2) && ($1.nums == 2)) { //#6116
                $k[$j++] = $1.stc; //#6113
                $1.enca(); //#6113
                $1.cset = "setc"; //#6114
                break; //#6115
            } //#6115
            if ($1.nums >= 4) { //#6121
                $k[$j++] = $1.stc; //#6118
                $1.enca(); //#6118
                $1.cset = "setc"; //#6119
                break; //#6120
            } //#6120
            $k[$j++] = 0; //#6122
            $1.abeforeb(); //#6122
            if ($k[--$j]) { //#6126
                $k[$j++] = $1.sta; //#6123
                $1.enca(); //#6123
                $1.cset = "seta"; //#6124
                break; //#6125
            } //#6125
            $k[$j++] = $1.stb; //#6127
            $1.enca(); //#6127
            $1.cset = "setb"; //#6128
            break; //#6129
        } //#6129
        $1.i = 0; //#6133
        for (;;) { //#6216
            if ($1.i == $1.msglen) { //#6134
                break; //#6134
            } //#6134
            $k[$j++] = $1.i; //#6136
            $1.numsscr(); //#6136
            $1.nums = $k[--$j]; //#6136
            $1.nchars = $k[--$j]; //#6136
            for (;;) { //#6214
                if ((($eq($1.cset, "seta") || $eq($1.cset, "setb")) && ($1.nums >= 4)) && ($get($1.msg, $1.i) != $1.fn1)) { //#6153
                    if (($1.nums % 2) == 0) { //#6151
                        $k[$j++] = $1.swc; //#6143
                        if ($eq($1.cset, "seta")) { //#6143
                            $1.enca(); //#6143
                        } else { //#6143
                            $1.encb(); //#6143
                        } //#6143
                        $1.cset = "setc"; //#6144
                        break; //#6145
                    } else { //#6151
                        $k[$j++] = $get($1.msg, $1.i); //#6147
                        if ($eq($1.cset, "seta")) { //#6147
                            $1.enca(); //#6147
                        } else { //#6147
                            $1.encb(); //#6147
                        } //#6147
                        $1.i = $1.i + 1; //#6148
                        $k[$j++] = $1.swc; //#6149
                        if ($eq($1.cset, "seta")) { //#6149
                            $1.enca(); //#6149
                        } else { //#6149
                            $1.encb(); //#6149
                        } //#6149
                        $1.cset = "setc"; //#6150
                        break; //#6151
                    } //#6151
                } //#6151
                $k[$j++] = $eq($1.cset, "setb"); //#6154
                $k[$j++] = $get($1.msg, $1.i); //#6154
                $1.anotb(); //#6154
                var _70 = $k[--$j]; //#6154
                var _71 = $k[--$j]; //#6154
                if ((_71 && _70)) { //#6166
                    if ($1.i < ($1.msglen - 1)) { //#6162
                        $k[$j++] = $1.i + 1; //#6156
                        $1.bbeforea(); //#6156
                        if ($k[--$j]) { //#6161
                            $k[$j++] = $1.sft; //#6157
                            $1.encb(); //#6157
                            $k[$j++] = $get($1.msg, $1.i); //#6158
                            $1.enca(); //#6158
                            $1.i = $1.i + 1; //#6159
                            break; //#6160
                        } //#6160
                    } //#6160
                    $k[$j++] = $1.swa; //#6163
                    $1.encb(); //#6163
                    $1.cset = "seta"; //#6164
                    break; //#6165
                } //#6165
                $k[$j++] = $eq($1.cset, "seta"); //#6167
                $k[$j++] = $get($1.msg, $1.i); //#6167
                $1.bnota(); //#6167
                var _7G = $k[--$j]; //#6167
                var _7H = $k[--$j]; //#6167
                if ((_7H && _7G)) { //#6179
                    if ($1.i < ($1.msglen - 1)) { //#6175
                        $k[$j++] = $1.i + 1; //#6169
                        $1.abeforeb(); //#6169
                        if ($k[--$j]) { //#6174
                            $k[$j++] = $1.sft; //#6170
                            $1.enca(); //#6170
                            $k[$j++] = $get($1.msg, $1.i); //#6171
                            $1.encb(); //#6171
                            $1.i = $1.i + 1; //#6172
                            break; //#6173
                        } //#6173
                    } //#6173
                    $k[$j++] = $1.swb; //#6176
                    $1.enca(); //#6176
                    $1.cset = "setb"; //#6177
                    break; //#6178
                } //#6178
                if (($eq($1.cset, "setc") && ($1.nums < 2)) && (($get($1.msg, $1.i) > -1) || ($get($1.msg, $1.i) == $1.fn4))) { //#6189
                    $k[$j++] = $1.i; //#6181
                    $1.abeforeb(); //#6181
                    if ($k[--$j]) { //#6185
                        $k[$j++] = $1.swa; //#6182
                        $1.encc(); //#6182
                        $1.cset = "seta"; //#6183
                        break; //#6184
                    } //#6184
                    $k[$j++] = $1.swb; //#6186
                    $1.encc(); //#6186
                    $1.cset = "setb"; //#6187
                    break; //#6188
                } //#6188
                if ($eq($1.cset, "seta")) { //#6196
                    $k[$j++] = $get($1.msg, $1.i); //#6193
                    $1.enca(); //#6193
                    $1.i = $1.i + 1; //#6194
                    break; //#6195
                } //#6195
                if ($eq($1.cset, "setb")) { //#6201
                    $k[$j++] = $get($1.msg, $1.i); //#6198
                    $1.encb(); //#6198
                    $1.i = $1.i + 1; //#6199
                    break; //#6200
                } //#6200
                if ($eq($1.cset, "setc")) { //#6211
                    if ($get($1.msg, $1.i) <= -1) { //#6208
                        $k[$j++] = $get($1.msg, $1.i); //#6204
                        $1.encc(); //#6204
                        $1.i = $1.i + 1; //#6205
                    } else { //#6208
                        $k[$j++] = $geti($1.msg, $1.i, 2); //#6207
                        $1.encc(); //#6207
                        $1.i = $1.i + 2; //#6208
                    } //#6208
                    break; //#6210
                } //#6210
                break; //#6213
            } //#6213
        } //#6213
        $1.cws = $geti($1.cws, 0, $1.j); //#6217
    } //#6217
    var _85 = $a($1.j + 2); //#6221
    $puti(_85, 0, $1.cws); //#6221
    $1.cws = _85; //#6221
    $1.csum = $get($1.cws, 0); //#6222
    for (var _8B = 1, _8A = $1.j - 1; _8B <= _8A; _8B += 1) { //#6226
        $1.i = _8B; //#6224
        $1.csum = $f($1.csum + ($get($1.cws, $1.i) * $1.i)); //#6225
    } //#6225
    $1.csum = $1.csum % 103; //#6227
    $put($1.cws, $1.j, $1.csum); //#6228
    $put($1.cws, $1.j + 1, $get($1.seta, $1.stp)); //#6229
    var _8R = $get($1.options, 'debugcws') !== undefined; //#6231
    if (_8R) { //#6231
        $k[$j++] = 'bwipp.debugcws'; //#6231
        $k[$j++] = $1.cws; //#6231
        bwipp_raiseerror(); //#6231
    } //#6231
    $1.encs = $a(["212222", "222122", "222221", "121223", "121322", "131222", "122213", "122312", "132212", "221213", "221312", "231212", "112232", "122132", "122231", "113222", "123122", "123221", "223211", "221132", "221231", "213212", "223112", "312131", "311222", "321122", "321221", "312212", "322112", "322211", "212123", "212321", "232121", "111323", "131123", "131321", "112313", "132113", "132311", "211313", "231113", "231311", "112133", "112331", "132131", "113123", "113321", "133121", "313121", "211331", "231131", "213113", "213311", "213131", "311123", "311321", "331121", "312113", "312311", "332111", "314111", "221411", "431111", "111224", "111422", "121124", "121421", "141122", "141221", "112214", "112412", "122114", "122411", "142112", "142211", "241211", "221114", "413111", "241112", "134111", "111242", "121142", "121241", "114212", "124112", "124211", "411212", "421112", "421211", "212141", "214121", "412121", "111143", "111341", "131141", "114113", "114311", "411113", "411311", "113141", "114131", "311141", "411131", "211412", "211214", "211232", "2331112"]); //#6252
    $1.sbs = $s(($1.cws.length * 6) + 1); //#6256
    for (var _8Y = 0, _8X = $1.cws.length - 1; _8Y <= _8X; _8Y += 1) { //#6260
        $1.i = _8Y; //#6258
        $puti($1.sbs, $1.i * 6, $get($1.encs, $get($1.cws, $1.i))); //#6259
    } //#6259
    $k[$j++] = Infinity; //#6270
    $k[$j++] = Infinity; //#6265
    var _8g = $1.sbs; //#6265
    for (var _8h = 0, _8i = _8g.length; _8h < _8i; _8h++) { //#6265
        $k[$j++] = $get(_8g, _8h) - 48; //#6265
    } //#6265
    var _8k = $a(); //#6265
    $k[$j++] = Infinity; //#6266
    for (var _8m = 0, _8n = ~~(($1.sbs.length + 1) / 2); _8m < _8n; _8m++) { //#6266
        $k[$j++] = $1.height; //#6266
    } //#6266
    var _8p = $a(); //#6266
    $k[$j++] = Infinity; //#6267
    for (var _8r = 0, _8s = ~~(($1.sbs.length + 1) / 2); _8r < _8s; _8r++) { //#6267
        $k[$j++] = 0; //#6267
    } //#6267
    var _8t = $a(); //#6267
    $k[$j++] = 'ren'; //#6270
    $k[$j++] = bwipp_renlinear; //#6270
    $k[$j++] = 'sbs'; //#6270
    $k[$j++] = _8k; //#6270
    $k[$j++] = 'bhs'; //#6270
    $k[$j++] = _8p; //#6270
    $k[$j++] = 'bbs'; //#6270
    $k[$j++] = _8t; //#6270
    $k[$j++] = 'txt'; //#6270
    $k[$j++] = $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])]); //#6270
    $k[$j++] = 'textxalign'; //#6270
    $k[$j++] = "center"; //#6270
    $k[$j++] = 'opt'; //#6270
    $k[$j++] = $1.options; //#6270
    var _92 = $d(); //#6270
    $k[$j++] = _92; //#6273
    if (!$1.dontdraw) { //#6273
        bwipp_renlinear(); //#6273
    } //#6273
}

function bwipp_gs1_128() {
    var $1 = {}; //#6308
    $1.ctx = null; //#6310
    $1.dontdraw = false; //#6311
    $1.includetext = false; //#6312
    $1.textfont = "OCR-B"; //#6313
    $1.textsize = 10; //#6314
    $1.textxoffset = 0; //#6315
    $1.textyoffset = -8; //#6316
    $1.height = 0.5; //#6317
    $1.linkagea = false; //#6318
    $1.linkagec = false; //#6319
    $1.parse = false; //#6320
    $1.dontlint = false; //#6321
    $1.lintreqs = false; //#6322
    $k[$j++] = $1; //#6324
    bwipp_processoptions(); //#6324
    $1.options = $k[--$j]; //#6324
    $1.barcode = $k[--$j]; //#6325
    $1.text = $1.barcode; //#6327
    $k[$j++] = $1.barcode; //#6329
    $k[$j++] = 'ai'; //#6329
    bwipp_gs1process(); //#6329
    $1.fncs = $k[--$j]; //#6330
    $1.vals = $k[--$j]; //#6331
    $1.ais = $k[--$j]; //#6332
    $1.fnc1 = -1; //#6335
    $1.c128 = $a([$1.fnc1]); //#6336
    for (var _B = 0, _A = $1.ais.length - 1; _B <= _A; _B += 1) { //#6352
        $1.i = _B; //#6338
        $1.ai = $get($1.ais, $1.i); //#6339
        $1.val = $get($1.vals, $1.i); //#6340
        var _L = $a(($1.c128.length + $1.ai.length) + $1.val.length); //#6341
        $puti(_L, 0, $1.c128); //#6342
        $k[$j++] = _L; //#6343
        $k[$j++] = _L; //#6343
        $k[$j++] = $1.c128.length; //#6343
        $k[$j++] = $1.ai; //#6343
        $k[$j++] = Infinity; //#6343
        var _P = $k[--$j]; //#6343
        var _Q = $k[--$j]; //#6343
        $k[$j++] = _P; //#6343
        $forall(_Q); //#6343
        var _R = $a(); //#6343
        var _S = $k[--$j]; //#6343
        $puti($k[--$j], _S, _R); //#6343
        var _U = $k[--$j]; //#6344
        $k[$j++] = _U; //#6344
        $k[$j++] = _U; //#6344
        $k[$j++] = $1.c128.length + $1.ai.length; //#6344
        $k[$j++] = $1.val; //#6344
        $k[$j++] = Infinity; //#6344
        var _Y = $k[--$j]; //#6344
        var _Z = $k[--$j]; //#6344
        $k[$j++] = _Y; //#6344
        $forall(_Z); //#6344
        var _a = $a(); //#6344
        var _b = $k[--$j]; //#6344
        $puti($k[--$j], _b, _a); //#6344
        $1.c128 = $k[--$j]; //#6345
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#6351
            var _k = $a($1.c128.length + 1); //#6347
            $puti(_k, 0, $1.c128); //#6348
            $put(_k, $1.c128.length, $1.fnc1); //#6349
            $1.c128 = _k; //#6350
        } //#6350
    } //#6350
    $1.barcode = $s(($1.c128.length + 1) * 5); //#6355
    $1.i = 0; //#6356
    $1.j = 0; //#6356
    for (;;) { //#6366
        if ($1.i == $1.c128.length) { //#6357
            break; //#6357
        } //#6357
        var _u = $get($1.c128, $1.i); //#6358
        $k[$j++] = _u; //#6363
        if (_u == $1.fnc1) { //#6362
            $j--; //#6359
            $puti($1.barcode, $1.j, "^FNC1"); //#6359
            $1.j = $1.j + 4; //#6360
        } else { //#6362
            $put($1.barcode, $1.j, $k[--$j]); //#6362
        } //#6362
        $1.i = $1.i + 1; //#6364
        $1.j = $1.j + 1; //#6365
    } //#6365
    if ($1.linkagea || $1.linkagec) { //#6370
        $k[$j++] = $1.barcode; //#6368
        $k[$j++] = $1.j; //#6368
        if ($1.linkagea) { //#6368
            $k[$j++] = "^LNKA"; //#6368
        } else { //#6368
            $k[$j++] = "^LNKC"; //#6368
        } //#6368
        var _19 = $k[--$j]; //#6368
        var _1A = $k[--$j]; //#6368
        $puti($k[--$j], _1A, _19); //#6368
        $1.j = $1.j + 5; //#6369
    } //#6369
    $1.barcode = $geti($1.barcode, 0, $1.j); //#6371
    delete $1.options["parse"]; //#6374
    $put($1.options, "height", $1.height); //#6375
    $put($1.options, "dontdraw", true); //#6376
    $put($1.options, "parsefnc", true); //#6377
    $k[$j++] = 'args'; //#6378
    $k[$j++] = $1.barcode; //#6378
    $k[$j++] = $1.options; //#6378
    bwipp_code128(); //#6378
    var _1N = $k[--$j]; //#6378
    $1[$k[--$j]] = _1N; //#6378
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#6380
    $put($1.args, "textxalign", "center"); //#6381
    $put($1.args, "opt", $1.options); //#6382
    $k[$j++] = $1.args; //#6385
    if (!$1.dontdraw) { //#6385
        bwipp_renlinear(); //#6385
    } //#6385
}

function bwipp_ean14() {
    var $1 = {}; //#6416
    $1.ctx = null; //#6418
    $1.dontdraw = false; //#6419
    $1.includetext = false; //#6420
    $1.textfont = "OCR-B"; //#6421
    $1.textsize = 10; //#6422
    $1.textxoffset = 0; //#6423
    $1.textyoffset = -8; //#6424
    $1.height = 1; //#6425
    $k[$j++] = $1; //#6427
    bwipp_processoptions(); //#6427
    $1.options = $k[--$j]; //#6427
    $1.barcode = $k[--$j]; //#6428
    $1.text = $1.barcode; //#6431
    var _3 = $1.barcode; //#6432
    $k[$j++] = $s(_3.length); //#6433
    $k[$j++] = 0; //#6433
    $forall(_3, function() { //#6433
        var _5 = $k[--$j]; //#6433
        $k[$j++] = _5; //#6433
        if (_5 != 32) { //#6433
            var _6 = $k[--$j]; //#6433
            var _7 = $k[--$j]; //#6433
            var _8 = $k[--$j]; //#6433
            $put(_8, _7, _6); //#6433
            $k[$j++] = _8; //#6433
            $k[$j++] = $f(_7 + 1); //#6433
        } else { //#6433
            $j--; //#6433
        } //#6433
    }); //#6433
    var _9 = $k[--$j]; //#6434
    $1.barcode = $geti($k[--$j], 0, _9); //#6434
    $1.hasspace = $1.text.length != $1.barcode.length; //#6435
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#6440
        $k[$j++] = 'bwipp.ean14badAI'; //#6439
        $k[$j++] = "GS1-14 must begin with (01) application identifier"; //#6439
        bwipp_raiseerror(); //#6439
    } //#6439
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#6443
        $k[$j++] = 'bwipp.ean14badLength'; //#6442
        $k[$j++] = "GS1-14 must be 13 or 14 digits"; //#6442
        bwipp_raiseerror(); //#6442
    } //#6442
    var _K = $geti($1.barcode, 4, $1.barcode.length - 4); //#6444
    for (var _L = 0, _M = _K.length; _L < _M; _L++) { //#6448
        var _N = $get(_K, _L); //#6448
        if ((_N < 48) || (_N > 57)) { //#6447
            $k[$j++] = 'bwipp.ean14badCharacter'; //#6446
            $k[$j++] = "GS1-14 must contain only digits"; //#6446
            bwipp_raiseerror(); //#6446
        } //#6446
    } //#6446
    $1.checksum = 0; //#6451
    for (var _O = 0; _O <= 12; _O += 1) { //#6455
        $1.i = _O; //#6453
        $k[$j++] = 'checksum'; //#6454
        $k[$j++] = $1.checksum; //#6454
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#6454
        if (($1.i % 2) == 0) { //#6454
            var _U = $k[--$j]; //#6454
            $k[$j++] = _U * 3; //#6454
        } //#6454
        var _V = $k[--$j]; //#6454
        var _W = $k[--$j]; //#6454
        $1[$k[--$j]] = $f(_W + _V); //#6454
    } //#6454
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#6456
    if ($1.barcode.length == 18) { //#6470
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#6460
            $k[$j++] = 'bwipp.ean14badCheckDigit'; //#6459
            $k[$j++] = "Incorrect GS1-14 check digit provided"; //#6459
            bwipp_raiseerror(); //#6459
        } //#6459
    } else { //#6470
        var _d = $s(18); //#6462
        $puti(_d, 0, $1.barcode); //#6463
        $put(_d, 17, $1.checksum + 48); //#6464
        $1.barcode = _d; //#6465
        var _i = $1.hasspace ? 2 : 1; //#6466
        var _j = $s($1.text.length + _i); //#6466
        $puti(_j, _j.length - 2, " "); //#6467
        $put(_j, _j.length - 1, $1.checksum + 48); //#6468
        $puti(_j, 0, $1.text); //#6469
        $1.text = _j; //#6470
    } //#6470
    $1.gtin = $geti($1.barcode, 4, 14); //#6472
    $1.barcode = $s(21); //#6475
    $puti($1.barcode, 0, "^FNC101"); //#6476
    var _r = $1.gtin; //#6477
    $puti($1.barcode, 7, _r); //#6477
    $put($1.options, "dontdraw", true); //#6480
    $put($1.options, "parsefnc", true); //#6481
    $k[$j++] = 'args'; //#6482
    $k[$j++] = $1.barcode; //#6482
    $k[$j++] = $1.options; //#6482
    bwipp_code128(); //#6482
    var _w = $k[--$j]; //#6482
    $1[$k[--$j]] = _w; //#6482
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#6484
    $put($1.args, "textxalign", "center"); //#6485
    $put($1.args, "opt", $1.options); //#6486
    $k[$j++] = $1.args; //#6489
    if (!$1.dontdraw) { //#6489
        bwipp_renlinear(); //#6489
    } //#6489
}

function bwipp_sscc18() {
    var $1 = {}; //#6520
    $1.ctx = null; //#6522
    $1.dontdraw = false; //#6523
    $1.includetext = false; //#6524
    $1.textfont = "OCR-B"; //#6525
    $1.textsize = 10; //#6526
    $1.textxoffset = 0; //#6527
    $1.textyoffset = -8; //#6528
    $1.height = 1; //#6529
    $k[$j++] = $1; //#6531
    bwipp_processoptions(); //#6531
    $1.options = $k[--$j]; //#6531
    $1.barcode = $k[--$j]; //#6532
    $1.text = $1.barcode; //#6535
    var _3 = $1.barcode; //#6536
    $k[$j++] = $s(_3.length); //#6537
    $k[$j++] = 0; //#6537
    $forall(_3, function() { //#6537
        var _5 = $k[--$j]; //#6537
        $k[$j++] = _5; //#6537
        if (_5 != 32) { //#6537
            var _6 = $k[--$j]; //#6537
            var _7 = $k[--$j]; //#6537
            var _8 = $k[--$j]; //#6537
            $put(_8, _7, _6); //#6537
            $k[$j++] = _8; //#6537
            $k[$j++] = $f(_7 + 1); //#6537
        } else { //#6537
            $j--; //#6537
        } //#6537
    }); //#6537
    var _9 = $k[--$j]; //#6538
    $1.barcode = $geti($k[--$j], 0, _9); //#6538
    $1.hasspace = $1.text.length != $1.barcode.length; //#6539
    if ($ne($geti($1.barcode, 0, 4), "(00)")) { //#6544
        $k[$j++] = 'bwipp.sscc18badAI'; //#6543
        $k[$j++] = "SSCC-18 must begin with (00) application identifier"; //#6543
        bwipp_raiseerror(); //#6543
    } //#6543
    if (($1.barcode.length != 21) && ($1.barcode.length != 22)) { //#6547
        $k[$j++] = 'bwipp.sscc18badLength'; //#6546
        $k[$j++] = "SSCC-18 must be 17 or 18 digits"; //#6546
        bwipp_raiseerror(); //#6546
    } //#6546
    var _K = $geti($1.barcode, 4, $1.barcode.length - 4); //#6548
    for (var _L = 0, _M = _K.length; _L < _M; _L++) { //#6552
        var _N = $get(_K, _L); //#6552
        if ((_N < 48) || (_N > 57)) { //#6551
            $k[$j++] = 'bwipp.sscc18badCharacter'; //#6550
            $k[$j++] = "SSCC-18 must contain only digits"; //#6550
            bwipp_raiseerror(); //#6550
        } //#6550
    } //#6550
    $1.checksum = 0; //#6555
    for (var _O = 0; _O <= 16; _O += 1) { //#6559
        $1.i = _O; //#6557
        $k[$j++] = 'checksum'; //#6558
        $k[$j++] = $1.checksum; //#6558
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#6558
        if (($1.i % 2) == 0) { //#6558
            var _U = $k[--$j]; //#6558
            $k[$j++] = _U * 3; //#6558
        } //#6558
        var _V = $k[--$j]; //#6558
        var _W = $k[--$j]; //#6558
        $1[$k[--$j]] = $f(_W + _V); //#6558
    } //#6558
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#6560
    if ($1.barcode.length == 22) { //#6574
        if ($get($1.barcode, 21) != ($1.checksum + 48)) { //#6564
            $k[$j++] = 'bwipp.sscc18badCheckDigit'; //#6563
            $k[$j++] = "Incorrect SSCC-18 check digit provided"; //#6563
            bwipp_raiseerror(); //#6563
        } //#6563
    } else { //#6574
        var _d = $s(22); //#6566
        $puti(_d, 0, $1.barcode); //#6567
        $put(_d, 21, $1.checksum + 48); //#6568
        $1.barcode = _d; //#6569
        var _i = $1.hasspace ? 2 : 1; //#6570
        var _j = $s($1.text.length + _i); //#6570
        $puti(_j, _j.length - 2, " "); //#6571
        $put(_j, _j.length - 1, $1.checksum + 48); //#6572
        $puti(_j, 0, $1.text); //#6573
        $1.text = _j; //#6574
    } //#6574
    $1.sscc = $geti($1.barcode, 4, 18); //#6576
    $1.barcode = $s(25); //#6579
    $puti($1.barcode, 0, "^FNC100"); //#6580
    var _r = $1.sscc; //#6581
    $puti($1.barcode, 7, _r); //#6581
    $put($1.options, "dontdraw", true); //#6584
    $put($1.options, "parsefnc", true); //#6585
    $k[$j++] = 'args'; //#6586
    $k[$j++] = $1.barcode; //#6586
    $k[$j++] = $1.options; //#6586
    bwipp_code128(); //#6586
    var _w = $k[--$j]; //#6586
    $1[$k[--$j]] = _w; //#6586
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#6588
    $put($1.args, "textxalign", "center"); //#6589
    $put($1.args, "opt", $1.options); //#6590
    $k[$j++] = $1.args; //#6593
    if (!$1.dontdraw) { //#6593
        bwipp_renlinear(); //#6593
    } //#6593
}

function bwipp_code39() {
    var $1 = {}; //#6625
    $1.ctx = null; //#6627
    $1.dontdraw = false; //#6628
    $1.includecheck = false; //#6629
    $1.validatecheck = false; //#6630
    $1.includetext = false; //#6631
    $1.includecheckintext = false; //#6632
    $1.hidestars = false; //#6633
    $1.textfont = "OCR-B"; //#6634
    $1.textsize = 10; //#6635
    $1.textyoffset = -8; //#6636
    $1.height = 1; //#6637
    $k[$j++] = $1; //#6639
    bwipp_processoptions(); //#6639
    $1.options = $k[--$j]; //#6639
    $1.barcode = $k[--$j]; //#6640
    $1.encs = $a(["1113313111", "3113111131", "1133111131", "3133111111", "1113311131", "3113311111", "1133311111", "1113113131", "3113113111", "1133113111", "3111131131", "1131131131", "3131131111", "1111331131", "3111331111", "1131331111", "1111133131", "3111133111", "1131133111", "1111333111", "3111111331", "1131111331", "3131111311", "1111311331", "3111311311", "1131311311", "1111113331", "3111113311", "1131113311", "1111313311", "3311111131", "1331111131", "3331111111", "1311311131", "3311311111", "1331311111", "1311113131", "3311113111", "1331113111", "1313131111", "1313111311", "1311131311", "1113131311", "1311313111"]); //#6656
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#6659
    $1.charvals = new Map; //#6660
    for (var _3 = 0; _3 <= 42; _3 += 1) { //#6661
        $put($1.charvals, $geti($1.barchars, _3, 1), _3); //#6661
    } //#6661
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#6669
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#6666
        if (!_D) { //#6668
            $k[$j++] = 'bwipp.code39badCharacter'; //#6667
            $k[$j++] = "Code 39 must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#6667
            bwipp_raiseerror(); //#6667
        } //#6667
    } //#6667
    $k[$j++] = 'barlen'; //#6671
    $k[$j++] = $1.barcode.length; //#6671
    if ($1.validatecheck) { //#6671
        var _G = $k[--$j]; //#6671
        $k[$j++] = $f(_G - 1); //#6671
    } //#6671
    var _H = $k[--$j]; //#6671
    $1[$k[--$j]] = _H; //#6671
    $1.checksum = 0; //#6673
    for (var _L = 0, _K = $f($1.barlen - 1); _L <= _K; _L += 1) { //#6677
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _L, 1)) + $1.checksum); //#6676
    } //#6676
    $1.checksum = $1.checksum % 43; //#6678
    if ($1.validatecheck) { //#6685
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#6682
            $k[$j++] = 'bwipp.code39badCheckDigit'; //#6681
            $k[$j++] = "Incorrect Code 39 check digit provided"; //#6681
            bwipp_raiseerror(); //#6681
        } //#6681
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#6683
        $1.includecheck = true; //#6684
    } //#6684
    var _e = $1.includecheck ? 3 : 2; //#6687
    $1.sbs = $s($f($1.barlen + _e) * 10); //#6687
    var _i = $1.includecheck ? 3 : 2; //#6688
    $1.txt = $a($f($1.barlen + _i)); //#6688
    $puti($1.sbs, 0, $get($1.encs, 43)); //#6691
    if (!$1.hidestars) { //#6695
        $put($1.txt, 0, $a(["*", 0, $1.textyoffset, $1.textfont, $1.textsize])); //#6693
    } else { //#6695
        $put($1.txt, 0, $a(["", 0, $1.textyoffset, $1.textfont, $1.textsize])); //#6695
    } //#6695
    for (var _10 = 0, _z = $f($1.barlen - 1); _10 <= _z; _10 += 1) { //#6703
        $1.i = _10; //#6699
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#6700
        $puti($1.sbs, ($1.i * 10) + 10, $get($1.encs, $1.indx)); //#6701
        $put($1.txt, $1.i + 1, $a([$geti($1.barcode, $1.i, 1), ($1.i + 1) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6702
    } //#6702
    if ($1.includecheck) { //#6724
        $puti($1.sbs, $f(($1.barlen * 10) + 10), $get($1.encs, $1.checksum)); //#6707
        if ($1.includecheckintext) { //#6711
            $put($1.txt, $f($1.barlen + 1), $a([$geti($1.barchars, $1.checksum, 1), $f($1.barlen + 1) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6709
        } else { //#6711
            $put($1.txt, $f($1.barlen + 1), $a(["", $f($1.barlen + 1) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6711
        } //#6711
        $puti($1.sbs, $f(($1.barlen * 10) + 20), $get($1.encs, 43)); //#6713
        if (!$1.hidestars) { //#6717
            $put($1.txt, $f($1.barlen + 2), $a(["*", $f($1.barlen + 2) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6715
        } else { //#6717
            $put($1.txt, $f($1.barlen + 2), $a(["", $f($1.barlen + 2) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6717
        } //#6717
    } else { //#6724
        $puti($1.sbs, $f(($1.barlen * 10) + 10), $get($1.encs, 43)); //#6720
        if (!$1.hidestars) { //#6724
            $put($1.txt, $f($1.barlen + 1), $a(["*", $f($1.barlen + 1) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6722
        } else { //#6724
            $put($1.txt, $f($1.barlen + 1), $a(["", $f($1.barlen + 1) * 16, $1.textyoffset, $1.textfont, $1.textsize])); //#6724
        } //#6724
    } //#6724
    $k[$j++] = Infinity; //#6737
    $k[$j++] = Infinity; //#6731
    var _2L = $1.sbs; //#6731
    for (var _2M = 0, _2N = _2L.length; _2M < _2N; _2M++) { //#6731
        $k[$j++] = $get(_2L, _2M) - 48; //#6731
    } //#6731
    var _2P = $a(); //#6731
    $k[$j++] = Infinity; //#6732
    for (var _2R = 0, _2S = ~~(($1.sbs.length + 1) / 2); _2R < _2S; _2R++) { //#6732
        $k[$j++] = $1.height; //#6732
    } //#6732
    var _2U = $a(); //#6732
    $k[$j++] = Infinity; //#6733
    for (var _2W = 0, _2X = ~~(($1.sbs.length + 1) / 2); _2W < _2X; _2W++) { //#6733
        $k[$j++] = 0; //#6733
    } //#6733
    var _2Y = $a(); //#6733
    $k[$j++] = 'ren'; //#6736
    $k[$j++] = bwipp_renlinear; //#6736
    $k[$j++] = 'sbs'; //#6736
    $k[$j++] = _2P; //#6736
    $k[$j++] = 'bhs'; //#6736
    $k[$j++] = _2U; //#6736
    $k[$j++] = 'bbs'; //#6736
    $k[$j++] = _2Y; //#6736
    if ($1.includetext) { //#6736
        $k[$j++] = 'txt'; //#6735
        $k[$j++] = $1.txt; //#6735
    } //#6735
    $k[$j++] = 'opt'; //#6737
    $k[$j++] = $1.options; //#6737
    var _2c = $d(); //#6737
    $k[$j++] = _2c; //#6740
    if (!$1.dontdraw) { //#6740
        bwipp_renlinear(); //#6740
    } //#6740
}

function bwipp_code39ext() {
    var $1 = {}; //#6776
    $1.ctx = null; //#6778
    $1.dontdraw = false; //#6779
    $1.includetext = false; //#6780
    $1.parse = false; //#6781
    $k[$j++] = $1; //#6783
    bwipp_processoptions(); //#6783
    $1.options = $k[--$j]; //#6783
    $1.barcode = $k[--$j]; //#6784
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#6792
    $1.fncvals = _3; //#6793
    $k[$j++] = 'barcode'; //#6794
    $k[$j++] = $1.barcode; //#6794
    $k[$j++] = $1.fncvals; //#6794
    bwipp_parseinput(); //#6794
    var _6 = $k[--$j]; //#6794
    $1[$k[--$j]] = _6; //#6794
    $1.barlen = $1.barcode.length; //#6795
    delete $1.options["parse"]; //#6796
    $forall($1.barcode, function() { //#6803
        if ($k[--$j] >= 128) { //#6802
            $k[$j++] = 'bwipp.code39extBadCharacter'; //#6801
            $k[$j++] = "Code 39 Extended must contain only ASCII characters"; //#6801
            bwipp_raiseerror(); //#6801
        } //#6801
    }); //#6801
    $1.extencs = $a(["%U", "$A", "$B", "$C", "$D", "$E", "$F", "$G", "$H", "$I", "$J", "$K", "$L", "$M", "$N", "$O", "$P", "$Q", "$R", "$S", "$T", "$U", "$V", "$W", "$X", "$Y", "$Z", "%A", "%B", "%C", "%D", "%E", " ", "/A", "/B", "/C", "/D", "/E", "/F", "/G", "/H", "/I", "/J", "/K", "/L", "-", ".", "/O", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "/Z", "%F", "%G", "%H", "%I", "%J", "%V", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "%K", "%L", "%M", "%N", "%O", "%W", "+A", "+B", "+C", "+D", "+E", "+F", "+G", "+H", "+I", "+J", "+K", "+L", "+M", "+N", "+O", "+P", "+Q", "+R", "+S", "+T", "+U", "+V", "+W", "+X", "+Y", "+Z", "%P", "%Q", "%R", "%S", "%T"]); //#6816
    $1.newcode = $s($1.barlen * 2); //#6819
    $1.newtext = $s($1.barlen * 2); //#6820
    $1.j = 0; //#6821
    for (var _J = 0, _I = $1.barlen - 1; _J <= _I; _J += 1) { //#6829
        $1.i = _J; //#6823
        $1.extchar = $get($1.extencs, $get($1.barcode, $1.i)); //#6824
        $puti($1.newcode, $1.j, $1.extchar); //#6825
        $put($1.newtext, $1.j, $get($1.barcode, $1.i)); //#6826
        if ($1.extchar.length != 1) { //#6827
            $puti($1.newtext, $1.j + 1, " "); //#6827
        } //#6827
        $1.j = $1.j + $1.extchar.length; //#6828
    } //#6828
    $1.newcode = $geti($1.newcode, 0, $1.j); //#6830
    $1.newtext = $geti($1.newtext, 0, $1.j); //#6831
    $put($1.options, "dontdraw", true); //#6834
    $k[$j++] = 'args'; //#6835
    $k[$j++] = $1.newcode; //#6835
    $k[$j++] = $1.options; //#6835
    bwipp_code39(); //#6835
    var _l = $k[--$j]; //#6835
    $1[$k[--$j]] = _l; //#6835
    if ($1.includetext) { //#6847
        $1.txt = $get($1.args, "txt"); //#6839
        for (var _s = 0, _r = $1.newtext.length - 1; _s <= _r; _s += 1) { //#6845
            $1.i = _s; //#6841
            $1.txtentry = $get($1.txt, $1.i + 1); //#6842
            $put($1.txtentry, 0, $geti($1.newtext, $1.i, 1)); //#6843
            $put($1.txt, $1.i + 1, $1.txtentry); //#6844
        } //#6844
        $put($1.args, "txt", $1.txt); //#6846
    } //#6846
    $put($1.args, "opt", $1.options); //#6848
    $k[$j++] = $1.args; //#6851
    if (!$1.dontdraw) { //#6851
        bwipp_renlinear(); //#6851
    } //#6851
}

function bwipp_code32() {
    var $1 = {}; //#6884
    $1.ctx = null; //#6886
    $1.dontdraw = false; //#6887
    $1.includetext = false; //#6888
    $1.textfont = "OCR-B"; //#6889
    $1.textsize = 10; //#6890
    $1.textyoffset = -8; //#6891
    $1.textxoffset = 0; //#6892
    $1.height = 1; //#6893
    $k[$j++] = $1; //#6895
    bwipp_processoptions(); //#6895
    $1.options = $k[--$j]; //#6895
    $1.barcode = $k[--$j]; //#6896
    if (($1.barcode.length != 8) && ($1.barcode.length != 9)) { //#6901
        $k[$j++] = 'bwipp.code32badLength'; //#6900
        $k[$j++] = "Italian Pharmacode must be 8 or 9 digits"; //#6900
        bwipp_raiseerror(); //#6900
    } //#6900
    $forall($1.barcode, function() { //#6906
        var _5 = $k[--$j]; //#6903
        if ((_5 < 48) || (_5 > 57)) { //#6905
            $k[$j++] = 'bwipp.code32badCharacter'; //#6904
            $k[$j++] = "Italian Pharmacode must contain only digits"; //#6904
            bwipp_raiseerror(); //#6904
        } //#6904
    }); //#6904
    $1.checksum = 0; //#6909
    for (var _6 = 0; _6 <= 7; _6 += 1) { //#6914
        $1.i = _6; //#6911
        $k[$j++] = $f($get($1.barcode, $1.i) - 48); //#6912
        if (($1.i % 2) != 0) { //#6912
            var _B = $k[--$j]; //#6912
            $k[$j++] = _B * 2; //#6912
        } //#6912
        var _C = $k[--$j]; //#6912
        $k[$j++] = _C; //#6912
        if (_C > 9) { //#6912
            var _D = $k[--$j]; //#6912
            $k[$j++] = $f(_D - 9); //#6912
        } //#6912
        $1.checksum = $f($k[--$j] + $1.checksum); //#6913
    } //#6913
    $1.checksum = $1.checksum % 10; //#6915
    if ($1.barcode.length == 9) { //#6920
        if ($get($1.barcode, 8) != $f($1.checksum + 48)) { //#6919
            $k[$j++] = 'bwipp.code32badCheckDigit'; //#6918
            $k[$j++] = "Incorrect Italian Pharmacode check digit provided"; //#6918
            bwipp_raiseerror(); //#6918
        } //#6918
    } //#6918
    var _L = $s(10); //#6921
    $puti(_L, 0, $1.barcode); //#6922
    $put(_L, 8, $f($1.checksum + 48)); //#6923
    $1.text = _L; //#6924
    $1.val = $cvrs($s(6), $cvi($1.text), 32); //#6927
    $1.barcode = $s(6); //#6928
    for (var _S = 0; _S <= 5; _S += 1) { //#6929
        $put($1.barcode, _S, 48); //#6929
    } //#6929
    $puti($1.barcode, 6 - $1.val.length, $1.val); //#6930
    for (var _X = 0; _X <= 5; _X += 1) { //#6937
        var _Z = $get($1.barcode, _X); //#6934
        $k[$j++] = _X; //#6935
        $k[$j++] = _Z; //#6935
        $k[$j++] = _Z; //#6935
        for (var _a = 0, _b = "AEIO".length; _a < _b; _a++) { //#6935
            if ($k[--$j] >= $get("AEIO", _a)) { //#6935
                var _e = $k[--$j]; //#6935
                $k[$j++] = $f(_e + 1); //#6935
            } //#6935
            var _f = $k[--$j]; //#6935
            $k[$j++] = _f; //#6935
            $k[$j++] = _f; //#6935
        } //#6935
        $j--; //#6935
        var _h = $k[--$j]; //#6936
        $put($1.barcode, $k[--$j], _h); //#6936
    } //#6936
    $puti($1.text, 1, $geti($1.text, 0, 9)); //#6940
    $put($1.text, 0, 65); //#6941
    $put($1.options, "dontdraw", true); //#6944
    $k[$j++] = 'args'; //#6945
    $k[$j++] = $1.barcode; //#6945
    $k[$j++] = $1.options; //#6945
    bwipp_code39(); //#6945
    var _q = $k[--$j]; //#6945
    var _r = $k[--$j]; //#6945
    $1[_r] = _q; //#6945
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#6947
    $put($1.args, "textxalign", "center"); //#6948
    $put($1.args, "opt", $1.options); //#6949
    $k[$j++] = $1.args; //#6952
    if (!$1.dontdraw) { //#6952
        bwipp_renlinear(); //#6952
    } //#6952
}

function bwipp_pzn() {
    var $1 = {}; //#6983
    $1.ctx = null; //#6985
    $1.dontdraw = false; //#6986
    $1.includetext = false; //#6987
    $1.textfont = "OCR-B"; //#6988
    $1.textsize = 10; //#6989
    $1.textyoffset = -8; //#6990
    $1.textxoffset = 0; //#6991
    $1.height = 1; //#6992
    $1.pzn8 = false; //#6993
    $k[$j++] = $1; //#6995
    bwipp_processoptions(); //#6995
    $1.options = $k[--$j]; //#6995
    $1.barcode = $k[--$j]; //#6996
    if ($1.pzn8) { //#7005
        if (($1.barcode.length != 7) && ($1.barcode.length != 8)) { //#7002
            $k[$j++] = 'bwipp.pzn8badLength'; //#7001
            $k[$j++] = "PZN8 must be 7 or 8 digits"; //#7001
            bwipp_raiseerror(); //#7001
        } //#7001
    } else { //#7005
        if (($1.barcode.length != 6) && ($1.barcode.length != 7)) { //#7006
            $k[$j++] = 'bwipp.pzn7badLength'; //#7005
            $k[$j++] = "PZN7 must be 6 or 7 digits"; //#7005
            bwipp_raiseerror(); //#7005
        } //#7005
    } //#7005
    $forall($1.barcode, function() { //#7012
        var _8 = $k[--$j]; //#7009
        if ((_8 < 48) || (_8 > 57)) { //#7011
            $k[$j++] = 'bwipp.pznBadCharacter'; //#7010
            $k[$j++] = "PZN must contain only digits"; //#7010
            bwipp_raiseerror(); //#7010
        } //#7010
    }); //#7010
    var _A = $1.pzn8 ? 9 : 8; //#7015
    $1.msglen = _A; //#7015
    $1.checksum = 0; //#7016
    for (var _D = 0, _C = $1.msglen - 3; _D <= _C; _D += 1) { //#7021
        $1.i = _D; //#7018
        var _J = $1.pzn8 ? 1 : 2; //#7019
        $1.checksum = $f(($f($get($1.barcode, $1.i) - 48) * ($1.i + _J)) + $1.checksum); //#7020
    } //#7020
    $1.checksum = $1.checksum % 11; //#7022
    if ($1.checksum == 10) { //#7025
        $k[$j++] = 'bwipp.pznBadInputSequence'; //#7024
        $k[$j++] = "Incorrect PZN input sequence provided"; //#7024
        bwipp_raiseerror(); //#7024
    } //#7024
    if ($1.barcode.length == ($1.msglen - 1)) { //#7030
        if ($get($1.barcode, $1.msglen - 2) != $f($1.checksum + 48)) { //#7029
            $k[$j++] = 'bwipp.pznBadCheckDigit'; //#7028
            $k[$j++] = "Incorrect PZN check digit provided"; //#7028
            bwipp_raiseerror(); //#7028
        } //#7028
    } //#7028
    var _U = $s($1.msglen); //#7031
    $put(_U, 0, 45); //#7032
    $puti(_U, 1, $1.barcode); //#7033
    $put(_U, $1.msglen - 1, $f($1.checksum + 48)); //#7034
    $1.msg = _U; //#7035
    $put($1.options, "dontdraw", true); //#7038
    $k[$j++] = 'args'; //#7039
    $k[$j++] = $1.msg; //#7039
    $k[$j++] = $1.options; //#7039
    bwipp_code39(); //#7039
    var _b = $k[--$j]; //#7039
    $1[$k[--$j]] = _b; //#7039
    $1.text = $s($1.msglen + 5); //#7042
    $puti($1.text, 0, "PZN - "); //#7043
    $puti($1.text, 6, $geti($1.msg, 1, $1.msglen - 1)); //#7044
    var _r = $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])]); //#7046
    $put($1.args, "txt", _r); //#7046
    $put($1.args, "textxalign", "center"); //#7047
    $put($1.args, "opt", $1.options); //#7048
    $k[$j++] = $1.args; //#7051
    if (!$1.dontdraw) { //#7051
        bwipp_renlinear(); //#7051
    } //#7051
}

function bwipp_code93() {
    var $1 = {}; //#7084
    $1.ctx = null; //#7086
    $1.dontdraw = false; //#7087
    $1.includecheck = false; //#7088
    $1.includetext = false; //#7089
    $1.textfont = "OCR-B"; //#7090
    $1.textsize = 10; //#7091
    $1.textyoffset = -8; //#7092
    $1.height = 1; //#7093
    $1.parse = false; //#7094
    $1.parsefnc = false; //#7095
    $k[$j++] = $1; //#7097
    bwipp_processoptions(); //#7097
    $1.options = $k[--$j]; //#7097
    $1.barcode = $k[--$j]; //#7098
    $1.encs = $a(["131112", "111213", "111312", "111411", "121113", "121212", "121311", "111114", "131211", "141111", "211113", "211212", "211311", "221112", "221211", "231111", "112113", "112212", "112311", "122112", "132111", "111123", "111222", "111321", "121122", "131121", "212112", "212211", "211122", "211221", "221121", "222111", "112122", "112221", "122121", "123111", "121131", "311112", "311211", "321111", "112131", "113121", "211131", "121221", "312111", "311121", "122211", "111141", "1111411"]); //#7114
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#7117
    $1.charvals = new Map; //#7118
    for (var _3 = 0; _3 <= 42; _3 += 1) { //#7119
        $put($1.charvals, $get($1.barchars, _3), _3); //#7119
    } //#7119
    $1.sft1 = -1; //#7121
    $1.sft2 = -2; //#7121
    $1.sft3 = -3; //#7121
    $1.sft4 = -4; //#7121
    $put($1.charvals, $1.sft1, 43); //#7123
    $put($1.charvals, $1.sft2, 44); //#7124
    $put($1.charvals, $1.sft3, 45); //#7125
    $put($1.charvals, $1.sft4, 46); //#7126
    var _L = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["SFT$", $1.sft1],
        ["SFT%", $1.sft2],
        ["SFT/", $1.sft3],
        ["SFT+", $1.sft4]
    ]); //#7137
    $1.fncvals = _L; //#7138
    $k[$j++] = 'msg'; //#7139
    $k[$j++] = $1.barcode; //#7139
    $k[$j++] = $1.fncvals; //#7139
    bwipp_parseinput(); //#7139
    var _O = $k[--$j]; //#7139
    $1[$k[--$j]] = _O; //#7139
    $1.msglen = $1.msg.length; //#7140
    $forall($1.msg, function() { //#7147
        var _U = $get($1.charvals, $k[--$j]) !== undefined; //#7144
        if (!_U) { //#7146
            $k[$j++] = 'bwipp.code93BadCharacter'; //#7145
            $k[$j++] = "Code 93 must only contain digits, capital letters, spaces, the symbols -.$/+ and shift non-data characters"; //#7145
            bwipp_raiseerror(); //#7145
        } //#7145
    }); //#7145
    if ($1.includecheck) { //#7152
        $1.sbs = $s(($1.msglen * 6) + 25); //#7150
    } else { //#7152
        $1.sbs = $s(($1.msglen * 6) + 13); //#7152
    } //#7152
    $1.txt = $a($1.msglen); //#7154
    $puti($1.sbs, 0, $get($1.encs, 47)); //#7157
    $1.checksum1 = 0; //#7159
    $1.checksum2 = 0; //#7159
    for (var _h = 0, _g = $1.msglen - 1; _h <= _g; _h += 1) { //#7168
        $1.i = _h; //#7161
        $1.indx = $get($1.charvals, $get($1.msg, $1.i)); //#7162
        $puti($1.sbs, ($1.i * 6) + 6, $get($1.encs, $1.indx)); //#7163
        var _u = $get($1.msg, $1.i); //#7164
        $k[$j++] = 'char'; //#7164
        $k[$j++] = _u; //#7164
        if (_u < 0) { //#7164
            $j--; //#7164
            $k[$j++] = " "; //#7164
        } else { //#7164
            var _v = $s(1); //#7164
            $put(_v, 0, $k[--$j]); //#7164
            $k[$j++] = _v; //#7164
        } //#7164
        var _x = $k[--$j]; //#7164
        $1[$k[--$j]] = _x; //#7164
        $put($1.txt, $1.i, $a([$1.char, ($1.i * 9) + 9, $1.textyoffset, $1.textfont, $1.textsize])); //#7165
        $1.checksum1 = $f($1.checksum1 + ((((($1.msglen - $1.i) - 1) % 20) + 1) * $1.indx)); //#7166
        $1.checksum2 = $f($1.checksum2 + (((($1.msglen - $1.i) % 15) + 1) * $1.indx)); //#7167
    } //#7167
    if ($1.includecheck) { //#7180
        $1.checksum1 = $1.checksum1 % 47; //#7172
        $1.checksum2 = $f($1.checksum2 + $1.checksum1) % 47; //#7173
        $puti($1.sbs, ($1.msglen * 6) + 6, $get($1.encs, $1.checksum1)); //#7174
        $puti($1.sbs, ($1.msglen * 6) + 12, $get($1.encs, $1.checksum2)); //#7175
        $puti($1.sbs, ($1.msglen * 6) + 18, $get($1.encs, 48)); //#7177
    } else { //#7180
        $puti($1.sbs, ($1.msglen * 6) + 6, $get($1.encs, 48)); //#7180
    } //#7180
    $k[$j++] = Infinity; //#7192
    $k[$j++] = Infinity; //#7186
    var _1b = $1.sbs; //#7186
    for (var _1c = 0, _1d = _1b.length; _1c < _1d; _1c++) { //#7186
        $k[$j++] = $get(_1b, _1c) - 48; //#7186
    } //#7186
    var _1f = $a(); //#7186
    $k[$j++] = Infinity; //#7187
    for (var _1h = 0, _1i = ~~(($1.sbs.length + 1) / 2); _1h < _1i; _1h++) { //#7187
        $k[$j++] = $1.height; //#7187
    } //#7187
    var _1k = $a(); //#7187
    $k[$j++] = Infinity; //#7188
    for (var _1m = 0, _1n = ~~(($1.sbs.length + 1) / 2); _1m < _1n; _1m++) { //#7188
        $k[$j++] = 0; //#7188
    } //#7188
    var _1o = $a(); //#7188
    $k[$j++] = 'ren'; //#7191
    $k[$j++] = bwipp_renlinear; //#7191
    $k[$j++] = 'sbs'; //#7191
    $k[$j++] = _1f; //#7191
    $k[$j++] = 'bhs'; //#7191
    $k[$j++] = _1k; //#7191
    $k[$j++] = 'bbs'; //#7191
    $k[$j++] = _1o; //#7191
    if ($1.includetext) { //#7191
        $k[$j++] = 'txt'; //#7190
        $k[$j++] = $1.txt; //#7190
    } //#7190
    $k[$j++] = 'opt'; //#7192
    $k[$j++] = $1.options; //#7192
    var _1s = $d(); //#7192
    $k[$j++] = _1s; //#7195
    if (!$1.dontdraw) { //#7195
        bwipp_renlinear(); //#7195
    } //#7195
}

function bwipp_code93ext() {
    var $1 = {}; //#7231
    $1.ctx = null; //#7233
    $1.dontdraw = false; //#7234
    $1.includetext = false; //#7235
    $1.parse = false; //#7236
    $k[$j++] = $1; //#7238
    bwipp_processoptions(); //#7238
    $1.options = $k[--$j]; //#7238
    $1.barcode = $k[--$j]; //#7239
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#7247
    $1.fncvals = _3; //#7248
    $k[$j++] = 'barcode'; //#7249
    $k[$j++] = $1.barcode; //#7249
    $k[$j++] = $1.fncvals; //#7249
    bwipp_parseinput(); //#7249
    var _6 = $k[--$j]; //#7249
    $1[$k[--$j]] = _6; //#7249
    $1.barlen = $1.barcode.length; //#7250
    delete $1.options["parse"]; //#7251
    $1.extencs = $a(["^SFT%U", "^SFT$A", "^SFT$B", "^SFT$C", "^SFT$D", "^SFT$E", "^SFT$F", "^SFT$G", "^SFT$H", "^SFT$I", "^SFT$J", "^SFT$K", "^SFT$L", "^SFT$M", "^SFT$N", "^SFT$O", "^SFT$P", "^SFT$Q", "^SFT$R", "^SFT$S", "^SFT$T", "^SFT$U", "^SFT$V", "^SFT$W", "^SFT$X", "^SFT$Y", "^SFT$Z", "^SFT%A", "^SFT%B", "^SFT%C", "^SFT%D", "^SFT%E", " ", "^SFT/A", "^SFT/B", "^SFT/C", "$", "%", "^SFT/F", "^SFT/G", "^SFT/H", "^SFT/I", "^SFT/J", "+", "^SFT/L", "-", ".", "/", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "^SFT/Z", "^SFT%F", "^SFT%G", "^SFT%H", "^SFT%I", "^SFT%J", "^SFT%V", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "^SFT%K", "^SFT%L", "^SFT%M", "^SFT%N", "^SFT%O", "^SFT%W", "^SFT+A", "^SFT+B", "^SFT+C", "^SFT+D", "^SFT+E", "^SFT+F", "^SFT+G", "^SFT+H", "^SFT+I", "^SFT+J", "^SFT+K", "^SFT+L", "^SFT+M", "^SFT+N", "^SFT+O", "^SFT+P", "^SFT+Q", "^SFT+R", "^SFT+S", "^SFT+T", "^SFT+U", "^SFT+V", "^SFT+W", "^SFT+X", "^SFT+Y", "^SFT+Z", "^SFT%P", "^SFT%Q", "^SFT%R", "^SFT%S", "^SFT%T"]); //#7272
    $1.newcode = $s($1.barlen * 6); //#7275
    $1.newtext = $s($1.barlen * 6); //#7276
    $1.j = 0; //#7277
    $1.k = 0; //#7277
    for (var _H = 0, _G = $1.barlen - 1; _H <= _G; _H += 1) { //#7287
        $1.i = _H; //#7279
        $1.extchar = $get($1.extencs, $get($1.barcode, $1.i)); //#7280
        $1.extlen = $1.extchar.length; //#7281
        $puti($1.newcode, $1.j, $1.extchar); //#7282
        $put($1.newtext, $1.k, $get($1.barcode, $1.i)); //#7283
        if ($1.extlen != 1) { //#7284
            $puti($1.newtext, $1.k + 1, " "); //#7284
        } //#7284
        $1.j = $1.j + $1.extlen; //#7285
        var _d = ($1.extlen == 1) ? 1 : 2; //#7286
        $1.k = $1.k + _d; //#7286
    } //#7286
    $1.newcode = $geti($1.newcode, 0, $1.j); //#7288
    $1.newtext = $geti($1.newtext, 0, $1.k); //#7289
    $put($1.options, "dontdraw", true); //#7292
    $put($1.options, "parsefnc", true); //#7293
    $k[$j++] = 'args'; //#7294
    $k[$j++] = $1.newcode; //#7294
    $k[$j++] = $1.options; //#7294
    bwipp_code93(); //#7294
    var _o = $k[--$j]; //#7294
    $1[$k[--$j]] = _o; //#7294
    if ($1.includetext) { //#7306
        $1.txt = $get($1.args, "txt"); //#7298
        for (var _v = 0, _u = $1.newtext.length - 1; _v <= _u; _v += 1) { //#7304
            $1.i = _v; //#7300
            $1.txtentry = $get($1.txt, $1.i); //#7301
            $put($1.txtentry, 0, $geti($1.newtext, $1.i, 1)); //#7302
            $put($1.txt, $1.i, $1.txtentry); //#7303
        } //#7303
        $put($1.args, "txt", $1.txt); //#7305
    } //#7305
    $put($1.args, "opt", $1.options); //#7307
    $k[$j++] = $1.args; //#7310
    if (!$1.dontdraw) { //#7310
        bwipp_renlinear(); //#7310
    } //#7310
}

function bwipp_interleaved2of5() {
    var $1 = {}; //#7344
    $1.ctx = null; //#7346
    $1.dontdraw = false; //#7347
    $1.includecheck = false; //#7348
    $1.includetext = false; //#7349
    $1.includecheckintext = false; //#7350
    $1.textfont = "OCR-B"; //#7351
    $1.textsize = 10; //#7352
    $1.textyoffset = -8; //#7353
    $1.height = 1; //#7354
    $k[$j++] = $1; //#7356
    bwipp_processoptions(); //#7356
    $1.options = $k[--$j]; //#7356
    $1.barcode = $k[--$j]; //#7357
    $forall($1.barcode, function() { //#7366
        var _3 = $k[--$j]; //#7363
        if ((_3 < 48) || (_3 > 57)) { //#7365
            $k[$j++] = 'bwipp.interleaved2of5badCharacter'; //#7364
            $k[$j++] = "Interleaved 2 of 5 must contain only digits"; //#7364
            bwipp_raiseerror(); //#7364
        } //#7364
    }); //#7364
    $1.barlen = $1.barcode.length; //#7368
    if (((($1.barlen % 2) == 0) && $1.includecheck) || ((($1.barlen % 2) != 0) && (!$1.includecheck))) { //#7379
        $1.pad = $s($1.barlen + 1); //#7374
        $put($1.pad, 0, 48); //#7375
        $puti($1.pad, 1, $1.barcode); //#7376
        $1.barcode = $1.pad; //#7377
        $1.barlen = $1.barlen + 1; //#7378
    } //#7378
    if ($1.includecheck) { //#7398
        $1.checksum = 0; //#7383
        for (var _J = 0, _I = $1.barlen - 1; _J <= _I; _J += 1) { //#7391
            $1.i = _J; //#7385
            if (($1.i % 2) == 0) { //#7389
                $1.checksum = $1.checksum + (($get($1.barcode, $1.i) - 48) * 3); //#7387
            } else { //#7389
                $1.checksum = $1.checksum + ($get($1.barcode, $1.i) - 48); //#7389
            } //#7389
        } //#7389
        $1.checksum = (10 - ($1.checksum % 10)) % 10; //#7392
        $1.pad = $s($1.barlen + 1); //#7393
        $puti($1.pad, 0, $1.barcode); //#7394
        $put($1.pad, $1.barlen, $1.checksum + 48); //#7395
        $1.barcode = $1.pad; //#7396
        $1.barlen = $1.barlen + 1; //#7397
    } //#7397
    $1.encs = $a(["11221", "21112", "12112", "22111", "11212", "21211", "12211", "11122", "21121", "12121", "1111", "2111"]); //#7406
    $1.barchars = "0123456789"; //#7409
    $1.sbs = $s(($1.barlen * 5) + 8); //#7412
    $1.txt = $a($1.barlen); //#7413
    $puti($1.sbs, 0, $get($1.encs, 10)); //#7416
    for (var _n = 0, _m = $1.barlen - 1; _n <= _m; _n += 2) { //#7450
        $1.i = _n; //#7419
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#7421
        $j--; //#7422
        $1.indx = $k[--$j].length; //#7423
        $j -= 2; //#7424
        $1.enca = $get($1.encs, $1.indx); //#7425
        $search($1.barchars, $geti($1.barcode, $1.i + 1, 1)); //#7427
        $j--; //#7428
        $1.indx = $k[--$j].length; //#7429
        $j -= 2; //#7430
        $1.encb = $get($1.encs, $1.indx); //#7431
        $1.intl = $s($1.enca.length * 2); //#7434
        for (var _18 = 0, _17 = $1.enca.length - 1; _18 <= _17; _18 += 1) { //#7441
            $1.j = _18; //#7436
            $1.achar = $get($1.enca, $1.j); //#7437
            $1.bchar = $get($1.encb, $1.j); //#7438
            $put($1.intl, $1.j * 2, $1.achar); //#7439
            $put($1.intl, ($1.j * 2) + 1, $1.bchar); //#7440
        } //#7440
        $puti($1.sbs, ($1.i * 5) + 4, $1.intl); //#7443
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 9) + 4, $1.textyoffset, $1.textfont, $1.textsize])); //#7444
        if (($1.includecheck && (!$1.includecheckintext)) && (($1.barlen - 2) == $1.i)) { //#7448
            $put($1.txt, $1.i + 1, $a([" ", (($1.i + 1) * 9) + 4, $1.textyoffset, $1.textfont, $1.textsize])); //#7446
        } else { //#7448
            $put($1.txt, $1.i + 1, $a([$geti($1.barcode, $1.i + 1, 1), (($1.i + 1) * 9) + 4, $1.textyoffset, $1.textfont, $1.textsize])); //#7448
        } //#7448
    } //#7448
    $puti($1.sbs, ($1.barlen * 5) + 4, $get($1.encs, 11)); //#7453
    $k[$j++] = Infinity; //#7466
    $k[$j++] = Infinity; //#7458
    var _1x = $1.sbs; //#7458
    for (var _1y = 0, _1z = _1x.length; _1y < _1z; _1y++) { //#7458
        $k[$j++] = $get(_1x, _1y) - 48; //#7458
    } //#7458
    var _21 = $a(); //#7458
    $k[$j++] = Infinity; //#7459
    for (var _23 = 0, _24 = ~~(($1.sbs.length + 1) / 2); _23 < _24; _23++) { //#7459
        $k[$j++] = $1.height; //#7459
    } //#7459
    var _26 = $a(); //#7459
    $k[$j++] = Infinity; //#7460
    for (var _28 = 0, _29 = ~~(($1.sbs.length + 1) / 2); _28 < _29; _28++) { //#7460
        $k[$j++] = 0; //#7460
    } //#7460
    var _2A = $a(); //#7460
    $k[$j++] = 'ren'; //#7463
    $k[$j++] = bwipp_renlinear; //#7463
    $k[$j++] = 'sbs'; //#7463
    $k[$j++] = _21; //#7463
    $k[$j++] = 'bhs'; //#7463
    $k[$j++] = _26; //#7463
    $k[$j++] = 'bbs'; //#7463
    $k[$j++] = _2A; //#7463
    if ($1.includetext) { //#7463
        $k[$j++] = 'txt'; //#7462
        $k[$j++] = $1.txt; //#7462
    } //#7462
    $k[$j++] = 'barratio'; //#7466
    $k[$j++] = 2; //#7466
    $k[$j++] = 'spaceratio'; //#7466
    $k[$j++] = 2; //#7466
    $k[$j++] = 'opt'; //#7466
    $k[$j++] = $1.options; //#7466
    var _2E = $d(); //#7466
    $k[$j++] = _2E; //#7469
    if (!$1.dontdraw) { //#7469
        bwipp_renlinear(); //#7469
    } //#7469
}

function bwipp_itf14() {
    var $1 = {}; //#7502
    $1.ctx = null; //#7504
    $1.dontdraw = false; //#7505
    $1.includetext = false; //#7506
    $1.includecheckintext = true; //#7507
    $1.textfont = "OCR-B"; //#7508
    $1.textsize = 10; //#7509
    $1.textxoffset = 0; //#7510
    $1.textyoffset = 3; //#7511
    $1.height = 0.5; //#7512
    $1.showborder = true; //#7513
    $1.borderwidth = 4; //#7514
    $1.borderleft = 15; //#7515
    $1.borderright = 15; //#7516
    $k[$j++] = $1; //#7518
    bwipp_processoptions(); //#7518
    $1.options = $k[--$j]; //#7518
    $1.barcode = $k[--$j]; //#7519
    $1.text = $1.barcode; //#7522
    var _3 = $1.barcode; //#7523
    $k[$j++] = $s(_3.length); //#7524
    $k[$j++] = 0; //#7524
    $forall(_3, function() { //#7524
        var _5 = $k[--$j]; //#7524
        $k[$j++] = _5; //#7524
        if (_5 != 32) { //#7524
            var _6 = $k[--$j]; //#7524
            var _7 = $k[--$j]; //#7524
            var _8 = $k[--$j]; //#7524
            $put(_8, _7, _6); //#7524
            $k[$j++] = _8; //#7524
            $k[$j++] = $f(_7 + 1); //#7524
        } else { //#7524
            $j--; //#7524
        } //#7524
    }); //#7524
    var _9 = $k[--$j]; //#7525
    $1.barcode = $geti($k[--$j], 0, _9); //#7525
    $1.hasspace = $1.text.length != $1.barcode.length; //#7526
    if (($1.barcode.length != 13) && ($1.barcode.length != 14)) { //#7531
        $k[$j++] = 'bwipp.itf14badLength'; //#7530
        $k[$j++] = "ITF-14 must be 13 or 14 digits"; //#7530
        bwipp_raiseerror(); //#7530
    } //#7530
    var _G = $1.barcode; //#7532
    for (var _H = 0, _I = _G.length; _H < _I; _H++) { //#7536
        var _J = $get(_G, _H); //#7536
        if ((_J < 48) || (_J > 57)) { //#7535
            $k[$j++] = 'bwipp.itf14badCharacter'; //#7534
            $k[$j++] = "ITF-14 must contain only digits"; //#7534
            bwipp_raiseerror(); //#7534
        } //#7534
    } //#7534
    $1.checksum = 0; //#7539
    for (var _K = 0; _K <= 12; _K += 1) { //#7543
        $1.i = _K; //#7541
        $k[$j++] = 'checksum'; //#7542
        $k[$j++] = $1.checksum; //#7542
        $k[$j++] = $f($get($1.barcode, $1.i) - 48); //#7542
        if (($1.i % 2) == 0) { //#7542
            var _Q = $k[--$j]; //#7542
            $k[$j++] = _Q * 3; //#7542
        } //#7542
        var _R = $k[--$j]; //#7542
        var _S = $k[--$j]; //#7542
        $1[$k[--$j]] = $f(_S + _R); //#7542
    } //#7542
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#7544
    if ($1.barcode.length == 14) { //#7558
        if ($get($1.barcode, 13) != ($1.checksum + 48)) { //#7548
            $k[$j++] = 'bwipp.itf14badCheckDigit'; //#7547
            $k[$j++] = "Incorrect ITF-14 check digit provided"; //#7547
            bwipp_raiseerror(); //#7547
        } //#7547
    } else { //#7558
        var _Z = $s(14); //#7550
        $puti(_Z, 0, $1.barcode); //#7551
        $put(_Z, 13, $1.checksum + 48); //#7552
        $1.barcode = _Z; //#7553
        var _e = $1.hasspace ? 2 : 1; //#7554
        var _f = $s($1.text.length + _e); //#7554
        $puti(_f, _f.length - 2, " "); //#7555
        $put(_f, _f.length - 1, $1.checksum + 48); //#7556
        $puti(_f, 0, $1.text); //#7557
        $1.text = _f; //#7558
    } //#7558
    var _i = $1.options; //#7562
    $put(_i, "dontdraw", true); //#7562
    $put($1.options, "showborder", $1.showborder); //#7563
    $put($1.options, "borderwidth", $1.borderwidth); //#7564
    $put($1.options, "borderleft", $1.borderleft); //#7565
    $put($1.options, "borderright", $1.borderright); //#7566
    var _r = $1.options; //#7567
    $put(_r, "height", $1.height); //#7567
    $put($1.options, "textyoffset", $1.textyoffset); //#7568
    $k[$j++] = 'args'; //#7569
    $k[$j++] = $1.barcode; //#7569
    $k[$j++] = $1.options; //#7569
    bwipp_interleaved2of5(); //#7569
    var _x = $k[--$j]; //#7569
    $1[$k[--$j]] = _x; //#7569
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#7571
    $put($1.args, "textxalign", "center"); //#7572
    $put($1.args, "opt", $1.options); //#7573
    $k[$j++] = $1.args; //#7576
    if (!$1.dontdraw) { //#7576
        bwipp_renlinear(); //#7576
    } //#7576
}

function bwipp_identcode() {
    var $1 = {}; //#7607
    $1.ctx = null; //#7609
    $1.dontdraw = false; //#7610
    $1.includetext = false; //#7611
    $1.textfont = "OCR-B"; //#7612
    $1.textsize = 10; //#7613
    $1.textxoffset = 0; //#7614
    $1.textyoffset = -8; //#7615
    $1.height = 1; //#7616
    $k[$j++] = $1; //#7618
    bwipp_processoptions(); //#7618
    $1.options = $k[--$j]; //#7618
    $1.barcode = $k[--$j]; //#7619
    if (($1.barcode.length != 11) && ($1.barcode.length != 12)) { //#7624
        $k[$j++] = 'bwipp.identcodeBadLength'; //#7623
        $k[$j++] = "Deutsche Post Identcode must be 11 or 12 digits"; //#7623
        bwipp_raiseerror(); //#7623
    } //#7623
    $forall($1.barcode, function() { //#7629
        var _5 = $k[--$j]; //#7626
        if ((_5 < 48) || (_5 > 57)) { //#7628
            $k[$j++] = 'bwipp.identcodeBadCharacter'; //#7627
            $k[$j++] = "Deutsche Post Identcode must contain only digits"; //#7627
            bwipp_raiseerror(); //#7627
        } //#7627
    }); //#7627
    $1.checksum = 0; //#7632
    for (var _6 = 0; _6 <= 10; _6 += 1) { //#7636
        $1.i = _6; //#7634
        $k[$j++] = 'checksum'; //#7635
        $k[$j++] = $1.checksum; //#7635
        $k[$j++] = $f($get($1.barcode, $1.i) - 48); //#7635
        if (($1.i % 2) == 0) { //#7635
            var _C = $k[--$j]; //#7635
            $k[$j++] = _C * 4; //#7635
        } else { //#7635
            var _D = $k[--$j]; //#7635
            $k[$j++] = _D * 9; //#7635
        } //#7635
        var _E = $k[--$j]; //#7635
        var _F = $k[--$j]; //#7635
        $1[$k[--$j]] = $f(_F + _E); //#7635
    } //#7635
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#7637
    if ($1.barcode.length == 12) { //#7642
        if ($get($1.barcode, 11) != ($1.checksum + 48)) { //#7641
            $k[$j++] = 'bwipp.identcodeBadCheckDigit'; //#7640
            $k[$j++] = "Incorrect Deutsche Post Identcode check digit provided"; //#7640
            bwipp_raiseerror(); //#7640
        } //#7640
    } //#7640
    var _M = $s(12); //#7643
    $puti(_M, 0, $1.barcode); //#7644
    $put(_M, 11, $1.checksum + 48); //#7645
    $1.barcode = _M; //#7646
    $1.text = $strcpy($s(16), "  .       .     "); //#7649
    $puti($1.text, 0, $geti($1.barcode, 0, 2)); //#7650
    $puti($1.text, 3, $geti($1.barcode, 2, 3)); //#7651
    $puti($1.text, 7, $geti($1.barcode, 5, 3)); //#7652
    $puti($1.text, 11, $geti($1.barcode, 8, 3)); //#7653
    $puti($1.text, 15, $geti($1.barcode, 11, 1)); //#7654
    $put($1.options, "dontdraw", true); //#7657
    $put($1.options, "includecheck", false); //#7658
    var _i = $1.barcode; //#7659
    $k[$j++] = 'args'; //#7659
    $k[$j++] = _i; //#7659
    $k[$j++] = $1.options; //#7659
    bwipp_interleaved2of5(); //#7659
    var _k = $k[--$j]; //#7659
    $1[$k[--$j]] = _k; //#7659
    var _r = $1.textsize; //#7661
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, _r])])); //#7661
    $put($1.args, "textxalign", "center"); //#7662
    $put($1.args, "opt", $1.options); //#7663
    $k[$j++] = $1.args; //#7666
    if (!$1.dontdraw) { //#7666
        bwipp_renlinear(); //#7666
    } //#7666
}

function bwipp_leitcode() {
    var $1 = {}; //#7697
    $1.ctx = null; //#7699
    $1.dontdraw = false; //#7700
    $1.includetext = false; //#7701
    $1.textfont = "OCR-B"; //#7702
    $1.textsize = 10; //#7703
    $1.textxoffset = 0; //#7704
    $1.textyoffset = -8; //#7705
    $1.height = 1; //#7706
    $k[$j++] = $1; //#7708
    bwipp_processoptions(); //#7708
    $1.options = $k[--$j]; //#7708
    $1.barcode = $k[--$j]; //#7709
    if (($1.barcode.length != 13) && ($1.barcode.length != 14)) { //#7714
        $k[$j++] = 'bwipp.leitcodeBadLength'; //#7713
        $k[$j++] = "Deutsche Post Leitcode must be 13 or 14 digits"; //#7713
        bwipp_raiseerror(); //#7713
    } //#7713
    $forall($1.barcode, function() { //#7719
        var _5 = $k[--$j]; //#7716
        if ((_5 < 48) || (_5 > 57)) { //#7718
            $k[$j++] = 'bwipp.leitcodeBadCharacter'; //#7717
            $k[$j++] = "Deutsche Post Leitcode must contain only digits"; //#7717
            bwipp_raiseerror(); //#7717
        } //#7717
    }); //#7717
    $1.checksum = 0; //#7722
    for (var _6 = 0; _6 <= 12; _6 += 1) { //#7726
        $1.i = _6; //#7724
        $k[$j++] = 'checksum'; //#7725
        $k[$j++] = $1.checksum; //#7725
        $k[$j++] = $f($get($1.barcode, $1.i) - 48); //#7725
        if (($1.i % 2) == 0) { //#7725
            var _C = $k[--$j]; //#7725
            $k[$j++] = _C * 4; //#7725
        } else { //#7725
            var _D = $k[--$j]; //#7725
            $k[$j++] = _D * 9; //#7725
        } //#7725
        var _E = $k[--$j]; //#7725
        var _F = $k[--$j]; //#7725
        $1[$k[--$j]] = $f(_F + _E); //#7725
    } //#7725
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#7727
    if ($1.barcode.length == 14) { //#7732
        if ($get($1.barcode, 13) != ($1.checksum + 48)) { //#7731
            $k[$j++] = 'bwipp.leitcodeBadCheckDigit'; //#7730
            $k[$j++] = "Incorrect Deutsche Post Leitcode check digit provided"; //#7730
            bwipp_raiseerror(); //#7730
        } //#7730
    } //#7730
    var _M = $s(14); //#7733
    $puti(_M, 0, $1.barcode); //#7734
    $put(_M, 13, $1.checksum + 48); //#7735
    $1.barcode = _M; //#7736
    $1.text = $strcpy($s(18), "     .   .   .    "); //#7739
    $puti($1.text, 0, $geti($1.barcode, 0, 5)); //#7740
    $puti($1.text, 6, $geti($1.barcode, 5, 3)); //#7741
    $puti($1.text, 10, $geti($1.barcode, 8, 3)); //#7742
    $puti($1.text, 14, $geti($1.barcode, 11, 2)); //#7743
    $puti($1.text, 17, $geti($1.barcode, 13, 1)); //#7744
    $put($1.options, "dontdraw", true); //#7747
    $put($1.options, "includecheck", false); //#7748
    var _i = $1.barcode; //#7749
    $k[$j++] = 'args'; //#7749
    $k[$j++] = _i; //#7749
    $k[$j++] = $1.options; //#7749
    bwipp_interleaved2of5(); //#7749
    var _k = $k[--$j]; //#7749
    $1[$k[--$j]] = _k; //#7749
    var _r = $1.textsize; //#7751
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, _r])])); //#7751
    $put($1.args, "textxalign", "center"); //#7752
    $put($1.args, "opt", $1.options); //#7753
    $k[$j++] = $1.args; //#7756
    if (!$1.dontdraw) { //#7756
        bwipp_renlinear(); //#7756
    } //#7756
}

function bwipp_databaromni() {
    var $1 = {}; //#7789
    $1.ctx = null; //#7791
    $1.dontdraw = false; //#7792
    $1.height = 33 / 72; //#7793
    $1.linkage = false; //#7794
    $1.format = "omni"; //#7795
    $1.barxmult = 33; //#7796
    $k[$j++] = $1; //#7798
    bwipp_processoptions(); //#7798
    $1.options = $k[--$j]; //#7798
    $1.barcode = $k[--$j]; //#7799
    if ($eq($1.format, "truncated")) { //#7801
        $1.height = 13 / 72; //#7801
    } //#7801
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#7808
        $k[$j++] = 'bwipp.databaromniBadAI'; //#7807
        $k[$j++] = "GS1 DataBar Omnidirectional must begin with (01) application identifier"; //#7807
        bwipp_raiseerror(); //#7807
    } //#7807
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#7811
        $k[$j++] = 'bwipp.databaromniBadLength'; //#7810
        $k[$j++] = "GS1 DataBar Omnidirectional must be 13 or 14 digits"; //#7810
        bwipp_raiseerror(); //#7810
    } //#7810
    var _9 = $geti($1.barcode, 4, $1.barcode.length - 4); //#7812
    for (var _A = 0, _B = _9.length; _A < _B; _A++) { //#7816
        var _C = $get(_9, _A); //#7816
        if ((_C < 48) || (_C > 57)) { //#7815
            $k[$j++] = 'bwipp.databaromniBadCharacter'; //#7814
            $k[$j++] = "GS1 DataBar Omnidirectional must contain only digits"; //#7814
            bwipp_raiseerror(); //#7814
        } //#7814
    } //#7814
    $1.checksum = 0; //#7819
    for (var _D = 0; _D <= 12; _D += 1) { //#7823
        $1.i = _D; //#7821
        $k[$j++] = 'checksum'; //#7822
        $k[$j++] = $1.checksum; //#7822
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#7822
        if (($1.i % 2) == 0) { //#7822
            var _J = $k[--$j]; //#7822
            $k[$j++] = _J * 3; //#7822
        } //#7822
        var _K = $k[--$j]; //#7822
        var _L = $k[--$j]; //#7822
        $1[$k[--$j]] = $f(_L + _K); //#7822
    } //#7822
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#7824
    if ($1.barcode.length == 18) { //#7829
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#7828
            $k[$j++] = 'bwipp.databaromniBadCheckDigit'; //#7827
            $k[$j++] = "Incorrect GS1 DataBar Omnidirectional check digit provided"; //#7827
            bwipp_raiseerror(); //#7827
        } //#7827
    } //#7827
    var _S = $s(18); //#7830
    $puti(_S, 0, $1.barcode); //#7831
    $put(_S, 17, $1.checksum + 48); //#7832
    $1.barcode = _S; //#7833
    $1.txt = $a($1.barcode.length); //#7836
    for (var _Z = 0, _Y = $1.barcode.length - 1; _Z <= _Y; _Z += 1) { //#7840
        $1.i = _Z; //#7838
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#7839
    } //#7839
    $1.ncr = function() {
        var _g = $k[--$j]; //#7843
        var _h = $k[--$j]; //#7843
        var _i = $f(_h - _g); //#7843
        if (_g < $f(_h - _g)) { //#7843
            var _ = _i; //#7843
            _i = _g; //#7843
            _g = _; //#7843
        } //#7843
        $k[$j++] = _i; //#7850
        $k[$j++] = 1; //#7850
        $k[$j++] = 1; //#7850
        for (var _k = _h, _j = $f(_g + 1); _k >= _j; _k -= 1) { //#7850
            var _l = $k[--$j]; //#7846
            var _m = $k[--$j]; //#7847
            var _n = $k[--$j]; //#7847
            $k[$j++] = _n; //#7849
            $k[$j++] = _m; //#7849
            $k[$j++] = _l * _k; //#7849
            if ($le(_m, _n)) { //#7849
                var _o = $k[--$j]; //#7848
                var _p = $k[--$j]; //#7848
                $k[$j++] = $f(_p + 1); //#7848
                $k[$j++] = ~~(_o / _p); //#7848
            } //#7848
        } //#7848
        for (;;) { //#7854
            var _q = $k[--$j]; //#7852
            var _r = $k[--$j]; //#7852
            var _s = $k[--$j]; //#7852
            $k[$j++] = _s; //#7852
            $k[$j++] = _r; //#7852
            $k[$j++] = _q; //#7852
            if ($gt(_r, _s)) { //#7852
                break; //#7852
            } //#7852
            var _t = $k[--$j]; //#7853
            var _u = $k[--$j]; //#7853
            $k[$j++] = $f(_u + 1); //#7853
            $k[$j++] = ~~(_t / _u); //#7853
        } //#7853
        var _v = $k[--$j]; //#7855
        var _w = $k[--$j]; //#7855
        $k[$j++] = _v; //#7855
        $k[$j++] = _w; //#7855
        $j--; //#7855
        var _x = $k[--$j]; //#7855
        var _y = $k[--$j]; //#7855
        $k[$j++] = _x; //#7855
        $k[$j++] = _y; //#7855
        $j--; //#7855
    }; //#7855
    $1.getRSSwidths = function() {
        $1.oe = $k[--$j]; //#7859
        $1.el = $k[--$j]; //#7860
        $1.mw = $k[--$j]; //#7861
        $1.nm = $k[--$j]; //#7862
        $1.val = $k[--$j]; //#7863
        $1.out = $a($1.el); //#7864
        $1.mask = 0; //#7865
        for (var _18 = 0, _17 = $f($1.el - 2); _18 <= _17; _18 += 1) { //#7892
            $1.bar = _18; //#7867
            $1.ew = 1; //#7868
            var _1A = $1.bar; //#7869
            $1.mask = $1.mask | ((_1A < 0 ? 1 >>> -_1A : 1 << _1A)); //#7869
            for (;;) { //#7888
                $k[$j++] = 'sval'; //#7870
                $k[$j++] = $f($f($1.nm - $1.ew) - 1); //#7870
                $k[$j++] = $f($f($1.el - $1.bar) - 2); //#7870
                $1.ncr(); //#7870
                var _1F = $k[--$j]; //#7870
                $1[$k[--$j]] = _1F; //#7870
                if (($1.oe && ($1.mask == 0)) && (($f(($f($f($1.nm - $1.ew) - ($1.el * 2))) + ($1.bar * 2))) >= -2)) { //#7873
                    $k[$j++] = 'sval'; //#7872
                    $k[$j++] = $1.sval; //#7872
                    $k[$j++] = $f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar); //#7872
                    $k[$j++] = $f($f($1.el - $1.bar) - 2); //#7872
                    $1.ncr(); //#7872
                    var _1U = $k[--$j]; //#7872
                    var _1V = $k[--$j]; //#7872
                    $1[$k[--$j]] = $f(_1V - _1U); //#7872
                } //#7872
                if ($f($1.el - $1.bar) > 2) { //#7882
                    $1.lval = 0; //#7875
                    for (var _1f = $f(($f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar)) + 2), _1e = $f($1.mw + 1); _1f >= _1e; _1f -= 1) { //#7879
                        $k[$j++] = $f(($f($f($1.nm - _1f) - $1.ew)) - 1); //#7877
                        $k[$j++] = $f($f($1.el - $1.bar) - 3); //#7877
                        $1.ncr(); //#7877
                        $1.lval = $f($k[--$j] + $1.lval); //#7878
                    } //#7878
                    $1.sval = $f($1.sval - ($1.lval * ($f($f($1.el - $1.bar) - 1)))); //#7880
                } else { //#7882
                    if ($f($1.nm - $1.ew) > $1.mw) { //#7882
                        $1.sval = $f($1.sval - 1); //#7882
                    } //#7882
                } //#7882
                $1.val = $f($1.val - $1.sval); //#7884
                if ($1.val < 0) { //#7885
                    break; //#7885
                } //#7885
                $1.ew = $1.ew + 1; //#7886
                var _1z = $1.bar; //#7887
                $1.mask = $1.mask & (~((_1z < 0 ? 1 >>> -_1z : 1 << _1z))); //#7887
            } //#7887
            $1.val = $f($1.val + $1.sval); //#7889
            $1.nm = $f($1.nm - $1.ew); //#7890
            $put($1.out, $1.bar, $1.ew); //#7891
        } //#7891
        $put($1.out, $f($1.el - 1), $1.nm); //#7893
        $k[$j++] = $1.out; //#7894
    }; //#7894
    $k[$j++] = Infinity; //#7899
    var _2C = $1.linkage ? 1 : 0; //#7898
    var _2E = $geti($1.barcode, 4, 13); //#7899
    $k[$j++] = _2C; //#7899
    for (var _2F = 0, _2G = _2E.length; _2F < _2G; _2F++) { //#7899
        $k[$j++] = $f($get(_2E, _2F) - 48); //#7899
    } //#7899
    $1.binval = $a(); //#7899
    for (var _2J = 0; _2J <= 12; _2J += 1) { //#7906
        $1.i = _2J; //#7903
        var _2K = $1.binval; //#7904
        var _2L = $1.i; //#7904
        $put(_2K, _2L + 1, $f($get(_2K, _2L + 1) + (($get($1.binval, $1.i) % 4537077) * 10))); //#7904
        $put($1.binval, $1.i, ~~($get($1.binval, $1.i) / 4537077)); //#7905
    } //#7905
    $1.right = $get($1.binval, 13) % 4537077; //#7907
    var _2X = $1.binval; //#7908
    $put(_2X, 13, ~~($get(_2X, 13) / 4537077)); //#7908
    $1.left = 0; //#7910
    $1.i = true; //#7911
    for (var _2Z = 0; _2Z <= 13; _2Z += 1) { //#7921
        $1.j = _2Z; //#7913
        var _2c = $get($1.binval, $1.j); //#7914
        $k[$j++] = _2c; //#7920
        if ((_2c == 0) && $1.i) { //#7919
            $j--; //#7916
        } else { //#7919
            $1.i = false; //#7918
            $1.left = $f($1.left + ($k[--$j] * (~~Math.pow(10, 13 - $1.j)))); //#7919
        } //#7919
    } //#7919
    $1.d1 = ~~($1.left / 1597); //#7923
    $1.d2 = $1.left % 1597; //#7924
    $1.d3 = ~~($1.right / 1597); //#7925
    $1.d4 = $1.right % 1597; //#7926
    $1.tab164 = $a([160, 0, 12, 4, 8, 1, 161, 1, 960, 161, 10, 6, 6, 3, 80, 10, 2014, 961, 8, 8, 4, 5, 31, 34, 2714, 2015, 6, 10, 3, 6, 10, 70, 2840, 2715, 4, 12, 1, 8, 1, 126]); //#7935
    $1.tab154 = $a([335, 0, 5, 10, 2, 7, 4, 84, 1035, 336, 7, 8, 4, 5, 20, 35, 1515, 1036, 9, 6, 6, 3, 48, 10, 1596, 1516, 11, 4, 8, 1, 81, 1]); //#7942
    $1.i = 0; //#7945
    for (;;) { //#7955
        if ($1.d1 <= $get($1.tab164, $1.i)) { //#7953
            var _2t = $geti($1.tab164, $1.i + 1, 7); //#7947
            for (var _2u = 0, _2v = _2t.length; _2u < _2v; _2u++) { //#7947
                $k[$j++] = $get(_2t, _2u); //#7947
            } //#7947
            $1.d1te = $k[--$j]; //#7948
            $1.d1to = $k[--$j]; //#7948
            $1.d1mwe = $k[--$j]; //#7949
            $1.d1mwo = $k[--$j]; //#7949
            $1.d1ele = $k[--$j]; //#7950
            $1.d1elo = $k[--$j]; //#7950
            $1.d1gs = $k[--$j]; //#7951
            break; //#7952
        } //#7952
        $1.i = $1.i + 8; //#7954
    } //#7954
    $1.i = 0; //#7957
    for (;;) { //#7967
        if ($1.d2 <= $get($1.tab154, $1.i)) { //#7965
            var _3B = $geti($1.tab154, $1.i + 1, 7); //#7959
            for (var _3C = 0, _3D = _3B.length; _3C < _3D; _3C++) { //#7959
                $k[$j++] = $get(_3B, _3C); //#7959
            } //#7959
            $1.d2te = $k[--$j]; //#7960
            $1.d2to = $k[--$j]; //#7960
            $1.d2mwe = $k[--$j]; //#7961
            $1.d2mwo = $k[--$j]; //#7961
            $1.d2ele = $k[--$j]; //#7962
            $1.d2elo = $k[--$j]; //#7962
            $1.d2gs = $k[--$j]; //#7963
            break; //#7964
        } //#7964
        $1.i = $1.i + 8; //#7966
    } //#7966
    $1.i = 0; //#7969
    for (;;) { //#7979
        if ($1.d3 <= $get($1.tab164, $1.i)) { //#7977
            var _3T = $geti($1.tab164, $1.i + 1, 7); //#7971
            for (var _3U = 0, _3V = _3T.length; _3U < _3V; _3U++) { //#7971
                $k[$j++] = $get(_3T, _3U); //#7971
            } //#7971
            $1.d3te = $k[--$j]; //#7972
            $1.d3to = $k[--$j]; //#7972
            $1.d3mwe = $k[--$j]; //#7973
            $1.d3mwo = $k[--$j]; //#7973
            $1.d3ele = $k[--$j]; //#7974
            $1.d3elo = $k[--$j]; //#7974
            $1.d3gs = $k[--$j]; //#7975
            break; //#7976
        } //#7976
        $1.i = $1.i + 8; //#7978
    } //#7978
    $1.i = 0; //#7981
    for (;;) { //#7991
        if ($1.d4 <= $get($1.tab154, $1.i)) { //#7989
            var _3l = $geti($1.tab154, $1.i + 1, 7); //#7983
            for (var _3m = 0, _3n = _3l.length; _3m < _3n; _3m++) { //#7983
                $k[$j++] = $get(_3l, _3m); //#7983
            } //#7983
            $1.d4te = $k[--$j]; //#7984
            $1.d4to = $k[--$j]; //#7984
            $1.d4mwe = $k[--$j]; //#7985
            $1.d4mwo = $k[--$j]; //#7985
            $1.d4ele = $k[--$j]; //#7986
            $1.d4elo = $k[--$j]; //#7986
            $1.d4gs = $k[--$j]; //#7987
            break; //#7988
        } //#7988
        $1.i = $1.i + 8; //#7990
    } //#7990
    $k[$j++] = 'd1wo'; //#7993
    $k[$j++] = ~~($f($1.d1 - $1.d1gs) / $1.d1te); //#7993
    $k[$j++] = $1.d1elo; //#7993
    $k[$j++] = $1.d1mwo; //#7993
    $k[$j++] = 4; //#7993
    $k[$j++] = false; //#7993
    $1.getRSSwidths(); //#7993
    var _42 = $k[--$j]; //#7993
    $1[$k[--$j]] = _42; //#7993
    $k[$j++] = 'd1we'; //#7994
    $k[$j++] = $f($1.d1 - $1.d1gs) % $1.d1te; //#7994
    $k[$j++] = $1.d1ele; //#7994
    $k[$j++] = $1.d1mwe; //#7994
    $k[$j++] = 4; //#7994
    $k[$j++] = true; //#7994
    $1.getRSSwidths(); //#7994
    var _49 = $k[--$j]; //#7994
    $1[$k[--$j]] = _49; //#7994
    $k[$j++] = 'd2wo'; //#7995
    $k[$j++] = $f($1.d2 - $1.d2gs) % $1.d2to; //#7995
    $k[$j++] = $1.d2elo; //#7995
    $k[$j++] = $1.d2mwo; //#7995
    $k[$j++] = 4; //#7995
    $k[$j++] = true; //#7995
    $1.getRSSwidths(); //#7995
    var _4G = $k[--$j]; //#7995
    $1[$k[--$j]] = _4G; //#7995
    $k[$j++] = 'd2we'; //#7996
    $k[$j++] = ~~($f($1.d2 - $1.d2gs) / $1.d2to); //#7996
    $k[$j++] = $1.d2ele; //#7996
    $k[$j++] = $1.d2mwe; //#7996
    $k[$j++] = 4; //#7996
    $k[$j++] = false; //#7996
    $1.getRSSwidths(); //#7996
    var _4N = $k[--$j]; //#7996
    $1[$k[--$j]] = _4N; //#7996
    $k[$j++] = 'd3wo'; //#7997
    $k[$j++] = ~~($f($1.d3 - $1.d3gs) / $1.d3te); //#7997
    $k[$j++] = $1.d3elo; //#7997
    $k[$j++] = $1.d3mwo; //#7997
    $k[$j++] = 4; //#7997
    $k[$j++] = false; //#7997
    $1.getRSSwidths(); //#7997
    var _4U = $k[--$j]; //#7997
    $1[$k[--$j]] = _4U; //#7997
    $k[$j++] = 'd3we'; //#7998
    $k[$j++] = $f($1.d3 - $1.d3gs) % $1.d3te; //#7998
    $k[$j++] = $1.d3ele; //#7998
    $k[$j++] = $1.d3mwe; //#7998
    $k[$j++] = 4; //#7998
    $k[$j++] = true; //#7998
    $1.getRSSwidths(); //#7998
    var _4b = $k[--$j]; //#7998
    $1[$k[--$j]] = _4b; //#7998
    $k[$j++] = 'd4wo'; //#7999
    $k[$j++] = $f($1.d4 - $1.d4gs) % $1.d4to; //#7999
    $k[$j++] = $1.d4elo; //#7999
    $k[$j++] = $1.d4mwo; //#7999
    $k[$j++] = 4; //#7999
    $k[$j++] = true; //#7999
    $1.getRSSwidths(); //#7999
    var _4i = $k[--$j]; //#7999
    $1[$k[--$j]] = _4i; //#7999
    $k[$j++] = 'd4we'; //#8000
    $k[$j++] = ~~($f($1.d4 - $1.d4gs) / $1.d4to); //#8000
    $k[$j++] = $1.d4ele; //#8000
    $k[$j++] = $1.d4mwe; //#8000
    $k[$j++] = 4; //#8000
    $k[$j++] = false; //#8000
    $1.getRSSwidths(); //#8000
    var _4p = $k[--$j]; //#8000
    $1[$k[--$j]] = _4p; //#8000
    $1.d1w = $a(8); //#8002
    for (var _4s = 0; _4s <= 3; _4s += 1) { //#8007
        $1.i = _4s; //#8004
        $put($1.d1w, $1.i * 2, $get($1.d1wo, $1.i)); //#8005
        $put($1.d1w, ($1.i * 2) + 1, $get($1.d1we, $1.i)); //#8006
    } //#8006
    $1.d2w = $a(8); //#8009
    for (var _54 = 0; _54 <= 3; _54 += 1) { //#8014
        $1.i = _54; //#8011
        $put($1.d2w, 7 - ($1.i * 2), $get($1.d2wo, $1.i)); //#8012
        $put($1.d2w, 6 - ($1.i * 2), $get($1.d2we, $1.i)); //#8013
    } //#8013
    $1.d3w = $a(8); //#8016
    for (var _5G = 0; _5G <= 3; _5G += 1) { //#8021
        $1.i = _5G; //#8018
        $put($1.d3w, 7 - ($1.i * 2), $get($1.d3wo, $1.i)); //#8019
        $put($1.d3w, 6 - ($1.i * 2), $get($1.d3we, $1.i)); //#8020
    } //#8020
    $1.d4w = $a(8); //#8023
    for (var _5S = 0; _5S <= 3; _5S += 1) { //#8028
        $1.i = _5S; //#8025
        $put($1.d4w, $1.i * 2, $get($1.d4wo, $1.i)); //#8026
        $put($1.d4w, ($1.i * 2) + 1, $get($1.d4we, $1.i)); //#8027
    } //#8027
    $k[$j++] = Infinity; //#8034
    var _5d = $1.d1w; //#8031
    for (var _5e = 0, _5f = _5d.length; _5e < _5f; _5e++) { //#8031
        $k[$j++] = $get(_5d, _5e); //#8031
    } //#8031
    var _5h = $1.d2w; //#8032
    for (var _5i = 0, _5j = _5h.length; _5i < _5j; _5i++) { //#8032
        $k[$j++] = $get(_5h, _5i); //#8032
    } //#8032
    var _5l = $1.d3w; //#8033
    for (var _5m = 0, _5n = _5l.length; _5m < _5n; _5m++) { //#8033
        $k[$j++] = $get(_5l, _5m); //#8033
    } //#8033
    var _5p = $1.d4w; //#8034
    for (var _5q = 0, _5r = _5p.length; _5q < _5r; _5q++) { //#8034
        $k[$j++] = $get(_5p, _5q); //#8034
    } //#8034
    $1.widths = $a(); //#8034
    $1.checkweights = $a([1, 3, 9, 27, 2, 6, 18, 54, 58, 72, 24, 8, 29, 36, 12, 4, 74, 51, 17, 32, 37, 65, 48, 16, 64, 34, 23, 69, 49, 68, 46, 59]); //#8043
    $1.checkwidths = $a([3, 8, 2, 1, 1, 3, 5, 5, 1, 1, 3, 3, 7, 1, 1, 3, 1, 9, 1, 1, 2, 7, 4, 1, 1, 2, 5, 6, 1, 1, 2, 3, 8, 1, 1, 1, 5, 7, 1, 1, 1, 3, 9, 1, 1]); //#8049
    $1.checksum = 0; //#8052
    for (var _5w = 0; _5w <= 31; _5w += 1) { //#8056
        $1.i = _5w; //#8054
        $1.checksum = $f($1.checksum + ($get($1.widths, $1.i) * $get($1.checkweights, $1.i))); //#8055
    } //#8055
    $1.checksum = $1.checksum % 79; //#8057
    if ($1.checksum >= 8) { //#8058
        $1.checksum = $f($1.checksum + 1); //#8058
    } //#8058
    if ($1.checksum >= 72) { //#8059
        $1.checksum = $f($1.checksum + 1); //#8059
    } //#8059
    $1.checklt = $geti($1.checkwidths, (~~($1.checksum / 9)) * 5, 5); //#8060
    $1.checkrtrev = $geti($1.checkwidths, ($1.checksum % 9) * 5, 5); //#8061
    $1.checkrt = $a(5); //#8062
    for (var _6G = 0; _6G <= 4; _6G += 1) { //#8066
        $1.i = _6G; //#8064
        $put($1.checkrt, $1.i, $get($1.checkrtrev, 4 - $1.i)); //#8065
    } //#8065
    if ($eq($1.format, "omni") || $eq($1.format, "truncated")) { //#8188
        $k[$j++] = Infinity; //#8073
        var _6O = $1.d1w; //#8072
        $k[$j++] = 1; //#8072
        for (var _6P = 0, _6Q = _6O.length; _6P < _6Q; _6P++) { //#8072
            $k[$j++] = $get(_6O, _6P); //#8072
        } //#8072
        var _6S = $1.checklt; //#8072
        for (var _6T = 0, _6U = _6S.length; _6T < _6U; _6T++) { //#8072
            $k[$j++] = $get(_6S, _6T); //#8072
        } //#8072
        var _6W = $1.d2w; //#8072
        for (var _6X = 0, _6Y = _6W.length; _6X < _6Y; _6X++) { //#8072
            $k[$j++] = $get(_6W, _6X); //#8072
        } //#8072
        var _6a = $1.d4w; //#8073
        for (var _6b = 0, _6c = _6a.length; _6b < _6c; _6b++) { //#8073
            $k[$j++] = $get(_6a, _6b); //#8073
        } //#8073
        var _6e = $1.checkrt; //#8073
        for (var _6f = 0, _6g = _6e.length; _6f < _6g; _6f++) { //#8073
            $k[$j++] = $get(_6e, _6f); //#8073
        } //#8073
        var _6i = $1.d3w; //#8073
        for (var _6j = 0, _6k = _6i.length; _6j < _6k; _6j++) { //#8073
            $k[$j++] = $get(_6i, _6j); //#8073
        } //#8073
        $k[$j++] = 1; //#8073
        $k[$j++] = 1; //#8073
        $1.sbs = $a(); //#8073
        $k[$j++] = Infinity; //#8083
        var _6n = $1.sbs; //#8078
        $k[$j++] = Infinity; //#8079
        for (var _6p = 0, _6q = ~~(($1.sbs.length + 1) / 2); _6p < _6q; _6p++) { //#8079
            $k[$j++] = $1.height; //#8079
        } //#8079
        var _6s = $a(); //#8079
        $k[$j++] = Infinity; //#8080
        for (var _6u = 0, _6v = ~~(($1.sbs.length + 1) / 2); _6u < _6v; _6u++) { //#8080
            $k[$j++] = 0; //#8080
        } //#8080
        var _6w = $a(); //#8080
        $k[$j++] = 'ren'; //#8083
        $k[$j++] = bwipp_renlinear; //#8083
        $k[$j++] = 'sbs'; //#8083
        $k[$j++] = _6n; //#8083
        $k[$j++] = 'bhs'; //#8083
        $k[$j++] = _6s; //#8083
        $k[$j++] = 'bbs'; //#8083
        $k[$j++] = _6w; //#8083
        $k[$j++] = 'txt'; //#8083
        $k[$j++] = $1.txt; //#8083
        $k[$j++] = 'textxalign'; //#8083
        $k[$j++] = "center"; //#8083
        $k[$j++] = 'opt'; //#8083
        $k[$j++] = $1.options; //#8083
        var _6z = $d(); //#8083
        $k[$j++] = _6z; //#8086
        if (!$1.dontdraw) { //#8086
            bwipp_renlinear(); //#8086
        } //#8086
    } else { //#8188
        $k[$j++] = Infinity; //#8090
        var _71 = $1.d1w; //#8090
        $k[$j++] = 1; //#8090
        $k[$j++] = 1; //#8090
        for (var _72 = 0, _73 = _71.length; _72 < _73; _72++) { //#8090
            $k[$j++] = $get(_71, _72); //#8090
        } //#8090
        var _75 = $1.checklt; //#8090
        for (var _76 = 0, _77 = _75.length; _76 < _77; _76++) { //#8090
            $k[$j++] = $get(_75, _76); //#8090
        } //#8090
        var _79 = $1.d2w; //#8090
        for (var _7A = 0, _7B = _79.length; _7A < _7B; _7A++) { //#8090
            $k[$j++] = $get(_79, _7A); //#8090
        } //#8090
        $k[$j++] = 1; //#8090
        $k[$j++] = 1; //#8090
        $k[$j++] = 0; //#8090
        $1.top = $a(); //#8090
        $k[$j++] = Infinity; //#8091
        var _7E = $1.d4w; //#8091
        $k[$j++] = 1; //#8091
        $k[$j++] = 1; //#8091
        for (var _7F = 0, _7G = _7E.length; _7F < _7G; _7F++) { //#8091
            $k[$j++] = $get(_7E, _7F); //#8091
        } //#8091
        var _7I = $1.checkrt; //#8091
        for (var _7J = 0, _7K = _7I.length; _7J < _7K; _7J++) { //#8091
            $k[$j++] = $get(_7I, _7J); //#8091
        } //#8091
        var _7M = $1.d3w; //#8091
        for (var _7N = 0, _7O = _7M.length; _7N < _7O; _7N++) { //#8091
            $k[$j++] = $get(_7M, _7N); //#8091
        } //#8091
        $k[$j++] = 1; //#8091
        $k[$j++] = 1; //#8091
        $k[$j++] = 0; //#8091
        $1.bot = $a(); //#8091
        for (var _7R = 0; _7R <= 24; _7R += 2) { //#8096
            $1.i = _7R; //#8093
            for (var _7V = 0, _7W = $get($1.top, $1.i); _7V < _7W; _7V++) { //#8094
                $k[$j++] = 0; //#8094
            } //#8094
            for (var _7a = 0, _7b = $get($1.top, $1.i + 1); _7a < _7b; _7a++) { //#8095
                $k[$j++] = 1; //#8095
            } //#8095
        } //#8095
        $astore($a(50)); //#8097
        $1.top = $k[--$j]; //#8097
        for (var _7e = 0; _7e <= 24; _7e += 2) { //#8102
            $1.i = _7e; //#8099
            for (var _7i = 0, _7j = $get($1.bot, $1.i); _7i < _7j; _7i++) { //#8100
                $k[$j++] = 1; //#8100
            } //#8100
            for (var _7n = 0, _7o = $get($1.bot, $1.i + 1); _7n < _7o; _7n++) { //#8101
                $k[$j++] = 0; //#8101
            } //#8101
        } //#8101
        $astore($a(50)); //#8103
        $1.bot = $k[--$j]; //#8103
        if ($eq($1.format, "stacked")) { //#8125
            $1.sep = $a(50); //#8107
            $put($1.sep, 0, 0); //#8108
            for (var _7u = 1; _7u <= 49; _7u += 1) { //#8116
                $1.i = _7u; //#8110
                if ($eq($get($1.top, $1.i), $get($1.bot, $1.i))) { //#8114
                    $put($1.sep, $1.i, $f(1 - $get($1.top, $1.i))); //#8112
                } else { //#8114
                    $put($1.sep, $1.i, $f(1 - $get($1.sep, $1.i - 1))); //#8114
                } //#8114
            } //#8114
            $puti($1.sep, 0, $a([0, 0, 0, 0])); //#8117
            $puti($1.sep, 46, $a([0, 0, 0, 0])); //#8118
            $k[$j++] = Infinity; //#8122
            for (var _8F = 0, _8G = 5; _8F < _8G; _8F++) { //#8120
                $aload($1.top); //#8120
            } //#8120
            $aload($1.sep); //#8121
            for (var _8J = 0, _8K = 7; _8J < _8K; _8J++) { //#8122
                $aload($1.bot); //#8122
            } //#8122
            $1.pixs = $a(); //#8122
            $1.pixy = ~~($1.pixs.length / 50); //#8124
        } //#8124
        if ($eq($1.format, "stackedomni")) { //#8175
            $k[$j++] = Infinity; //#8129
            $forall($1.top, function() { //#8129
                var _8Q = $k[--$j]; //#8129
                $k[$j++] = $f(1 - _8Q); //#8129
            }); //#8129
            $1.sep1 = $a(); //#8129
            $puti($1.sep1, 0, $a([0, 0, 0, 0])); //#8130
            $puti($1.sep1, 46, $a([0, 0, 0, 0])); //#8131
            for (var _8W = 18; _8W <= 30; _8W += 1) { //#8144
                $1.i = _8W; //#8133
                if ($get($1.top, $1.i) == 0) { //#8141
                    if ($get($1.top, $1.i - 1) == 1) { //#8138
                        $k[$j++] = 1; //#8136
                    } else { //#8138
                        var _8g = ($get($1.sep1, $1.i - 1) == 0) ? 1 : 0; //#8138
                        $k[$j++] = _8g; //#8138
                    } //#8138
                } else { //#8141
                    $k[$j++] = 0; //#8141
                } //#8141
                $put($1.sep1, $1.i, $k[--$j]); //#8143
            } //#8143
            $k[$j++] = Infinity; //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            for (var _8k = 0, _8l = 21; _8k < _8l; _8k++) { //#8145
                $k[$j++] = 0; //#8145
                $k[$j++] = 1; //#8145
            } //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            $k[$j++] = 0; //#8145
            $1.sep2 = $a(); //#8145
            $k[$j++] = Infinity; //#8146
            $forall($1.bot, function() { //#8146
                var _8o = $k[--$j]; //#8146
                $k[$j++] = $f(1 - _8o); //#8146
            }); //#8146
            $1.sep3 = $a(); //#8146
            $puti($1.sep3, 0, $a([0, 0, 0, 0])); //#8147
            $puti($1.sep3, 46, $a([0, 0, 0, 0])); //#8148
            for (var _8u = 19; _8u <= 31; _8u += 1) { //#8161
                $1.i = _8u; //#8150
                if ($get($1.bot, $1.i) == 0) { //#8158
                    if ($get($1.bot, $1.i - 1) == 1) { //#8155
                        $k[$j++] = 1; //#8153
                    } else { //#8155
                        var _94 = ($get($1.sep3, $1.i - 1) == 0) ? 1 : 0; //#8155
                        $k[$j++] = _94; //#8155
                    } //#8155
                } else { //#8158
                    $k[$j++] = 0; //#8158
                } //#8158
                $put($1.sep3, $1.i, $k[--$j]); //#8160
            } //#8160
            $1.f3 = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1]); //#8162
            $k[$j++] = true; //#8163
            for (var _99 = 0; _99 <= 12; _99 += 1) { //#8163
                var _9E = $k[--$j]; //#8163
                $k[$j++] = _9E && $eq($get($1.bot, _99 + 19), $get($1.f3, _99)); //#8163
            } //#8163
            if ($k[--$j]) { //#8166
                $puti($1.sep3, 19, $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0])); //#8165
            } //#8165
            $k[$j++] = Infinity; //#8172
            for (var _9J = 0, _9K = $1.barxmult; _9J < _9K; _9J++) { //#8168
                $aload($1.top); //#8168
            } //#8168
            $aload($1.sep1); //#8169
            $aload($1.sep2); //#8170
            $aload($1.sep3); //#8171
            for (var _9Q = 0, _9R = $1.barxmult; _9Q < _9R; _9Q++) { //#8172
                $aload($1.bot); //#8172
            } //#8172
            $1.pixs = $a(); //#8172
            $1.pixy = ~~($1.pixs.length / 50); //#8174
        } //#8174
        var _9Z = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", 50],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", 50 / 72],
            ["opt", $1.options]
        ]); //#8185
        $k[$j++] = _9Z; //#8188
        if (!$1.dontdraw) { //#8188
            bwipp_renmatrix(); //#8188
        } //#8188
    } //#8188
}

function bwipp_databarstacked() {
    var $1 = {}; //#8223
    $1.ctx = null; //#8225
    $1.dontdraw = false; //#8226
    $k[$j++] = $1; //#8228
    bwipp_processoptions(); //#8228
    $1.options = $k[--$j]; //#8228
    $1.barcode = $k[--$j]; //#8229
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#8234
        $k[$j++] = 'bwipp.databarstackedBadAI'; //#8233
        $k[$j++] = "GS1 DataBar Stacked must begin with (01) application identifier"; //#8233
        bwipp_raiseerror(); //#8233
    } //#8233
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#8237
        $k[$j++] = 'bwipp.databarstackedBadLength'; //#8236
        $k[$j++] = "GS1 DataBar Stacked must be 13 or 14 digits"; //#8236
        bwipp_raiseerror(); //#8236
    } //#8236
    var _8 = $geti($1.barcode, 4, $1.barcode.length - 4); //#8238
    for (var _9 = 0, _A = _8.length; _9 < _A; _9++) { //#8242
        var _B = $get(_8, _9); //#8242
        if ((_B < 48) || (_B > 57)) { //#8241
            $k[$j++] = 'bwipp.databarstackedBadCharacter'; //#8240
            $k[$j++] = "GS1 DataBar Stacked must contain only digits"; //#8240
            bwipp_raiseerror(); //#8240
        } //#8240
    } //#8240
    $1.checksum = 0; //#8245
    for (var _C = 0; _C <= 12; _C += 1) { //#8249
        $1.i = _C; //#8247
        $k[$j++] = 'checksum'; //#8248
        $k[$j++] = $1.checksum; //#8248
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#8248
        if (($1.i % 2) == 0) { //#8248
            var _I = $k[--$j]; //#8248
            $k[$j++] = _I * 3; //#8248
        } //#8248
        var _J = $k[--$j]; //#8248
        var _K = $k[--$j]; //#8248
        $1[$k[--$j]] = $f(_K + _J); //#8248
    } //#8248
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#8250
    if ($1.barcode.length == 18) { //#8255
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#8254
            $k[$j++] = 'bwipp.databarstackedBadCheckDigit'; //#8253
            $k[$j++] = "Incorrect GS1 DataBar Stacked check digit provided"; //#8253
            bwipp_raiseerror(); //#8253
        } //#8253
    } //#8253
    var _R = $s(18); //#8256
    $puti(_R, 0, $1.barcode); //#8257
    $put(_R, 17, $1.checksum + 48); //#8258
    $1.barcode = _R; //#8259
    $put($1.options, "dontdraw", true); //#8262
    $put($1.options, "format", "stacked"); //#8263
    $k[$j++] = 'args'; //#8265
    $k[$j++] = $1.barcode; //#8265
    $k[$j++] = $1.options; //#8265
    bwipp_databaromni(); //#8265
    var _Y = $k[--$j]; //#8265
    $1[$k[--$j]] = _Y; //#8265
    $put($1.args, "opt", $1.options); //#8267
    $k[$j++] = $1.args; //#8270
    if (!$1.dontdraw) { //#8270
        bwipp_renmatrix(); //#8270
    } //#8270
}

function bwipp_databarstackedomni() {
    var $1 = {}; //#8301
    $1.ctx = null; //#8303
    $1.dontdraw = false; //#8304
    $k[$j++] = $1; //#8306
    bwipp_processoptions(); //#8306
    $1.options = $k[--$j]; //#8306
    $1.barcode = $k[--$j]; //#8307
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#8312
        $k[$j++] = 'bwipp.databarstackedomniBadAI'; //#8311
        $k[$j++] = "GS1 DataBar Stacked Omnidirectional must begin with (01) application identifier"; //#8311
        bwipp_raiseerror(); //#8311
    } //#8311
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#8315
        $k[$j++] = 'bwipp.databarstackedomniBadLength'; //#8314
        $k[$j++] = "GS1 DataBar Stacked Omnidirectional must be 13 or 14 digits"; //#8314
        bwipp_raiseerror(); //#8314
    } //#8314
    var _8 = $geti($1.barcode, 4, $1.barcode.length - 4); //#8316
    for (var _9 = 0, _A = _8.length; _9 < _A; _9++) { //#8320
        var _B = $get(_8, _9); //#8320
        if ((_B < 48) || (_B > 57)) { //#8319
            $k[$j++] = 'bwipp.databarstackedomniBadCharacter'; //#8318
            $k[$j++] = "GS1 DataBar Stacked Omnidirectional must contain only digits"; //#8318
            bwipp_raiseerror(); //#8318
        } //#8318
    } //#8318
    $1.checksum = 0; //#8323
    for (var _C = 0; _C <= 12; _C += 1) { //#8327
        $1.i = _C; //#8325
        $k[$j++] = 'checksum'; //#8326
        $k[$j++] = $1.checksum; //#8326
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#8326
        if (($1.i % 2) == 0) { //#8326
            var _I = $k[--$j]; //#8326
            $k[$j++] = _I * 3; //#8326
        } //#8326
        var _J = $k[--$j]; //#8326
        var _K = $k[--$j]; //#8326
        $1[$k[--$j]] = $f(_K + _J); //#8326
    } //#8326
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#8328
    if ($1.barcode.length == 18) { //#8333
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#8332
            $k[$j++] = 'bwipp.databarstackedomniBadCheckDigit'; //#8331
            $k[$j++] = "Incorrect GS1 DataBar Stacked Omnidirectional check digit provided"; //#8331
            bwipp_raiseerror(); //#8331
        } //#8331
    } //#8331
    var _R = $s(18); //#8334
    $puti(_R, 0, $1.barcode); //#8335
    $put(_R, 17, $1.checksum + 48); //#8336
    $1.barcode = _R; //#8337
    $put($1.options, "dontdraw", true); //#8340
    $put($1.options, "format", "stackedomni"); //#8341
    $k[$j++] = 'args'; //#8343
    $k[$j++] = $1.barcode; //#8343
    $k[$j++] = $1.options; //#8343
    bwipp_databaromni(); //#8343
    var _Y = $k[--$j]; //#8343
    $1[$k[--$j]] = _Y; //#8343
    $put($1.args, "opt", $1.options); //#8345
    $k[$j++] = $1.args; //#8348
    if (!$1.dontdraw) { //#8348
        bwipp_renmatrix(); //#8348
    } //#8348
}

function bwipp_databartruncated() {
    var $1 = {}; //#8379
    $1.ctx = null; //#8381
    $1.dontdraw = false; //#8382
    $k[$j++] = $1; //#8384
    bwipp_processoptions(); //#8384
    $1.options = $k[--$j]; //#8384
    $1.barcode = $k[--$j]; //#8385
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#8390
        $k[$j++] = 'bwipp.databartruncatedBadAI'; //#8389
        $k[$j++] = "GS1 DataBar Truncated must begin with (01) application identifier"; //#8389
        bwipp_raiseerror(); //#8389
    } //#8389
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#8393
        $k[$j++] = 'bwipp.databartruncatedBadLength'; //#8392
        $k[$j++] = "GS1 DataBar Truncated must be 13 or 14 digits"; //#8392
        bwipp_raiseerror(); //#8392
    } //#8392
    var _8 = $geti($1.barcode, 4, $1.barcode.length - 4); //#8394
    for (var _9 = 0, _A = _8.length; _9 < _A; _9++) { //#8398
        var _B = $get(_8, _9); //#8398
        if ((_B < 48) || (_B > 57)) { //#8397
            $k[$j++] = 'bwipp.databartruncatedBadCharacter'; //#8396
            $k[$j++] = "GS1 DataBar Truncated must contain only digits"; //#8396
            bwipp_raiseerror(); //#8396
        } //#8396
    } //#8396
    $1.checksum = 0; //#8401
    for (var _C = 0; _C <= 12; _C += 1) { //#8405
        $1.i = _C; //#8403
        $k[$j++] = 'checksum'; //#8404
        $k[$j++] = $1.checksum; //#8404
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#8404
        if (($1.i % 2) == 0) { //#8404
            var _I = $k[--$j]; //#8404
            $k[$j++] = _I * 3; //#8404
        } //#8404
        var _J = $k[--$j]; //#8404
        var _K = $k[--$j]; //#8404
        $1[$k[--$j]] = $f(_K + _J); //#8404
    } //#8404
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#8406
    if ($1.barcode.length == 18) { //#8411
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#8410
            $k[$j++] = 'bwipp.databartruncatedBadCheckDigit'; //#8409
            $k[$j++] = "Incorrect GS1 DataBar Truncated check digit provided"; //#8409
            bwipp_raiseerror(); //#8409
        } //#8409
    } //#8409
    var _R = $s(18); //#8412
    $puti(_R, 0, $1.barcode); //#8413
    $put(_R, 17, $1.checksum + 48); //#8414
    $1.barcode = _R; //#8415
    $put($1.options, "dontdraw", true); //#8418
    $put($1.options, "format", "truncated"); //#8419
    $k[$j++] = 'args'; //#8421
    $k[$j++] = $1.barcode; //#8421
    $k[$j++] = $1.options; //#8421
    bwipp_databaromni(); //#8421
    var _Y = $k[--$j]; //#8421
    $1[$k[--$j]] = _Y; //#8421
    $put($1.args, "opt", $1.options); //#8423
    $k[$j++] = $1.args; //#8426
    if (!$1.dontdraw) { //#8426
        bwipp_renlinear(); //#8426
    } //#8426
}

function bwipp_databarlimited() {
    var $1 = {}; //#8458
    $1.ctx = null; //#8460
    $1.dontdraw = false; //#8461
    $1.height = 10 / 72; //#8462
    $1.linkage = false; //#8463
    $k[$j++] = $1; //#8465
    bwipp_processoptions(); //#8465
    $1.options = $k[--$j]; //#8465
    $1.barcode = $k[--$j]; //#8466
    if ($ne($geti($1.barcode, 0, 4), "(01)")) { //#8473
        $k[$j++] = 'bwipp.databarlimitedBadAI'; //#8472
        $k[$j++] = "GS1 DataBar Limited must begin with (01) application identifier"; //#8472
        bwipp_raiseerror(); //#8472
    } //#8472
    if (($1.barcode.length != 17) && ($1.barcode.length != 18)) { //#8476
        $k[$j++] = 'bwipp.databarlimitedBadLength'; //#8475
        $k[$j++] = "GS1 DataBar Limited must be 13 or 14 digits"; //#8475
        bwipp_raiseerror(); //#8475
    } //#8475
    var _7 = $get($1.barcode, 4); //#8477
    if ((_7 < 48) || (_7 > 49)) { //#8479
        $k[$j++] = 'bwipp.databarlimitedBadStartDigit'; //#8478
        $k[$j++] = "GS1 DataBar Limited must begin with 0 or 1"; //#8478
        bwipp_raiseerror(); //#8478
    } //#8478
    var _A = $geti($1.barcode, 5, $1.barcode.length - 5); //#8480
    for (var _B = 0, _C = _A.length; _B < _C; _B++) { //#8484
        var _D = $get(_A, _B); //#8484
        if ((_D < 48) || (_D > 57)) { //#8483
            $k[$j++] = 'bwipp.databarlimitedBadCharacter'; //#8482
            $k[$j++] = "GS1 DataBar Limited must contain only digits"; //#8482
            bwipp_raiseerror(); //#8482
        } //#8482
    } //#8482
    $1.checksum = 0; //#8487
    for (var _E = 0; _E <= 12; _E += 1) { //#8491
        $1.i = _E; //#8489
        $k[$j++] = 'checksum'; //#8490
        $k[$j++] = $1.checksum; //#8490
        $k[$j++] = $f($get($1.barcode, $1.i + 4) - 48); //#8490
        if (($1.i % 2) == 0) { //#8490
            var _K = $k[--$j]; //#8490
            $k[$j++] = _K * 3; //#8490
        } //#8490
        var _L = $k[--$j]; //#8490
        var _M = $k[--$j]; //#8490
        $1[$k[--$j]] = $f(_M + _L); //#8490
    } //#8490
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#8492
    if ($1.barcode.length == 18) { //#8497
        if ($get($1.barcode, 17) != ($1.checksum + 48)) { //#8496
            $k[$j++] = 'bwipp.databarlimitedBadCheckDigit'; //#8495
            $k[$j++] = "Incorrect GS1 DataBar Limited check digit provided"; //#8495
            bwipp_raiseerror(); //#8495
        } //#8495
    } //#8495
    var _T = $s(18); //#8498
    $puti(_T, 0, $1.barcode); //#8499
    $put(_T, 17, $1.checksum + 48); //#8500
    $1.barcode = _T; //#8501
    $1.linkval = $a([2, 0, 1, 5, 1, 3, 3, 5, 3, 1, 0, 9, 6]); //#8505
    $k[$j++] = Infinity; //#8508
    var _Y = $geti($1.barcode, 4, 13); //#8508
    for (var _Z = 0, _a = _Y.length; _Z < _a; _Z++) { //#8508
        $k[$j++] = $f($get(_Y, _Z) - 48); //#8508
    } //#8508
    $1.binval = $a(); //#8508
    if ($1.linkage) { //#8515
        for (var _g = 0, _f = $1.binval.length - 1; _g <= _f; _g += 1) { //#8514
            $1.i = _g; //#8512
            $put($1.binval, $1.i, $f($get($1.binval, $1.i) + $get($1.linkval, $1.i))); //#8513
        } //#8513
    } //#8513
    $1.txt = $a($1.barcode.length); //#8518
    for (var _t = 0, _s = $1.barcode.length - 1; _t <= _s; _t += 1) { //#8522
        $1.i = _t; //#8520
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#8521
    } //#8521
    $1.ncr = function() {
        var _10 = $k[--$j]; //#8525
        var _11 = $k[--$j]; //#8525
        var _12 = $f(_11 - _10); //#8525
        if (_10 < $f(_11 - _10)) { //#8525
            var _ = _12; //#8525
            _12 = _10; //#8525
            _10 = _; //#8525
        } //#8525
        $k[$j++] = _12; //#8532
        $k[$j++] = 1; //#8532
        $k[$j++] = 1; //#8532
        for (var _14 = _11, _13 = $f(_10 + 1); _14 >= _13; _14 -= 1) { //#8532
            var _15 = $k[--$j]; //#8528
            var _16 = $k[--$j]; //#8529
            var _17 = $k[--$j]; //#8529
            $k[$j++] = _17; //#8531
            $k[$j++] = _16; //#8531
            $k[$j++] = _15 * _14; //#8531
            if ($le(_16, _17)) { //#8531
                var _18 = $k[--$j]; //#8530
                var _19 = $k[--$j]; //#8530
                $k[$j++] = $f(_19 + 1); //#8530
                $k[$j++] = ~~(_18 / _19); //#8530
            } //#8530
        } //#8530
        for (;;) { //#8536
            var _1A = $k[--$j]; //#8534
            var _1B = $k[--$j]; //#8534
            var _1C = $k[--$j]; //#8534
            $k[$j++] = _1C; //#8534
            $k[$j++] = _1B; //#8534
            $k[$j++] = _1A; //#8534
            if ($gt(_1B, _1C)) { //#8534
                break; //#8534
            } //#8534
            var _1D = $k[--$j]; //#8535
            var _1E = $k[--$j]; //#8535
            $k[$j++] = $f(_1E + 1); //#8535
            $k[$j++] = ~~(_1D / _1E); //#8535
        } //#8535
        var _1F = $k[--$j]; //#8537
        var _1G = $k[--$j]; //#8537
        $k[$j++] = _1F; //#8537
        $k[$j++] = _1G; //#8537
        $j--; //#8537
        var _1H = $k[--$j]; //#8537
        var _1I = $k[--$j]; //#8537
        $k[$j++] = _1H; //#8537
        $k[$j++] = _1I; //#8537
        $j--; //#8537
    }; //#8537
    $1.getRSSwidths = function() {
        $1.oe = $k[--$j]; //#8541
        $1.el = $k[--$j]; //#8542
        $1.mw = $k[--$j]; //#8543
        $1.nm = $k[--$j]; //#8544
        $1.val = $k[--$j]; //#8545
        $1.out = $a($1.el); //#8546
        $1.mask = 0; //#8547
        for (var _1S = 0, _1R = $f($1.el - 2); _1S <= _1R; _1S += 1) { //#8574
            $1.bar = _1S; //#8549
            $1.ew = 1; //#8550
            var _1U = $1.bar; //#8551
            $1.mask = $1.mask | ((_1U < 0 ? 1 >>> -_1U : 1 << _1U)); //#8551
            for (;;) { //#8570
                $k[$j++] = 'sval'; //#8552
                $k[$j++] = $f($f($1.nm - $1.ew) - 1); //#8552
                $k[$j++] = $f($f($1.el - $1.bar) - 2); //#8552
                $1.ncr(); //#8552
                var _1Z = $k[--$j]; //#8552
                $1[$k[--$j]] = _1Z; //#8552
                if (($1.oe && ($1.mask == 0)) && (($f(($f($f($1.nm - $1.ew) - ($1.el * 2))) + ($1.bar * 2))) >= -2)) { //#8555
                    $k[$j++] = 'sval'; //#8554
                    $k[$j++] = $1.sval; //#8554
                    $k[$j++] = $f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar); //#8554
                    $k[$j++] = $f($f($1.el - $1.bar) - 2); //#8554
                    $1.ncr(); //#8554
                    var _1o = $k[--$j]; //#8554
                    var _1p = $k[--$j]; //#8554
                    $1[$k[--$j]] = $f(_1p - _1o); //#8554
                } //#8554
                if ($f($1.el - $1.bar) > 2) { //#8564
                    $1.lval = 0; //#8557
                    for (var _1z = $f(($f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar)) + 2), _1y = $f($1.mw + 1); _1z >= _1y; _1z -= 1) { //#8561
                        $k[$j++] = $f(($f($f($1.nm - _1z) - $1.ew)) - 1); //#8559
                        $k[$j++] = $f($f($1.el - $1.bar) - 3); //#8559
                        $1.ncr(); //#8559
                        $1.lval = $f($k[--$j] + $1.lval); //#8560
                    } //#8560
                    $1.sval = $f($1.sval - ($1.lval * ($f($f($1.el - $1.bar) - 1)))); //#8562
                } else { //#8564
                    if ($f($1.nm - $1.ew) > $1.mw) { //#8564
                        $1.sval = $f($1.sval - 1); //#8564
                    } //#8564
                } //#8564
                $1.val = $f($1.val - $1.sval); //#8566
                if ($1.val < 0) { //#8567
                    break; //#8567
                } //#8567
                $1.ew = $1.ew + 1; //#8568
                var _2J = $1.bar; //#8569
                $1.mask = $1.mask & (~((_2J < 0 ? 1 >>> -_2J : 1 << _2J))); //#8569
            } //#8569
            $1.val = $f($1.val + $1.sval); //#8571
            $1.nm = $f($1.nm - $1.ew); //#8572
            $put($1.out, $1.bar, $1.ew); //#8573
        } //#8573
        $put($1.out, $f($1.el - 1), $1.nm); //#8575
        $k[$j++] = $1.out; //#8576
    }; //#8576
    for (var _2V = 0; _2V <= 11; _2V += 1) { //#8583
        $1.i = _2V; //#8580
        var _2W = $1.binval; //#8581
        var _2X = $1.i; //#8581
        $put(_2W, _2X + 1, $f($get(_2W, _2X + 1) + (($get($1.binval, $1.i) % 2013571) * 10))); //#8581
        $put($1.binval, $1.i, ~~($get($1.binval, $1.i) / 2013571)); //#8582
    } //#8582
    $1.d2 = $get($1.binval, 12) % 2013571; //#8584
    var _2j = $1.binval; //#8585
    $put(_2j, 12, ~~($get(_2j, 12) / 2013571)); //#8585
    $1.d1 = 0; //#8587
    $1.i = true; //#8588
    for (var _2l = 0; _2l <= 12; _2l += 1) { //#8598
        $1.j = _2l; //#8590
        var _2o = $get($1.binval, $1.j); //#8591
        $k[$j++] = _2o; //#8597
        if ((_2o == 0) && $1.i) { //#8596
            $j--; //#8593
        } else { //#8596
            $1.i = false; //#8595
            $1.d1 = $f($1.d1 + ($k[--$j] * (~~Math.pow(10, 12 - $1.j)))); //#8596
        } //#8596
    } //#8596
    $1.tab267 = $a([183063, 0, 17, 9, 6, 3, 6538, 28, 820063, 183064, 13, 13, 5, 4, 875, 728, 1000775, 820064, 9, 17, 3, 6, 28, 6454, 1491020, 1000776, 15, 11, 5, 4, 2415, 203, 1979844, 1491021, 11, 15, 4, 5, 203, 2408, 1996938, 1979845, 19, 7, 8, 1, 17094, 1, 2013570, 1996939, 7, 19, 1, 8, 1, 16632]); //#8609
    $1.i = 0; //#8612
    for (;;) { //#8622
        if ($1.d1 <= $get($1.tab267, $1.i)) { //#8620
            var _30 = $geti($1.tab267, $1.i + 1, 7); //#8614
            for (var _31 = 0, _32 = _30.length; _31 < _32; _31++) { //#8614
                $k[$j++] = $get(_30, _31); //#8614
            } //#8614
            $1.d1te = $k[--$j]; //#8615
            $1.d1to = $k[--$j]; //#8615
            $1.d1mwe = $k[--$j]; //#8616
            $1.d1mwo = $k[--$j]; //#8616
            $1.d1ele = $k[--$j]; //#8617
            $1.d1elo = $k[--$j]; //#8617
            $1.d1gs = $k[--$j]; //#8618
            break; //#8619
        } //#8619
        $1.i = $1.i + 8; //#8621
    } //#8621
    $1.i = 0; //#8624
    for (;;) { //#8634
        if ($1.d2 <= $get($1.tab267, $1.i)) { //#8632
            var _3I = $geti($1.tab267, $1.i + 1, 7); //#8626
            for (var _3J = 0, _3K = _3I.length; _3J < _3K; _3J++) { //#8626
                $k[$j++] = $get(_3I, _3J); //#8626
            } //#8626
            $1.d2te = $k[--$j]; //#8627
            $1.d2to = $k[--$j]; //#8627
            $1.d2mwe = $k[--$j]; //#8628
            $1.d2mwo = $k[--$j]; //#8628
            $1.d2ele = $k[--$j]; //#8629
            $1.d2elo = $k[--$j]; //#8629
            $1.d2gs = $k[--$j]; //#8630
            break; //#8631
        } //#8631
        $1.i = $1.i + 8; //#8633
    } //#8633
    $k[$j++] = 'd1wo'; //#8636
    $k[$j++] = ~~($f($1.d1 - $1.d1gs) / $1.d1te); //#8636
    $k[$j++] = $1.d1elo; //#8636
    $k[$j++] = $1.d1mwo; //#8636
    $k[$j++] = 7; //#8636
    $k[$j++] = false; //#8636
    $1.getRSSwidths(); //#8636
    var _3Z = $k[--$j]; //#8636
    $1[$k[--$j]] = _3Z; //#8636
    $k[$j++] = 'd1we'; //#8637
    $k[$j++] = $f($1.d1 - $1.d1gs) % $1.d1te; //#8637
    $k[$j++] = $1.d1ele; //#8637
    $k[$j++] = $1.d1mwe; //#8637
    $k[$j++] = 7; //#8637
    $k[$j++] = true; //#8637
    $1.getRSSwidths(); //#8637
    var _3g = $k[--$j]; //#8637
    $1[$k[--$j]] = _3g; //#8637
    $k[$j++] = 'd2wo'; //#8638
    $k[$j++] = ~~($f($1.d2 - $1.d2gs) / $1.d2te); //#8638
    $k[$j++] = $1.d2elo; //#8638
    $k[$j++] = $1.d2mwo; //#8638
    $k[$j++] = 7; //#8638
    $k[$j++] = false; //#8638
    $1.getRSSwidths(); //#8638
    var _3n = $k[--$j]; //#8638
    $1[$k[--$j]] = _3n; //#8638
    $k[$j++] = 'd2we'; //#8639
    $k[$j++] = $f($1.d2 - $1.d2gs) % $1.d2te; //#8639
    $k[$j++] = $1.d2ele; //#8639
    $k[$j++] = $1.d2mwe; //#8639
    $k[$j++] = 7; //#8639
    $k[$j++] = true; //#8639
    $1.getRSSwidths(); //#8639
    var _3u = $k[--$j]; //#8639
    $1[$k[--$j]] = _3u; //#8639
    $1.d1w = $a(14); //#8641
    for (var _3x = 0; _3x <= 6; _3x += 1) { //#8646
        $1.i = _3x; //#8643
        $put($1.d1w, $1.i * 2, $get($1.d1wo, $1.i)); //#8644
        $put($1.d1w, ($1.i * 2) + 1, $get($1.d1we, $1.i)); //#8645
    } //#8645
    $1.d2w = $a(14); //#8648
    for (var _49 = 0; _49 <= 6; _49 += 1) { //#8653
        $1.i = _49; //#8650
        $put($1.d2w, $1.i * 2, $get($1.d2wo, $1.i)); //#8651
        $put($1.d2w, ($1.i * 2) + 1, $get($1.d2we, $1.i)); //#8652
    } //#8652
    $k[$j++] = Infinity; //#8657
    var _4K = $1.d1w; //#8656
    for (var _4L = 0, _4M = _4K.length; _4L < _4M; _4L++) { //#8656
        $k[$j++] = $get(_4K, _4L); //#8656
    } //#8656
    var _4O = $1.d2w; //#8657
    for (var _4P = 0, _4Q = _4O.length; _4P < _4Q; _4P++) { //#8657
        $k[$j++] = $get(_4O, _4P); //#8657
    } //#8657
    $1.widths = $a(); //#8657
    $1.checkweights = $a([1, 3, 9, 27, 81, 65, 17, 51, 64, 14, 42, 37, 22, 66, 20, 60, 2, 6, 18, 54, 73, 41, 34, 13, 39, 28, 84, 74]); //#8664
    $k[$j++] = Infinity; //#8679
    for (var _4U = 0; _4U <= 43; _4U += 1) { //#8667
        $k[$j++] = _4U; //#8667
    } //#8667
    $k[$j++] = 45; //#8669
    $k[$j++] = 52; //#8669
    $k[$j++] = 57; //#8669
    for (var _4V = 63; _4V <= 66; _4V += 1) { //#8669
        $k[$j++] = _4V; //#8669
    } //#8669
    for (var _4W = 73; _4W <= 79; _4W += 1) { //#8670
        $k[$j++] = _4W; //#8670
    } //#8670
    $k[$j++] = 82; //#8672
    for (var _4X = 126; _4X <= 130; _4X += 1) { //#8672
        $k[$j++] = _4X; //#8672
    } //#8672
    $k[$j++] = 132; //#8674
    for (var _4Y = 141; _4Y <= 146; _4Y += 1) { //#8674
        $k[$j++] = _4Y; //#8674
    } //#8674
    for (var _4Z = 210; _4Z <= 217; _4Z += 1) { //#8675
        $k[$j++] = _4Z; //#8675
    } //#8675
    $k[$j++] = 220; //#8677
    for (var _4a = 316; _4a <= 320; _4a += 1) { //#8677
        $k[$j++] = _4a; //#8677
    } //#8677
    $k[$j++] = 322; //#8679
    $k[$j++] = 323; //#8679
    $k[$j++] = 326; //#8679
    $k[$j++] = 337; //#8679
    $1.checkseq = $a(); //#8679
    $1.checksum = 0; //#8683
    for (var _4c = 0; _4c <= 27; _4c += 1) { //#8687
        $1.i = _4c; //#8685
        $1.checksum = $f($1.checksum + ($get($1.widths, $1.i) * $get($1.checkweights, $1.i))); //#8686
    } //#8686
    $1.checksum = $1.checksum % 89; //#8688
    $1.seq = $get($1.checkseq, $1.checksum); //#8689
    $k[$j++] = 'swidths'; //#8690
    $k[$j++] = ~~($1.seq / 21); //#8690
    $k[$j++] = 8; //#8690
    $k[$j++] = 3; //#8690
    $k[$j++] = 6; //#8690
    $k[$j++] = false; //#8690
    $1.getRSSwidths(); //#8690
    var _4p = $k[--$j]; //#8690
    $1[$k[--$j]] = _4p; //#8690
    $k[$j++] = 'bwidths'; //#8691
    $k[$j++] = $1.seq % 21; //#8691
    $k[$j++] = 8; //#8691
    $k[$j++] = 3; //#8691
    $k[$j++] = 6; //#8691
    $k[$j++] = false; //#8691
    $1.getRSSwidths(); //#8691
    var _4s = $k[--$j]; //#8691
    $1[$k[--$j]] = _4s; //#8691
    $1.checkwidths = $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1]); //#8693
    for (var _4v = 0; _4v <= 5; _4v += 1) { //#8698
        $1.i = _4v; //#8695
        $put($1.checkwidths, $1.i * 2, $get($1.swidths, $1.i)); //#8696
        $put($1.checkwidths, ($1.i * 2) + 1, $get($1.bwidths, $1.i)); //#8697
    } //#8697
    $k[$j++] = Infinity; //#8701
    var _56 = $1.d1w; //#8701
    $k[$j++] = 1; //#8701
    for (var _57 = 0, _58 = _56.length; _57 < _58; _57++) { //#8701
        $k[$j++] = $get(_56, _57); //#8701
    } //#8701
    var _5A = $1.checkwidths; //#8701
    for (var _5B = 0, _5C = _5A.length; _5B < _5C; _5B++) { //#8701
        $k[$j++] = $get(_5A, _5B); //#8701
    } //#8701
    var _5E = $1.d2w; //#8701
    for (var _5F = 0, _5G = _5E.length; _5F < _5G; _5F++) { //#8701
        $k[$j++] = $get(_5E, _5F); //#8701
    } //#8701
    $k[$j++] = 1; //#8701
    $k[$j++] = 1; //#8701
    $k[$j++] = 5; //#8701
    $1.sbs = $a(); //#8701
    $k[$j++] = Infinity; //#8712
    var _5J = $1.sbs; //#8707
    $k[$j++] = Infinity; //#8708
    for (var _5L = 0, _5M = ~~(($1.sbs.length + 1) / 2); _5L < _5M; _5L++) { //#8708
        $k[$j++] = $1.height; //#8708
    } //#8708
    var _5O = $a(); //#8708
    $k[$j++] = Infinity; //#8709
    for (var _5Q = 0, _5R = ~~(($1.sbs.length + 1) / 2); _5Q < _5R; _5Q++) { //#8709
        $k[$j++] = 0; //#8709
    } //#8709
    var _5S = $a(); //#8709
    $k[$j++] = 'ren'; //#8712
    $k[$j++] = bwipp_renlinear; //#8712
    $k[$j++] = 'sbs'; //#8712
    $k[$j++] = _5J; //#8712
    $k[$j++] = 'bhs'; //#8712
    $k[$j++] = _5O; //#8712
    $k[$j++] = 'bbs'; //#8712
    $k[$j++] = _5S; //#8712
    $k[$j++] = 'txt'; //#8712
    $k[$j++] = $1.txt; //#8712
    $k[$j++] = 'textxalign'; //#8712
    $k[$j++] = "center"; //#8712
    $k[$j++] = 'opt'; //#8712
    $k[$j++] = $1.options; //#8712
    var _5V = $d(); //#8712
    $k[$j++] = _5V; //#8715
    if (!$1.dontdraw) { //#8715
        bwipp_renlinear(); //#8715
    } //#8715
}

function bwipp_databarexpanded() {
    var $1 = {}; //#8751
    $1.ctx = null; //#8753
    $1.parse = false; //#8754
    $1.dontlint = false; //#8755
    $1.lintreqs = true; //#8756
    $1.dontdraw = false; //#8757
    $1.height = 34 / 72; //#8758
    $1.format = "expanded"; //#8759
    $1.segments = -1; //#8760
    $1.linkage = false; //#8761
    $1.barxmult = 34; //#8762
    $k[$j++] = $1; //#8764
    bwipp_processoptions(); //#8764
    $1.options = $k[--$j]; //#8764
    $1.barcode = $k[--$j]; //#8765
    if ($1.segments == -1) { //#8773
        var _4 = $eq($1.format, "expandedstacked") ? 4 : 22; //#8770
        $1.segments = _4; //#8770
    } else { //#8773
        if ((($1.segments < 2) || ($1.segments > 22)) || (($1.segments % 2) != 0)) { //#8774
            $k[$j++] = 'bwipp.gs1databarexpandedBadSegments'; //#8773
            $k[$j++] = "The number of segments must be even from 2 to 22"; //#8773
            bwipp_raiseerror(); //#8773
        } //#8773
    } //#8773
    $k[$j++] = $1.barcode; //#8777
    $k[$j++] = 'ai'; //#8777
    bwipp_gs1process(); //#8777
    $1.fncs = $k[--$j]; //#8778
    $1.vals = $k[--$j]; //#8779
    $1.ais = $k[--$j]; //#8780
    for (;;) { //#8868
        if ($1.ais.length == 2) { //#8792
            if ($eq($get($1.ais, 0), "01") && $eq($get($1.ais, 1), "3103")) { //#8791
                if ($eq($geti($get($1.vals, 0), 0, 1), "9") && ($cvi($get($1.vals, 1)) <= 32767)) { //#8790
                    $k[$j++] = "0100"; //#8789
                    $k[$j++] = false; //#8789
                    break; //#8789
                } //#8789
            } //#8789
        } //#8789
        if ($1.ais.length == 2) { //#8801
            if ($eq($get($1.ais, 0), "01") && $eq($get($1.ais, 1), "3202")) { //#8800
                if ($eq($geti($get($1.vals, 0), 0, 1), "9") && ($cvi($get($1.vals, 1)) <= 9999)) { //#8799
                    $k[$j++] = "0101"; //#8798
                    $k[$j++] = false; //#8798
                    break; //#8798
                } //#8798
            } //#8798
        } //#8798
        if ($1.ais.length == 2) { //#8810
            if ($eq($get($1.ais, 0), "01") && $eq($get($1.ais, 1), "3203")) { //#8809
                if ($eq($geti($get($1.vals, 0), 0, 1), "9") && ($cvi($get($1.vals, 1)) <= 22767)) { //#8808
                    $k[$j++] = "0101"; //#8807
                    $k[$j++] = false; //#8807
                    break; //#8807
                } //#8807
            } //#8807
        } //#8807
        var _h = $1.ais.length; //#8813
        if ((_h == 2) || (_h == 3)) { //#8844
            $k[$j++] = 'ai310x'; //#8814
            $k[$j++] = false; //#8814
            for (var _i = 3100; _i <= 3109; _i += 1) { //#8814
                var _n = $k[--$j]; //#8814
                $k[$j++] = _n || $eq($cvrs($s(4), _i, 10), $get($1.ais, 1)); //#8814
            } //#8814
            var _o = $k[--$j]; //#8814
            $1[$k[--$j]] = _o; //#8814
            $k[$j++] = 'ai320x'; //#8815
            $k[$j++] = false; //#8815
            for (var _q = 3200; _q <= 3209; _q += 1) { //#8815
                var _v = $k[--$j]; //#8815
                $k[$j++] = _v || $eq($cvrs($s(4), _q, 10), $get($1.ais, 1)); //#8815
            } //#8815
            var _w = $k[--$j]; //#8815
            $1[$k[--$j]] = _w; //#8815
            if ($1.ais.length == 3) { //#8819
                var _z = $a(["11", "13", "15", "17"]); //#8817
                $k[$j++] = 'aibad'; //#8817
                $k[$j++] = true; //#8817
                for (var _10 = 0, _11 = _z.length; _10 < _11; _10++) { //#8817
                    var _15 = $k[--$j]; //#8817
                    $k[$j++] = _15 && $ne($get(_z, _10), $get($1.ais, 2)); //#8817
                } //#8817
                var _16 = $k[--$j]; //#8817
                $1[$k[--$j]] = _16; //#8817
            } else { //#8819
                $1.aibad = false; //#8819
            } //#8819
            if (($eq($get($1.ais, 0), "01") && ($1.ai310x || $1.ai320x)) && (!$1.aibad)) { //#8843
                if ($1.ais.length == 3) { //#8840
                    var _1M = $cvi($geti($get($1.vals, 2), 2, 2)); //#8825
                    var _1Q = $cvi($geti($get($1.vals, 2), 4, 2)); //#8826
                    if ((($eq($geti($get($1.vals, 0), 0, 1), "9") && ($cvi($get($1.vals, 1)) <= 99999)) && ((_1M >= 1) && (_1M <= 12))) && ((_1Q >= 0) && (_1Q <= 31))) { //#8835
                        if ($1.ai310x && $eq($get($1.ais, 2), "11")) { //#8827
                            $k[$j++] = "0111000"; //#8827
                            $k[$j++] = false; //#8827
                            break; //#8827
                        } //#8827
                        if ($1.ai320x && $eq($get($1.ais, 2), "11")) { //#8828
                            $k[$j++] = "0111001"; //#8828
                            $k[$j++] = false; //#8828
                            break; //#8828
                        } //#8828
                        if ($1.ai310x && $eq($get($1.ais, 2), "13")) { //#8829
                            $k[$j++] = "0111010"; //#8829
                            $k[$j++] = false; //#8829
                            break; //#8829
                        } //#8829
                        if ($1.ai320x && $eq($get($1.ais, 2), "13")) { //#8830
                            $k[$j++] = "0111011"; //#8830
                            $k[$j++] = false; //#8830
                            break; //#8830
                        } //#8830
                        if ($1.ai310x && $eq($get($1.ais, 2), "15")) { //#8831
                            $k[$j++] = "0111100"; //#8831
                            $k[$j++] = false; //#8831
                            break; //#8831
                        } //#8831
                        if ($1.ai320x && $eq($get($1.ais, 2), "15")) { //#8832
                            $k[$j++] = "0111101"; //#8832
                            $k[$j++] = false; //#8832
                            break; //#8832
                        } //#8832
                        if ($1.ai310x && $eq($get($1.ais, 2), "17")) { //#8833
                            $k[$j++] = "0111110"; //#8833
                            $k[$j++] = false; //#8833
                            break; //#8833
                        } //#8833
                        if ($1.ai320x && $eq($get($1.ais, 2), "17")) { //#8834
                            $k[$j++] = "0111111"; //#8834
                            $k[$j++] = false; //#8834
                            break; //#8834
                        } //#8834
                    } //#8834
                } else { //#8840
                    if ($eq($geti($get($1.vals, 0), 0, 1), "9") && ($cvi($get($1.vals, 1)) <= 99999)) { //#8841
                        if ($1.ai310x) { //#8839
                            $k[$j++] = "0111000"; //#8839
                            $k[$j++] = false; //#8839
                            break; //#8839
                        } //#8839
                        if ($1.ai320x) { //#8840
                            $k[$j++] = "0111001"; //#8840
                            $k[$j++] = false; //#8840
                            break; //#8840
                        } //#8840
                    } //#8840
                } //#8840
            } //#8840
        } //#8840
        if ($1.ais.length >= 2) { //#8852
            $k[$j++] = 'ai392x'; //#8848
            $k[$j++] = false; //#8848
            for (var _1x = 3920; _1x <= 3923; _1x += 1) { //#8848
                var _22 = $k[--$j]; //#8848
                $k[$j++] = _22 || $eq($cvrs($s(4), _1x, 10), $get($1.ais, 1)); //#8848
            } //#8848
            var _23 = $k[--$j]; //#8848
            $1[$k[--$j]] = _23; //#8848
            if ($eq($get($1.ais, 0), "01") && $1.ai392x) { //#8851
                if ($eq($geti($get($1.vals, 0), 0, 1), "9")) { //#8850
                    $k[$j++] = "01100"; //#8850
                    $k[$j++] = true; //#8850
                    break; //#8850
                } //#8850
            } //#8850
        } //#8850
        if ($1.ais.length >= 2) { //#8860
            $k[$j++] = 'ai393x'; //#8856
            $k[$j++] = false; //#8856
            for (var _2C = 3930; _2C <= 3933; _2C += 1) { //#8856
                var _2H = $k[--$j]; //#8856
                $k[$j++] = _2H || $eq($cvrs($s(4), _2C, 10), $get($1.ais, 1)); //#8856
            } //#8856
            var _2I = $k[--$j]; //#8856
            $1[$k[--$j]] = _2I; //#8856
            if ($eq($get($1.ais, 0), "01") && $1.ai393x) { //#8859
                if ($eq($geti($get($1.vals, 0), 0, 1), "9")) { //#8858
                    $k[$j++] = "01101"; //#8858
                    $k[$j++] = true; //#8858
                    break; //#8858
                } //#8858
            } //#8858
        } //#8858
        if ($eq($get($1.ais, 0), "01")) { //#8863
            $k[$j++] = "1"; //#8863
            $k[$j++] = true; //#8863
            break; //#8863
        } //#8863
        $k[$j++] = "00"; //#8866
        $k[$j++] = true; //#8866
        break; //#8866
    } //#8866
    $1.gpfallow = $k[--$j]; //#8869
    $1.method = $k[--$j]; //#8870
    $1.conv12to40 = function() {
        var _2V = $strcpy($s(40), "0000000000000000000000000000000000000000"); //#8873
        var _2W = $k[--$j]; //#8874
        var _2a = $cvrs($s(10), $cvi($geti(_2W, 0, 3)), 2); //#8874
        $puti($geti(_2V, 0, 10), 10 - _2a.length, _2a); //#8874
        var _2e = $cvrs($s(10), $cvi($geti(_2W, 3, 3)), 2); //#8875
        $puti($geti(_2V, 10, 10), 10 - _2e.length, _2e); //#8875
        var _2i = $cvrs($s(10), $cvi($geti(_2W, 6, 3)), 2); //#8876
        $puti($geti(_2V, 20, 10), 10 - _2i.length, _2i); //#8876
        var _2m = $cvrs($s(10), $cvi($geti(_2W, 9, 3)), 2); //#8877
        $puti($geti(_2V, 30, 10), 10 - _2m.length, _2m); //#8877
        $k[$j++] = _2V; //#8878
        $k[$j++] = _2W; //#8878
        $j--; //#8878
    }; //#8878
    $1.conv13to44 = function() {
        var _2o = $strcpy($s(44), "00000000000000000000000000000000000000000000"); //#8882
        var _2p = $k[--$j]; //#8883
        var _2t = $cvrs($s(4), $cvi($geti(_2p, 0, 1)), 2); //#8883
        $puti($geti(_2o, 0, 4), 4 - _2t.length, _2t); //#8883
        $k[$j++] = _2o; //#8884
        $k[$j++] = _2o; //#8884
        $k[$j++] = $geti(_2p, 1, 12); //#8884
        $1.conv12to40(); //#8884
        var _2v = $k[--$j]; //#8884
        $puti($k[--$j], 4, _2v); //#8884
    }; //#8884
    $1.tobin = function() {
        var _2y = $s($k[--$j]); //#8888
        $k[$j++] = _2y; //#8888
        for (var _30 = 0, _2z = _2y.length - 1; _30 <= _2z; _30 += 1) { //#8888
            var _31 = $k[--$j]; //#8888
            $put(_31, _30, 48); //#8888
            $k[$j++] = _31; //#8888
        } //#8888
        var _32 = $k[--$j]; //#8889
        var _35 = $cvrs($s(_32.length), $k[--$j], 2); //#8889
        $puti(_32, _32.length - _35.length, _35); //#8889
        $k[$j++] = _32; //#8889
    }; //#8889
    $1.fnc1 = -1; //#8892
    $1.lnumeric = -2; //#8892
    $1.lalphanumeric = -3; //#8892
    $1.liso646 = -4; //#8892
    if ($eq($1.method, "00")) { //#8897
        $1.cdf = $a([]); //#8895
        $1.gpf = $a([]); //#8896
    } //#8896
    if ($eq($1.method, "1")) { //#8906
        $k[$j++] = 'cdf'; //#8900
        $k[$j++] = $geti($get($1.vals, 0), 0, 13); //#8900
        $1.conv13to44(); //#8900
        var _3D = $k[--$j]; //#8900
        $1[$k[--$j]] = _3D; //#8900
        $k[$j++] = Infinity; //#8901
        var _3F = $1.cdf; //#8901
        for (var _3G = 0, _3H = _3F.length; _3G < _3H; _3G++) { //#8901
            $k[$j++] = $f($get(_3F, _3G) - 48); //#8901
        } //#8901
        $1.cdf = $a(); //#8901
        $1.gpf = $a([]); //#8902
        $1.ais = $geti($1.ais, 1, $1.ais.length - 1); //#8903
        $1.vals = $geti($1.vals, 1, $1.vals.length - 1); //#8904
        $1.fncs = $geti($1.fncs, 1, $1.fncs.length - 1); //#8905
    } //#8905
    if ($eq($1.method, "0100")) { //#8917
        $1.cdf = $s(55); //#8909
        $k[$j++] = $1.cdf; //#8910
        $k[$j++] = 0; //#8910
        $k[$j++] = $geti($get($1.vals, 0), 1, 12); //#8910
        $1.conv12to40(); //#8910
        var _3a = $k[--$j]; //#8910
        var _3b = $k[--$j]; //#8910
        $puti($k[--$j], _3b, _3a); //#8910
        $k[$j++] = $1.cdf; //#8911
        $k[$j++] = 40; //#8911
        $k[$j++] = $cvi($get($1.vals, 1)); //#8911
        $k[$j++] = 15; //#8911
        $1.tobin(); //#8911
        var _3g = $k[--$j]; //#8911
        var _3h = $k[--$j]; //#8911
        $puti($k[--$j], _3h, _3g); //#8911
        $k[$j++] = Infinity; //#8912
        var _3j = $1.cdf; //#8912
        for (var _3k = 0, _3l = _3j.length; _3k < _3l; _3k++) { //#8912
            $k[$j++] = $get(_3j, _3k) - 48; //#8912
        } //#8912
        $1.cdf = $a(); //#8912
        $1.gpf = $a([]); //#8913
        $1.ais = $a([]); //#8914
        $1.vals = $a([]); //#8915
        $1.fncs = $a([]); //#8916
    } //#8916
    if ($eq($1.method, "0101")) { //#8933
        $1.cdf = $s(55); //#8920
        $k[$j++] = $1.cdf; //#8921
        $k[$j++] = 0; //#8921
        $k[$j++] = $geti($get($1.vals, 0), 1, 12); //#8921
        $1.conv12to40(); //#8921
        var _3y = $k[--$j]; //#8921
        var _3z = $k[--$j]; //#8921
        $puti($k[--$j], _3z, _3y); //#8921
        if ($eq($get($1.ais, 1), "3202")) { //#8925
            $k[$j++] = $cvi($get($1.vals, 1)); //#8923
            $k[$j++] = 15; //#8923
            $1.tobin(); //#8923
        } else { //#8925
            $k[$j++] = $cvi($get($1.vals, 1)) + 10000; //#8925
            $k[$j++] = 15; //#8925
            $1.tobin(); //#8925
        } //#8925
        $puti($1.cdf, 40, $k[--$j]); //#8927
        $k[$j++] = Infinity; //#8928
        var _49 = $1.cdf; //#8928
        for (var _4A = 0, _4B = _49.length; _4A < _4B; _4A++) { //#8928
            $k[$j++] = $get(_49, _4A) - 48; //#8928
        } //#8928
        $1.cdf = $a(); //#8928
        $1.gpf = $a([]); //#8929
        $1.ais = $a([]); //#8930
        $1.vals = $a([]); //#8931
        $1.fncs = $a([]); //#8932
    } //#8932
    if ($1.method.length == 7) { //#8955
        $1.cdf = $s(76); //#8936
        $k[$j++] = $1.cdf; //#8937
        $k[$j++] = 0; //#8937
        $k[$j++] = $geti($get($1.vals, 0), 1, 12); //#8937
        $1.conv12to40(); //#8937
        var _4O = $k[--$j]; //#8937
        var _4P = $k[--$j]; //#8937
        $puti($k[--$j], _4P, _4O); //#8937
        var _4R = $s(6); //#8938
        $puti(_4R, 0, $geti($get($1.ais, 1), 3, 1)); //#8938
        $puti(_4R, 1, $geti($get($1.vals, 1), 1, 5)); //#8939
        $k[$j++] = $cvi(_4R); //#8939
        $k[$j++] = 20; //#8939
        $1.tobin(); //#8939
        $puti($1.cdf, 40, $k[--$j]); //#8940
        if ($1.ais.length == 3) { //#8947
            var _4c = $get($1.vals, 2); //#8942
            $k[$j++] = ($cvi($geti(_4c, 0, 2)) * 384) + ((($cvi($geti(_4c, 2, 2)) - 1) * 32) + $cvi($geti(_4c, 4, 2))); //#8945
        } else { //#8947
            $k[$j++] = 38400; //#8947
        } //#8947
        $k[$j++] = 16; //#8949
        $1.tobin(); //#8949
        $puti($1.cdf, 60, $k[--$j]); //#8949
        $k[$j++] = Infinity; //#8950
        var _4i = $1.cdf; //#8950
        for (var _4j = 0, _4k = _4i.length; _4j < _4k; _4j++) { //#8950
            $k[$j++] = $get(_4i, _4j) - 48; //#8950
        } //#8950
        $1.cdf = $a(); //#8950
        $1.gpf = $a([]); //#8951
        $1.ais = $a([]); //#8952
        $1.vals = $a([]); //#8953
        $1.fncs = $a([]); //#8954
    } //#8954
    if ($eq($1.method, "01100")) { //#8966
        $1.cdf = $s(42); //#8958
        $k[$j++] = $1.cdf; //#8959
        $k[$j++] = 0; //#8959
        $k[$j++] = $geti($get($1.vals, 0), 1, 12); //#8959
        $1.conv12to40(); //#8959
        var _4x = $k[--$j]; //#8959
        var _4y = $k[--$j]; //#8959
        $puti($k[--$j], _4y, _4x); //#8959
        $k[$j++] = $1.cdf; //#8960
        $k[$j++] = 40; //#8960
        $k[$j++] = $cvi($geti($get($1.ais, 1), 3, 1)); //#8960
        $k[$j++] = 2; //#8960
        $1.tobin(); //#8960
        var _54 = $k[--$j]; //#8960
        var _55 = $k[--$j]; //#8960
        $puti($k[--$j], _55, _54); //#8960
        $k[$j++] = Infinity; //#8961
        var _57 = $1.cdf; //#8961
        for (var _58 = 0, _59 = _57.length; _58 < _59; _58++) { //#8961
            $k[$j++] = $get(_57, _58) - 48; //#8961
        } //#8961
        $1.cdf = $a(); //#8961
        $k[$j++] = Infinity; //#8962
        $forall($get($1.vals, 1)); //#8962
        if ($1.ais.length > 2) { //#8962
            $k[$j++] = $1.fnc1; //#8962
        } //#8962
        $1.gpf = $a(); //#8962
        $1.ais = $geti($1.ais, 2, $1.ais.length - 2); //#8963
        $1.vals = $geti($1.vals, 2, $1.vals.length - 2); //#8964
        $1.fncs = $geti($1.fncs, 2, $1.fncs.length - 2); //#8965
    } //#8965
    if ($eq($1.method, "01101")) { //#8978
        $1.cdf = $s(52); //#8969
        $k[$j++] = $1.cdf; //#8970
        $k[$j++] = 0; //#8970
        $k[$j++] = $geti($get($1.vals, 0), 1, 12); //#8970
        $1.conv12to40(); //#8970
        var _5W = $k[--$j]; //#8970
        var _5X = $k[--$j]; //#8970
        $puti($k[--$j], _5X, _5W); //#8970
        $k[$j++] = $1.cdf; //#8971
        $k[$j++] = 40; //#8971
        $k[$j++] = $cvi($geti($get($1.ais, 1), 3, 1)); //#8971
        $k[$j++] = 2; //#8971
        $1.tobin(); //#8971
        var _5d = $k[--$j]; //#8971
        var _5e = $k[--$j]; //#8971
        $puti($k[--$j], _5e, _5d); //#8971
        $k[$j++] = $1.cdf; //#8972
        $k[$j++] = 42; //#8972
        $k[$j++] = $cvi($geti($get($1.vals, 1), 0, 3)); //#8972
        $k[$j++] = 10; //#8972
        $1.tobin(); //#8972
        var _5k = $k[--$j]; //#8972
        var _5l = $k[--$j]; //#8972
        $puti($k[--$j], _5l, _5k); //#8972
        $k[$j++] = Infinity; //#8973
        var _5n = $1.cdf; //#8973
        for (var _5o = 0, _5p = _5n.length; _5o < _5p; _5o++) { //#8973
            $k[$j++] = $get(_5n, _5o) - 48; //#8973
        } //#8973
        $1.cdf = $a(); //#8973
        $k[$j++] = Infinity; //#8974
        var _5t = $get($1.vals, 1); //#8974
        var _5u = $geti(_5t, 3, _5t.length - 3); //#8974
        for (var _5v = 0, _5w = _5u.length; _5v < _5w; _5v++) { //#8974
            $k[$j++] = $get(_5u, _5v); //#8974
        } //#8974
        if ($1.ais.length > 2) { //#8974
            $k[$j++] = $1.fnc1; //#8974
        } //#8974
        $1.gpf = $a(); //#8974
        $1.ais = $geti($1.ais, 2, $1.ais.length - 2); //#8975
        $1.vals = $geti($1.vals, 2, $1.vals.length - 2); //#8976
        $1.fncs = $geti($1.fncs, 2, $1.fncs.length - 2); //#8977
    } //#8977
    if ($1.gpfallow) { //#8984
        $1.vlf = $a(2); //#8982
    } else { //#8984
        $1.vlf = $a([]); //#8984
    } //#8984
    $k[$j++] = Infinity; //#8998
    for (var _6D = 0; _6D <= 119; _6D += 1) { //#8997
        var _6F = $strcpy($s(2), "00"); //#8990
        var _6H = $cvrs($s(2), _6D, 11); //#8990
        $puti(_6F, 2 - _6H.length, _6H); //#8991
        $k[$j++] = _6D; //#8992
        $k[$j++] = _6F; //#8992
        if ($get(_6F, 0) == 65) { //#8992
            var _6J = $k[--$j]; //#8992
            $put(_6J, 0, 94); //#8992
            $k[$j++] = _6J; //#8992
        } //#8992
        var _6K = $k[--$j]; //#8993
        $k[$j++] = _6K; //#8993
        if ($get(_6K, 1) == 65) { //#8993
            var _6M = $k[--$j]; //#8993
            $put(_6M, 1, 94); //#8993
            $k[$j++] = _6M; //#8993
        } //#8993
        var _6N = $k[--$j]; //#8994
        var _6Q = $strcpy($s(7), "0000000"); //#8995
        var _6S = $cvrs($s(7), $f($k[--$j] + 8), 2); //#8995
        $puti(_6Q, 7 - _6S.length, _6S); //#8996
        $k[$j++] = _6N; //#8996
        $k[$j++] = _6Q; //#8996
    } //#8996
    $k[$j++] = $1.lalphanumeric; //#8998
    $k[$j++] = "0000"; //#8998
    $1.numeric = $d(); //#8999
    $k[$j++] = Infinity; //#9008
    for (var _6V = 48; _6V <= 57; _6V += 1) { //#9002
        $k[$j++] = _6V; //#9002
        $k[$j++] = _6V - 43; //#9002
        $k[$j++] = 5; //#9002
        $1.tobin(); //#9002
    } //#9002
    $k[$j++] = $1.fnc1; //#9004
    $k[$j++] = "01111"; //#9004
    for (var _6X = 65; _6X <= 90; _6X += 1) { //#9004
        $k[$j++] = _6X; //#9004
        $k[$j++] = _6X - 33; //#9004
        $k[$j++] = 6; //#9004
        $1.tobin(); //#9004
    } //#9004
    $k[$j++] = 42; //#9006
    $k[$j++] = "111010"; //#9006
    for (var _6Y = 44; _6Y <= 47; _6Y += 1) { //#9006
        $k[$j++] = _6Y; //#9006
        $k[$j++] = _6Y + 15; //#9006
        $k[$j++] = 6; //#9006
        $1.tobin(); //#9006
    } //#9006
    $k[$j++] = $1.lnumeric; //#9008
    $k[$j++] = "000"; //#9008
    $k[$j++] = $1.liso646; //#9008
    $k[$j++] = "00100"; //#9008
    $1.alphanumeric = $d(); //#9009
    $k[$j++] = Infinity; //#9023
    for (var _6c = 48; _6c <= 57; _6c += 1) { //#9012
        $k[$j++] = _6c; //#9012
        $k[$j++] = _6c - 43; //#9012
        $k[$j++] = 5; //#9012
        $1.tobin(); //#9012
    } //#9012
    $k[$j++] = $1.fnc1; //#9014
    $k[$j++] = "01111"; //#9014
    for (var _6e = 65; _6e <= 90; _6e += 1) { //#9014
        $k[$j++] = _6e; //#9014
        $k[$j++] = _6e - 1; //#9014
        $k[$j++] = 7; //#9014
        $1.tobin(); //#9014
    } //#9014
    for (var _6f = 97; _6f <= 122; _6f += 1) { //#9015
        $k[$j++] = _6f; //#9015
        $k[$j++] = _6f - 7; //#9015
        $k[$j++] = 7; //#9015
        $1.tobin(); //#9015
    } //#9015
    $k[$j++] = 33; //#9018
    $k[$j++] = "11101000"; //#9018
    $k[$j++] = 34; //#9018
    $k[$j++] = "11101001"; //#9018
    for (var _6g = 37; _6g <= 47; _6g += 1) { //#9018
        $k[$j++] = _6g; //#9018
        $k[$j++] = _6g + 197; //#9018
        $k[$j++] = 8; //#9018
        $1.tobin(); //#9018
    } //#9018
    for (var _6h = 58; _6h <= 63; _6h += 1) { //#9019
        $k[$j++] = _6h; //#9019
        $k[$j++] = _6h + 187; //#9019
        $k[$j++] = 8; //#9019
        $1.tobin(); //#9019
    } //#9019
    $k[$j++] = 95; //#9023
    $k[$j++] = "11111011"; //#9023
    $k[$j++] = 32; //#9023
    $k[$j++] = "11111100"; //#9023
    $k[$j++] = $1.lnumeric; //#9023
    $k[$j++] = "000"; //#9023
    $k[$j++] = $1.lalphanumeric; //#9023
    $k[$j++] = "00100"; //#9023
    $1.iso646 = $d(); //#9024
    for (var _6n = 0, _6m = $1.ais.length - 1; _6n <= _6m; _6n += 1) { //#9043
        $1.i = _6n; //#9029
        $1.ai = $get($1.ais, $1.i); //#9030
        $1.val = $get($1.vals, $1.i); //#9031
        var _6x = $a(($1.gpf.length + $1.ai.length) + $1.val.length); //#9032
        $puti(_6x, 0, $1.gpf); //#9033
        $k[$j++] = _6x; //#9034
        $k[$j++] = _6x; //#9034
        $k[$j++] = $1.gpf.length; //#9034
        $k[$j++] = $1.ai; //#9034
        $k[$j++] = Infinity; //#9034
        var _71 = $k[--$j]; //#9034
        var _72 = $k[--$j]; //#9034
        $k[$j++] = _71; //#9034
        $forall(_72); //#9034
        var _73 = $a(); //#9034
        var _74 = $k[--$j]; //#9034
        $puti($k[--$j], _74, _73); //#9034
        var _76 = $k[--$j]; //#9035
        $k[$j++] = _76; //#9035
        $k[$j++] = _76; //#9035
        $k[$j++] = $1.gpf.length + $1.ai.length; //#9035
        $k[$j++] = $1.val; //#9035
        $k[$j++] = Infinity; //#9035
        var _7A = $k[--$j]; //#9035
        var _7B = $k[--$j]; //#9035
        $k[$j++] = _7A; //#9035
        $forall(_7B); //#9035
        var _7C = $a(); //#9035
        var _7D = $k[--$j]; //#9035
        $puti($k[--$j], _7D, _7C); //#9035
        $1.gpf = $k[--$j]; //#9036
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#9042
            var _7M = $a($1.gpf.length + 1); //#9038
            $puti(_7M, 0, $1.gpf); //#9039
            $put(_7M, $1.gpf.length, $1.fnc1); //#9040
            $1.gpf = _7M; //#9041
        } //#9041
    } //#9041
    $1.rembits = function() {
        var _7Q = $k[--$j]; //#9047
        var _7R = 48; //#9049
        var _7S = (~~Math.ceil(_7Q / 12)) * 12; //#9049
        if (((~~Math.ceil(_7Q / 12)) * 12) < 48) { //#9049
            var _ = _7R; //#9049
            _7R = _7S; //#9049
            _7S = _; //#9049
        } //#9049
        var _7T = ~~(_7S / 12); //#9050
        $k[$j++] = _7Q; //#9054
        $k[$j++] = _7S; //#9054
        $k[$j++] = _7T; //#9054
        if ((_7T % $1.segments) == 1) { //#9053
            var _7V = $k[--$j]; //#9051
            var _7W = $k[--$j]; //#9051
            $k[$j++] = $f(_7V + 1) * 12; //#9051
            $k[$j++] = _7W; //#9051
            $j--; //#9051
        } else { //#9053
            $j--; //#9053
        } //#9053
        var _7X = $k[--$j]; //#9055
        var _7Y = $k[--$j]; //#9055
        $k[$j++] = $f(_7X - _7Y); //#9055
    }; //#9055
    $1.encode = function() {
        var _7Z = $k[--$j]; //#9059
        $k[$j++] = _7Z; //#9059
        if ($ne(_7Z, 'raw')) { //#9059
            var _7a = $k[--$j]; //#9059
            var _7c = $get(_7a, $k[--$j]); //#9059
            $k[$j++] = _7c; //#9059
        } else { //#9059
            $j--; //#9059
        } //#9059
        $k[$j++] = Infinity; //#9060
        var _7d = $k[--$j]; //#9060
        var _7e = $k[--$j]; //#9060
        $k[$j++] = _7d; //#9060
        $forall(_7e, function() { //#9060
            var _7f = $k[--$j]; //#9060
            $k[$j++] = $f(_7f - 48); //#9060
        }); //#9060
        var _7g = $a(); //#9060
        $puti($1.gpfenc, $1.j, _7g); //#9062
        $1.j = _7g.length + $1.j; //#9063
    }; //#9063
    $k[$j++] = Infinity; //#9067
    for (var _7l = 0, _7m = $1.gpf.length; _7l < _7m; _7l++) { //#9067
        $k[$j++] = 0; //#9067
    } //#9067
    $k[$j++] = 0; //#9067
    $k[$j++] = -1; //#9067
    $1.numericruns = $a(); //#9067
    $k[$j++] = Infinity; //#9068
    for (var _7p = 0, _7q = $1.gpf.length; _7p < _7q; _7p++) { //#9068
        $k[$j++] = 0; //#9068
    } //#9068
    $k[$j++] = 0; //#9068
    $1.alphanumericruns = $a(); //#9068
    $k[$j++] = Infinity; //#9069
    for (var _7t = 0, _7u = $1.gpf.length; _7t < _7u; _7t++) { //#9069
        $k[$j++] = 0; //#9069
    } //#9069
    $k[$j++] = 9999; //#9069
    $1.nextiso646only = $a(); //#9069
    for (var _7x = $1.gpf.length - 1; _7x >= 0; _7x -= 1) { //#9091
        $1.i = _7x; //#9071
        var _82 = $strcpy($s(2), "00"); //#9073
        var _85 = $get($1.gpf, $1.i); //#9074
        $k[$j++] = $get($1.gpf, $1.i); //#9074
        $k[$j++] = _82; //#9074
        $k[$j++] = _82; //#9074
        $k[$j++] = 0; //#9074
        $k[$j++] = _85; //#9074
        if (_85 == $1.fnc1) { //#9074
            $j--; //#9074
            $k[$j++] = 94; //#9074
        } //#9074
        var _87 = $k[--$j]; //#9074
        var _88 = $k[--$j]; //#9074
        $put($k[--$j], _88, _87); //#9074
        if ($1.i < ($1.gpf.length - 1)) { //#9075
            var _8C = $k[--$j]; //#9075
            var _8F = $get($1.gpf, $1.i + 1); //#9075
            $k[$j++] = _8C; //#9075
            $k[$j++] = _8C; //#9075
            $k[$j++] = 1; //#9075
            $k[$j++] = _8F; //#9075
            if (_8F == $1.fnc1) { //#9075
                $j--; //#9075
                $k[$j++] = 94; //#9075
            } //#9075
            var _8H = $k[--$j]; //#9075
            var _8I = $k[--$j]; //#9075
            $put($k[--$j], _8I, _8H); //#9075
        } //#9075
        var _8M = $get($1.numeric, $k[--$j]) !== undefined; //#9076
        if (_8M) { //#9079
            $put($1.numericruns, $1.i, $f($get($1.numericruns, $1.i + 2) + 2)); //#9077
        } else { //#9079
            $put($1.numericruns, $1.i, 0); //#9079
        } //#9079
        var _8U = $k[--$j]; //#9081
        var _8W = $get($1.alphanumeric, _8U) !== undefined; //#9081
        $k[$j++] = _8U; //#9085
        if (_8W) { //#9084
            $put($1.alphanumericruns, $1.i, $f($get($1.alphanumericruns, $1.i + 1) + 1)); //#9082
        } else { //#9084
            $put($1.alphanumericruns, $1.i, 0); //#9084
        } //#9084
        var _8e = $k[--$j]; //#9086
        var _8g = $get($1.iso646, _8e) !== undefined; //#9086
        var _8i = $get($1.alphanumeric, _8e) !== undefined; //#9086
        if (_8g && (!_8i)) { //#9089
            $put($1.nextiso646only, $1.i, 0); //#9087
        } else { //#9089
            $put($1.nextiso646only, $1.i, $f($get($1.nextiso646only, $1.i + 1) + 1)); //#9089
        } //#9089
    } //#9089
    $1.gpfenc = $a(252); //#9094
    $1.i = 0; //#9095
    $1.j = 0; //#9095
    $1.mode = "numeric"; //#9095
    for (;;) { //#9185
        if ($1.i == $1.gpf.length) { //#9097
            break; //#9097
        } //#9097
        for (;;) { //#9184
            if ($eq($1.mode, "numeric")) { //#9133
                if ($1.i <= ($1.gpf.length - 2)) { //#9130
                    var _8w = $s(2); //#9102
                    var _8z = $get($1.gpf, $1.i); //#9103
                    $k[$j++] = _8w; //#9103
                    $k[$j++] = _8w; //#9103
                    $k[$j++] = 0; //#9103
                    $k[$j++] = _8z; //#9103
                    if (_8z == $1.fnc1) { //#9103
                        $j--; //#9103
                        $k[$j++] = 94; //#9103
                    } //#9103
                    var _91 = $k[--$j]; //#9103
                    var _92 = $k[--$j]; //#9103
                    $put($k[--$j], _92, _91); //#9103
                    var _94 = $k[--$j]; //#9104
                    var _97 = $get($1.gpf, $1.i + 1); //#9104
                    $k[$j++] = _94; //#9104
                    $k[$j++] = _94; //#9104
                    $k[$j++] = 1; //#9104
                    $k[$j++] = _97; //#9104
                    if (_97 == $1.fnc1) { //#9104
                        $j--; //#9104
                        $k[$j++] = 94; //#9104
                    } //#9104
                    var _99 = $k[--$j]; //#9104
                    var _9A = $k[--$j]; //#9104
                    $put($k[--$j], _9A, _99); //#9104
                    var _9C = $k[--$j]; //#9105
                    var _9E = $get($1.numeric, _9C) !== undefined; //#9105
                    $k[$j++] = _9C; //#9109
                    if (_9E) { //#9109
                        $k[$j++] = $1.numeric; //#9106
                        $1.encode(); //#9106
                        $1.i = $1.i + 2; //#9107
                        break; //#9108
                    } //#9108
                    $j--; //#9110
                    $k[$j++] = $1.lalphanumeric; //#9111
                    $k[$j++] = $1.numeric; //#9111
                    $1.encode(); //#9111
                    $1.mode = "alphanumeric"; //#9112
                    break; //#9113
                } else { //#9130
                    var _9L = $get($1.gpf, $1.i); //#9115
                    if ((_9L < 48) || (_9L > 57)) { //#9119
                        $k[$j++] = $1.lalphanumeric; //#9116
                        $k[$j++] = $1.numeric; //#9116
                        $1.encode(); //#9116
                        $1.mode = "alphanumeric"; //#9117
                        break; //#9118
                    } //#9118
                    $k[$j++] = 'rem'; //#9120
                    $k[$j++] = ((((12 + 1) + $1.method.length) + $1.vlf.length) + $1.cdf.length) + $1.j; //#9120
                    $1.rembits(); //#9120
                    var _9S = $k[--$j]; //#9120
                    $1[$k[--$j]] = _9S; //#9120
                    if (($1.rem >= 4) && ($1.rem <= 6)) { //#9130
                        var _9Z = $geti($strcpy($s(6), "000000"), 0, $1.rem); //#9122
                        var _9e = $cvrs($s(4), $f($get($1.gpf, $1.i) - 47), 2); //#9123
                        $puti(_9Z, 4 - _9e.length, _9e); //#9124
                        $k[$j++] = _9Z; //#9124
                        $k[$j++] = 'raw'; //#9124
                        $1.encode(); //#9124
                        $1.i = $1.i + 1; //#9125
                        break; //#9126
                    } else { //#9130
                        var _9g = $s(2); //#9128
                        $put(_9g, 0, $get($1.gpf, $1.i)); //#9128
                        $put(_9g, 1, 94); //#9128
                        $k[$j++] = _9g; //#9128
                        $k[$j++] = $1.numeric; //#9128
                        $1.encode(); //#9128
                        $1.i = $1.i + 1; //#9129
                        break; //#9130
                    } //#9130
                } //#9130
            } //#9130
            if ($eq($1.mode, "alphanumeric")) { //#9160
                if ($get($1.gpf, $1.i) == $1.fnc1) { //#9141
                    $k[$j++] = $1.fnc1; //#9137
                    $k[$j++] = $1.alphanumeric; //#9137
                    $1.encode(); //#9137
                    $1.mode = "numeric"; //#9138
                    $1.i = $1.i + 1; //#9139
                    break; //#9140
                } //#9140
                var _9w = $get($1.gpf, $1.i); //#9142
                var _9y = $get($1.iso646, _9w) !== undefined; //#9142
                var _A0 = $get($1.alphanumeric, _9w) !== undefined; //#9142
                if (_9y && (!_A0)) { //#9146
                    $k[$j++] = $1.liso646; //#9143
                    $k[$j++] = $1.alphanumeric; //#9143
                    $1.encode(); //#9143
                    $1.mode = "iso646"; //#9144
                    break; //#9145
                } //#9145
                if ($get($1.numericruns, $1.i) >= 6) { //#9151
                    $k[$j++] = $1.lnumeric; //#9148
                    $k[$j++] = $1.alphanumeric; //#9148
                    $1.encode(); //#9148
                    $1.mode = "numeric"; //#9149
                    break; //#9150
                } //#9150
                var _AA = $get($1.numericruns, $1.i); //#9152
                if ((_AA >= 4) && ($f(_AA + $1.i) == $1.gpf.length)) { //#9156
                    $k[$j++] = $1.lnumeric; //#9153
                    $k[$j++] = $1.alphanumeric; //#9153
                    $1.encode(); //#9153
                    $1.mode = "numeric"; //#9154
                    break; //#9155
                } //#9155
                $k[$j++] = $get($1.gpf, $1.i); //#9157
                $k[$j++] = $1.alphanumeric; //#9157
                $1.encode(); //#9157
                $1.i = $1.i + 1; //#9158
                break; //#9159
            } //#9159
            if ($eq($1.mode, "iso646")) { //#9182
                if ($get($1.gpf, $1.i) == $1.fnc1) { //#9168
                    $k[$j++] = $1.fnc1; //#9164
                    $k[$j++] = $1.iso646; //#9164
                    $1.encode(); //#9164
                    $1.mode = "numeric"; //#9165
                    $1.i = $1.i + 1; //#9166
                    break; //#9167
                } //#9167
                if (($get($1.numericruns, $1.i) >= 4) && ($get($1.nextiso646only, $1.i) >= 10)) { //#9173
                    $k[$j++] = $1.lnumeric; //#9170
                    $k[$j++] = $1.iso646; //#9170
                    $1.encode(); //#9170
                    $1.mode = "numeric"; //#9171
                    break; //#9172
                } //#9172
                if (($get($1.alphanumericruns, $1.i) >= 5) && ($get($1.nextiso646only, $1.i) >= 10)) { //#9178
                    $k[$j++] = $1.lalphanumeric; //#9175
                    $k[$j++] = $1.iso646; //#9175
                    $1.encode(); //#9175
                    $1.mode = "alphanumeric"; //#9176
                    break; //#9177
                } //#9177
                $k[$j++] = $get($1.gpf, $1.i); //#9179
                $k[$j++] = $1.iso646; //#9179
                $1.encode(); //#9179
                $1.i = $1.i + 1; //#9180
                break; //#9181
            } //#9181
        } //#9181
    } //#9181
    $1.gpf = $geti($1.gpfenc, 0, $1.j); //#9186
    var _Au = ((((1 + 12) + $1.method.length) + $1.vlf.length) + $1.cdf.length) + $1.gpf.length; //#9190
    $k[$j++] = _Au; //#9190
    $k[$j++] = _Au; //#9190
    $1.rembits(); //#9190
    var _Av = $k[--$j]; //#9190
    $1.pad = $a(_Av); //#9190
    $k[$j++] = _Av; //#9197
    if ($1.vlf.length != 0) { //#9196
        var _Ay = $k[--$j]; //#9192
        var _B0 = ~~($f($k[--$j] + _Ay) / 12); //#9193
        $put($1.vlf, 0, _B0 % 2); //#9193
        var _B2 = (_B0 <= 14) ? 0 : 1; //#9194
        $put($1.vlf, 1, _B2); //#9194
    } else { //#9196
        $j -= 2; //#9196
    } //#9196
    if ($1.pad.length > 0) { //#9206
        for (var _B7 = 0, _B6 = $1.pad.length - 1; _B7 <= _B6; _B7 += 5) { //#9202
            $1.i = _B7; //#9200
            var _B8 = $1.pad; //#9201
            var _B9 = $1.i; //#9201
            var _BA = $a([0, 0, 1, 0, 0]); //#9201
            var _BB = $1.pad; //#9201
            var _BC = $1.i; //#9201
            var _BD = 5; //#9201
            var _BE = _BB.length - _BC; //#9201
            if ((_BB.length - _BC) > 5) { //#9201
                var _ = _BD; //#9201
                _BD = _BE; //#9201
                _BE = _; //#9201
            } //#9201
            $puti(_B8, _B9, $geti(_BA, 0, _BE)); //#9201
        } //#9201
        if ($eq($1.mode, "numeric")) { //#9205
            $k[$j++] = Infinity; //#9204
            $k[$j++] = 0; //#9204
            $k[$j++] = 0; //#9204
            $k[$j++] = 0; //#9204
            $k[$j++] = 0; //#9204
            $aload($1.pad); //#9204
            $1.pad = $geti($a(), 0, $1.pad.length); //#9204
        } //#9204
    } //#9204
    $k[$j++] = Infinity; //#9215
    var _BM = $1.linkage ? 1 : 0; //#9210
    $k[$j++] = _BM; //#9211
    $forall($1.method, function() { //#9211
        var _BO = $k[--$j]; //#9211
        $k[$j++] = $f(_BO - 48); //#9211
    }); //#9211
    $aload($1.vlf); //#9212
    $aload($1.cdf); //#9213
    $aload($1.gpf); //#9214
    $aload($1.pad); //#9215
    $1.binval = $a(); //#9215
    $1.datalen = ~~($1.binval.length / 12); //#9217
    $1.ncr = function() {
        var _BV = $k[--$j]; //#9220
        var _BW = $k[--$j]; //#9220
        var _BX = $f(_BW - _BV); //#9220
        if (_BV < $f(_BW - _BV)) { //#9220
            var _ = _BX; //#9220
            _BX = _BV; //#9220
            _BV = _; //#9220
        } //#9220
        $k[$j++] = _BX; //#9227
        $k[$j++] = 1; //#9227
        $k[$j++] = 1; //#9227
        for (var _BZ = _BW, _BY = $f(_BV + 1); _BZ >= _BY; _BZ -= 1) { //#9227
            var _Ba = $k[--$j]; //#9223
            var _Bb = $k[--$j]; //#9224
            var _Bc = $k[--$j]; //#9224
            $k[$j++] = _Bc; //#9226
            $k[$j++] = _Bb; //#9226
            $k[$j++] = _Ba * _BZ; //#9226
            if ($le(_Bb, _Bc)) { //#9226
                var _Bd = $k[--$j]; //#9225
                var _Be = $k[--$j]; //#9225
                $k[$j++] = $f(_Be + 1); //#9225
                $k[$j++] = ~~(_Bd / _Be); //#9225
            } //#9225
        } //#9225
        for (;;) { //#9231
            var _Bf = $k[--$j]; //#9229
            var _Bg = $k[--$j]; //#9229
            var _Bh = $k[--$j]; //#9229
            $k[$j++] = _Bh; //#9229
            $k[$j++] = _Bg; //#9229
            $k[$j++] = _Bf; //#9229
            if ($gt(_Bg, _Bh)) { //#9229
                break; //#9229
            } //#9229
            var _Bi = $k[--$j]; //#9230
            var _Bj = $k[--$j]; //#9230
            $k[$j++] = $f(_Bj + 1); //#9230
            $k[$j++] = ~~(_Bi / _Bj); //#9230
        } //#9230
        var _Bk = $k[--$j]; //#9232
        var _Bl = $k[--$j]; //#9232
        $k[$j++] = _Bk; //#9232
        $k[$j++] = _Bl; //#9232
        $j--; //#9232
        var _Bm = $k[--$j]; //#9232
        var _Bn = $k[--$j]; //#9232
        $k[$j++] = _Bm; //#9232
        $k[$j++] = _Bn; //#9232
        $j--; //#9232
    }; //#9232
    $1.getRSSwidths = function() {
        $1.oe = $k[--$j]; //#9236
        $1.el = $k[--$j]; //#9237
        $1.mw = $k[--$j]; //#9238
        $1.nm = $k[--$j]; //#9239
        $1.val = $k[--$j]; //#9240
        $1.out = $a($1.el); //#9241
        $1.mask = 0; //#9242
        for (var _Bx = 0, _Bw = $f($1.el - 2); _Bx <= _Bw; _Bx += 1) { //#9269
            $1.bar = _Bx; //#9244
            $1.ew = 1; //#9245
            var _Bz = $1.bar; //#9246
            $1.mask = $1.mask | ((_Bz < 0 ? 1 >>> -_Bz : 1 << _Bz)); //#9246
            for (;;) { //#9265
                $k[$j++] = 'sval'; //#9247
                $k[$j++] = $f($f($1.nm - $1.ew) - 1); //#9247
                $k[$j++] = $f($f($1.el - $1.bar) - 2); //#9247
                $1.ncr(); //#9247
                var _C4 = $k[--$j]; //#9247
                $1[$k[--$j]] = _C4; //#9247
                if (($1.oe && ($1.mask == 0)) && (($f(($f($f($1.nm - $1.ew) - ($1.el * 2))) + ($1.bar * 2))) >= -2)) { //#9250
                    $k[$j++] = 'sval'; //#9249
                    $k[$j++] = $1.sval; //#9249
                    $k[$j++] = $f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar); //#9249
                    $k[$j++] = $f($f($1.el - $1.bar) - 2); //#9249
                    $1.ncr(); //#9249
                    var _CJ = $k[--$j]; //#9249
                    var _CK = $k[--$j]; //#9249
                    $1[$k[--$j]] = $f(_CK - _CJ); //#9249
                } //#9249
                if ($f($1.el - $1.bar) > 2) { //#9259
                    $1.lval = 0; //#9252
                    for (var _CU = $f(($f(($f($f($1.nm - $1.ew) - $1.el)) + $1.bar)) + 2), _CT = $f($1.mw + 1); _CU >= _CT; _CU -= 1) { //#9256
                        $k[$j++] = $f(($f($f($1.nm - _CU) - $1.ew)) - 1); //#9254
                        $k[$j++] = $f($f($1.el - $1.bar) - 3); //#9254
                        $1.ncr(); //#9254
                        $1.lval = $f($k[--$j] + $1.lval); //#9255
                    } //#9255
                    $1.sval = $f($1.sval - ($1.lval * ($f($f($1.el - $1.bar) - 1)))); //#9257
                } else { //#9259
                    if ($f($1.nm - $1.ew) > $1.mw) { //#9259
                        $1.sval = $f($1.sval - 1); //#9259
                    } //#9259
                } //#9259
                $1.val = $f($1.val - $1.sval); //#9261
                if ($1.val < 0) { //#9262
                    break; //#9262
                } //#9262
                $1.ew = $1.ew + 1; //#9263
                var _Co = $1.bar; //#9264
                $1.mask = $1.mask & (~((_Co < 0 ? 1 >>> -_Co : 1 << _Co))); //#9264
            } //#9264
            $1.val = $f($1.val + $1.sval); //#9266
            $1.nm = $f($1.nm - $1.ew); //#9267
            $put($1.out, $1.bar, $1.ew); //#9268
        } //#9268
        $put($1.out, $f($1.el - 1), $1.nm); //#9270
        $k[$j++] = $1.out; //#9271
    }; //#9271
    $1.tab174 = $a([347, 0, 12, 5, 7, 2, 87, 4, 1387, 348, 10, 7, 5, 4, 52, 20, 2947, 1388, 8, 9, 4, 5, 30, 52, 3987, 2948, 6, 11, 3, 6, 10, 104, 4191, 3988, 4, 13, 1, 8, 1, 204]); //#9281
    $1.dxw = $a($1.datalen); //#9284
    for (var _D5 = 0, _D4 = $1.datalen - 1; _D5 <= _D4; _D5 += 1) { //#9325
        $1.x = _D5; //#9288
        $1.d = $geti($1.binval, $1.x * 12, 12); //#9290
        $k[$j++] = 'd'; //#9291
        $k[$j++] = 0; //#9291
        for (var _D9 = 0; _D9 <= 11; _D9 += 1) { //#9291
            $1.j = _D9; //#9291
            var _DE = $k[--$j]; //#9291
            $k[$j++] = $f(_DE + ((~~Math.pow(2, 11 - $1.j)) * $get($1.d, $1.j))); //#9291
        } //#9291
        var _DF = $k[--$j]; //#9291
        $1[$k[--$j]] = _DF; //#9291
        $1.j = 0; //#9293
        for (;;) { //#9303
            if ($le($1.d, $get($1.tab174, $1.j))) { //#9301
                var _DN = $geti($1.tab174, $1.j + 1, 7); //#9295
                for (var _DO = 0, _DP = _DN.length; _DO < _DP; _DO++) { //#9295
                    $k[$j++] = $get(_DN, _DO); //#9295
                } //#9295
                $1.dte = $k[--$j]; //#9296
                $1.dto = $k[--$j]; //#9296
                $1.dmwe = $k[--$j]; //#9297
                $1.dmwo = $k[--$j]; //#9297
                $1.dele = $k[--$j]; //#9298
                $1.delo = $k[--$j]; //#9298
                $1.dgs = $k[--$j]; //#9299
                break; //#9300
            } //#9300
            $1.j = $1.j + 8; //#9302
        } //#9302
        $k[$j++] = 'dwo'; //#9305
        $k[$j++] = ~~($f($1.d - $1.dgs) / $1.dte); //#9305
        $k[$j++] = $1.delo; //#9305
        $k[$j++] = $1.dmwo; //#9305
        $k[$j++] = 4; //#9305
        $k[$j++] = true; //#9305
        $1.getRSSwidths(); //#9305
        var _De = $k[--$j]; //#9305
        $1[$k[--$j]] = _De; //#9305
        $k[$j++] = 'dwe'; //#9306
        $k[$j++] = $f($1.d - $1.dgs) % $1.dte; //#9306
        $k[$j++] = $1.dele; //#9306
        $k[$j++] = $1.dmwe; //#9306
        $k[$j++] = 4; //#9306
        $k[$j++] = false; //#9306
        $1.getRSSwidths(); //#9306
        var _Dl = $k[--$j]; //#9306
        $1[$k[--$j]] = _Dl; //#9306
        $1.dw = $a(8); //#9308
        if (($1.x % 2) == 0) { //#9319
            for (var _Dp = 0; _Dp <= 3; _Dp += 1) { //#9314
                $1.j = _Dp; //#9311
                $put($1.dw, 7 - ($1.j * 2), $get($1.dwo, $1.j)); //#9312
                $put($1.dw, 6 - ($1.j * 2), $get($1.dwe, $1.j)); //#9313
            } //#9313
        } else { //#9319
            for (var _E0 = 0; _E0 <= 3; _E0 += 1) { //#9320
                $1.j = _E0; //#9317
                $put($1.dw, $1.j * 2, $get($1.dwo, $1.j)); //#9318
                $put($1.dw, ($1.j * 2) + 1, $get($1.dwe, $1.j)); //#9319
            } //#9319
        } //#9319
        $put($1.dxw, $1.x, $1.dw); //#9323
    } //#9323
    $1.finderwidths = $a([1, 8, 4, 1, 1, 1, 1, 4, 8, 1, 3, 6, 4, 1, 1, 1, 1, 4, 6, 3, 3, 4, 6, 1, 1, 1, 1, 6, 4, 3, 3, 2, 8, 1, 1, 1, 1, 8, 2, 3, 2, 6, 5, 1, 1, 1, 1, 5, 6, 2, 2, 2, 9, 1, 1, 1, 1, 9, 2, 2]); //#9335
    $1.finderseq = $a([$a([0, 1]), $a([0, 3, 2]), $a([0, 5, 2, 7]), $a([0, 9, 2, 7, 4]), $a([0, 9, 2, 7, 6, 11]), $a([0, 9, 2, 7, 8, 11, 10]), $a([0, 1, 2, 3, 4, 5, 6, 7]), $a([0, 1, 2, 3, 4, 5, 6, 9, 8]), $a([0, 1, 2, 3, 4, 5, 6, 9, 10, 11]), $a([0, 1, 2, 3, 4, 7, 6, 9, 8, 11, 10])]); //#9348
    $1.seq = $get($1.finderseq, ~~(($1.datalen - 2) / 2)); //#9351
    $1.fxw = $a($1.seq.length); //#9352
    for (var _EX = 0, _EW = $1.seq.length - 1; _EX <= _EW; _EX += 1) { //#9356
        $1.x = _EX; //#9354
        $put($1.fxw, $1.x, $geti($1.finderwidths, $get($1.seq, $1.x) * 5, 5)); //#9355
    } //#9355
    $1.checkweights = $a([-1, -1, -1, -1, -1, -1, -1, -1, 77, 96, 32, 81, 27, 9, 3, 1, 20, 60, 180, 118, 143, 7, 21, 63, 205, 209, 140, 117, 39, 13, 145, 189, 193, 157, 49, 147, 19, 57, 171, 91, 132, 44, 85, 169, 197, 136, 186, 62, 185, 133, 188, 142, 4, 12, 36, 108, 50, 87, 29, 80, 97, 173, 128, 113, 150, 28, 84, 41, 123, 158, 52, 156, 166, 196, 206, 139, 187, 203, 138, 46, 76, 17, 51, 153, 37, 111, 122, 155, 146, 119, 110, 107, 106, 176, 129, 43, 16, 48, 144, 10, 30, 90, 59, 177, 164, 125, 112, 178, 200, 137, 116, 109, 70, 210, 208, 202, 184, 130, 179, 115, 190, 204, 68, 93, 31, 151, 191, 134, 148, 22, 66, 198, 172, 94, 71, 2, 40, 154, 192, 64, 162, 54, 18, 6, 120, 149, 25, 75, 14, 42, 126, 167, 175, 199, 207, 69, 23, 78, 26, 79, 103, 98, 83, 38, 114, 131, 182, 124, 159, 53, 88, 170, 127, 183, 61, 161, 55, 165, 73, 8, 24, 72, 5, 15, 89, 100, 174, 58, 160, 194, 135, 45]); //#9384
    $k[$j++] = Infinity; //#9388
    $forall($1.seq, function() { //#9388
        $aload($geti($1.checkweights, $k[--$j] * 16, 16)); //#9388
    }); //#9388
    var _Ek = $a(); //#9388
    $1.checkweightseq = $geti(_Ek, 8, _Ek.length - 8); //#9389
    $k[$j++] = Infinity; //#9392
    var _Em = $1.dxw; //#9392
    for (var _En = 0, _Eo = _Em.length; _En < _Eo; _En++) { //#9392
        $forall($get(_Em, _En)); //#9392
    } //#9392
    $1.widths = $a(); //#9392
    $1.checksum = 0; //#9395
    for (var _Et = 0, _Es = $1.widths.length - 1; _Et <= _Es; _Et += 1) { //#9399
        $1.i = _Et; //#9397
        $1.checksum = $f($1.checksum + ($get($1.widths, $1.i) * $get($1.checkweightseq, $1.i))); //#9398
    } //#9398
    $1.checksum = $f(($1.checksum % 211) + (($1.datalen - 3) * 211)); //#9400
    $1.i = 0; //#9402
    for (;;) { //#9412
        if ($1.checksum <= $get($1.tab174, $1.i)) { //#9410
            var _F9 = $geti($1.tab174, $1.i + 1, 7); //#9404
            for (var _FA = 0, _FB = _F9.length; _FA < _FB; _FA++) { //#9404
                $k[$j++] = $get(_F9, _FA); //#9404
            } //#9404
            $1.cte = $k[--$j]; //#9405
            $1.cto = $k[--$j]; //#9405
            $1.cmwe = $k[--$j]; //#9406
            $1.cmwo = $k[--$j]; //#9406
            $1.cele = $k[--$j]; //#9407
            $1.celo = $k[--$j]; //#9407
            $1.cgs = $k[--$j]; //#9408
            break; //#9409
        } //#9409
        $1.i = $1.i + 8; //#9411
    } //#9411
    $k[$j++] = 'cwo'; //#9414
    $k[$j++] = ~~($f($1.checksum - $1.cgs) / $1.cte); //#9414
    $k[$j++] = $1.celo; //#9414
    $k[$j++] = $1.cmwo; //#9414
    $k[$j++] = 4; //#9414
    $k[$j++] = true; //#9414
    $1.getRSSwidths(); //#9414
    var _FQ = $k[--$j]; //#9414
    $1[$k[--$j]] = _FQ; //#9414
    $k[$j++] = 'cwe'; //#9415
    $k[$j++] = $f($1.checksum - $1.cgs) % $1.cte; //#9415
    $k[$j++] = $1.cele; //#9415
    $k[$j++] = $1.cmwe; //#9415
    $k[$j++] = 4; //#9415
    $k[$j++] = false; //#9415
    $1.getRSSwidths(); //#9415
    var _FX = $k[--$j]; //#9415
    $1[$k[--$j]] = _FX; //#9415
    $1.cw = $a(8); //#9417
    for (var _Fa = 0; _Fa <= 3; _Fa += 1) { //#9422
        $1.i = _Fa; //#9419
        $put($1.cw, $1.i * 2, $get($1.cwo, $1.i)); //#9420
        $put($1.cw, ($1.i * 2) + 1, $get($1.cwe, $1.i)); //#9421
    } //#9421
    var _Fl = $a(22); //#9424
    $put(_Fl, 0, $1.cw); //#9425
    $puti(_Fl, 1, $1.dxw); //#9425
    $1.dxw = $geti(_Fl, 0, $1.datalen + 1); //#9426
    $1.datalen = $1.dxw.length; //#9427
    $1.rows = $a(~~Math.ceil($1.datalen / $1.segments)); //#9430
    $1.numrows = $1.rows.length; //#9431
    for (var _Fx = 0, _Fw = $1.numrows - 1; _Fx <= _Fw; _Fx += 1) { //#9446
        $1.r = _Fx; //#9433
        $k[$j++] = Infinity; //#9434
        if ((($1.segments % 4) != 0) && (($1.r % 2) == 1)) { //#9435
            $k[$j++] = 0; //#9435
        } //#9435
        $k[$j++] = 1; //#9443
        $k[$j++] = 1; //#9443
        for (var _G2 = 0, _G1 = $1.segments - 1; _G2 <= _G1; _G2 += 1) { //#9443
            $1.pos = _G2 + ($1.r * $1.segments); //#9438
            if ($1.pos < $1.datalen) { //#9442
                $forall($get($1.dxw, $1.pos)); //#9440
                if (($1.pos % 2) == 0) { //#9441
                    $forall($get($1.fxw, ~~($1.pos / 2))); //#9441
                } //#9441
            } //#9441
        } //#9441
        var _GE = $counttomark() + 2; //#9445
        $k[$j++] = 1; //#9445
        $k[$j++] = 1; //#9445
        $astore($a(_GE)); //#9445
        $put($1.rows, $1.r, $k[--$j]); //#9445
        $j--; //#9445
    } //#9445
    if ($ne($1.format, "expandedstacked")) { //#9574
        var _GL = $get($1.rows, 0); //#9451
        $1.sbs = $geti(_GL, 1, _GL.length - 1); //#9451
        $k[$j++] = Infinity; //#9460
        $k[$j++] = 1; //#9459
        for (var _GP = 0, _GO = $1.datalen - 1; _GP <= _GO; _GP += 1) { //#9459
            $1.i = _GP; //#9456
            $forall($get($1.dxw, $1.i)); //#9457
            if (($1.i % 2) == 0) { //#9458
                $forall($get($1.fxw, ~~($1.i / 2))); //#9458
            } //#9458
        } //#9458
        $k[$j++] = 1; //#9460
        $k[$j++] = 1; //#9460
        $1.sbs = $a(); //#9460
        delete $1.options["parse"]; //#9463
        $k[$j++] = Infinity; //#9470
        var _GZ = $1.sbs; //#9467
        $k[$j++] = Infinity; //#9468
        for (var _Gb = 0, _Gc = ~~(($1.sbs.length + 1) / 2); _Gb < _Gc; _Gb++) { //#9468
            $k[$j++] = $1.height; //#9468
        } //#9468
        var _Ge = $a(); //#9468
        $k[$j++] = Infinity; //#9469
        for (var _Gg = 0, _Gh = ~~(($1.sbs.length + 1) / 2); _Gg < _Gh; _Gg++) { //#9469
            $k[$j++] = 0; //#9469
        } //#9469
        var _Gi = $a(); //#9469
        $k[$j++] = 'ren'; //#9470
        $k[$j++] = bwipp_renlinear; //#9470
        $k[$j++] = 'sbs'; //#9470
        $k[$j++] = _GZ; //#9470
        $k[$j++] = 'bhs'; //#9470
        $k[$j++] = _Ge; //#9470
        $k[$j++] = 'bbs'; //#9470
        $k[$j++] = _Gi; //#9470
        $k[$j++] = 'opt'; //#9470
        $k[$j++] = $1.options; //#9470
        var _Gk = $d(); //#9470
        $k[$j++] = _Gk; //#9473
        if (!$1.dontdraw) { //#9473
            bwipp_renlinear(); //#9473
        } //#9473
    } else { //#9574
        $1.seps = $a($1.numrows); //#9477
        for (var _Gq = 0, _Gp = $1.numrows - 1; _Gq <= _Gp; _Gq += 1) { //#9533
            $1.r = _Gq; //#9480
            $1.row = $get($1.rows, $1.r); //#9481
            $k[$j++] = Infinity; //#9484
            for (var _Gw = 0, _Gv = $1.row.length - 1; _Gw <= _Gv; _Gw += 2) { //#9489
                $1.i = _Gw; //#9486
                for (var _H0 = 0, _H1 = $get($1.row, $1.i); _H0 < _H1; _H0++) { //#9487
                    $k[$j++] = 0; //#9487
                } //#9487
                if ($1.i < ($1.row.length - 1)) { //#9488
                    for (var _H7 = 0, _H8 = $get($1.row, $1.i + 1); _H7 < _H8; _H7++) { //#9488
                        $k[$j++] = 1; //#9488
                    } //#9488
                } //#9488
            } //#9488
            $astore($a($counttomark())); //#9490
            $1.row = $k[--$j]; //#9490
            $j--; //#9490
            $k[$j++] = Infinity; //#9493
            $forall($1.row, function() { //#9493
                var _HD = $k[--$j]; //#9493
                $k[$j++] = $f(1 - _HD); //#9493
            }); //#9493
            $1.sep = $a(); //#9493
            $k[$j++] = Infinity; //#9496
            for (var _HH = 19, _HG = $1.row.length - 13; _HH <= _HG; _HH += 98) { //#9495
                $k[$j++] = _HH; //#9495
            } //#9495
            for (var _HK = 68, _HJ = $1.row.length - 13; _HK <= _HJ; _HK += 98) { //#9496
                $k[$j++] = _HK; //#9496
            } //#9496
            $1.finderpos = $a(); //#9496
            var _HM = $1.finderpos; //#9498
            for (var _HN = 0, _HO = _HM.length; _HN < _HO; _HN++) { //#9512
                var _HP = $get(_HM, _HN); //#9512
                for (var _HR = _HP, _HQ = $f(_HP + 14); _HR <= _HQ; _HR += 1) { //#9511
                    $1.i = _HR; //#9500
                    if ($get($1.row, $1.i) == 0) { //#9508
                        if ($get($1.row, $1.i - 1) == 1) { //#9505
                            $k[$j++] = 1; //#9503
                        } else { //#9505
                            var _Hb = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#9505
                            $k[$j++] = _Hb; //#9505
                        } //#9505
                    } else { //#9508
                        $k[$j++] = 0; //#9508
                    } //#9508
                    $put($1.sep, $1.i, $k[--$j]); //#9510
                } //#9510
            } //#9510
            $puti($1.sep, 0, $a([0, 0, 0, 0])); //#9513
            $puti($1.sep, $1.row.length - 4, $a([0, 0, 0, 0])); //#9514
            if ((($1.segments % 4) == 0) && (($1.r % 2) == 1)) { //#9528
                if (($get($1.rows, $1.r).length != $get($1.rows, 0).length) && (($1.finderpos.length % 2) == 1)) { //#9526
                    $k[$j++] = Infinity; //#9520
                    $k[$j++] = 0; //#9520
                    $aload($1.row); //#9520
                    $1.row = $a(); //#9520
                    $k[$j++] = Infinity; //#9521
                    $k[$j++] = 0; //#9521
                    $aload($1.sep); //#9521
                    $1.sep = $a(); //#9521
                } else { //#9526
                    for (var _Hx = $1.row.length - 1; _Hx >= 0; _Hx -= 1) { //#9523
                        $k[$j++] = $get($1.row, _Hx); //#9523
                    } //#9523
                    $astore($1.row); //#9524
                    $j--; //#9524
                    for (var _I2 = $1.sep.length - 1; _I2 >= 0; _I2 -= 1) { //#9525
                        $k[$j++] = $get($1.sep, _I2); //#9525
                    } //#9525
                    $astore($1.sep); //#9526
                    $j--; //#9526
                } //#9526
            } //#9526
            $put($1.rows, $1.r, $1.row); //#9530
            $put($1.seps, $1.r, $1.sep); //#9531
        } //#9531
        $1.pixx = $get($1.rows, 0).length; //#9536
        $k[$j++] = Infinity; //#9537
        for (var _IF = 0, _IG = $1.pixx; _IF < _IG; _IF++) { //#9537
            $k[$j++] = 0; //#9537
        } //#9537
        var _IH = $a(); //#9537
        $puti(_IH, 0, $get($1.rows, $1.numrows - 1)); //#9537
        $put($1.rows, $1.numrows - 1, _IH); //#9538
        $k[$j++] = Infinity; //#9539
        for (var _IO = 0, _IP = $1.pixx; _IO < _IP; _IO++) { //#9539
            $k[$j++] = 0; //#9539
        } //#9539
        var _IQ = $a(); //#9539
        $puti(_IQ, 0, $get($1.seps, $1.numrows - 1)); //#9539
        $put($1.seps, $1.numrows - 1, _IQ); //#9540
        $k[$j++] = Infinity; //#9543
        for (var _IX = 0, _IY = (~~($1.pixx / 2)) + 1; _IX < _IY; _IX++) { //#9543
            $k[$j++] = 0; //#9543
            $k[$j++] = 1; //#9543
        } //#9543
        $1.sep = $geti($a(), 0, $1.pixx); //#9543
        $puti($1.sep, 0, $a([0, 0, 0, 0])); //#9544
        $puti($1.sep, $1.pixx - 4, $a([0, 0, 0, 0])); //#9545
        $k[$j++] = Infinity; //#9557
        for (var _Ij = 0, _Ii = $1.numrows - 1; _Ij <= _Ii; _Ij += 1) { //#9559
            $1.r = _Ij; //#9550
            if ($1.r != 0) { //#9553
                $aload($get($1.seps, $1.r)); //#9552
            } //#9552
            for (var _Ip = 0, _Iq = $1.barxmult; _Ip < _Iq; _Ip++) { //#9554
                $aload($get($1.rows, $1.r)); //#9554
            } //#9554
            if ($1.r != ($1.numrows - 1)) { //#9558
                $aload($get($1.seps, $1.r)); //#9556
                $aload($1.sep); //#9557
            } //#9557
        } //#9557
        $1.pixs = $a(); //#9557
        delete $1.options["parse"]; //#9562
        var _JA = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", ~~($1.pixs.length / $1.pixx)],
            ["height", (~~($1.pixs.length / $1.pixx)) / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#9571
        $k[$j++] = _JA; //#9574
        if (!$1.dontdraw) { //#9574
            bwipp_renmatrix(); //#9574
        } //#9574
    } //#9574
}

function bwipp_databarexpandedstacked() {
    var $1 = {}; //#9609
    $1.ctx = null; //#9611
    $1.dontdraw = false; //#9612
    $k[$j++] = $1; //#9614
    bwipp_processoptions(); //#9614
    $1.options = $k[--$j]; //#9614
    $1.barcode = $k[--$j]; //#9615
    $put($1.options, "dontdraw", true); //#9618
    $put($1.options, "format", "expandedstacked"); //#9619
    $k[$j++] = 'args'; //#9621
    $k[$j++] = $1.barcode; //#9621
    $k[$j++] = $1.options; //#9621
    bwipp_databarexpanded(); //#9621
    var _6 = $k[--$j]; //#9621
    $1[$k[--$j]] = _6; //#9621
    $put($1.args, "opt", $1.options); //#9623
    $k[$j++] = $1.args; //#9626
    if (!$1.dontdraw) { //#9626
        bwipp_renmatrix(); //#9626
    } //#9626
}

function bwipp_gs1northamericancoupon() {
    var $1 = {}; //#9658
    $1.ctx = null; //#9660
    $1.dontdraw = false; //#9661
    $1.includetext = false; //#9662
    $1.coupontextfont = "OCR-B"; //#9663
    $1.coupontextsize = 9; //#9664
    $1.coupontextxoffset = null; //#9665
    $1.coupontextyoffset = null; //#9666
    $1.parse = false; //#9667
    $1.dontlint = false; //#9668
    $1.lintreqs = true; //#9669
    $k[$j++] = $1; //#9671
    bwipp_processoptions(); //#9671
    $1.options = $k[--$j]; //#9671
    $1.barcode = $k[--$j]; //#9672
    $k[$j++] = $1.barcode; //#9674
    $k[$j++] = 'ai'; //#9674
    bwipp_gs1process(); //#9674
    $j--; //#9675
    $1.vals = $k[--$j]; //#9676
    $1.ais = $k[--$j]; //#9677
    if ($1.ais.length != 1) { //#9682
        $k[$j++] = 'bwipp.gs1northamericancouponBadAIStructure'; //#9681
        $k[$j++] = "A GS1 North American Coupon should consist of a single AI (8110)"; //#9681
        bwipp_raiseerror(); //#9681
    } //#9681
    if ($ne($get($1.ais, 0), "8110")) { //#9685
        $k[$j++] = 'bwipp.gs1northamericancouponBadAIStructure'; //#9684
        $k[$j++] = "A GS1 North American Coupon should consist of a single AI (8110)"; //#9684
        bwipp_raiseerror(); //#9684
    } //#9684
    $1.val = $get($1.vals, 0); //#9688
    $1.vli = $f($get($1.val, 0) - 48); //#9689
    if (($1.vli < 0) || ($1.vli > 6)) { //#9692
        $k[$j++] = 'bwipp.gs1northamericancouponBadVLI'; //#9691
        $k[$j++] = "The AI (8110) data should start with a Company Prefix length indicator in the range 0 to 6"; //#9691
        bwipp_raiseerror(); //#9691
    } //#9691
    $1.gcp = $geti($1.val, 1, $f($1.vli + 6)); //#9693
    $1.cod = $geti($1.val, $f($1.vli + 7), 6); //#9694
    $1.coupontext = $s($1.gcp.length + 7); //#9695
    $puti($1.coupontext, 0, $1.gcp); //#9696
    $puti($1.coupontext, $1.gcp.length, "-"); //#9697
    $puti($1.coupontext, $1.gcp.length + 1, $1.cod); //#9698
    delete $1.options["parse"]; //#9701
    $put($1.options, "dontdraw", true); //#9702
    $k[$j++] = 'args'; //#9704
    $k[$j++] = $1.barcode; //#9704
    $k[$j++] = $1.options; //#9704
    bwipp_databarexpandedstacked(); //#9704
    var _X = $k[--$j]; //#9704
    $1[$k[--$j]] = _X; //#9704
    if ($1.includetext) { //#9723
        if ($eq($1.coupontextxoffset, null)) { //#9710
            $1.coupontextxoffset = 0; //#9709
        } //#9709
        if ($eq($1.coupontextyoffset, null)) { //#9713
            $1.coupontextyoffset = $f(($get($1.args, "height") * 72) + 3); //#9712
        } //#9712
        var _f = $get($1.args, "txt") !== undefined; //#9714
        if (_f) { //#9721
            $1.txt = $get($1.args, "txt"); //#9715
            $1.newtxt = $a($1.txt.length + 1); //#9716
            $puti($1.newtxt, 0, $1.txt); //#9717
            $put($1.newtxt, $1.newtxt.length - 1, $a([$1.coupontext, $1.coupontextxoffset, $1.coupontextyoffset, $1.coupontextfont, $1.coupontextsize])); //#9718
            $put($1.args, "txt", $1.newtxt); //#9719
        } else { //#9721
            $put($1.args, "txt", $a([$a([$1.coupontext, $1.coupontextxoffset, $1.coupontextyoffset, $1.coupontextfont, $1.coupontextsize])])); //#9721
        } //#9721
    } //#9721
    $put($1.args, "opt", $1.options); //#9725
    $k[$j++] = $1.args; //#9728
    if (!$1.dontdraw) { //#9728
        bwipp_renmatrix(); //#9728
    } //#9728
}

function bwipp_pharmacode() {
    var $1 = {}; //#9758
    $1.ctx = null; //#9760
    $1.dontdraw = false; //#9761
    $1.height = (8 * 2.835) / 72; //#9762
    $1.nwidth = 0.5 * 2.835; //#9763
    $1.wwidth = 1.5 * 2.835; //#9764
    $1.swidth = 1 * 2.835; //#9765
    $k[$j++] = $1; //#9767
    bwipp_processoptions(); //#9767
    $1.options = $k[--$j]; //#9767
    $1.barcode = $k[--$j]; //#9768
    if (($1.barcode.length < 1) || ($1.barcode.length > 6)) { //#9773
        $k[$j++] = 'bwipp.pharmacodeBadLength'; //#9772
        $k[$j++] = "Pharmacode must be 1 to 6 digits"; //#9772
        bwipp_raiseerror(); //#9772
    } //#9772
    $forall($1.barcode, function() { //#9778
        var _5 = $k[--$j]; //#9775
        if ((_5 < 48) || (_5 > 57)) { //#9777
            $k[$j++] = 'bwipp.pharmacodeBadCharacter'; //#9776
            $k[$j++] = "Pharmacode must contain only digits"; //#9776
            bwipp_raiseerror(); //#9776
        } //#9776
    }); //#9776
    var _7 = $cvi($1.barcode); //#9779
    if ((_7 < 3) || (_7 > 131070)) { //#9781
        $k[$j++] = 'bwipp.pharmacodeBadValue'; //#9780
        $k[$j++] = "Pharmacode value must be between 3 and 131070"; //#9780
        bwipp_raiseerror(); //#9780
    } //#9780
    $1.txt = $a($1.barcode.length); //#9784
    for (var _C = 0, _B = $1.barcode.length - 1; _C <= _B; _C += 1) { //#9788
        $1.i = _C; //#9786
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#9787
    } //#9787
    $1.barcode = $cvrs($s(17), $cvi($1.barcode) + 1, 2); //#9791
    $1.barcode = $geti($1.barcode, 1, $1.barcode.length - 1); //#9792
    $1.barlen = $1.barcode.length; //#9794
    $1.sbs = $a($1.barlen * 2); //#9795
    for (var _U = 0, _T = $1.barlen - 1; _U <= _T; _U += 1) { //#9806
        $1.i = _U; //#9798
        $1.enc = $geti($1.barcode, $1.i, 1); //#9799
        if ($eq($1.enc, "0")) { //#9803
            $put($1.sbs, $1.i * 2, $1.nwidth); //#9801
        } else { //#9803
            $put($1.sbs, $1.i * 2, $1.wwidth); //#9803
        } //#9803
        $put($1.sbs, ($1.i * 2) + 1, $1.swidth); //#9805
    } //#9805
    $k[$j++] = Infinity; //#9816
    var _i = $1.sbs; //#9811
    $k[$j++] = Infinity; //#9812
    for (var _k = 0, _l = ~~(($1.sbs.length + 1) / 2); _k < _l; _k++) { //#9812
        $k[$j++] = $1.height; //#9812
    } //#9812
    var _n = $a(); //#9812
    $k[$j++] = Infinity; //#9813
    for (var _p = 0, _q = ~~(($1.sbs.length + 1) / 2); _p < _q; _p++) { //#9813
        $k[$j++] = 0; //#9813
    } //#9813
    var _r = $a(); //#9813
    $k[$j++] = 'ren'; //#9816
    $k[$j++] = bwipp_renlinear; //#9816
    $k[$j++] = 'sbs'; //#9816
    $k[$j++] = _i; //#9816
    $k[$j++] = 'bhs'; //#9816
    $k[$j++] = _n; //#9816
    $k[$j++] = 'bbs'; //#9816
    $k[$j++] = _r; //#9816
    $k[$j++] = 'txt'; //#9816
    $k[$j++] = $1.txt; //#9816
    $k[$j++] = 'textxalign'; //#9816
    $k[$j++] = "center"; //#9816
    $k[$j++] = 'opt'; //#9816
    $k[$j++] = $1.options; //#9816
    var _u = $d(); //#9816
    $k[$j++] = _u; //#9819
    if (!$1.dontdraw) { //#9819
        bwipp_renlinear(); //#9819
    } //#9819
}

function bwipp_pharmacode2() {
    var $1 = {}; //#9849
    $1.ctx = null; //#9851
    $1.dontdraw = false; //#9852
    $1.includetext = false; //#9853
    $1.height = 4; //#9854
    $k[$j++] = $1; //#9856
    bwipp_processoptions(); //#9856
    $1.options = $k[--$j]; //#9856
    $1.barcode = $k[--$j]; //#9857
    if (($1.barcode.length < 1) || ($1.barcode.length > 8)) { //#9862
        $k[$j++] = 'bwipp.pharmacode2BadLength'; //#9861
        $k[$j++] = "Two-track Pharmacode must be 1 to 6 digits"; //#9861
        bwipp_raiseerror(); //#9861
    } //#9861
    $forall($1.barcode, function() { //#9867
        var _5 = $k[--$j]; //#9864
        if ((_5 < 48) || (_5 > 57)) { //#9866
            $k[$j++] = 'bwipp.pharmacode2badCharacter'; //#9865
            $k[$j++] = "Two-track Pharmacode must contain only digits"; //#9865
            bwipp_raiseerror(); //#9865
        } //#9865
    }); //#9865
    var _7 = $cvi($1.barcode); //#9868
    if ((_7 < 4) || (_7 > 64570080)) { //#9870
        $k[$j++] = 'bwipp.pharmacode2badValue'; //#9869
        $k[$j++] = "Two-track Pharmacode value must be between 4 and 64570080"; //#9869
        bwipp_raiseerror(); //#9869
    } //#9869
    $1.txt = $a($1.barcode.length); //#9873
    for (var _C = 0, _B = $1.barcode.length - 1; _C <= _B; _C += 1) { //#9877
        $1.i = _C; //#9875
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#9876
    } //#9876
    $1.encstr = $s(16); //#9879
    $1.sbs = $a(32); //#9880
    $1.bar = (1 / 25.4) * $1.height; //#9881
    $1.spc = (1 / 25.4) * 72; //#9882
    $1.i = 15; //#9885
    $1.val = $cvi($1.barcode); //#9886
    for (;;) { //#9893
        if ($1.val == 0) { //#9888
            break; //#9888
        } //#9888
        var _P = $1.val % 3; //#9889
        $1.val = ~~($f($1.val - $get($a([3, 1, 2]), _P)) / 3); //#9890
        $put($1.encstr, $1.i, $get($a([2, 0, 1]), _P)); //#9891
        $1.i = $1.i - 1; //#9892
    } //#9892
    $1.encstr = $geti($1.encstr, $1.i + 1, 15 - $1.i); //#9894
    $1.bhs = $a($1.encstr.length); //#9897
    $1.bbs = $a($1.encstr.length); //#9898
    for (var _i = 0, _h = $1.encstr.length - 1; _i <= _h; _i += 1) { //#9904
        $1.i = _i; //#9900
        var _l = $get($1.encstr, $1.i); //#9901
        $put($1.bhs, $1.i, $1.bar * $get($a([1, 1, 2]), _l)); //#9902
        $put($1.bbs, $1.i, $get($a([0, $1.bar, 0]), _l)); //#9903
    } //#9903
    $k[$j++] = Infinity; //#9915
    var _w = $1.bhs; //#9909
    var _x = $1.bbs; //#9910
    $k[$j++] = Infinity; //#9911
    for (var _z = 0, _10 = $1.encstr.length * 2; _z < _10; _z++) { //#9911
        $k[$j++] = $1.spc; //#9911
    } //#9911
    var _12 = $a(); //#9911
    $k[$j++] = 'ren'; //#9915
    $k[$j++] = bwipp_renlinear; //#9915
    $k[$j++] = 'bhs'; //#9915
    $k[$j++] = _w; //#9915
    $k[$j++] = 'bbs'; //#9915
    $k[$j++] = _x; //#9915
    $k[$j++] = 'sbs'; //#9915
    $k[$j++] = _12; //#9915
    $k[$j++] = 'txt'; //#9915
    $k[$j++] = $1.txt; //#9915
    $k[$j++] = 'textxalign'; //#9915
    $k[$j++] = "center"; //#9915
    $k[$j++] = 'textyoffset'; //#9915
    $k[$j++] = 4; //#9915
    $k[$j++] = 'opt'; //#9915
    $k[$j++] = $1.options; //#9915
    var _15 = $d(); //#9915
    $k[$j++] = _15; //#9918
    if (!$1.dontdraw) { //#9918
        bwipp_renlinear(); //#9918
    } //#9918
}

function bwipp_code2of5() {
    var $1 = {}; //#9950
    $1.ctx = null; //#9952
    $1.dontdraw = false; //#9953
    $1.includecheck = false; //#9954
    $1.validatecheck = false; //#9955
    $1.includetext = false; //#9956
    $1.includecheckintext = false; //#9957
    $1.textfont = "OCR-B"; //#9958
    $1.textsize = 10; //#9959
    $1.textyoffset = -8; //#9960
    $1.height = 1; //#9961
    $1.version = "industrial"; //#9962
    $k[$j++] = $1; //#9964
    bwipp_processoptions(); //#9964
    $1.options = $k[--$j]; //#9964
    $1.barcode = $k[--$j]; //#9965
    $forall($1.barcode, function() { //#9974
        var _3 = $k[--$j]; //#9971
        if ((_3 < 48) || (_3 > 57)) { //#9973
            $k[$j++] = 'bwipp.code2of5badCharacter'; //#9972
            $k[$j++] = "Code 25 must contain only digits"; //#9972
            bwipp_raiseerror(); //#9972
        } //#9972
    }); //#9972
    $k[$j++] = 'barlen'; //#9976
    $k[$j++] = $1.barcode.length; //#9976
    if ($1.validatecheck) { //#9976
        var _6 = $k[--$j]; //#9976
        $k[$j++] = $f(_6 - 1); //#9976
    } //#9976
    var _7 = $k[--$j]; //#9976
    $1[$k[--$j]] = _7; //#9976
    $1.checksum = 0; //#9978
    for (var _B = 0, _A = $f($1.barlen - 1); _B <= _A; _B += 1) { //#9982
        $1.i = _B; //#9980
        $k[$j++] = 'checksum'; //#9981
        $k[$j++] = $1.checksum; //#9981
        $k[$j++] = $f($get($1.barcode, $1.i) - 48); //#9981
        if (($f($1.barlen - $1.i) % 2) != 0) { //#9981
            var _I = $k[--$j]; //#9981
            $k[$j++] = _I * 3; //#9981
        } //#9981
        var _J = $k[--$j]; //#9981
        var _K = $k[--$j]; //#9981
        $1[$k[--$j]] = $f(_K + _J); //#9981
    } //#9981
    $1.checksum = (10 - ($1.checksum % 10)) % 10; //#9983
    if ($1.validatecheck) { //#9990
        if ($get($1.barcode, $1.barlen) != ($1.checksum + 48)) { //#9987
            $k[$j++] = 'bwipp.code2of5badCheckDigit'; //#9986
            $k[$j++] = "Incorrect Code 25 check digit provided"; //#9986
            bwipp_raiseerror(); //#9986
        } //#9986
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#9988
        $1.includecheck = true; //#9989
    } //#9989
    var _a = new Map([
        ["industrial", $a(["1111313111", "3111111131", "1131111131", "3131111111", "1111311131", "3111311111", "1131311111", "1111113131", "3111113111", "1131113111", "313111", "31113"])],
        ["iata", $a(["1111313111", "3111111131", "1131111131", "3131111111", "1111311131", "3111311111", "1131311111", "1111113131", "3111113111", "1131113111", "1111", "311"])],
        ["matrix", $a(["113311", "311131", "131131", "331111", "113131", "313111", "133111", "111331", "311311", "131311", "311111", "31111"])],
        ["coop", $a(["331111", "111331", "113131", "113311", "131131", "131311", "133111", "311131", "311311", "313111", "3131", "133"])],
        ["datalogic", $a(["113311", "311131", "131131", "331111", "113131", "313111", "133111", "111331", "311311", "131311", "1111", "311"])]
    ]); //#10015
    $1.versions = _a; //#10017
    var _d = $get($1.versions, $1.version) !== undefined; //#10020
    if (!_d) { //#10022
        $k[$j++] = 'bwipp.code2of5badVersion'; //#10021
        $k[$j++] = "Unrecognised Code 25 version"; //#10021
        bwipp_raiseerror(); //#10021
    } //#10021
    $1.encs = $get($1.versions, $1.version); //#10023
    $1.cs = $get($1.encs, 0).length; //#10025
    $k[$j++] = 'cw'; //#10026
    $k[$j++] = 0; //#10026
    $forall($get($1.encs, 0), function() { //#10026
        var _l = $k[--$j]; //#10026
        var _m = $k[--$j]; //#10026
        $k[$j++] = $f(_m + $f(_l - 48)); //#10026
    }); //#10026
    var _n = $k[--$j]; //#10026
    $1[$k[--$j]] = _n; //#10026
    $1.ss = $get($1.encs, 10).length; //#10027
    $k[$j++] = 'sw'; //#10028
    $k[$j++] = 0; //#10028
    $forall($get($1.encs, 10), function() { //#10028
        var _t = $k[--$j]; //#10028
        var _u = $k[--$j]; //#10028
        $k[$j++] = $f(_u + $f(_t - 48)); //#10028
    }); //#10028
    var _v = $k[--$j]; //#10028
    $1[$k[--$j]] = _v; //#10028
    $1.es = $get($1.encs, 11).length; //#10029
    $1.barchars = "0123456789"; //#10033
    $k[$j++] = 'sbs'; //#10036
    $k[$j++] = $1.barlen; //#10036
    if ($1.includecheck) { //#10036
        var _11 = $k[--$j]; //#10036
        $k[$j++] = $f(_11 + 1); //#10036
    } //#10036
    var _16 = $s($f(($f(($k[--$j] * $1.cs) + $1.ss)) + $1.es)); //#10036
    $1[$k[--$j]] = _16; //#10036
    $k[$j++] = 'txt'; //#10037
    $k[$j++] = $1.barlen; //#10037
    if ($1.includecheck) { //#10037
        var _1A = $k[--$j]; //#10037
        $k[$j++] = $f(_1A + 1); //#10037
    } //#10037
    var _1C = $a($k[--$j]); //#10037
    $1[$k[--$j]] = _1C; //#10037
    $puti($1.sbs, 0, $get($1.encs, 10)); //#10040
    for (var _1J = 0, _1I = $f($1.barlen - 1); _1J <= _1I; _1J += 1) { //#10051
        $1.i = _1J; //#10042
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#10044
        $j--; //#10045
        $1.indx = $k[--$j].length; //#10046
        $j -= 2; //#10047
        $1.enc = $get($1.encs, $1.indx); //#10048
        $puti($1.sbs, ($1.i * $1.cs) + $1.ss, $1.enc); //#10049
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), $f(($1.i * $1.cw) + $1.sw), $1.textyoffset, $1.textfont, $1.textsize])); //#10050
    } //#10050
    if ($1.includecheck) { //#10063
        $puti($1.sbs, $f(($1.barlen * $1.cs) + $1.ss), $get($1.encs, $1.checksum)); //#10055
        $puti($1.sbs, $f(($f(($1.barlen * $1.cs) + $1.cs)) + $1.ss), $get($1.encs, 11)); //#10056
        if ($1.includecheckintext) { //#10060
            $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum, 1), $f(($1.barlen * $1.cw) + $1.sw), $1.textyoffset, $1.textfont, $1.textsize])); //#10058
        } else { //#10060
            $put($1.txt, $1.barlen, $a([" ", $f(($1.barlen * $1.cw) + $1.sw), $1.textyoffset, $1.textfont, $1.textsize])); //#10060
        } //#10060
    } else { //#10063
        $puti($1.sbs, $f(($1.barlen * $1.cs) + $1.ss), $get($1.encs, 11)); //#10063
    } //#10063
    $k[$j++] = Infinity; //#10075
    $k[$j++] = Infinity; //#10069
    $forall($1.sbs, function() { //#10069
        var _2R = $k[--$j]; //#10069
        $k[$j++] = $f(_2R - 48); //#10069
    }); //#10069
    var _2S = $a(); //#10069
    $k[$j++] = Infinity; //#10070
    for (var _2U = 0, _2V = ~~(($1.sbs.length + 1) / 2); _2U < _2V; _2U++) { //#10070
        $k[$j++] = $1.height; //#10070
    } //#10070
    var _2X = $a(); //#10070
    $k[$j++] = Infinity; //#10071
    for (var _2Z = 0, _2a = ~~(($1.sbs.length + 1) / 2); _2Z < _2a; _2Z++) { //#10071
        $k[$j++] = 0; //#10071
    } //#10071
    var _2b = $a(); //#10071
    $k[$j++] = 'ren'; //#10074
    $k[$j++] = bwipp_renlinear; //#10074
    $k[$j++] = 'sbs'; //#10074
    $k[$j++] = _2S; //#10074
    $k[$j++] = 'bhs'; //#10074
    $k[$j++] = _2X; //#10074
    $k[$j++] = 'bbs'; //#10074
    $k[$j++] = _2b; //#10074
    if ($1.includetext) { //#10074
        $k[$j++] = 'txt'; //#10073
        $k[$j++] = $1.txt; //#10073
    } //#10073
    $k[$j++] = 'opt'; //#10075
    $k[$j++] = $1.options; //#10075
    var _2f = $d(); //#10075
    $k[$j++] = _2f; //#10078
    if (!$1.dontdraw) { //#10078
        bwipp_renlinear(); //#10078
    } //#10078
}

function bwipp_industrial2of5() {
    var $1 = {}; //#10111
    $1.ctx = null; //#10113
    $1.dontdraw = false; //#10114
    $1.includetext = false; //#10115
    $1.textfont = "OCR-B"; //#10116
    $1.textsize = 10; //#10117
    $1.textxoffset = 0; //#10118
    $1.textyoffset = -8; //#10119
    $1.height = 1; //#10120
    $k[$j++] = $1; //#10122
    bwipp_processoptions(); //#10122
    $1.options = $k[--$j]; //#10122
    $1.barcode = $k[--$j]; //#10123
    $put($1.options, "dontdraw", true); //#10126
    $put($1.options, "version", "industrial"); //#10127
    $k[$j++] = 'args'; //#10129
    $k[$j++] = $1.barcode; //#10129
    $k[$j++] = $1.options; //#10129
    bwipp_code2of5(); //#10129
    var _6 = $k[--$j]; //#10129
    $1[$k[--$j]] = _6; //#10129
    $put($1.args, "opt", $1.options); //#10131
    $k[$j++] = $1.args; //#10134
    if (!$1.dontdraw) { //#10134
        bwipp_renlinear(); //#10134
    } //#10134
}

function bwipp_iata2of5() {
    var $1 = {}; //#10165
    $1.ctx = null; //#10167
    $1.dontdraw = false; //#10168
    $1.includetext = false; //#10169
    $1.textfont = "OCR-B"; //#10170
    $1.textsize = 10; //#10171
    $1.textxoffset = 0; //#10172
    $1.textyoffset = -8; //#10173
    $1.height = 1; //#10174
    $k[$j++] = $1; //#10176
    bwipp_processoptions(); //#10176
    $1.options = $k[--$j]; //#10176
    $1.barcode = $k[--$j]; //#10177
    $put($1.options, "dontdraw", true); //#10180
    $put($1.options, "version", "iata"); //#10181
    $k[$j++] = 'args'; //#10183
    $k[$j++] = $1.barcode; //#10183
    $k[$j++] = $1.options; //#10183
    bwipp_code2of5(); //#10183
    var _6 = $k[--$j]; //#10183
    $1[$k[--$j]] = _6; //#10183
    $put($1.args, "opt", $1.options); //#10185
    $k[$j++] = $1.args; //#10188
    if (!$1.dontdraw) { //#10188
        bwipp_renlinear(); //#10188
    } //#10188
}

function bwipp_matrix2of5() {
    var $1 = {}; //#10219
    $1.ctx = null; //#10221
    $1.dontdraw = false; //#10222
    $1.includetext = false; //#10223
    $1.textfont = "OCR-B"; //#10224
    $1.textsize = 10; //#10225
    $1.textxoffset = 0; //#10226
    $1.textyoffset = -8; //#10227
    $1.height = 1; //#10228
    $k[$j++] = $1; //#10230
    bwipp_processoptions(); //#10230
    $1.options = $k[--$j]; //#10230
    $1.barcode = $k[--$j]; //#10231
    $put($1.options, "dontdraw", true); //#10234
    $put($1.options, "version", "matrix"); //#10235
    $k[$j++] = 'args'; //#10237
    $k[$j++] = $1.barcode; //#10237
    $k[$j++] = $1.options; //#10237
    bwipp_code2of5(); //#10237
    var _6 = $k[--$j]; //#10237
    $1[$k[--$j]] = _6; //#10237
    $put($1.args, "opt", $1.options); //#10239
    $k[$j++] = $1.args; //#10242
    if (!$1.dontdraw) { //#10242
        bwipp_renlinear(); //#10242
    } //#10242
}

function bwipp_coop2of5() {
    var $1 = {}; //#10273
    $1.ctx = null; //#10275
    $1.dontdraw = false; //#10276
    $1.includetext = false; //#10277
    $1.textfont = "OCR-B"; //#10278
    $1.textsize = 10; //#10279
    $1.textxoffset = 0; //#10280
    $1.textyoffset = -8; //#10281
    $1.height = 1; //#10282
    $k[$j++] = $1; //#10284
    bwipp_processoptions(); //#10284
    $1.options = $k[--$j]; //#10284
    $1.barcode = $k[--$j]; //#10285
    $put($1.options, "dontdraw", true); //#10288
    $put($1.options, "version", "coop"); //#10289
    $k[$j++] = 'args'; //#10291
    $k[$j++] = $1.barcode; //#10291
    $k[$j++] = $1.options; //#10291
    bwipp_code2of5(); //#10291
    var _6 = $k[--$j]; //#10291
    $1[$k[--$j]] = _6; //#10291
    $put($1.args, "opt", $1.options); //#10293
    $k[$j++] = $1.args; //#10296
    if (!$1.dontdraw) { //#10296
        bwipp_renlinear(); //#10296
    } //#10296
}

function bwipp_datalogic2of5() {
    var $1 = {}; //#10327
    $1.ctx = null; //#10329
    $1.dontdraw = false; //#10330
    $1.includetext = false; //#10331
    $1.textfont = "OCR-B"; //#10332
    $1.textsize = 10; //#10333
    $1.textxoffset = 0; //#10334
    $1.textyoffset = -8; //#10335
    $1.height = 1; //#10336
    $k[$j++] = $1; //#10338
    bwipp_processoptions(); //#10338
    $1.options = $k[--$j]; //#10338
    $1.barcode = $k[--$j]; //#10339
    $put($1.options, "dontdraw", true); //#10342
    $put($1.options, "version", "datalogic"); //#10343
    $k[$j++] = 'args'; //#10345
    $k[$j++] = $1.barcode; //#10345
    $k[$j++] = $1.options; //#10345
    bwipp_code2of5(); //#10345
    var _6 = $k[--$j]; //#10345
    $1[$k[--$j]] = _6; //#10345
    $put($1.args, "opt", $1.options); //#10347
    $k[$j++] = $1.args; //#10350
    if (!$1.dontdraw) { //#10350
        bwipp_renlinear(); //#10350
    } //#10350
}

function bwipp_code11() {
    var $1 = {}; //#10382
    $1.ctx = null; //#10384
    $1.dontdraw = false; //#10385
    $1.includecheck = false; //#10386
    $1.validatecheck = false; //#10387
    $1.includetext = false; //#10388
    $1.includecheckintext = false; //#10389
    $1.textfont = "OCR-B"; //#10390
    $1.textsize = 10; //#10391
    $1.textyoffset = -8; //#10392
    $1.height = 1; //#10393
    $k[$j++] = $1; //#10395
    bwipp_processoptions(); //#10395
    $1.options = $k[--$j]; //#10395
    $1.barcode = $k[--$j]; //#10396
    $1.encs = $a(["111131", "311131", "131131", "331111", "113131", "313111", "133111", "111331", "311311", "311111", "113111", "113311"]); //#10406
    $1.barchars = "0123456789-"; //#10409
    $1.charvals = new Map; //#10410
    for (var _3 = 0; _3 <= 10; _3 += 1) { //#10411
        $put($1.charvals, $geti($1.barchars, _3, 1), _3); //#10411
    } //#10411
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#10419
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#10416
        if (!_D) { //#10418
            $k[$j++] = 'bwipp.code11badCharacter'; //#10417
            $k[$j++] = "Code 11 must contain only digits and dashes"; //#10417
            bwipp_raiseerror(); //#10417
        } //#10417
    } //#10417
    $1.barlen = $1.barcode.length; //#10421
    if ($1.validatecheck) { //#10427
        if ($1.barlen == 11) { //#10425
            $k[$j++] = 'bwipp.code11badLength'; //#10424
            $k[$j++] = "Code 11 cannot be 11 characters using check digits"; //#10424
            bwipp_raiseerror(); //#10424
        } //#10424
        var _J = ($1.barlen <= 10) ? 1 : 2; //#10426
        $1.barlen = $1.barlen - _J; //#10426
    } //#10426
    $k[$j++] = 'numchecks'; //#10429
    if ($1.includecheck || $1.validatecheck) { //#10429
        var _N = ($1.barlen >= 10) ? 2 : 1; //#10429
        $k[$j++] = _N; //#10429
    } else { //#10429
        $k[$j++] = 0; //#10429
    } //#10429
    var _O = $k[--$j]; //#10429
    $1[$k[--$j]] = _O; //#10429
    $1.checksum1 = 0; //#10430
    $1.checksum2 = 0; //#10430
    for (var _S = 0, _R = $1.barlen - 1; _S <= _R; _S += 1) { //#10436
        $1.i = _S; //#10432
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#10433
        $1.checksum1 = $f($1.checksum1 + ((((($1.barlen - $1.i) - 1) % 10) + 1) * $1.indx)); //#10434
        $1.checksum2 = $f($1.checksum2 + (((($1.barlen - $1.i) % 9) + 1) * $1.indx)); //#10435
    } //#10435
    $1.checksum1 = $1.checksum1 % 11; //#10437
    $1.checksum2 = $f($1.checksum2 + $1.checksum1) % 11; //#10438
    if ($1.validatecheck) { //#10452
        if ($1.numchecks == 1) { //#10447
            if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum1)) { //#10443
                $k[$j++] = 'bwipp.code11badCheckDigit'; //#10442
                $k[$j++] = "Incorrect Code 11 check digit provided"; //#10442
                bwipp_raiseerror(); //#10442
            } //#10442
        } else { //#10447
            var _r = $1.barcode; //#10445
            if (($get(_r, $1.barlen) != $get($1.barchars, $1.checksum1)) || ($get($1.barcode, $1.barlen + 1) != $get($1.barchars, $1.checksum2))) { //#10448
                $k[$j++] = 'bwipp.code11badCheckDigits'; //#10447
                $k[$j++] = "Incorrect Code 11 check digits provided"; //#10447
                bwipp_raiseerror(); //#10447
            } //#10447
        } //#10447
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#10450
        $1.includecheck = true; //#10451
    } //#10451
    $1.sbs = $s($f(($f($1.barlen + $1.numchecks) * 6) + 12)); //#10454
    $1.txt = $a($f($1.barlen + $1.numchecks)); //#10455
    $puti($1.sbs, 0, $get($1.encs, 11)); //#10458
    $1.xpos = 8; //#10460
    for (var _1H = 0, _1G = $1.barlen - 1; _1H <= _1G; _1H += 1) { //#10470
        $1.i = _1H; //#10462
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#10463
        $1.enc = $get($1.encs, $1.indx); //#10464
        $puti($1.sbs, ($1.i * 6) + 6, $1.enc); //#10465
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10466
        for (var _1d = 0; _1d <= 5; _1d += 1) { //#10469
            $1.xpos = $f($f($get($1.enc, _1d) - 48) + $1.xpos); //#10468
        } //#10468
    } //#10468
    if ($1.includecheck) { //#10499
        if ($1.barlen >= 10) { //#10496
            $puti($1.sbs, ($1.barlen * 6) + 6, $get($1.encs, $1.checksum1)); //#10475
            $puti($1.sbs, ($1.barlen * 6) + 12, $get($1.encs, $1.checksum2)); //#10476
            if ($1.includecheckintext) { //#10486
                $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum1, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10478
                $1.enc = $get($1.encs, $1.checksum1); //#10479
                for (var _27 = 0; _27 <= 5; _27 += 1) { //#10482
                    $1.xpos = $f($f($get($1.enc, _27) - 48) + $1.xpos); //#10481
                } //#10481
                $put($1.txt, $1.barlen + 1, $a([$geti($1.barchars, $1.checksum2, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10483
            } else { //#10486
                $put($1.txt, $1.barlen, $a(["", $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10485
                $put($1.txt, $1.barlen + 1, $a(["", $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10486
            } //#10486
            $puti($1.sbs, ($1.barlen * 6) + 18, $get($1.encs, 11)); //#10488
        } else { //#10496
            $puti($1.sbs, ($1.barlen * 6) + 6, $get($1.encs, $1.checksum1)); //#10490
            if ($1.includecheckintext) { //#10494
                $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum1, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10492
            } else { //#10494
                $put($1.txt, $1.barlen, $a(["", $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10494
            } //#10494
            $puti($1.sbs, ($1.barlen * 6) + 12, $get($1.encs, 11)); //#10496
        } //#10496
    } else { //#10499
        $puti($1.sbs, ($1.barlen * 6) + 6, $get($1.encs, 11)); //#10499
    } //#10499
    $k[$j++] = Infinity; //#10511
    $k[$j++] = Infinity; //#10505
    var _38 = $1.sbs; //#10505
    for (var _39 = 0, _3A = _38.length; _39 < _3A; _39++) { //#10505
        $k[$j++] = $get(_38, _39) - 48; //#10505
    } //#10505
    var _3C = $a(); //#10505
    $k[$j++] = Infinity; //#10506
    for (var _3E = 0, _3F = ~~(($1.sbs.length + 1) / 2); _3E < _3F; _3E++) { //#10506
        $k[$j++] = $1.height; //#10506
    } //#10506
    var _3H = $a(); //#10506
    $k[$j++] = Infinity; //#10507
    for (var _3J = 0, _3K = ~~(($1.sbs.length + 1) / 2); _3J < _3K; _3J++) { //#10507
        $k[$j++] = 0; //#10507
    } //#10507
    var _3L = $a(); //#10507
    $k[$j++] = 'ren'; //#10510
    $k[$j++] = bwipp_renlinear; //#10510
    $k[$j++] = 'sbs'; //#10510
    $k[$j++] = _3C; //#10510
    $k[$j++] = 'bhs'; //#10510
    $k[$j++] = _3H; //#10510
    $k[$j++] = 'bbs'; //#10510
    $k[$j++] = _3L; //#10510
    if ($1.includetext) { //#10510
        $k[$j++] = 'txt'; //#10509
        $k[$j++] = $1.txt; //#10509
    } //#10509
    $k[$j++] = 'opt'; //#10511
    $k[$j++] = $1.options; //#10511
    var _3P = $d(); //#10511
    $k[$j++] = _3P; //#10514
    if (!$1.dontdraw) { //#10514
        bwipp_renlinear(); //#10514
    } //#10514
}

function bwipp_bc412() {
    var $1 = {}; //#10548
    $1.ctx = null; //#10550
    $1.dontdraw = false; //#10551
    $1.includecheck = false; //#10552
    $1.validatecheck = false; //#10553
    $1.includetext = false; //#10554
    $1.includecheckintext = false; //#10555
    $1.includestartstop = false; //#10556
    $1.semi = false; //#10557
    $1.textfont = "OCR-B"; //#10558
    $1.textsize = 10; //#10559
    $1.textyoffset = -8; //#10560
    $1.height = 1; //#10561
    $k[$j++] = $1; //#10563
    bwipp_processoptions(); //#10563
    $1.options = $k[--$j]; //#10563
    $1.barcode = $k[--$j]; //#10564
    if ($1.semi) { //#10569
        $1.includestartstop = true; //#10568
    } //#10568
    $1.barchars = "0R9GLVHA8EZ4NTS1J2Q6C7DYKBUIX3FWP5M"; //#10575
    $1.charvals = new Map; //#10576
    for (var _3 = 0; _3 <= 34; _3 += 1) { //#10577
        $put($1.charvals, $geti($1.barchars, _3, 1), _3); //#10577
    } //#10577
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#10585
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#10582
        if (!_D) { //#10584
            $k[$j++] = 'bwipp.bc412badCharacter'; //#10583
            $k[$j++] = "BC412 must contain only digits and capital letters except O"; //#10583
            bwipp_raiseerror(); //#10583
        } //#10583
    } //#10583
    if ($1.semi) { //#10641
        if ($1.validatecheck) { //#10595
            if (($1.barcode.length < 8) || ($1.barcode.length > 19)) { //#10592
                $k[$j++] = 'bwipp.bc412semivalidateBadLength'; //#10591
                $k[$j++] = "BC412 semi with check digit must be 8 to 19 characters long"; //#10591
                bwipp_raiseerror(); //#10591
            } //#10591
        } else { //#10595
            if (($1.barcode.length < 7) || ($1.barcode.length > 18)) { //#10596
                $k[$j++] = 'bwipp.bc412semiBadLength'; //#10595
                $k[$j++] = "BC412 semi must be 7 to 18 characters long"; //#10595
                bwipp_raiseerror(); //#10595
            } //#10595
        } //#10595
        $1.barlen = $1.barcode.length; //#10599
        if (!$1.validatecheck) { //#10607
            $1.barlen = $1.barlen + 1; //#10601
            $1.sbarcode = $s($1.barlen); //#10602
            $put($1.sbarcode, 0, $get($1.barcode, 0)); //#10603
            $put($1.sbarcode, 1, 48); //#10604
            $puti($1.sbarcode, 2, $geti($1.barcode, 1, $1.barlen - 2)); //#10605
            $1.barcode = $1.sbarcode; //#10606
        } //#10606
        $1.sumodd = 0; //#10608
        $1.sumeven = 0; //#10608
        for (var _a = 0, _Z = $1.barlen - 1; _a <= _Z; _a += 1) { //#10617
            $1.i = _a; //#10610
            $k[$j++] = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#10616
            if (($1.i % 2) == 0) { //#10615
                $1.sumodd = $f($k[--$j] + $1.sumodd); //#10613
            } else { //#10615
                $1.sumeven = $f($k[--$j] + $1.sumeven); //#10615
            } //#10615
        } //#10615
        $1.checksum = ($f(($1.sumodd % 35) + (($1.sumeven % 35) * 2))) % 35; //#10618
        if ($1.validatecheck) { //#10625
            if ($1.checksum != 0) { //#10622
                $k[$j++] = 'bwipp.bc412semiBadCheckDigit'; //#10621
                $k[$j++] = "Incorrect BC412 semi check digit provided"; //#10621
                bwipp_raiseerror(); //#10621
            } //#10621
        } else { //#10625
            $1.checksum = ($1.checksum * 17) % 35; //#10624
            $put($1.barcode, 1, $get($1.barchars, $1.checksum)); //#10625
        } //#10625
    } else { //#10641
        $k[$j++] = 'barlen'; //#10628
        $k[$j++] = $1.barcode.length; //#10628
        if ($1.validatecheck) { //#10628
            var _w = $k[--$j]; //#10628
            $k[$j++] = $f(_w - 1); //#10628
        } //#10628
        var _x = $k[--$j]; //#10628
        $1[$k[--$j]] = _x; //#10628
        $1.checksum = 0; //#10630
        for (var _11 = 0, _10 = $1.barlen - 1; _11 <= _10; _11 += 1) { //#10634
            $1.checksum = $f($get($1.charvals, $geti($1.barcode, _11, 1)) + $1.checksum); //#10633
        } //#10633
        $1.checksum = $1.checksum % 35; //#10635
        if ($1.validatecheck) { //#10642
            if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#10639
                $k[$j++] = 'bwipp.bc412badCheckDigit'; //#10638
                $k[$j++] = "Incorrect BC412 check digit provided"; //#10638
                bwipp_raiseerror(); //#10638
            } //#10638
            $1.barcode = $geti($1.barcode, 0, $1.barlen); //#10640
            $1.includecheck = true; //#10641
        } //#10641
    } //#10641
    $1.encs = $a(["11111115", "13111212", "11131113", "12111213", "12121311", "13131111", "12111312", "11131212", "11121411", "11151111", "15111111", "11111511", "12131211", "13121112", "13111311", "11111214", "12121113", "11111313", "13111113", "11121213", "11141112", "11121312", "11141211", "14121111", "12121212", "11131311", "13121211", "12111411", "14111211", "11111412", "12111114", "14111112", "12141111", "11121114", "12131112", "12", "111"]); //#10656
    $1.sbs = $s((($1.barlen + 1) * 8) + 5); //#10659
    if ($1.includecheck) { //#10663
        $1.txt = $a($1.barlen + 1); //#10661
    } else { //#10663
        $1.txt = $a($1.barlen); //#10663
    } //#10663
    if ($1.includestartstop) { //#10673
        $puti($1.sbs, 0, $get($1.encs, 35)); //#10668
        $1.pos = 2; //#10669
        $1.txtpos = 3; //#10670
    } else { //#10673
        $1.pos = 0; //#10672
        $1.txtpos = 0; //#10673
    } //#10673
    for (var _1W = 0, _1V = $1.barlen - 1; _1W <= _1V; _1W += 1) { //#10682
        $1.i = _1W; //#10677
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#10678
        $puti($1.sbs, $1.pos, $get($1.encs, $1.indx)); //#10679
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 12) + $1.txtpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10680
        $1.pos = $1.pos + 8; //#10681
    } //#10681
    if ($1.includecheck) { //#10693
        $puti($1.sbs, $1.pos, $get($1.encs, $1.checksum)); //#10686
        if ($1.includecheckintext) { //#10690
            $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum, 1), ($1.barlen * 12) + $1.txtpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10688
        } else { //#10690
            $put($1.txt, $1.barlen, $a(["", ($1.barlen * 12) + $1.txtpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10690
        } //#10690
        $1.pos = $1.pos + 8; //#10692
    } //#10692
    if ($1.includestartstop) { //#10699
        $puti($1.sbs, $1.pos, $get($1.encs, 36)); //#10697
        $1.pos = $1.pos + 3; //#10698
    } //#10698
    $1.sbs = $geti($1.sbs, 0, $1.pos); //#10702
    $k[$j++] = Infinity; //#10711
    $k[$j++] = Infinity; //#10705
    var _2T = $1.sbs; //#10705
    for (var _2U = 0, _2V = _2T.length; _2U < _2V; _2U++) { //#10705
        $k[$j++] = $f($get(_2T, _2U) - 48); //#10705
    } //#10705
    var _2X = $a(); //#10705
    $k[$j++] = Infinity; //#10706
    for (var _2Z = 0, _2a = ~~(($1.sbs.length + 1) / 2); _2Z < _2a; _2Z++) { //#10706
        $k[$j++] = $1.height; //#10706
    } //#10706
    var _2c = $a(); //#10706
    $k[$j++] = Infinity; //#10707
    for (var _2e = 0, _2f = ~~(($1.sbs.length + 1) / 2); _2e < _2f; _2e++) { //#10707
        $k[$j++] = 0; //#10707
    } //#10707
    var _2g = $a(); //#10707
    $k[$j++] = 'ren'; //#10710
    $k[$j++] = bwipp_renlinear; //#10710
    $k[$j++] = 'sbs'; //#10710
    $k[$j++] = _2X; //#10710
    $k[$j++] = 'bhs'; //#10710
    $k[$j++] = _2c; //#10710
    $k[$j++] = 'bbs'; //#10710
    $k[$j++] = _2g; //#10710
    if ($1.includetext) { //#10710
        $k[$j++] = 'txt'; //#10709
        $k[$j++] = $1.txt; //#10709
    } //#10709
    $k[$j++] = 'opt'; //#10711
    $k[$j++] = $1.options; //#10711
    var _2k = $d(); //#10711
    $k[$j++] = _2k; //#10714
    if (!$1.dontdraw) { //#10714
        bwipp_renlinear(); //#10714
    } //#10714
}

function bwipp_rationalizedCodabar() {
    var $1 = {}; //#10748
    $1.ctx = null; //#10750
    $1.dontdraw = false; //#10751
    $1.altstartstop = false; //#10752
    $1.includecheck = false; //#10753
    $1.validatecheck = false; //#10754
    $1.includetext = false; //#10755
    $1.includecheckintext = false; //#10756
    $1.textfont = "OCR-B"; //#10757
    $1.textsize = 10; //#10758
    $1.textyoffset = -8; //#10759
    $1.height = 1; //#10760
    $k[$j++] = $1; //#10762
    bwipp_processoptions(); //#10762
    $1.options = $k[--$j]; //#10762
    $1.barcode = $k[--$j]; //#10763
    $1.encs = $a(["11111331", "11113311", "11131131", "33111111", "11311311", "31111311", "13111131", "13113111", "13311111", "31131111", "11133111", "11331111", "31113131", "31311131", "31313111", "11313131", "11331311", "13131131", "11131331", "11133311"]); //#10774
    $1.barcharsnormal = "0123456789-$:/.+ABCD"; //#10777
    $1.barcharsalt = "0123456789-$:/.+TN*E"; //#10778
    var _4 = $1.altstartstop ? $1.barcharsalt : $1.barcharsnormal; //#10781
    $1.barchars = _4; //#10781
    $1.charvals = new Map; //#10783
    for (var _5 = 0; _5 <= 19; _5 += 1) { //#10784
        $put($1.charvals, $geti($1.barchars, _5, 1), _5); //#10784
    } //#10784
    $1.bodyvals = new Map; //#10785
    for (var _9 = 0; _9 <= 15; _9 += 1) { //#10786
        $put($1.bodyvals, $geti($1.barchars, _9, 1), _9); //#10786
    } //#10786
    $1.ssvals = new Map; //#10787
    for (var _D = 16; _D <= 19; _D += 1) { //#10788
        $put($1.ssvals, $geti($1.barchars, _D, 1), _D); //#10788
    } //#10788
    var _K = $get($1.ssvals, $geti($1.barcode, 0, 1)) !== undefined; //#10791
    var _P = $get($1.ssvals, $geti($1.barcode, $1.barcode.length - 1, 1)) !== undefined; //#10792
    if ((!_K) || (!_P)) { //#10798
        if ($1.altstartstop) { //#10796
            $k[$j++] = 'bwipp.rationalizedCodabarBadAltStartStop'; //#10794
            $k[$j++] = "Codabar start and stop characters must be one of E N T or *"; //#10794
            bwipp_raiseerror(); //#10794
        } else { //#10796
            $k[$j++] = 'bwipp.rationalizedCodabarBadStartStop'; //#10796
            $k[$j++] = "Codabar start and stop characters must be one of A B C or D"; //#10796
            bwipp_raiseerror(); //#10796
        } //#10796
    } //#10796
    for (var _T = 1, _S = $1.barcode.length - 2; _T <= _S; _T += 1) { //#10803
        var _X = $get($1.bodyvals, $geti($1.barcode, _T, 1)) !== undefined; //#10800
        if (!_X) { //#10802
            $k[$j++] = 'bwipp.rationalizedCodabarBadCharacter'; //#10801
            $k[$j++] = "Codabar body must contain only digits and symbols - $ : / . +"; //#10801
            bwipp_raiseerror(); //#10801
        } //#10801
    } //#10801
    $k[$j++] = 'barlen'; //#10805
    $k[$j++] = $1.barcode.length; //#10805
    if ($1.validatecheck) { //#10805
        var _a = $k[--$j]; //#10805
        $k[$j++] = $f(_a - 1); //#10805
    } //#10805
    var _b = $k[--$j]; //#10805
    $1[$k[--$j]] = _b; //#10805
    $1.checksum = 0; //#10807
    for (var _f = 0, _e = $f($1.barlen - 2); _f <= _e; _f += 1) { //#10811
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _f, 1)) + $1.checksum); //#10810
    } //#10810
    $1.checksum = $f($get($1.charvals, $geti($1.barcode, $1.barcode.length - 1, 1)) + $1.checksum); //#10813
    $1.checksum = ($f(16 - ($1.checksum % 16))) % 16; //#10814
    if ($1.validatecheck) { //#10824
        if ($get($1.barcode, $f($1.barlen - 1)) != $get($1.barchars, $1.checksum)) { //#10818
            $k[$j++] = 'bwipp.rationalizedCodabarBadCheckDigit'; //#10817
            $k[$j++] = "Incorrect Codabar check digit provided"; //#10817
            bwipp_raiseerror(); //#10817
        } //#10817
        var _10 = $s($1.barlen); //#10819
        $puti(_10, 0, $geti($1.barcode, 0, $f($1.barlen - 1))); //#10820
        $puti(_10, $f($1.barlen - 1), $geti($1.barcode, $1.barlen, 1)); //#10821
        $1.barcode = _10; //#10822
        $1.includecheck = true; //#10823
    } //#10823
    $k[$j++] = 'sbs'; //#10826
    $k[$j++] = $1.barlen; //#10826
    if ($1.includecheck) { //#10826
        var _1A = $k[--$j]; //#10826
        $k[$j++] = $f(_1A + 1); //#10826
    } //#10826
    var _1C = $s($k[--$j] * 8); //#10826
    $1[$k[--$j]] = _1C; //#10826
    $k[$j++] = 'txt'; //#10827
    $k[$j++] = $1.barlen; //#10827
    if ($1.includecheck) { //#10827
        var _1G = $k[--$j]; //#10827
        $k[$j++] = $f(_1G + 1); //#10827
    } //#10827
    var _1I = $a($k[--$j]); //#10827
    $1[$k[--$j]] = _1I; //#10827
    $1.xpos = 0; //#10829
    for (var _1M = 0, _1L = $f($1.barlen - 2); _1M <= _1L; _1M += 1) { //#10839
        $1.i = _1M; //#10831
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#10832
        $1.enc = $get($1.encs, $1.indx); //#10833
        $puti($1.sbs, $1.i * 8, $1.enc); //#10834
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10835
        for (var _1i = 0; _1i <= 7; _1i += 1) { //#10838
            $1.xpos = $f($f($get($1.enc, _1i) - 48) + $1.xpos); //#10837
        } //#10837
    } //#10837
    if ($1.includecheck) { //#10863
        $puti($1.sbs, $f(($1.barlen * 8) - 8), $get($1.encs, $1.checksum)); //#10844
        if ($1.includecheckintext) { //#10848
            $put($1.txt, $f($1.barlen - 1), $a([$geti($1.barchars, $1.checksum, 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10846
        } else { //#10848
            $put($1.txt, $f($1.barlen - 1), $a([" ", $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10848
        } //#10848
        for (var _2A = 0; _2A <= 7; _2A += 1) { //#10852
            $1.xpos = $f($f($get($get($1.encs, $1.checksum), _2A) - 48) + $1.xpos); //#10851
        } //#10851
        $1.indx = $get($1.charvals, $geti($1.barcode, $f($1.barlen - 1), 1)); //#10854
        $1.enc = $get($1.encs, $1.indx); //#10855
        $puti($1.sbs, $1.barlen * 8, $1.enc); //#10856
        $put($1.txt, $1.barlen, $a([$geti($1.barcode, $f($1.barlen - 1), 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10857
    } else { //#10863
        $1.indx = $get($1.charvals, $geti($1.barcode, $f($1.barlen - 1), 1)); //#10860
        $1.enc = $get($1.encs, $1.indx); //#10861
        $puti($1.sbs, $f(($1.barlen * 8) - 8), $1.enc); //#10862
        $put($1.txt, $f($1.barlen - 1), $a([$geti($1.barcode, $f($1.barlen - 1), 1), $1.xpos, $1.textyoffset, $1.textfont, $1.textsize])); //#10863
    } //#10863
    $k[$j++] = Infinity; //#10875
    $k[$j++] = Infinity; //#10869
    $forall($1.sbs, function() { //#10869
        var _2x = $k[--$j]; //#10869
        $k[$j++] = $f(_2x - 48); //#10869
    }); //#10869
    var _2y = $a(); //#10869
    $k[$j++] = Infinity; //#10870
    for (var _30 = 0, _31 = ~~(($1.sbs.length + 1) / 2); _30 < _31; _30++) { //#10870
        $k[$j++] = $1.height; //#10870
    } //#10870
    var _33 = $a(); //#10870
    $k[$j++] = Infinity; //#10871
    for (var _35 = 0, _36 = ~~(($1.sbs.length + 1) / 2); _35 < _36; _35++) { //#10871
        $k[$j++] = 0; //#10871
    } //#10871
    var _37 = $a(); //#10871
    $k[$j++] = 'ren'; //#10874
    $k[$j++] = bwipp_renlinear; //#10874
    $k[$j++] = 'sbs'; //#10874
    $k[$j++] = _2y; //#10874
    $k[$j++] = 'bhs'; //#10874
    $k[$j++] = _33; //#10874
    $k[$j++] = 'bbs'; //#10874
    $k[$j++] = _37; //#10874
    if ($1.includetext) { //#10874
        $k[$j++] = 'txt'; //#10873
        $k[$j++] = $1.txt; //#10873
    } //#10873
    $k[$j++] = 'opt'; //#10875
    $k[$j++] = $1.options; //#10875
    var _3B = $d(); //#10875
    $k[$j++] = _3B; //#10878
    if (!$1.dontdraw) { //#10878
        bwipp_renlinear(); //#10878
    } //#10878
}

function bwipp_onecode() {
    var $1 = {}; //#10912
    $1.ctx = null; //#10914
    $1.dontdraw = false; //#10915
    $1.height = 0.15; //#10916
    $k[$j++] = $1; //#10918
    bwipp_processoptions(); //#10918
    $1.options = $k[--$j]; //#10918
    $1.barcode = $k[--$j]; //#10919
    $1.barlen = $1.barcode.length; //#10923
    $k[$j++] = Infinity; //#10932
    var _5 = $eq($geti($1.barcode, 5, 1), "9") ? 14 : 11; //#10929
    $k[$j++] = 2; //#10932
    $k[$j++] = 2; //#10932
    $k[$j++] = 5; //#10932
    $k[$j++] = 5; //#10932
    $k[$j++] = _5; //#10932
    $k[$j++] = _5; //#10932
    $k[$j++] = 20; //#10932
    $k[$j++] = 20; //#10932
    $k[$j++] = 25; //#10932
    $k[$j++] = 25; //#10932
    $k[$j++] = 29; //#10932
    $k[$j++] = 29; //#10932
    $1.txtdict = $d(); //#10933
    $1.txt = $a($1.barlen + 6); //#10934
    $1.spacecnt = 0; //#10935
    for (var _B = 0, _A = $1.barlen - 1; _B <= _A; _B += 1) { //#10943
        $1.i = _B; //#10937
        var _E = $get($1.txtdict, $1.i) !== undefined; //#10938
        if (_E) { //#10941
            $put($1.txt, $1.i + $1.spacecnt, $a([" ", 0, 0, "", 0])); //#10939
            $1.spacecnt = $1.spacecnt + 1; //#10940
        } //#10940
        $put($1.txt, $1.i + $1.spacecnt, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#10942
    } //#10942
    $1.txt = $geti($1.txt, 0, $1.barcode.length + $1.spacecnt); //#10944
    $1.normalize = function() {
        $1.base = $k[--$j]; //#10947
        $1.num = $k[--$j]; //#10948
        for (var _Y = $1.num.length - 1; _Y >= 1; _Y -= 1) { //#10953
            $1.i = _Y; //#10950
            var _Z = $1.num; //#10951
            var _a = $1.i; //#10951
            $put(_Z, _a - 1, $f($get(_Z, _a - 1) + (~~($get($1.num, $1.i) / $1.base)))); //#10951
            $put($1.num, $1.i, $get($1.num, $1.i) % $1.base); //#10952
        } //#10952
        for (;;) { //#10959
            if ($lt($get($1.num, 0), $1.base)) { //#10955
                break; //#10955
            } //#10955
            $k[$j++] = Infinity; //#10956
            $k[$j++] = 0; //#10956
            $forall($1.num); //#10956
            $1.num = $a(); //#10956
            $put($1.num, 0, $f($get($1.num, 0) + (~~($get($1.num, 1) / $1.base)))); //#10957
            $put($1.num, 1, $get($1.num, 1) % $1.base); //#10958
        } //#10958
        $k[$j++] = Infinity; //#10961
        $1.i = true; //#10961
        var _11 = $1.num; //#10961
        for (var _12 = 0, _13 = _11.length; _12 < _13; _12++) { //#10961
            var _14 = $get(_11, _12); //#10961
            $k[$j++] = _14; //#10961
            if ((_14 == 0) && $1.i) { //#10961
                $j--; //#10961
            } else { //#10961
                $1.i = false; //#10961
            } //#10961
        } //#10961
        $1.num = $a(); //#10961
        if ($1.num.length == 0) { //#10962
            $1.num = $a([0]); //#10962
        } //#10962
        $k[$j++] = $1.num; //#10963
    }; //#10963
    $1.bigadd = function() {
        var _1A = $k[--$j]; //#10967
        var _1B = $k[--$j]; //#10967
        $1.offset = Math.abs(_1A.length - _1B.length); //#10968
        if (_1A.length < _1B.length) { //#10969
            var _ = _1A; //#10969
            _1A = _1B; //#10969
            _1B = _; //#10969
        } //#10969
        $1.a = _1A; //#10970
        $1.b = _1B; //#10970
        for (var _1E = 0, _1D = $1.b.length - 1; _1E <= _1D; _1E += 1) { //#10973
            var _1F = $1.a; //#10972
            var _1G = $1.offset; //#10972
            $put(_1F, _1E + _1G, $f($get(_1F, _1E + _1G) + $get($1.b, _1E))); //#10972
        } //#10972
        $k[$j++] = $1.a; //#10974
    }; //#10974
    if ($1.barlen == 20) { //#10978
        $k[$j++] = $a([0]); //#10978
    } //#10978
    if ($1.barlen == 25) { //#10979
        $k[$j++] = $a([1]); //#10979
    } //#10979
    if ($1.barlen == 29) { //#10980
        $k[$j++] = $a([1, 0, 0, 0, 0, 1]); //#10980
    } //#10980
    if ($1.barlen == 31) { //#10981
        $k[$j++] = $a([1, 0, 0, 0, 1, 0, 0, 0, 0, 1]); //#10981
    } //#10981
    var _1T = $k[--$j]; //#10982
    $k[$j++] = 'binval'; //#10982
    $k[$j++] = _1T; //#10982
    $k[$j++] = Infinity; //#10982
    var _1W = $geti($1.barcode, 20, $1.barlen - 20); //#10982
    for (var _1X = 0, _1Y = _1W.length; _1X < _1Y; _1X++) { //#10982
        $k[$j++] = $f($get(_1W, _1X) - 48); //#10982
    } //#10982
    var _1a = $a(); //#10982
    $k[$j++] = _1a; //#10982
    $1.bigadd(); //#10982
    var _1b = $k[--$j]; //#10982
    $1[$k[--$j]] = _1b; //#10982
    $k[$j++] = Infinity; //#10983
    var _1d = $1.binval; //#10983
    for (var _1e = 0, _1f = _1d.length; _1e < _1f; _1e++) { //#10983
        $k[$j++] = $get(_1d, _1e); //#10983
    } //#10983
    $k[$j++] = $f($get($1.barcode, 0) - 48); //#10983
    $1.binval = $a(); //#10983
    $k[$j++] = Infinity; //#10984
    var _1k = $1.binval; //#10984
    for (var _1l = 0, _1m = _1k.length; _1l < _1m; _1l++) { //#10984
        $k[$j++] = $get(_1k, _1l) * 5; //#10984
    } //#10984
    var _1o = $a(); //#10984
    $k[$j++] = 'binval'; //#10984
    $k[$j++] = _1o; //#10984
    $k[$j++] = $a([$f($get($1.barcode, 1) - 48)]); //#10984
    $1.bigadd(); //#10984
    $k[$j++] = 10; //#10984
    $1.normalize(); //#10984
    var _1s = $k[--$j]; //#10984
    $1[$k[--$j]] = _1s; //#10984
    $k[$j++] = Infinity; //#10985
    var _1u = $1.binval; //#10985
    for (var _1v = 0, _1w = _1u.length; _1v < _1w; _1v++) { //#10985
        $k[$j++] = $get(_1u, _1v); //#10985
    } //#10985
    var _1z = $geti($1.barcode, 2, 18); //#10985
    for (var _20 = 0, _21 = _1z.length; _20 < _21; _20++) { //#10985
        $k[$j++] = $f($get(_1z, _20) - 48); //#10985
    } //#10985
    $1.binval = $a(); //#10985
    $1.bytes = $a(13); //#10988
    $k[$j++] = Infinity; //#10989
    var _25 = $1.binval; //#10989
    for (var _26 = 0, _27 = _25.length; _26 < _27; _26++) { //#10989
        $k[$j++] = $get(_25, _26); //#10989
    } //#10989
    $1.bintmp = $a(); //#10989
    for (var _2A = 12; _2A >= 0; _2A -= 1) { //#10999
        $1.i = _2A; //#10991
        for (var _2D = 0, _2C = $1.bintmp.length - 2; _2D <= _2C; _2D += 1) { //#10996
            $1.j = _2D; //#10993
            var _2E = $1.bintmp; //#10994
            var _2F = $1.j; //#10994
            $put(_2E, _2F + 1, $f($get(_2E, _2F + 1) + (($get($1.bintmp, $1.j) % 256) * 10))); //#10994
            $put($1.bintmp, $1.j, ~~($get($1.bintmp, $1.j) / 256)); //#10995
        } //#10995
        $put($1.bytes, $1.i, $get($1.bintmp, $1.bintmp.length - 1) % 256); //#10997
        var _2U = $1.bintmp; //#10998
        var _2V = $1.bintmp; //#10998
        $put(_2U, _2V.length - 1, ~~($get(_2U, _2V.length - 1) / 256)); //#10998
    } //#10998
    $1.fcs = 2047; //#11002
    $1.dat = $get($1.bytes, 0) << 5; //#11003
    for (var _2Z = 0, _2a = 6; _2Z < _2a; _2Z++) { //#11012
        if ((($1.fcs ^ $1.dat) & 1024) != 0) { //#11008
            $1.fcs = ($1.fcs << 1) ^ 3893; //#11006
        } else { //#11008
            $1.fcs = $1.fcs << 1; //#11008
        } //#11008
        $1.fcs = $1.fcs & 2047; //#11010
        $1.dat = $1.dat << 1; //#11011
    } //#11011
    for (var _2h = 1; _2h <= 12; _2h += 1) { //#11024
        $1.dat = $get($1.bytes, _2h) << 3; //#11014
        for (var _2k = 0, _2l = 8; _2k < _2l; _2k++) { //#11023
            if ((($1.fcs ^ $1.dat) & 1024) != 0) { //#11019
                $1.fcs = ($1.fcs << 1) ^ 3893; //#11017
            } else { //#11019
                $1.fcs = $1.fcs << 1; //#11019
            } //#11019
            $1.fcs = $1.fcs & 2047; //#11021
            $1.dat = $1.dat << 1; //#11022
        } //#11022
    } //#11022
    $1.codewords = $a(10); //#11027
    for (var _2t = 9; _2t >= 0; _2t -= 1) { //#11042
        $1.i = _2t; //#11029
        if ($1.i == 9) { //#11033
            $1.b = 636; //#11031
        } else { //#11033
            $1.b = 1365; //#11033
        } //#11033
        for (var _2x = 0, _2w = $1.binval.length - 2; _2x <= _2w; _2x += 1) { //#11039
            $1.j = _2x; //#11036
            var _2y = $1.binval; //#11037
            var _2z = $1.j; //#11037
            $put(_2y, _2z + 1, $f($get(_2y, _2z + 1) + (($get($1.binval, $1.j) % $1.b) * 10))); //#11037
            $put($1.binval, $1.j, ~~($get($1.binval, $1.j) / $1.b)); //#11038
        } //#11038
        $put($1.codewords, $1.i, $get($1.binval, $1.binval.length - 1) % $1.b); //#11040
        var _3H = $1.binval; //#11041
        var _3I = $1.binval; //#11041
        $put(_3H, _3I.length - 1, ~~($get(_3H, _3I.length - 1) / $1.b)); //#11041
    } //#11041
    $put($1.codewords, 9, $get($1.codewords, 9) * 2); //#11045
    if (($1.fcs & 1024) != 0) { //#11048
        $put($1.codewords, 0, $f($get($1.codewords, 0) + 659)); //#11047
    } //#11047
    $1.tab513 = $a([31, 7936, 47, 7808, 55, 7552, 59, 7040, 61, 6016, 62, 3968, 79, 7744, 87, 7488, 91, 6976, 93, 5952, 94, 3904, 103, 7360, 107, 6848, 109, 5824, 110, 3776, 115, 6592, 117, 5568, 118, 3520, 121, 5056, 122, 3008, 124, 1984, 143, 7712, 151, 7456, 155, 6944, 157, 5920, 158, 3872, 167, 7328, 171, 6816, 173, 5792, 174, 3744, 179, 6560, 181, 5536, 182, 3488, 185, 5024, 186, 2976, 188, 1952, 199, 7264, 203, 6752, 205, 5728, 206, 3680, 211, 6496, 213, 5472, 214, 3424, 217, 4960, 218, 2912, 220, 1888, 227, 6368, 229, 5344, 230, 3296, 233, 4832, 234, 2784, 236, 1760, 241, 4576, 242, 2528, 244, 1504, 248, 992, 271, 7696, 279, 7440, 283, 6928, 285, 5904, 286, 3856, 295, 7312, 299, 6800, 301, 5776, 302, 3728, 307, 6544, 309, 5520, 310, 3472, 313, 5008, 314, 2960, 316, 1936, 327, 7248, 331, 6736, 333, 5712, 334, 3664, 339, 6480, 341, 5456, 342, 3408, 345, 4944, 346, 2896, 348, 1872, 355, 6352, 357, 5328, 358, 3280, 361, 4816, 362, 2768, 364, 1744, 369, 4560, 370, 2512, 372, 1488, 376, 976, 391, 7216, 395, 6704, 397, 5680, 398, 3632, 403, 6448, 405, 5424, 406, 3376, 409, 4912, 410, 2864, 412, 1840, 419, 6320, 421, 5296, 422, 3248, 425, 4784, 426, 2736, 428, 1712, 433, 4528, 434, 2480, 436, 1456, 440, 944, 451, 6256, 453, 5232, 454, 3184, 457, 4720, 458, 2672, 460, 1648, 465, 4464, 466, 2416, 468, 1392, 472, 880, 481, 4336, 482, 2288, 484, 1264, 488, 752, 527, 7688, 535, 7432, 539, 6920, 541, 5896, 542, 3848, 551, 7304, 555, 6792, 557, 5768, 558, 3720, 563, 6536, 565, 5512, 566, 3464, 569, 5000, 570, 2952, 572, 1928, 583, 7240, 587, 6728, 589, 5704, 590, 3656, 595, 6472, 597, 5448, 598, 3400, 601, 4936, 602, 2888, 604, 1864, 611, 6344, 613, 5320, 614, 3272, 617, 4808, 618, 2760, 620, 1736, 625, 4552, 626, 2504, 628, 1480, 632, 968, 647, 7208, 651, 6696, 653, 5672, 654, 3624, 659, 6440, 661, 5416, 662, 3368, 665, 4904, 666, 2856, 668, 1832, 675, 6312, 677, 5288, 678, 3240, 681, 4776, 682, 2728, 684, 1704, 689, 4520, 690, 2472, 692, 1448, 696, 936, 707, 6248, 709, 5224, 710, 3176, 713, 4712, 714, 2664, 716, 1640, 721, 4456, 722, 2408, 724, 1384, 728, 872, 737, 4328, 738, 2280, 740, 1256, 775, 7192, 779, 6680, 781, 5656, 782, 3608, 787, 6424, 789, 5400, 790, 3352, 793, 4888, 794, 2840, 796, 1816, 803, 6296, 805, 5272, 806, 3224, 809, 4760, 810, 2712, 812, 1688, 817, 4504, 818, 2456, 820, 1432, 824, 920, 835, 6232, 837, 5208, 838, 3160, 841, 4696, 842, 2648, 844, 1624, 849, 4440, 850, 2392, 852, 1368, 865, 4312, 866, 2264, 868, 1240, 899, 6200, 901, 5176, 902, 3128, 905, 4664, 906, 2616, 908, 1592, 913, 4408, 914, 2360, 916, 1336, 929, 4280, 930, 2232, 932, 1208, 961, 4216, 962, 2168, 964, 1144, 1039, 7684, 1047, 7428, 1051, 6916, 1053, 5892, 1054, 3844, 1063, 7300, 1067, 6788, 1069, 5764, 1070, 3716, 1075, 6532, 1077, 5508, 1078, 3460, 1081, 4996, 1082, 2948, 1084, 1924, 1095, 7236, 1099, 6724, 1101, 5700, 1102, 3652, 1107, 6468, 1109, 5444, 1110, 3396, 1113, 4932, 1114, 2884, 1116, 1860, 1123, 6340, 1125, 5316, 1126, 3268, 1129, 4804, 1130, 2756, 1132, 1732, 1137, 4548, 1138, 2500, 1140, 1476, 1159, 7204, 1163, 6692, 1165, 5668, 1166, 3620, 1171, 6436, 1173, 5412, 1174, 3364, 1177, 4900, 1178, 2852, 1180, 1828, 1187, 6308, 1189, 5284, 1190, 3236, 1193, 4772, 1194, 2724, 1196, 1700, 1201, 4516, 1202, 2468, 1204, 1444, 1219, 6244, 1221, 5220, 1222, 3172, 1225, 4708, 1226, 2660, 1228, 1636, 1233, 4452, 1234, 2404, 1236, 1380, 1249, 4324, 1250, 2276, 1287, 7188, 1291, 6676, 1293, 5652, 1294, 3604, 1299, 6420, 1301, 5396, 1302, 3348, 1305, 4884, 1306, 2836, 1308, 1812, 1315, 6292, 1317, 5268, 1318, 3220, 1321, 4756, 1322, 2708, 1324, 1684, 1329, 4500, 1330, 2452, 1332, 1428, 1347, 6228, 1349, 5204, 1350, 3156, 1353, 4692, 1354, 2644, 1356, 1620, 1361, 4436, 1362, 2388, 1377, 4308, 1378, 2260, 1411, 6196, 1413, 5172, 1414, 3124, 1417, 4660, 1418, 2612, 1420, 1588, 1425, 4404, 1426, 2356, 1441, 4276, 1442, 2228, 1473, 4212, 1474, 2164, 1543, 7180, 1547, 6668, 1549, 5644, 1550, 3596, 1555, 6412, 1557, 5388, 1558, 3340, 1561, 4876, 1562, 2828, 1564, 1804, 1571, 6284, 1573, 5260, 1574, 3212, 1577, 4748, 1578, 2700, 1580, 1676, 1585, 4492, 1586, 2444, 1603, 6220, 1605, 5196, 1606, 3148, 1609, 4684, 1610, 2636, 1617, 4428, 1618, 2380, 1633, 4300, 1634, 2252, 1667, 6188, 1669, 5164, 1670, 3116, 1673, 4652, 1674, 2604, 1681, 4396, 1682, 2348, 1697, 4268, 1698, 2220, 1729, 4204, 1730, 2156, 1795, 6172, 1797, 5148, 1798, 3100, 1801, 4636, 1802, 2588, 1809, 4380, 1810, 2332, 1825, 4252, 1826, 2204, 1857, 4188, 1858, 2140, 1921, 4156, 1922, 2108, 2063, 7682, 2071, 7426, 2075, 6914, 2077, 5890, 2078, 3842, 2087, 7298, 2091, 6786, 2093, 5762, 2094, 3714, 2099, 6530, 2101, 5506, 2102, 3458, 2105, 4994, 2106, 2946, 2119, 7234, 2123, 6722, 2125, 5698, 2126, 3650, 2131, 6466, 2133, 5442, 2134, 3394, 2137, 4930, 2138, 2882, 2147, 6338, 2149, 5314, 2150, 3266, 2153, 4802, 2154, 2754, 2161, 4546, 2162, 2498, 2183, 7202, 2187, 6690, 2189, 5666, 2190, 3618, 2195, 6434, 2197, 5410, 2198, 3362, 2201, 4898, 2202, 2850, 2211, 6306, 2213, 5282, 2214, 3234, 2217, 4770, 2218, 2722, 2225, 4514, 2226, 2466, 2243, 6242, 2245, 5218, 2246, 3170, 2249, 4706, 2250, 2658, 2257, 4450, 2258, 2402, 2273, 4322, 2311, 7186, 2315, 6674, 2317, 5650, 2318, 3602, 2323, 6418, 2325, 5394, 2326, 3346, 2329, 4882, 2330, 2834, 2339, 6290, 2341, 5266, 2342, 3218, 2345, 4754, 2346, 2706, 2353, 4498, 2354, 2450, 2371, 6226, 2373, 5202, 2374, 3154, 2377, 4690, 2378, 2642, 2385, 4434, 2401, 4306, 2435, 6194, 2437, 5170, 2438, 3122, 2441, 4658, 2442, 2610, 2449, 4402, 2465, 4274, 2497, 4210, 2567, 7178, 2571, 6666, 2573, 5642, 2574, 3594, 2579, 6410, 2581, 5386, 2582, 3338, 2585, 4874, 2586, 2826, 2595, 6282, 2597, 5258, 2598, 3210, 2601, 4746, 2602, 2698, 2609, 4490, 2627, 6218, 2629, 5194, 2630, 3146, 2633, 4682, 2641, 4426, 2657, 4298, 2691, 6186, 2693, 5162, 2694, 3114, 2697, 4650, 2705, 4394, 2721, 4266, 2753, 4202, 2819, 6170, 2821, 5146, 2822, 3098, 2825, 4634, 2833, 4378, 2849, 4250, 2881, 4186, 2945, 4154, 3079, 7174, 3083, 6662, 3085, 5638, 3086, 3590, 3091, 6406, 3093, 5382, 3094, 3334, 3097, 4870, 3107, 6278, 3109, 5254, 3110, 3206, 3113, 4742, 3121, 4486, 3139, 6214, 3141, 5190, 3145, 4678, 3153, 4422, 3169, 4294, 3203, 6182, 3205, 5158, 3209, 4646, 3217, 4390, 3233, 4262, 3265, 4198, 3331, 6166, 3333, 5142, 3337, 4630, 3345, 4374, 3361, 4246, 3393, 4182, 3457, 4150, 3587, 6158, 3589, 5134, 3593, 4622, 3601, 4366, 3617, 4238, 3649, 4174, 3713, 4142, 3841, 4126, 4111, 7681, 4119, 7425, 4123, 6913, 4125, 5889, 4135, 7297, 4139, 6785, 4141, 5761, 4147, 6529, 4149, 5505, 4153, 4993, 4167, 7233, 4171, 6721, 4173, 5697, 4179, 6465, 4181, 5441, 4185, 4929, 4195, 6337, 4197, 5313, 4201, 4801, 4209, 4545, 4231, 7201, 4235, 6689, 4237, 5665, 4243, 6433, 4245, 5409, 4249, 4897, 4259, 6305, 4261, 5281, 4265, 4769, 4273, 4513, 4291, 6241, 4293, 5217, 4297, 4705, 4305, 4449, 4359, 7185, 4363, 6673, 4365, 5649, 4371, 6417, 4373, 5393, 4377, 4881, 4387, 6289, 4389, 5265, 4393, 4753, 4401, 4497, 4419, 6225, 4421, 5201, 4425, 4689, 4483, 6193, 4485, 5169, 4489, 4657, 4615, 7177, 4619, 6665, 4621, 5641, 4627, 6409, 4629, 5385, 4633, 4873, 4643, 6281, 4645, 5257, 4649, 4745, 4675, 6217, 4677, 5193, 4739, 6185, 4741, 5161, 4867, 6169, 4869, 5145, 5127, 7173, 5131, 6661, 5133, 5637, 5139, 6405, 5141, 5381, 5155, 6277, 5157, 5253, 5187, 6213, 5251, 6181, 5379, 6165, 5635, 6157, 6151, 7171, 6155, 6659, 6163, 6403, 6179, 6275, 6211, 5189, 4681, 4433, 4321, 3142, 2634, 2386, 2274, 1612, 1364, 1252, 856, 744, 496]); //#11139
    $1.tab213 = $a([3, 6144, 5, 5120, 6, 3072, 9, 4608, 10, 2560, 12, 1536, 17, 4352, 18, 2304, 20, 1280, 24, 768, 33, 4224, 34, 2176, 36, 1152, 40, 640, 48, 384, 65, 4160, 66, 2112, 68, 1088, 72, 576, 80, 320, 96, 192, 129, 4128, 130, 2080, 132, 1056, 136, 544, 144, 288, 257, 4112, 258, 2064, 260, 1040, 264, 528, 513, 4104, 514, 2056, 516, 1032, 1025, 4100, 1026, 2052, 2049, 4098, 4097, 2050, 1028, 520, 272, 160]); //#11148
    $1.chars = $a(10); //#11151
    for (var _3V = 0; _3V <= 9; _3V += 1) { //#11160
        $1.i = _3V; //#11153
        var _3Y = $get($1.codewords, $1.i); //#11154
        $k[$j++] = _3Y; //#11158
        if (_3Y <= 1286) { //#11157
            var _3b = $get($1.tab513, $k[--$j]); //#11155
            $k[$j++] = _3b; //#11155
        } else { //#11157
            var _3e = $get($1.tab213, $f($k[--$j] - 1287)); //#11157
            $k[$j++] = _3e; //#11157
        } //#11157
        $put($1.chars, $1.i, $k[--$j]); //#11159
    } //#11159
    for (var _3i = 9; _3i >= 0; _3i -= 1) { //#11167
        $1.i = _3i; //#11163
        if (((~~Math.pow(2, $1.i)) & $1.fcs) != 0) { //#11166
            $put($1.chars, $1.i, $get($1.chars, $1.i) ^ 8191); //#11165
        } //#11165
    } //#11165
    $1.barmap = $a([7, 2, 4, 3, 1, 10, 0, 0, 9, 12, 2, 8, 5, 5, 6, 11, 8, 9, 3, 1, 0, 1, 5, 12, 2, 5, 1, 8, 4, 4, 9, 11, 6, 3, 8, 10, 3, 9, 7, 6, 5, 11, 1, 4, 8, 5, 2, 12, 9, 10, 0, 2, 7, 1, 6, 7, 3, 6, 4, 9, 0, 3, 8, 6, 6, 4, 2, 7, 1, 1, 9, 9, 7, 10, 5, 2, 4, 0, 3, 8, 6, 2, 0, 4, 8, 11, 1, 0, 9, 8, 3, 12, 2, 6, 7, 7, 5, 1, 4, 10, 1, 12, 6, 9, 7, 3, 8, 0, 5, 8, 9, 7, 4, 6, 2, 10, 3, 4, 0, 5, 8, 4, 5, 7, 7, 11, 1, 9, 6, 0, 9, 6, 0, 6, 4, 8, 2, 1, 3, 2, 5, 9, 8, 12, 4, 11, 6, 1, 9, 5, 7, 4, 3, 3, 1, 2, 0, 7, 2, 0, 1, 3, 4, 1, 6, 10, 3, 5, 8, 7, 9, 4, 2, 11, 5, 6, 0, 8, 7, 12, 4, 2, 8, 1, 5, 10, 3, 0, 9, 3, 0, 9, 6, 5, 2, 4, 7, 8, 1, 7, 5, 0, 4, 5, 2, 3, 0, 10, 6, 12, 9, 2, 3, 11, 1, 6, 8, 8, 7, 9, 5, 4, 0, 11, 1, 5, 2, 2, 9, 1, 4, 12, 8, 3, 6, 6, 7, 0, 3, 7, 4, 7, 7, 5, 0, 12, 1, 11, 2, 9, 9, 0, 6, 8, 5, 3, 3, 10, 8, 2]); //#11185
    $1.bbs = $a(65); //#11188
    $1.bhs = $a(65); //#11189
    for (var _3t = 0; _3t <= 64; _3t += 1) { //#11210
        $1.i = _3t; //#11191
        $1.dec = ($get($1.chars, $get($1.barmap, $1.i * 4)) & (~~Math.pow(2, $get($1.barmap, ($1.i * 4) + 1)))) != 0; //#11192
        $1.asc = ($get($1.chars, $get($1.barmap, ($1.i * 4) + 2)) & (~~Math.pow(2, $get($1.barmap, ($1.i * 4) + 3)))) != 0; //#11193
        if ((!$1.dec) && (!$1.asc)) { //#11197
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11195
            $put($1.bhs, $1.i, (2 * $1.height) / 8); //#11196
        } //#11196
        if ((!$1.dec) && $1.asc) { //#11201
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11199
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11200
        } //#11200
        if ($1.dec && (!$1.asc)) { //#11205
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11203
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11204
        } //#11204
        if ($1.dec && $1.asc) { //#11209
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11207
            $put($1.bhs, $1.i, (8 * $1.height) / 8); //#11208
        } //#11208
    } //#11208
    $k[$j++] = Infinity; //#11223
    var _4g = $1.bbs; //#11215
    var _4h = $1.bhs; //#11216
    $k[$j++] = Infinity; //#11217
    for (var _4j = 0, _4k = $1.bhs.length - 1; _4j < _4k; _4j++) { //#11217
        $k[$j++] = 1.44; //#11217
        $k[$j++] = 1.872; //#11217
    } //#11217
    $k[$j++] = 1.44; //#11217
    var _4l = $a(); //#11217
    $k[$j++] = 'ren'; //#11223
    $k[$j++] = bwipp_renlinear; //#11223
    $k[$j++] = 'bbs'; //#11223
    $k[$j++] = _4g; //#11223
    $k[$j++] = 'bhs'; //#11223
    $k[$j++] = _4h; //#11223
    $k[$j++] = 'sbs'; //#11223
    $k[$j++] = _4l; //#11223
    $k[$j++] = 'txt'; //#11223
    $k[$j++] = $1.txt; //#11223
    $k[$j++] = 'textxalign'; //#11223
    $k[$j++] = "left"; //#11223
    $k[$j++] = 'textfont'; //#11223
    $k[$j++] = "OCR-B"; //#11223
    $k[$j++] = 'textyoffset'; //#11223
    $k[$j++] = 1; //#11223
    $k[$j++] = 'textxoffset'; //#11223
    $k[$j++] = -0.3; //#11223
    $k[$j++] = 'opt'; //#11223
    $k[$j++] = $1.options; //#11223
    var _4o = $d(); //#11223
    $k[$j++] = _4o; //#11226
    if (!$1.dontdraw) { //#11226
        bwipp_renlinear(); //#11226
    } //#11226
}

function bwipp_postnet() {
    var $1 = {}; //#11260
    $1.ctx = null; //#11262
    $1.dontdraw = false; //#11263
    $1.includetext = false; //#11264
    $1.validatecheck = false; //#11265
    $1.includecheckintext = false; //#11266
    $1.textfont = "OCR-B"; //#11267
    $1.textsize = 10; //#11268
    $1.textyoffset = -8; //#11269
    $1.height = 0.125; //#11270
    $k[$j++] = $1; //#11272
    bwipp_processoptions(); //#11272
    $1.options = $k[--$j]; //#11272
    $1.barcode = $k[--$j]; //#11273
    $k[$j++] = 'barlen'; //#11277
    $k[$j++] = $1.barcode.length; //#11277
    if ($1.validatecheck) { //#11277
        var _4 = $k[--$j]; //#11277
        $k[$j++] = $f(_4 - 1); //#11277
    } //#11277
    var _5 = $k[--$j]; //#11277
    $1[$k[--$j]] = _5; //#11277
    if ((($1.barlen != 5) && ($1.barlen != 9)) && ($1.barlen != 11)) { //#11282
        $k[$j++] = 'bwipp.postnetBadLength'; //#11281
        $k[$j++] = "USPS POSTNET must be 5, 9 or 11 digits excluding check digit"; //#11281
        bwipp_raiseerror(); //#11281
    } //#11281
    $forall($1.barcode, function() { //#11287
        var _B = $k[--$j]; //#11284
        if ((_B < 48) || (_B > 57)) { //#11286
            $k[$j++] = 'bwipp.postnetBadCharacter'; //#11285
            $k[$j++] = "USPS POSTNET must contain only digits"; //#11285
            bwipp_raiseerror(); //#11285
        } //#11285
    }); //#11285
    $1.barchars = "0123456789"; //#11291
    $1.encs = $a(["55222", "22255", "22525", "22552", "25225", "25252", "25522", "52225", "52252", "52522", "5", "5"]); //#11298
    $1.checksum = 0; //#11301
    for (var _F = 0, _E = $f($1.barlen - 1); _F <= _E; _F += 1) { //#11305
        $1.i = _F; //#11303
        $1.checksum = $f($1.checksum + $f($get($1.barcode, $1.i) - 48)); //#11304
    } //#11304
    $1.checksum = ($f(10 - ($1.checksum % 10))) % 10; //#11306
    if ($1.validatecheck) { //#11312
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#11310
            $k[$j++] = 'bwipp.postnetBadCheckDigit'; //#11309
            $k[$j++] = "Incorrect USPS POSTNET check digit provided"; //#11309
            bwipp_raiseerror(); //#11309
        } //#11309
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#11311
    } //#11311
    $1.bhs = $a($f(($1.barlen * 5) + 7)); //#11314
    $1.txt = $a($f($1.barlen + 1)); //#11315
    $1.enc = $get($1.encs, 10); //#11318
    $1.heights = $a($1.enc.length); //#11319
    for (var _f = 0, _e = $1.enc.length - 1; _f <= _e; _f += 1) { //#11323
        $1.j = _f; //#11321
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11322
    } //#11322
    $puti($1.bhs, 0, $1.heights); //#11324
    for (var _q = 0, _p = $f($1.barlen - 1); _q <= _p; _q += 1) { //#11336
        $1.i = _q; //#11327
        $1.enc = $get($1.encs, $f($get($1.barcode, $1.i) - 48)); //#11328
        $1.heights = $a($1.enc.length); //#11329
        for (var _10 = 0, _z = $1.enc.length - 1; _10 <= _z; _10 += 1) { //#11333
            $1.j = _10; //#11331
            $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11332
        } //#11332
        $puti($1.bhs, ($1.i * 5) + 1, $1.heights); //#11334
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 5) + 1) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11335
    } //#11335
    $1.enc = $get($1.encs, $1.checksum); //#11339
    $1.heights = $a($1.enc.length); //#11340
    for (var _1R = 0, _1Q = $1.enc.length - 1; _1R <= _1Q; _1R += 1) { //#11344
        $1.j = _1R; //#11342
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11343
    } //#11343
    $puti($1.bhs, $f(($1.barlen * 5) + 1), $1.heights); //#11345
    if ($1.includecheckintext) { //#11350
        $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum, 1), ($f(($1.barlen * 5) + 1)) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11348
    } else { //#11350
        $put($1.txt, $1.barlen, $a([" ", (($f(($1.barlen * 5) + 1)) * 72) / 25, $1.textyoffset, $1.textfont, $1.textsize])); //#11350
    } //#11350
    $1.enc = $get($1.encs, 11); //#11354
    $1.heights = $a($1.enc.length); //#11355
    for (var _1z = 0, _1y = $1.enc.length - 1; _1z <= _1y; _1z += 1) { //#11359
        $1.j = _1z; //#11357
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11358
    } //#11358
    $puti($1.bhs, $f(($1.barlen * 5) + 6), $1.heights); //#11360
    $k[$j++] = Infinity; //#11371
    var _29 = $1.bhs; //#11365
    $k[$j++] = Infinity; //#11366
    for (var _2B = 0, _2C = $1.bhs.length; _2B < _2C; _2B++) { //#11366
        $k[$j++] = 0; //#11366
    } //#11366
    var _2D = $a(); //#11366
    $k[$j++] = Infinity; //#11367
    for (var _2F = 0, _2G = $1.bhs.length - 1; _2F < _2G; _2F++) { //#11367
        $k[$j++] = 1.44; //#11367
        $k[$j++] = 1.872; //#11367
    } //#11367
    $k[$j++] = 1.44; //#11367
    var _2H = $a(); //#11367
    $k[$j++] = 'ren'; //#11370
    $k[$j++] = bwipp_renlinear; //#11370
    $k[$j++] = 'bhs'; //#11370
    $k[$j++] = _29; //#11370
    $k[$j++] = 'bbs'; //#11370
    $k[$j++] = _2D; //#11370
    $k[$j++] = 'sbs'; //#11370
    $k[$j++] = _2H; //#11370
    if ($1.includetext) { //#11370
        $k[$j++] = 'txt'; //#11369
        $k[$j++] = $1.txt; //#11369
    } //#11369
    $k[$j++] = 'opt'; //#11371
    $k[$j++] = $1.options; //#11371
    var _2L = $d(); //#11371
    $k[$j++] = _2L; //#11374
    if (!$1.dontdraw) { //#11374
        bwipp_renlinear(); //#11374
    } //#11374
}

function bwipp_planet() {
    var $1 = {}; //#11408
    $1.ctx = null; //#11410
    $1.dontdraw = false; //#11411
    $1.includetext = false; //#11412
    $1.validatecheck = false; //#11413
    $1.includecheckintext = false; //#11414
    $1.textfont = "OCR-B"; //#11415
    $1.textsize = 10; //#11416
    $1.textyoffset = -8; //#11417
    $1.height = 0.125; //#11418
    $k[$j++] = $1; //#11420
    bwipp_processoptions(); //#11420
    $1.options = $k[--$j]; //#11420
    $1.barcode = $k[--$j]; //#11421
    $k[$j++] = 'barlen'; //#11425
    $k[$j++] = $1.barcode.length; //#11425
    if ($1.validatecheck) { //#11425
        var _4 = $k[--$j]; //#11425
        $k[$j++] = $f(_4 - 1); //#11425
    } //#11425
    var _5 = $k[--$j]; //#11425
    $1[$k[--$j]] = _5; //#11425
    if (($1.barlen != 11) && ($1.barlen != 13)) { //#11430
        $k[$j++] = 'bwipp.planetBadLength'; //#11429
        $k[$j++] = "USPS PLANET must be 11 or 13 digits excluding check digit"; //#11429
        bwipp_raiseerror(); //#11429
    } //#11429
    $forall($1.barcode, function() { //#11435
        var _A = $k[--$j]; //#11432
        if ((_A < 48) || (_A > 57)) { //#11434
            $k[$j++] = 'bwipp.planetBadCharacter'; //#11433
            $k[$j++] = "USPS PLANET must contain only digits"; //#11433
            bwipp_raiseerror(); //#11433
        } //#11433
    }); //#11433
    $1.barchars = "0123456789"; //#11439
    $1.encs = $a(["22555", "55522", "55252", "55225", "52552", "52525", "52255", "25552", "25525", "25255", "5", "5"]); //#11446
    $1.checksum = 0; //#11450
    for (var _E = 0, _D = $f($1.barlen - 1); _E <= _D; _E += 1) { //#11454
        $1.i = _E; //#11452
        $1.checksum = $f($1.checksum + $f($get($1.barcode, $1.i) - 48)); //#11453
    } //#11453
    $1.checksum = ($f(10 - ($1.checksum % 10))) % 10; //#11455
    if ($1.validatecheck) { //#11461
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#11459
            $k[$j++] = 'bwipp.planetBadCheckDigit'; //#11458
            $k[$j++] = "Incorrect USPS PLANET check digit provided"; //#11458
            bwipp_raiseerror(); //#11458
        } //#11458
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#11460
    } //#11460
    $1.bhs = $a($f(($1.barlen * 5) + 7)); //#11463
    $1.txt = $a($f($1.barlen + 1)); //#11464
    $1.enc = $get($1.encs, 10); //#11467
    $1.heights = $a($1.enc.length); //#11468
    for (var _e = 0, _d = $1.enc.length - 1; _e <= _d; _e += 1) { //#11472
        $1.j = _e; //#11470
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11471
    } //#11471
    $puti($1.bhs, 0, $1.heights); //#11473
    for (var _p = 0, _o = $f($1.barlen - 1); _p <= _o; _p += 1) { //#11485
        $1.i = _p; //#11476
        $1.enc = $get($1.encs, $f($get($1.barcode, $1.i) - 48)); //#11477
        $1.heights = $a($1.enc.length); //#11478
        for (var _z = 0, _y = $1.enc.length - 1; _z <= _y; _z += 1) { //#11482
            $1.j = _z; //#11480
            $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11481
        } //#11481
        $puti($1.bhs, ($1.i * 5) + 1, $1.heights); //#11483
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 5) + 1) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11484
    } //#11484
    $1.enc = $get($1.encs, $1.checksum); //#11488
    $1.heights = $a($1.enc.length); //#11489
    for (var _1Q = 0, _1P = $1.enc.length - 1; _1Q <= _1P; _1Q += 1) { //#11493
        $1.j = _1Q; //#11491
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11492
    } //#11492
    $puti($1.bhs, $f(($1.barlen * 5) + 1), $1.heights); //#11494
    if ($1.includecheckintext) { //#11499
        $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum, 1), ($f(($1.barlen * 5) + 1)) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11497
    } else { //#11499
        $put($1.txt, $1.barlen, $a([" ", (($f(($1.barlen * 5) + 1)) * 72) / 25, $1.textyoffset, $1.textfont, $1.textsize])); //#11499
    } //#11499
    $1.enc = $get($1.encs, 11); //#11503
    $1.heights = $a($1.enc.length); //#11504
    for (var _1y = 0, _1x = $1.enc.length - 1; _1y <= _1x; _1y += 1) { //#11508
        $1.j = _1y; //#11506
        $put($1.heights, $1.j, ($cvi($geti($1.enc, $1.j, 1)) * $1.height) / 5); //#11507
    } //#11507
    $puti($1.bhs, $f(($1.barlen * 5) + 6), $1.heights); //#11509
    $k[$j++] = Infinity; //#11520
    var _28 = $1.bhs; //#11514
    $k[$j++] = Infinity; //#11515
    for (var _2A = 0, _2B = $1.bhs.length; _2A < _2B; _2A++) { //#11515
        $k[$j++] = 0; //#11515
    } //#11515
    var _2C = $a(); //#11515
    $k[$j++] = Infinity; //#11516
    for (var _2E = 0, _2F = $1.bhs.length - 1; _2E < _2F; _2E++) { //#11516
        $k[$j++] = 1.44; //#11516
        $k[$j++] = 1.872; //#11516
    } //#11516
    $k[$j++] = 1.44; //#11516
    var _2G = $a(); //#11516
    $k[$j++] = 'ren'; //#11519
    $k[$j++] = bwipp_renlinear; //#11519
    $k[$j++] = 'bhs'; //#11519
    $k[$j++] = _28; //#11519
    $k[$j++] = 'bbs'; //#11519
    $k[$j++] = _2C; //#11519
    $k[$j++] = 'sbs'; //#11519
    $k[$j++] = _2G; //#11519
    if ($1.includetext) { //#11519
        $k[$j++] = 'txt'; //#11518
        $k[$j++] = $1.txt; //#11518
    } //#11518
    $k[$j++] = 'opt'; //#11520
    $k[$j++] = $1.options; //#11520
    var _2K = $d(); //#11520
    $k[$j++] = _2K; //#11523
    if (!$1.dontdraw) { //#11523
        bwipp_renlinear(); //#11523
    } //#11523
}

function bwipp_royalmail() {
    var $1 = {}; //#11557
    $1.ctx = null; //#11559
    $1.dontdraw = false; //#11560
    $1.includetext = false; //#11561
    $1.validatecheck = false; //#11562
    $1.includecheckintext = false; //#11563
    $1.textfont = "OCR-B"; //#11564
    $1.textsize = 10; //#11565
    $1.textyoffset = -8; //#11566
    $1.height = 0.175; //#11567
    $k[$j++] = $1; //#11569
    bwipp_processoptions(); //#11569
    $1.options = $k[--$j]; //#11569
    $1.barcode = $k[--$j]; //#11570
    $1.barchars = "ZUVWXY501234B6789AHCDEFGNIJKLMTOPQRS"; //#11576
    $1.charvals = new Map; //#11577
    for (var _2 = 0; _2 <= 35; _2 += 1) { //#11578
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#11578
    } //#11578
    $1.encs = $a(["3300", "2211", "2301", "2310", "3201", "3210", "1122", "0033", "0123", "0132", "1023", "1032", "1302", "0213", "0303", "0312", "1203", "1212", "1320", "0231", "0321", "0330", "1221", "1230", "3102", "2013", "2103", "2112", "3003", "3012", "3120", "2031", "2121", "2130", "3021", "3030", "2", "3"]); //#11589
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#11597
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#11594
        if (!_D) { //#11596
            $k[$j++] = 'bwipp.royalmailBadCharacter'; //#11595
            $k[$j++] = "RM4SCC must contain only capital letters and digits"; //#11595
            bwipp_raiseerror(); //#11595
        } //#11595
    } //#11595
    $k[$j++] = 'barlen'; //#11599
    $k[$j++] = $1.barcode.length; //#11599
    if ($1.validatecheck) { //#11599
        var _G = $k[--$j]; //#11599
        $k[$j++] = $f(_G - 1); //#11599
    } //#11599
    var _H = $k[--$j]; //#11599
    $1[$k[--$j]] = _H; //#11599
    $1.checksumrow = 0; //#11601
    $1.checksumcol = 0; //#11602
    for (var _L = 0, _K = $f($1.barlen - 1); _L <= _K; _L += 1) { //#11608
        $1.i = _L; //#11604
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#11605
        $1.checksumrow = $1.checksumrow + (~~($1.indx / 6)); //#11606
        $1.checksumcol = $f($1.checksumcol + ($1.indx % 6)); //#11607
    } //#11607
    $1.checksum = $f((($1.checksumrow % 6) * 6) + ($1.checksumcol % 6)); //#11609
    if ($1.validatecheck) { //#11615
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#11613
            $k[$j++] = 'bwipp.royalmailBadCheckDigit'; //#11612
            $k[$j++] = "Incorrect RM4SCC check digit provided"; //#11612
            bwipp_raiseerror(); //#11612
        } //#11612
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#11614
    } //#11614
    $1.encstr = $s($f(($1.barlen * 4) + 6)); //#11617
    $1.txt = $a($f($1.barlen + 1)); //#11618
    $puti($1.encstr, 0, $get($1.encs, 36)); //#11621
    for (var _q = 0, _p = $f($1.barlen - 1); _q <= _p; _q += 1) { //#11628
        $1.i = _q; //#11624
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#11625
        $puti($1.encstr, ($1.i * 4) + 1, $get($1.encs, $1.indx)); //#11626
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.i * 4) + 1) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11627
    } //#11627
    $puti($1.encstr, $f(($1.barlen * 4) + 1), $get($1.encs, $1.checksum)); //#11631
    if ($1.includecheckintext) { //#11635
        $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum, 1), ($f(($1.barlen * 4) + 1)) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11633
    } else { //#11635
        $put($1.txt, $1.barlen, $a([" ", ($f(($1.barlen * 4) + 1)) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11635
    } //#11635
    $puti($1.encstr, $f(($1.barlen * 4) + 5), $get($1.encs, 37)); //#11639
    $1.bbs = $a($1.encstr.length); //#11641
    $1.bhs = $a($1.encstr.length); //#11642
    for (var _1i = 0, _1h = $1.encstr.length - 1; _1i <= _1h; _1i += 1) { //#11662
        $1.i = _1i; //#11644
        $1.enc = $geti($1.encstr, $1.i, 1); //#11645
        if ($eq($1.enc, "0")) { //#11649
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11647
            $put($1.bhs, $1.i, (2 * $1.height) / 8); //#11648
        } //#11648
        if ($eq($1.enc, "1")) { //#11653
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11651
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11652
        } //#11652
        if ($eq($1.enc, "2")) { //#11657
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11655
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11656
        } //#11656
        if ($eq($1.enc, "3")) { //#11661
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11659
            $put($1.bhs, $1.i, (8 * $1.height) / 8); //#11660
        } //#11660
    } //#11660
    $k[$j++] = Infinity; //#11673
    var _2E = $1.bbs; //#11667
    var _2F = $1.bhs; //#11668
    $k[$j++] = Infinity; //#11669
    for (var _2H = 0, _2I = $1.bhs.length - 1; _2H < _2I; _2H++) { //#11669
        $k[$j++] = 1.44; //#11669
        $k[$j++] = 1.872; //#11669
    } //#11669
    $k[$j++] = 1.44; //#11669
    var _2J = $a(); //#11669
    $k[$j++] = 'ren'; //#11672
    $k[$j++] = bwipp_renlinear; //#11672
    $k[$j++] = 'bbs'; //#11672
    $k[$j++] = _2E; //#11672
    $k[$j++] = 'bhs'; //#11672
    $k[$j++] = _2F; //#11672
    $k[$j++] = 'sbs'; //#11672
    $k[$j++] = _2J; //#11672
    if ($1.includetext) { //#11672
        $k[$j++] = 'txt'; //#11671
        $k[$j++] = $1.txt; //#11671
    } //#11671
    $k[$j++] = 'opt'; //#11673
    $k[$j++] = $1.options; //#11673
    var _2N = $d(); //#11673
    $k[$j++] = _2N; //#11676
    if (!$1.dontdraw) { //#11676
        bwipp_renlinear(); //#11676
    } //#11676
}

function bwipp_auspost() {
    var $1 = {}; //#11710
    $1.ctx = null; //#11712
    $1.dontdraw = false; //#11713
    $1.includetext = false; //#11714
    $1.textfont = "OCR-B"; //#11715
    $1.textsize = 10; //#11716
    $1.textyoffset = -8; //#11717
    $1.height = 0.175; //#11718
    $1.custinfoenc = "character"; //#11719
    $k[$j++] = $1; //#11721
    bwipp_processoptions(); //#11721
    $1.options = $k[--$j]; //#11721
    $1.barcode = $k[--$j]; //#11722
    $1.encs = $a(["000", "001", "002", "010", "011", "012", "020", "021", "022", "100", "101", "102", "110", "111", "112", "120", "121", "122", "200", "201", "202", "210", "211", "212", "220", "221", "222", "300", "301", "302", "310", "311", "312", "320", "321", "322", "023", "030", "031", "032", "033", "103", "113", "123", "130", "131", "132", "133", "203", "213", "223", "230", "231", "232", "233", "303", "313", "323", "330", "331", "332", "333", "003", "013", "00", "01", "02", "10", "11", "12", "20", "21", "22", "30", "13", "3"]); //#11739
    $1.barchars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789abcdefghijklmnopqrstuvwxyz #"; //#11742
    $1.barlen = $1.barcode.length; //#11745
    if ($eq($geti($1.barcode, 0, 2), "11")) { //#11746
        $k[$j++] = 37; //#11746
    } //#11746
    if ($eq($geti($1.barcode, 0, 2), "45")) { //#11747
        $k[$j++] = 37; //#11747
    } //#11747
    if ($eq($geti($1.barcode, 0, 2), "59")) { //#11748
        $k[$j++] = 52; //#11748
    } //#11748
    if ($eq($geti($1.barcode, 0, 2), "62")) { //#11749
        $k[$j++] = 67; //#11749
    } //#11749
    $1.encstr = $s($k[--$j]); //#11750
    $1.txt = $a($1.barlen - 2); //#11751
    $puti($1.encstr, 0, $get($1.encs, 74)); //#11754
    for (var _J = 0; _J <= 1; _J += 1) { //#11761
        $1.i = _J; //#11758
        $puti($1.encstr, ($1.i * 2) + 2, $get($1.encs, $cvi($geti($1.barcode, $1.i, 1)) + 64)); //#11760
    } //#11760
    for (var _R = 2; _R <= 9; _R += 1) { //#11769
        $1.i = _R; //#11765
        $puti($1.encstr, ($1.i * 2) + 2, $get($1.encs, $cvi($geti($1.barcode, $1.i, 1)) + 64)); //#11767
        $put($1.txt, $1.i - 2, $a([$geti($1.barcode, $1.i, 1), ((($1.i - 2) * 2) + 6) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11768
    } //#11768
    if ($eq($1.custinfoenc, "numeric")) { //#11791
        for (var _m = 0, _l = $1.barlen - 11; _m <= _l; _m += 1) { //#11778
            $1.i = _m; //#11774
            $puti($1.encstr, ($1.i * 2) + 22, $get($1.encs, $cvi($geti($1.barcode, $1.i + 10, 1)) + 64)); //#11776
            $put($1.txt, $1.i + 8, $a([$geti($1.barcode, $1.i + 10, 1), (($1.i * 2) + 22) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11777
        } //#11777
        $1.ciflen = ($1.barlen - 10) * 2; //#11779
    } else { //#11791
        for (var _17 = 0, _16 = $1.barlen - 11; _17 <= _16; _17 += 1) { //#11790
            $1.i = _17; //#11782
            $search($1.barchars, $geti($1.barcode, $1.i + 10, 1)); //#11783
            $j--; //#11784
            $1.indx = $k[--$j].length; //#11785
            $j -= 2; //#11786
            $1.enc = $get($1.encs, $1.indx); //#11787
            $puti($1.encstr, ($1.i * 3) + 22, $1.enc); //#11788
            $put($1.txt, $1.i + 8, $a([$geti($1.barcode, $1.i + 10, 1), (($1.i * 3) + 22) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11789
        } //#11789
        $1.ciflen = ($1.barlen - 10) * 3; //#11791
    } //#11791
    for (var _1X = 22 + $1.ciflen, _1W = $1.encstr.length - 14; _1X <= _1W; _1X += 1) { //#11797
        $puti($1.encstr, _1X, $get($1.encs, 75)); //#11796
    } //#11796
    $1.rstable = $a(64 * 64); //#11801
    $k[$j++] = $1.rstable; //#11802
    $k[$j++] = 0; //#11802
    $k[$j++] = Infinity; //#11802
    for (var _1d = 0, _1e = 64; _1d < _1e; _1d++) { //#11802
        $k[$j++] = 0; //#11802
    } //#11802
    var _1f = $a(); //#11802
    var _1g = $k[--$j]; //#11802
    $puti($k[--$j], _1g, _1f); //#11802
    $k[$j++] = $1.rstable; //#11803
    $k[$j++] = 64; //#11803
    $k[$j++] = Infinity; //#11803
    for (var _1j = 0; _1j <= 63; _1j += 1) { //#11803
        $k[$j++] = _1j; //#11803
    } //#11803
    var _1k = $a(); //#11803
    var _1l = $k[--$j]; //#11803
    $puti($k[--$j], _1l, _1k); //#11803
    $1.prev = 1; //#11804
    for (var _1n = 0, _1o = 64; _1n < _1o; _1n++) { //#11819
        $1.next = $1.prev << 1; //#11806
        if (($1.next & 64) != 0) { //#11809
            $1.next = $1.next ^ 67; //#11808
        } //#11808
        for (var _1s = 0; _1s <= 63; _1s += 1) { //#11817
            $1.j = _1s; //#11811
            $1.nextcell = function() {
                $k[$j++] = $1.rstable; //#11812
                $k[$j++] = (64 * $1.next) + $1.j; //#11812
            }; //#11812
            $1.nextcell(); //#11813
            var _20 = $k[--$j]; //#11813
            $put($k[--$j], _20, $get($1.rstable, (64 * $1.prev) + $1.j) << 1); //#11813
            $1.nextcell(); //#11814
            var _22 = $k[--$j]; //#11814
            if (($get($k[--$j], _22) & 64) != 0) { //#11816
                $1.nextcell(); //#11815
                $1.nextcell(); //#11815
                var _25 = $k[--$j]; //#11815
                var _27 = $get($k[--$j], _25); //#11815
                var _28 = $k[--$j]; //#11815
                $put($k[--$j], _28, _27 ^ 67); //#11815
            } //#11815
        } //#11815
        $1.prev = $1.next; //#11818
    } //#11818
    $1.rscodes = $a((~~(($1.encstr.length - 16) / 3)) + 4); //#11823
    $k[$j++] = $1.rscodes; //#11824
    $k[$j++] = 0; //#11824
    $k[$j++] = Infinity; //#11824
    for (var _2E = 0, _2F = 4; _2E < _2F; _2E++) { //#11824
        $k[$j++] = 0; //#11824
    } //#11824
    var _2G = $a(); //#11824
    var _2H = $k[--$j]; //#11824
    $puti($k[--$j], _2H, _2G); //#11824
    for (var _2L = 2, _2K = $1.encstr.length - 16; _2L <= _2K; _2L += 3) { //#11832
        $1.i = _2L; //#11826
        $put($1.rscodes, ($1.rscodes.length - (~~(($1.i - 2) / 3))) - 1, (($cvi($geti($1.encstr, $1.i, 1)) * 16) + ($cvi($geti($1.encstr, $1.i + 1, 1)) * 4)) + $cvi($geti($1.encstr, $1.i + 2, 1))); //#11831
    } //#11831
    for (var _2Z = $1.rscodes.length - 5; _2Z >= 0; _2Z -= 1) { //#11841
        $1.i = _2Z; //#11834
        for (var _2a = 0; _2a <= 4; _2a += 1) { //#11840
            $1.j = _2a; //#11836
            $put($1.rscodes, $1.i + $1.j, $xo($get($1.rscodes, $1.i + $1.j), $get($1.rstable, $f((64 * $get($a([48, 17, 29, 30, 1]), $1.j)) + $get($1.rscodes, $1.i + 4))))); //#11839
        } //#11839
    } //#11839
    $1.checkcode = $strcpy($s(12), "000000000000"); //#11842
    for (var _2s = 0; _2s <= 3; _2s += 1) { //#11847
        $1.i = _2s; //#11844
        $1.enc = $cvrs($s(3), $get($1.rscodes, 3 - $1.i), 4); //#11845
        $puti($1.checkcode, ($1.i * 3) + (3 - $1.enc.length), $1.enc); //#11846
    } //#11846
    $puti($1.encstr, $1.encstr.length - 14, $1.checkcode); //#11850
    $puti($1.encstr, $1.encstr.length - 2, $get($1.encs, 74)); //#11851
    $1.bbs = $a($1.encstr.length); //#11853
    $1.bhs = $a($1.encstr.length); //#11854
    for (var _3F = 0, _3E = $1.encstr.length - 1; _3F <= _3E; _3F += 1) { //#11874
        $1.i = _3F; //#11856
        $1.enc = $geti($1.encstr, $1.i, 1); //#11857
        if ($eq($1.enc, "0")) { //#11861
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11859
            $put($1.bhs, $1.i, (8 * $1.height) / 8); //#11860
        } //#11860
        if ($eq($1.enc, "1")) { //#11865
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11863
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11864
        } //#11864
        if ($eq($1.enc, "2")) { //#11869
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11867
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11868
        } //#11868
        if ($eq($1.enc, "3")) { //#11873
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11871
            $put($1.bhs, $1.i, (2 * $1.height) / 8); //#11872
        } //#11872
    } //#11872
    $k[$j++] = Infinity; //#11885
    var _3l = $1.bbs; //#11879
    var _3m = $1.bhs; //#11880
    $k[$j++] = Infinity; //#11881
    for (var _3o = 0, _3p = $1.bhs.length - 1; _3o < _3p; _3o++) { //#11881
        $k[$j++] = 1.44; //#11881
        $k[$j++] = 1.872; //#11881
    } //#11881
    $k[$j++] = 1.44; //#11881
    var _3q = $a(); //#11881
    $k[$j++] = 'ren'; //#11884
    $k[$j++] = bwipp_renlinear; //#11884
    $k[$j++] = 'bbs'; //#11884
    $k[$j++] = _3l; //#11884
    $k[$j++] = 'bhs'; //#11884
    $k[$j++] = _3m; //#11884
    $k[$j++] = 'sbs'; //#11884
    $k[$j++] = _3q; //#11884
    if ($1.includetext) { //#11884
        $k[$j++] = 'txt'; //#11883
        $k[$j++] = $1.txt; //#11883
    } //#11883
    $k[$j++] = 'opt'; //#11885
    $k[$j++] = $1.options; //#11885
    var _3u = $d(); //#11885
    $k[$j++] = _3u; //#11888
    if (!$1.dontdraw) { //#11888
        bwipp_renlinear(); //#11888
    } //#11888
}

function bwipp_kix() {
    var $1 = {}; //#11922
    $1.ctx = null; //#11924
    $1.dontdraw = false; //#11925
    $1.includetext = false; //#11926
    $1.textfont = "OCR-B"; //#11927
    $1.textsize = 10; //#11928
    $1.textyoffset = -8; //#11929
    $1.height = 0.175; //#11930
    $k[$j++] = $1; //#11932
    bwipp_processoptions(); //#11932
    $1.options = $k[--$j]; //#11932
    $1.barcode = $k[--$j]; //#11933
    $1.encs = $a(["0033", "0123", "0132", "1023", "1032", "1122", "0213", "0303", "0312", "1203", "1212", "1302", "0231", "0321", "0330", "1221", "1230", "1320", "2013", "2103", "2112", "3003", "3012", "3102", "2031", "2121", "2130", "3021", "3030", "3120", "2211", "2301", "2310", "3201", "3210", "3300"]); //#11946
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"; //#11949
    $1.charvals = new Map; //#11950
    for (var _3 = 0; _3 <= 35; _3 += 1) { //#11951
        $put($1.charvals, $geti($1.barchars, _3, 1), _3); //#11951
    } //#11951
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#11959
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#11956
        if (!_D) { //#11958
            $k[$j++] = 'bwipp.kixBadCharacter'; //#11957
            $k[$j++] = "KIX must contain only capital letters and digits"; //#11957
            bwipp_raiseerror(); //#11957
        } //#11957
    } //#11957
    $1.barlen = $1.barcode.length; //#11961
    $1.encstr = $s($1.barlen * 4); //#11962
    $1.txt = $a($1.barlen); //#11963
    for (var _L = 0, _K = $1.barlen - 1; _L <= _K; _L += 1) { //#11970
        $1.i = _L; //#11966
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#11967
        $puti($1.encstr, $1.i * 4, $get($1.encs, $1.indx)); //#11968
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 4) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#11969
    } //#11969
    $1.bbs = $a($1.encstr.length); //#11972
    $1.bhs = $a($1.encstr.length); //#11973
    for (var _m = 0, _l = $1.encstr.length - 1; _m <= _l; _m += 1) { //#11993
        $1.i = _m; //#11975
        $1.enc = $geti($1.encstr, $1.i, 1); //#11976
        if ($eq($1.enc, "0")) { //#11980
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11978
            $put($1.bhs, $1.i, (2 * $1.height) / 8); //#11979
        } //#11979
        if ($eq($1.enc, "1")) { //#11984
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11982
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11983
        } //#11983
        if ($eq($1.enc, "2")) { //#11988
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#11986
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#11987
        } //#11987
        if ($eq($1.enc, "3")) { //#11992
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#11990
            $put($1.bhs, $1.i, (8 * $1.height) / 8); //#11991
        } //#11991
    } //#11991
    $k[$j++] = Infinity; //#12004
    var _1I = $1.bbs; //#11998
    var _1J = $1.bhs; //#11999
    $k[$j++] = Infinity; //#12000
    for (var _1L = 0, _1M = $1.bhs.length - 1; _1L < _1M; _1L++) { //#12000
        $k[$j++] = 1.44; //#12000
        $k[$j++] = 1.872; //#12000
    } //#12000
    $k[$j++] = 1.44; //#12000
    var _1N = $a(); //#12000
    $k[$j++] = 'ren'; //#12003
    $k[$j++] = bwipp_renlinear; //#12003
    $k[$j++] = 'bbs'; //#12003
    $k[$j++] = _1I; //#12003
    $k[$j++] = 'bhs'; //#12003
    $k[$j++] = _1J; //#12003
    $k[$j++] = 'sbs'; //#12003
    $k[$j++] = _1N; //#12003
    if ($1.includetext) { //#12003
        $k[$j++] = 'txt'; //#12002
        $k[$j++] = $1.txt; //#12002
    } //#12002
    $k[$j++] = 'opt'; //#12004
    $k[$j++] = $1.options; //#12004
    var _1R = $d(); //#12004
    $k[$j++] = _1R; //#12007
    if (!$1.dontdraw) { //#12007
        bwipp_renlinear(); //#12007
    } //#12007
}

function bwipp_japanpost() {
    var $1 = {}; //#12041
    $1.ctx = null; //#12043
    $1.dontdraw = false; //#12044
    $1.includetext = false; //#12045
    $1.includecheckintext = false; //#12046
    $1.textfont = "OCR-B"; //#12047
    $1.textsize = 10; //#12048
    $1.textyoffset = -8; //#12049
    $1.height = 0.175; //#12050
    $k[$j++] = $1; //#12052
    bwipp_processoptions(); //#12052
    $1.options = $k[--$j]; //#12052
    $1.barcode = $k[--$j]; //#12053
    $forall($1.barcode, function() { //#12064
        var _3 = $k[--$j]; //#12059
        if (!(((_3 >= 48) && (_3 <= 57)) || (((_3 >= 65) && (_3 <= 90)) || (_3 == 45)))) { //#12063
            $k[$j++] = 'bwipp.japanPostBadCharacter'; //#12062
            $k[$j++] = "Japan Post must contain only digits, capital letters and the dash symbol"; //#12062
            if ('raiseerror'() === true) {
                return true;
            } //#12062
        } //#12062
    }); //#12062
    $1.encs = $a(["300", "330", "312", "132", "321", "303", "123", "231", "213", "033", "030", "120", "102", "210", "012", "201", "021", "003", "333", "31", "13"]); //#12072
    $1.barchars = "0123456789-ABCDEFGHIJKLMNOPQRSTUVWXYZ"; //#12075
    $1.barlen = $1.barcode.length; //#12078
    $1.encstr = $s(((20 + 1) * 3) + 4); //#12080
    $1.digits = $a(20); //#12081
    $1.txt = $a($1.barlen + 1); //#12082
    $puti($1.encstr, 0, $get($1.encs, 19)); //#12085
    $1.checksum = 0; //#12087
    $1.j = 0; //#12088
    $1.i = 0; //#12088
    for (var _F = 0, _E = $1.barlen - 1; _F <= _E; _F += 1) { //#12122
        $1.i = _F; //#12090
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#12091
        $j--; //#12092
        $1.indx = $k[--$j].length; //#12093
        $j -= 2; //#12094
        if (($1.indx >= 11) && ($1.indx < 37)) { //#12105
            if ($1.j > 18) { //#12096
                break; //#12096
            } //#12096
            $1.digit = (~~(($1.indx - 1) / 10)) + 10; //#12100
            $puti($1.encstr, ($1.j * 3) + 2, $get($1.encs, $1.digit)); //#12101
            $1.checksum = $1.checksum + $1.digit; //#12102
            $put($1.digits, $1.j, $1.digit); //#12103
            $1.j = $1.j + 1; //#12104
        } //#12104
        if ($1.j > 19) { //#12106
            break; //#12106
        } //#12106
        $1.digit = 0; //#12107
        if ($1.indx == 37) { //#12110
            $1.digit = 14; //#12109
        } //#12109
        if (($1.indx >= 11) && ($1.indx < 37)) { //#12113
            $1.digit = ($1.indx - 1) % 10; //#12112
        } //#12112
        if ($1.indx < 11) { //#12116
            $1.digit = $1.indx; //#12115
        } //#12115
        $puti($1.encstr, ($1.j * 3) + 2, $get($1.encs, $1.digit)); //#12117
        $1.checksum = $1.checksum + $1.digit; //#12118
        $put($1.digits, $1.j, $1.digit); //#12119
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), (($1.j * 3) + 2) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#12120
        $1.j = $1.j + 1; //#12121
    } //#12121
    for (var _14 = $1.j, _13 = 20 - 1; _14 <= _13; _14 += 1) { //#12130
        $1.k = _14; //#12126
        $puti($1.encstr, ($1.k * 3) + 2, $get($1.encs, 14)); //#12127
        $1.checksum = $1.checksum + 14; //#12128
        $put($1.digits, $1.k, 14); //#12129
    } //#12129
    $1.checksum = 19 - ($1.checksum % 19); //#12133
    $puti($1.encstr, 2 + (20 * 3), $get($1.encs, $1.checksum)); //#12134
    $puti($1.encstr, 2 + (21 * 3), $get($1.encs, 20)); //#12137
    $1.checkdigit = " "; //#12138
    if ($1.includecheckintext) { //#12141
        $1.checkdigit = $geti($1.barchars, $1.checksum, 1); //#12140
    } //#12140
    $put($1.txt, $1.i + 1, $a([$1.checkdigit, ((20 * 3) + 2) * 3.312, $1.textyoffset, $1.textfont, $1.textsize])); //#12142
    $puti($1.encstr, ((20 + 1) * 3) + 2, $get($1.encs, 20)); //#12145
    $1.bbs = $a((21 * 3) + 4); //#12147
    $1.bhs = $a($1.bbs.length); //#12148
    for (var _1d = 0, _1c = $1.bbs.length - 1; _1d <= _1c; _1d += 1) { //#12172
        $1.i = _1d; //#12150
        $1.enc = $geti($1.encstr, $1.i, 1); //#12151
        $1.bunit = 0; //#12152
        $1.hunit = 0; //#12153
        if ($eq($1.enc, "0")) { //#12157
            $1.bunit = 3; //#12155
            $1.hunit = 2; //#12156
        } //#12156
        if ($eq($1.enc, "1")) { //#12161
            $1.bunit = 0; //#12159
            $1.hunit = 5; //#12160
        } //#12160
        if ($eq($1.enc, "2")) { //#12165
            $1.bunit = 3; //#12163
            $1.hunit = 5; //#12164
        } //#12164
        if ($eq($1.enc, "3")) { //#12169
            $1.bunit = 0; //#12167
            $1.hunit = 8; //#12168
        } //#12168
        $put($1.bbs, $1.i, ($1.bunit * $1.height) / 8); //#12170
        $put($1.bhs, $1.i, ($1.hunit * $1.height) / 8); //#12171
    } //#12171
    $k[$j++] = Infinity; //#12183
    var _1t = $1.bbs; //#12177
    var _1u = $1.bhs; //#12178
    $k[$j++] = Infinity; //#12179
    for (var _1w = 0, _1x = $1.bhs.length - 1; _1w < _1x; _1w++) { //#12179
        $k[$j++] = 1.44; //#12179
        $k[$j++] = 1.872; //#12179
    } //#12179
    $k[$j++] = 1.44; //#12179
    var _1y = $a(); //#12179
    $k[$j++] = 'ren'; //#12182
    $k[$j++] = bwipp_renlinear; //#12182
    $k[$j++] = 'bbs'; //#12182
    $k[$j++] = _1t; //#12182
    $k[$j++] = 'bhs'; //#12182
    $k[$j++] = _1u; //#12182
    $k[$j++] = 'sbs'; //#12182
    $k[$j++] = _1y; //#12182
    if ($1.includetext) { //#12182
        $k[$j++] = 'txt'; //#12181
        $k[$j++] = $1.txt; //#12181
    } //#12181
    $k[$j++] = 'opt'; //#12183
    $k[$j++] = $1.options; //#12183
    var _22 = $d(); //#12183
    $k[$j++] = _22; //#12186
    if (!$1.dontdraw) { //#12186
        bwipp_renlinear(); //#12186
    } //#12186
}

function bwipp_msi() {
    var $1 = {}; //#12220
    $1.ctx = null; //#12222
    $1.dontdraw = false; //#12223
    $1.includecheck = false; //#12224
    $1.includetext = false; //#12225
    $1.includecheckintext = false; //#12226
    $1.checktype = "mod10"; //#12227
    $1.badmod11 = false; //#12228
    $1.textfont = "OCR-B"; //#12229
    $1.textsize = 10; //#12230
    $1.textyoffset = -8; //#12231
    $1.height = 1; //#12232
    $k[$j++] = $1; //#12234
    bwipp_processoptions(); //#12234
    $1.options = $k[--$j]; //#12234
    $1.barcode = $k[--$j]; //#12235
    $forall($1.barcode, function() { //#12244
        var _3 = $k[--$j]; //#12241
        if ((_3 < 48) || (_3 > 57)) { //#12243
            $k[$j++] = 'bwipp.msiBadCharacter'; //#12242
            $k[$j++] = "MSI must contain only digits"; //#12242
            bwipp_raiseerror(); //#12242
        } //#12242
    }); //#12242
    $1.encs = $a(["12121212", "12121221", "12122112", "12122121", "12211212", "12211221", "12212112", "12212121", "21121212", "21121221", "21", "121"]); //#12252
    $1.barchars = "0123456789"; //#12255
    $1.barlen = $1.barcode.length; //#12258
    $1.txtlen = $1.barlen; //#12259
    $1.mod10 = function() {
        $1.code = $k[--$j]; //#12262
        $k[$j++] = 0; //#12263
        $k[$j++] = 0; //#12263
        $forall($1.code, function() { //#12263
            var _9 = $k[--$j]; //#12263
            var _A = $k[--$j]; //#12263
            var _B = $k[--$j]; //#12263
            $k[$j++] = $f($f(_9 - 48) + (_A * 10)); //#12263
            $k[$j++] = _B; //#12263
        }); //#12263
        $j--; //#12263
        var _C = $k[--$j]; //#12263
        $k[$j++] = _C * 2; //#12264
        $k[$j++] = 0; //#12264
        for (;;) { //#12264
            var _D = $k[--$j]; //#12264
            var _E = $k[--$j]; //#12264
            var _F = ~~(_E / 10); //#12264
            $k[$j++] = $f(_D + (_E % 10)); //#12264
            $k[$j++] = _F; //#12264
            if (_F == 0) { //#12264
                $j--; //#12264
                break; //#12264
            } //#12264
            var _G = $k[--$j]; //#12264
            var _H = $k[--$j]; //#12264
            $k[$j++] = _G; //#12264
            $k[$j++] = _H; //#12264
        } //#12264
        $k[$j++] = 0; //#12265
        $k[$j++] = 0; //#12265
        $forall($1.code, function() { //#12265
            var _J = $k[--$j]; //#12265
            var _K = $k[--$j]; //#12265
            var _L = $k[--$j]; //#12265
            $k[$j++] = $f(_K + $f(_J - 48)); //#12265
            $k[$j++] = _L; //#12265
        }); //#12265
        var _M = $k[--$j]; //#12265
        var _N = $k[--$j]; //#12265
        $k[$j++] = _M; //#12265
        $k[$j++] = _N; //#12265
        $j--; //#12265
        var _O = $k[--$j]; //#12265
        var _R = $s($1.code.length + 1); //#12267
        $puti(_R, 0, $1.code); //#12267
        $put(_R, $1.code.length, $f((($f(10 - ($f($k[--$j] + _O) % 10))) % 10) + 48)); //#12267
        $k[$j++] = _R; //#12267
    }; //#12267
    $1.mod11 = function() {
        $1.code = $k[--$j]; //#12271
        $k[$j++] = $1.code.length - 1; //#12272
        $forall($1.code, function() { //#12272
            var _X = $k[--$j]; //#12272
            var _Y = $k[--$j]; //#12272
            $k[$j++] = $f(_X - 48); //#12272
            $k[$j++] = $f((_Y % 6) + 2); //#12272
            $k[$j++] = $f(_Y - 1); //#12272
        }); //#12272
        $j--; //#12272
        $k[$j++] = 0; //#12273
        for (var _a = 0, _b = $1.code.length; _a < _b; _a++) { //#12273
            var _c = $k[--$j]; //#12273
            var _d = $k[--$j]; //#12273
            var _e = $k[--$j]; //#12273
            $k[$j++] = $f(_c + (_e * _d)); //#12273
        } //#12273
        var _g = ($f(11 - ($k[--$j] % 11))) % 11; //#12275
        $k[$j++] = _g; //#12279
        if ((_g == 10) && $1.badmod11) { //#12278
            $j--; //#12276
            var _j = $s($1.code.length + 2); //#12276
            $puti(_j, 0, $1.code); //#12276
            $puti(_j, $1.code.length, "10"); //#12276
            $k[$j++] = _j; //#12276
        } else { //#12278
            var _n = $s($1.code.length + 1); //#12278
            $puti(_n, 0, $1.code); //#12278
            $put(_n, $1.code.length, $f($k[--$j] + 48)); //#12278
            $k[$j++] = _n; //#12278
        } //#12278
    }; //#12278
    $1.ncrmod11 = function() {
        $1.code = $k[--$j]; //#12283
        $k[$j++] = $1.code.length - 1; //#12284
        $forall($1.code, function() { //#12284
            var _u = $k[--$j]; //#12284
            var _v = $k[--$j]; //#12284
            $k[$j++] = $f(_u - 48); //#12284
            $k[$j++] = $f((_v % 8) + 2); //#12284
            $k[$j++] = $f(_v - 1); //#12284
        }); //#12284
        $j--; //#12284
        $k[$j++] = 0; //#12285
        for (var _x = 0, _y = $1.code.length; _x < _y; _x++) { //#12285
            var _z = $k[--$j]; //#12285
            var _10 = $k[--$j]; //#12285
            var _11 = $k[--$j]; //#12285
            $k[$j++] = $f(_z + (_11 * _10)); //#12285
        } //#12285
        var _13 = ($f(11 - ($k[--$j] % 11))) % 11; //#12287
        $k[$j++] = _13; //#12291
        if ((_13 == 10) && $1.badmod11) { //#12290
            $j--; //#12288
            var _16 = $s($1.code.length + 2); //#12288
            $puti(_16, 0, $1.code); //#12288
            $puti(_16, $1.code.length, "10"); //#12288
            $k[$j++] = _16; //#12288
        } else { //#12290
            var _1A = $s($1.code.length + 1); //#12290
            $puti(_1A, 0, $1.code); //#12290
            $put(_1A, $1.code.length, $f($k[--$j] + 48)); //#12290
            $k[$j++] = _1A; //#12290
        } //#12290
    }; //#12290
    if ($1.includecheck) { //#12305
        if ($eq($1.checktype, "mod10")) { //#12296
            $k[$j++] = $1.barcode; //#12296
            $1.mod10(); //#12296
        } //#12296
        if ($eq($1.checktype, "mod1010")) { //#12297
            $k[$j++] = $1.barcode; //#12297
            $1.mod10(); //#12297
            $1.mod10(); //#12297
        } //#12297
        if ($eq($1.checktype, "mod11")) { //#12298
            $k[$j++] = $1.barcode; //#12298
            $1.mod11(); //#12298
        } //#12298
        if ($eq($1.checktype, "ncrmod11")) { //#12299
            $k[$j++] = $1.barcode; //#12299
            $1.ncrmod11(); //#12299
        } //#12299
        if ($eq($1.checktype, "mod1110")) { //#12300
            $k[$j++] = $1.barcode; //#12300
            $1.mod11(); //#12300
            $1.mod10(); //#12300
        } //#12300
        if ($eq($1.checktype, "ncrmod1110")) { //#12301
            $k[$j++] = $1.barcode; //#12301
            $1.ncrmod11(); //#12301
            $1.mod10(); //#12301
        } //#12301
        $1.barcode = $k[--$j]; //#12302
        $1.barlen = $1.barcode.length; //#12303
        if ($1.includecheckintext) { //#12304
            $1.txtlen = $1.barlen; //#12304
        } //#12304
    } //#12304
    $1.sbs = $s(($1.barlen * 8) + 5); //#12307
    $1.txt = $a($1.barlen); //#12308
    $puti($1.sbs, 0, $get($1.encs, 10)); //#12311
    for (var _1e = 0, _1d = $1.barlen - 1; _1e <= _1d; _1e += 1) { //#12323
        $1.i = _1e; //#12314
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#12316
        $j--; //#12317
        $1.indx = $k[--$j].length; //#12318
        $j -= 2; //#12319
        $1.enc = $get($1.encs, $1.indx); //#12320
        $puti($1.sbs, ($1.i * 8) + 2, $1.enc); //#12321
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 12) + 3, $1.textyoffset, $1.textfont, $1.textsize])); //#12322
    } //#12322
    $puti($1.sbs, ($1.barlen * 8) + 2, $get($1.encs, 11)); //#12326
    $k[$j++] = Infinity; //#12337
    $k[$j++] = Infinity; //#12331
    var _24 = $1.sbs; //#12331
    for (var _25 = 0, _26 = _24.length; _25 < _26; _25++) { //#12331
        $k[$j++] = $get(_24, _25) - 48; //#12331
    } //#12331
    var _28 = $a(); //#12331
    $k[$j++] = Infinity; //#12332
    for (var _2A = 0, _2B = ~~(($1.sbs.length + 1) / 2); _2A < _2B; _2A++) { //#12332
        $k[$j++] = $1.height; //#12332
    } //#12332
    var _2D = $a(); //#12332
    $k[$j++] = Infinity; //#12333
    for (var _2F = 0, _2G = ~~(($1.sbs.length + 1) / 2); _2F < _2G; _2F++) { //#12333
        $k[$j++] = 0; //#12333
    } //#12333
    var _2H = $a(); //#12333
    $k[$j++] = 'ren'; //#12336
    $k[$j++] = bwipp_renlinear; //#12336
    $k[$j++] = 'sbs'; //#12336
    $k[$j++] = _28; //#12336
    $k[$j++] = 'bhs'; //#12336
    $k[$j++] = _2D; //#12336
    $k[$j++] = 'bbs'; //#12336
    $k[$j++] = _2H; //#12336
    if ($1.includetext) { //#12336
        $k[$j++] = 'txt'; //#12335
        $k[$j++] = $geti($1.txt, 0, $1.txtlen); //#12335
    } //#12335
    $k[$j++] = 'opt'; //#12337
    $k[$j++] = $1.options; //#12337
    var _2N = $d(); //#12337
    $k[$j++] = _2N; //#12340
    if (!$1.dontdraw) { //#12340
        bwipp_renlinear(); //#12340
    } //#12340
}

function bwipp_plessey() {
    var $1 = {}; //#12374
    $1.ctx = null; //#12376
    $1.dontdraw = false; //#12377
    $1.includetext = false; //#12378
    $1.validatecheck = false; //#12379
    $1.includecheckintext = false; //#12380
    $1.unidirectional = false; //#12381
    $1.textfont = "OCR-B"; //#12382
    $1.textsize = 10; //#12383
    $1.textyoffset = -8; //#12384
    $1.height = 1; //#12385
    $k[$j++] = $1; //#12387
    bwipp_processoptions(); //#12387
    $1.options = $k[--$j]; //#12387
    $1.barcode = $k[--$j]; //#12388
    $1.barchars = "0123456789ABCDEF"; //#12394
    $1.charvals = new Map; //#12395
    for (var _2 = 0; _2 <= 15; _2 += 1) { //#12396
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#12396
    } //#12396
    $1.encs = $a(["14141414", "32141414", "14321414", "32321414", "14143214", "32143214", "14323214", "32323214", "14141432", "32141432", "14321432", "32321432", "14143232", "32143232", "14323232", "32323232", "32321432", "541412323", "323"]); //#12405
    for (var _9 = 0, _8 = $1.barcode.length - 1; _9 <= _8; _9 += 1) { //#12413
        var _D = $get($1.charvals, $geti($1.barcode, _9, 1)) !== undefined; //#12410
        if (!_D) { //#12412
            $k[$j++] = 'bwipp.plesseyBadCharacter'; //#12411
            $k[$j++] = "Plessey must contain only digits and letters A B C D E F"; //#12411
            bwipp_raiseerror(); //#12411
        } //#12411
    } //#12411
    $k[$j++] = 'barlen'; //#12415
    $k[$j++] = $1.barcode.length; //#12415
    if ($1.validatecheck) { //#12415
        var _G = $k[--$j]; //#12415
        $k[$j++] = $f(_G - 2); //#12415
    } //#12415
    var _H = $k[--$j]; //#12415
    $1[$k[--$j]] = _H; //#12415
    $1.checkbits = $a($f(($1.barlen * 4) + 8)); //#12418
    $puti($1.checkbits, $1.barlen * 4, $a([0, 0, 0, 0, 0, 0, 0, 0])); //#12419
    for (var _Q = 0, _P = $f($1.barlen - 1); _Q <= _P; _Q += 1) { //#12429
        $1.i = _Q; //#12421
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#12422
        $puti($1.checkbits, $1.i * 4, $a([$1.indx & 1, ($1.indx >>> 1) & 1, ($1.indx >>> 2) & 1, $1.indx >>> 3])); //#12428
    } //#12428
    $1.checksalt = $a([1, 1, 1, 1, 0, 1, 0, 0, 1]); //#12430
    for (var _g = 0, _f = $f(($1.barlen * 4) - 1); _g <= _f; _g += 1) { //#12439
        $1.i = _g; //#12432
        if ($get($1.checkbits, $1.i) == 1) { //#12438
            for (var _k = 0; _k <= 8; _k += 1) { //#12437
                $1.j = _k; //#12435
                $put($1.checkbits, $1.i + $1.j, $xo($get($1.checkbits, $1.i + $1.j), $get($1.checksalt, $1.j))); //#12436
            } //#12436
        } //#12436
    } //#12436
    $1.checkval = 0; //#12440
    for (var _v = 0; _v <= 7; _v += 1) { //#12444
        $1.i = _v; //#12442
        $1.checkval = $f($1.checkval + ((~~Math.pow(2, $1.i)) * $get($1.checkbits, $f(($1.barlen * 4) + $1.i)))); //#12443
    } //#12443
    $1.checksum1 = $1.checkval & 15; //#12445
    $1.checksum2 = $1.checkval >>> 4; //#12446
    if ($1.validatecheck) { //#12453
        if (($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum1)) || ($get($1.barcode, $f($1.barlen + 1)) != $get($1.barchars, $1.checksum2))) { //#12451
            $k[$j++] = 'bwipp.plesseyBadCheckDigits'; //#12450
            $k[$j++] = "Incorrect Plessey check digits provided"; //#12450
            bwipp_raiseerror(); //#12450
        } //#12450
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#12452
    } //#12452
    var _1M = $1.unidirectional ? 27 : 33; //#12455
    $1.sbs = $s($f(($1.barlen * 8) + _1M)); //#12455
    $1.txt = $a($f($1.barlen + 2)); //#12456
    $puti($1.sbs, 0, $get($1.encs, 16)); //#12459
    for (var _1V = 0, _1U = $f($1.barlen - 1); _1V <= _1U; _1V += 1) { //#12466
        $1.i = _1V; //#12462
        $1.indx = $get($1.charvals, $geti($1.barcode, $1.i, 1)); //#12463
        $puti($1.sbs, ($1.i * 8) + 8, $get($1.encs, $1.indx)); //#12464
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), ($1.i * 20) + 20, $1.textyoffset, $1.textfont, $1.textsize])); //#12465
    } //#12465
    $puti($1.sbs, $f(($1.barlen * 8) + 8), $get($1.encs, $1.checksum1)); //#12469
    $puti($1.sbs, $f(($1.barlen * 8) + 16), $get($1.encs, $1.checksum2)); //#12470
    if ($1.includecheckintext) { //#12476
        $put($1.txt, $1.barlen, $a([$geti($1.barchars, $1.checksum1, 1), $f(($1.barlen * 20) + 20), $1.textyoffset, $1.textfont, $1.textsize])); //#12472
        $put($1.txt, $f($1.barlen + 1), $a([$geti($1.barchars, $1.checksum2, 1), $f(($f($1.barlen + 1) * 20) + 20), $1.textyoffset, $1.textfont, $1.textsize])); //#12473
    } else { //#12476
        $put($1.txt, $1.barlen, $a([" ", $f(($1.barlen * 20) + 20), $1.textyoffset, $1.textfont, $1.textsize])); //#12475
        $put($1.txt, $f($1.barlen + 1), $a([" ", $f(($f($1.barlen + 1) * 20) + 20), $1.textyoffset, $1.textfont, $1.textsize])); //#12476
    } //#12476
    var _2d = $1.unidirectional ? 18 : 17; //#12480
    $puti($1.sbs, $f(($1.barlen * 8) + 24), $get($1.encs, _2d)); //#12480
    $k[$j++] = Infinity; //#12491
    $k[$j++] = Infinity; //#12485
    var _2f = $1.sbs; //#12485
    for (var _2g = 0, _2h = _2f.length; _2g < _2h; _2g++) { //#12485
        $k[$j++] = $get(_2f, _2g) - 48; //#12485
    } //#12485
    var _2j = $a(); //#12485
    $k[$j++] = Infinity; //#12486
    for (var _2l = 0, _2m = ~~(($1.sbs.length + 1) / 2); _2l < _2m; _2l++) { //#12486
        $k[$j++] = $1.height; //#12486
    } //#12486
    var _2o = $a(); //#12486
    $k[$j++] = Infinity; //#12487
    for (var _2q = 0, _2r = ~~(($1.sbs.length + 1) / 2); _2q < _2r; _2q++) { //#12487
        $k[$j++] = 0; //#12487
    } //#12487
    var _2s = $a(); //#12487
    $k[$j++] = 'ren'; //#12490
    $k[$j++] = bwipp_renlinear; //#12490
    $k[$j++] = 'sbs'; //#12490
    $k[$j++] = _2j; //#12490
    $k[$j++] = 'bhs'; //#12490
    $k[$j++] = _2o; //#12490
    $k[$j++] = 'bbs'; //#12490
    $k[$j++] = _2s; //#12490
    if ($1.includetext) { //#12490
        $k[$j++] = 'txt'; //#12489
        $k[$j++] = $1.txt; //#12489
    } //#12489
    $k[$j++] = 'opt'; //#12491
    $k[$j++] = $1.options; //#12491
    var _2w = $d(); //#12491
    $k[$j++] = _2w; //#12494
    if (!$1.dontdraw) { //#12494
        bwipp_renlinear(); //#12494
    } //#12494
}

function bwipp_telepen() {
    var $1 = {}; //#12529
    $1.ctx = null; //#12531
    $1.numeric = false; //#12532
    $1.dontdraw = false; //#12533
    $1.includetext = false; //#12534
    $1.textfont = "OCR-B"; //#12535
    $1.textsize = 10; //#12536
    $1.textyoffset = -8; //#12537
    $1.height = 1; //#12538
    $1.parse = false; //#12539
    $k[$j++] = $1; //#12541
    bwipp_processoptions(); //#12541
    $1.options = $k[--$j]; //#12541
    $1.barcode = $k[--$j]; //#12542
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#12550
    $1.fncvals = _3; //#12551
    $k[$j++] = 'barcode'; //#12552
    $k[$j++] = $1.barcode; //#12552
    $k[$j++] = $1.fncvals; //#12552
    bwipp_parseinput(); //#12552
    var _6 = $k[--$j]; //#12552
    $1[$k[--$j]] = _6; //#12552
    $1.barlen = $1.barcode.length; //#12553
    delete $1.options["parse"]; //#12554
    $1.encs = $a(["31313131", "1131313111", "33313111", "1111313131", "3111313111", "11333131", "13133131", "111111313111", "31333111", "1131113131", "33113131", "1111333111", "3111113131", "1113133111", "1311133111", "111111113131", "3131113111", "11313331", "333331", "111131113111", "31113331", "1133113111", "1313113111", "1111113331", "31131331", "113111113111", "3311113111", "1111131331", "311111113111", "1113111331", "1311111331", "11111111113111", "31313311", "1131311131", "33311131", "1111313311", "3111311131", "11333311", "13133311", "111111311131", "31331131", "1131113311", "33113311", "1111331131", "3111113311", "1113131131", "1311131131", "111111113311", "3131111131", "1131131311", "33131311", "111131111131", "3111131311", "1133111131", "1313111131", "111111131311", "3113111311", "113111111131", "3311111131", "111113111311", "311111111131", "111311111311", "131111111311", "11111111111131", "3131311111", "11313133", "333133", "111131311111", "31113133", "1133311111", "1313311111", "1111113133", "313333", "113111311111", "3311311111", "11113333", "311111311111", "11131333", "13111333", "11111111311111", "31311133", "1131331111", "33331111", "1111311133", "3111331111", "11331133", "13131133", "111111331111", "3113131111", "1131111133", "33111133", "111113131111", "3111111133", "111311131111", "131111131111", "111111111133", "31311313", "113131111111", "3331111111", "1111311313", "311131111111", "11331313", "13131313", "11111131111111", "3133111111", "1131111313", "33111313", "111133111111", "3111111313", "111313111111", "131113111111", "111111111313", "313111111111", "1131131113", "33131113", "11113111111111", "3111131113", "113311111111", "131311111111", "111111131113", "3113111113", "11311111111111", "331111111111", "111113111113", "31111111111111", "111311111113", "131111111113", "1111111111111111"]); //#12591
    $1.barlen = $1.barcode.length; //#12594
    $1.sbs = $s(($1.barlen * 16) + 48); //#12595
    $1.txt = $a($1.barlen); //#12596
    $1.enc = $get($1.encs, 95); //#12599
    $puti($1.sbs, 0, $1.enc); //#12600
    $1.l = $1.enc.length; //#12601
    $1.checksum = 0; //#12603
    $1.i = 0; //#12604
    $1.j = 0; //#12604
    for (;;) { //#12636
        if ($1.i == $1.barlen) { //#12606
            break; //#12606
        } //#12606
        if ($1.numeric) { //#12629
            if ($get($1.barcode, $1.i) > 16) { //#12620
                $1.np = $geti($1.barcode, $1.i, 2); //#12609
                if ($eq($geti($1.np, 1, 1), "X")) { //#12613
                    $1.indx = $cvi($geti($1.np, 0, 1)) + 17; //#12611
                } else { //#12613
                    $1.indx = $cvi($1.np) + 27; //#12613
                } //#12613
                $put($1.txt, $1.j, $a([$1.np, ($1.j * 16) + 16, $1.textyoffset, $1.textfont, $1.textsize])); //#12615
                $1.i = $1.i + 2; //#12616
            } else { //#12620
                $1.indx = $get($1.barcode, $1.i); //#12618
                $put($1.txt, $1.j, $a([" ", ($1.j * 16) + 16, $1.textyoffset, $1.textfont, $1.textsize])); //#12619
                $1.i = $1.i + 1; //#12620
            } //#12620
        } else { //#12629
            $1.indx = $get($1.barcode, $1.i); //#12623
            if (($1.indx >= 32) && ($1.indx <= 126)) { //#12627
                $put($1.txt, $1.j, $a([$geti($1.barcode, $1.i, 1), ($1.j * 16) + 16, $1.textyoffset, $1.textfont, $1.textsize])); //#12625
            } else { //#12627
                $put($1.txt, $1.j, $a([" ", ($1.j * 16) + 16, $1.textyoffset, $1.textfont, $1.textsize])); //#12627
            } //#12627
            $1.i = $1.i + 1; //#12629
        } //#12629
        $1.checksum = $f($1.checksum + $1.indx); //#12631
        $1.enc = $get($1.encs, $1.indx); //#12632
        $puti($1.sbs, $1.l, $1.enc); //#12633
        $1.l = $1.l + $1.enc.length; //#12634
        $1.j = $1.j + 1; //#12635
    } //#12635
    $1.checksum = ($f(127 - ($1.checksum % 127))) % 127; //#12639
    $1.enc = $get($1.encs, $1.checksum); //#12640
    $puti($1.sbs, $1.l, $1.enc); //#12641
    $1.l = $1.l + $1.enc.length; //#12642
    $1.enc = $get($1.encs, 122); //#12645
    $puti($1.sbs, $1.l, $1.enc); //#12646
    $1.l = $1.l + $1.enc.length; //#12647
    $1.sbs = $geti($1.sbs, 0, $1.l); //#12650
    $1.txt = $geti($1.txt, 0, $1.j); //#12651
    $k[$j++] = Infinity; //#12662
    $k[$j++] = Infinity; //#12656
    var _1n = $1.sbs; //#12656
    for (var _1o = 0, _1p = _1n.length; _1o < _1p; _1o++) { //#12656
        $k[$j++] = $f($get(_1n, _1o) - 48); //#12656
    } //#12656
    var _1r = $a(); //#12656
    $k[$j++] = Infinity; //#12657
    for (var _1t = 0, _1u = ~~(($1.sbs.length + 1) / 2); _1t < _1u; _1t++) { //#12657
        $k[$j++] = $1.height; //#12657
    } //#12657
    var _1w = $a(); //#12657
    $k[$j++] = Infinity; //#12658
    for (var _1y = 0, _1z = ~~(($1.sbs.length + 1) / 2); _1y < _1z; _1y++) { //#12658
        $k[$j++] = 0; //#12658
    } //#12658
    var _20 = $a(); //#12658
    $k[$j++] = 'ren'; //#12661
    $k[$j++] = bwipp_renlinear; //#12661
    $k[$j++] = 'sbs'; //#12661
    $k[$j++] = _1r; //#12661
    $k[$j++] = 'bhs'; //#12661
    $k[$j++] = _1w; //#12661
    $k[$j++] = 'bbs'; //#12661
    $k[$j++] = _20; //#12661
    if ($1.includetext) { //#12661
        $k[$j++] = 'txt'; //#12660
        $k[$j++] = $1.txt; //#12660
    } //#12660
    $k[$j++] = 'opt'; //#12662
    $k[$j++] = $1.options; //#12662
    var _24 = $d(); //#12662
    $k[$j++] = _24; //#12665
    if (!$1.dontdraw) { //#12665
        bwipp_renlinear(); //#12665
    } //#12665
}

function bwipp_telepennumeric() {
    var $1 = {}; //#12698
    $1.ctx = null; //#12700
    $1.dontdraw = false; //#12701
    $1.includetext = false; //#12702
    $1.textfont = "OCR-B"; //#12703
    $1.textsize = 10; //#12704
    $1.textxoffset = 0; //#12705
    $1.textyoffset = -8; //#12706
    $1.height = 1; //#12707
    $k[$j++] = $1; //#12709
    bwipp_processoptions(); //#12709
    $1.options = $k[--$j]; //#12709
    $1.barcode = $k[--$j]; //#12710
    $put($1.options, "dontdraw", true); //#12713
    $put($1.options, "numeric", true); //#12714
    $k[$j++] = 'args'; //#12716
    $k[$j++] = $1.barcode; //#12716
    $k[$j++] = $1.options; //#12716
    bwipp_telepen(); //#12716
    var _6 = $k[--$j]; //#12716
    $1[$k[--$j]] = _6; //#12716
    $put($1.args, "opt", $1.options); //#12718
    $k[$j++] = $1.args; //#12721
    if (!$1.dontdraw) { //#12721
        bwipp_renlinear(); //#12721
    } //#12721
}

function bwipp_posicode() {
    var $1 = {}; //#12754
    $1.ctx = null; //#12756
    $1.dontdraw = false; //#12757
    $1.includetext = false; //#12758
    $1.textfont = "OCR-B"; //#12759
    $1.textsize = 10; //#12760
    $1.textxoffset = 0; //#12761
    $1.textyoffset = -8; //#12762
    $1.height = 1; //#12763
    $1.encoding = "auto"; //#12764
    $1.version = "a"; //#12765
    $1.checkoffset = 0; //#12766
    $1.raw = false; //#12767
    $1.parse = false; //#12768
    $1.parsefnc = false; //#12769
    $k[$j++] = $1; //#12771
    bwipp_processoptions(); //#12771
    $1.options = $k[--$j]; //#12771
    var _1 = $k[--$j]; //#12772
    $1.barcode = _1; //#12772
    $1.la0 = -1; //#12778
    $1.la1 = -2; //#12778
    $1.la2 = -3; //#12778
    $1.sf0 = -4; //#12779
    $1.sf1 = -5; //#12779
    $1.sf2 = -6; //#12779
    $1.fn1 = -7; //#12780
    $1.fn2 = -8; //#12780
    $1.fn3 = -9; //#12780
    $1.fn4 = -10; //#12780
    $1.charmapsnormal = $a([$a(["0", "^", "'"]), $a(["1", ";", 27]), $a(["2", "<", 28]), $a(["3", "=", 29]), $a(["4", ">", 30]), $a(["5", "?", 31]), $a(["6", "@", "!"]), $a(["7", "[", "\""]), $a(["8", 92, "#"]), $a(["9", "]", "&"]), $a(["A", "a", 1]), $a(["B", "b", 2]), $a(["C", "c", 3]), $a(["D", "d", 4]), $a(["E", "e", 5]), $a(["F", "f", 6]), $a(["G", "g", 7]), $a(["H", "h", 8]), $a(["I", "i", 9]), $a(["J", "j", 10]), $a(["K", "k", 11]), $a(["L", "l", 12]), $a(["M", "m", 13]), $a(["N", "n", 14]), $a(["O", "o", 15]), $a(["P", "p", 16]), $a(["Q", "q", 17]), $a(["R", "r", 18]), $a(["S", "s", 19]), $a(["T", "t", 20]), $a(["U", "u", 21]), $a(["V", "v", 22]), $a(["W", "w", 23]), $a(["X", "x", 24]), $a(["Y", "y", 25]), $a(["Z", "z", 26]), $a(["-", "_", 40]), $a([".", "`", 41]), $a([" ", 127, 0]), $a(["$", "{", "*"]), $a(["/", "|", ","]), $a(["+", "}", ":"]), $a(["%", "~", $1.fn1]), $a([$1.la1, $1.la0, $1.fn2]), $a([$1.sf1, $1.sf0, $1.fn3]), $a([$1.sf2, $1.sf2, $1.fn4])]); //#12801
    $1.chapmapslimited = $a([$a(["0", -98, -98]), $a(["1", -98, -98]), $a(["2", -98, -98]), $a(["3", -98, -98]), $a(["4", -98, -98]), $a(["5", -98, -98]), $a(["6", -98, -98]), $a(["7", -98, -98]), $a(["8", -98, -98]), $a(["9", -98, -98]), $a(["A", -98, -98]), $a(["B", -98, -98]), $a(["C", -98, -98]), $a(["D", -98, -98]), $a(["E", -98, -98]), $a(["F", -98, -98]), $a(["G", -98, -98]), $a(["H", -98, -98]), $a(["I", -98, -98]), $a(["J", -98, -98]), $a(["K", -98, -98]), $a(["L", -98, -98]), $a(["M", -98, -98]), $a(["N", -98, -98]), $a(["O", -98, -98]), $a(["P", -98, -98]), $a(["Q", -98, -98]), $a(["R", -98, -98]), $a(["S", -98, -98]), $a(["T", -98, -98]), $a(["U", -98, -98]), $a(["V", -98, -98]), $a(["W", -98, -98]), $a(["X", -98, -98]), $a(["Y", -98, -98]), $a(["Z", -98, -98]), $a(["-", -98, -98]), $a([".", -98, -98])]); //#12816
    $k[$j++] = 'charmaps'; //#12819
    if ($eq($1.version, "a") || $eq($1.version, "b")) { //#12819
        $k[$j++] = $1.charmapsnormal; //#12819
    } else { //#12819
        $k[$j++] = $1.chapmapslimited; //#12819
    } //#12819
    var _1e = $k[--$j]; //#12819
    $1[$k[--$j]] = _1e; //#12819
    var _1g = $1.charmaps; //#12823
    var _1h = $1.charmaps; //#12823
    var _1i = $1.charmaps; //#12823
    $1.charvals = $a([new Map, new Map, new Map]); //#12824
    for (var _1m = 0, _1l = $1.charmaps.length - 1; _1m <= _1l; _1m += 1) { //#12833
        $1.i = _1m; //#12826
        $1.encs = $get($1.charmaps, $1.i); //#12827
        for (var _1q = 0; _1q <= 2; _1q += 1) { //#12832
            $1.j = _1q; //#12829
            var _1t = $get($1.encs, $1.j); //#12830
            $k[$j++] = _1t; //#12830
            if ($eq($type(_1t), 'stringtype')) { //#12830
                var _1w = $get($k[--$j], 0); //#12830
                $k[$j++] = _1w; //#12830
            } //#12830
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#12831
        } //#12831
    } //#12831
    $1.set0 = $get($1.charvals, 0); //#12834
    $1.set1 = $get($1.charvals, 1); //#12835
    $1.set2 = $get($1.charvals, 2); //#12836
    if ($1.raw) { //#12838
        $1.encoding = "raw"; //#12838
    } //#12838
    if ($eq($1.encoding, "raw")) { //#12852
        $1.cws = $a($1.barcode.length); //#12841
        $1.i = 0; //#12842
        $1.j = 0; //#12842
        for (;;) { //#12849
            if ($1.i == $1.barcode.length) { //#12844
                break; //#12844
            } //#12844
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#12845
            $put($1.cws, $1.j, $1.cw); //#12846
            $1.i = $1.i + 4; //#12847
            $1.j = $1.j + 1; //#12848
        } //#12848
        $1.cws = $geti($1.cws, 0, $1.j); //#12850
        $1.text = ""; //#12851
    } //#12851
    if ($eq($1.encoding, "auto")) { //#12967
        var _2V = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["FNC1", $1.fn1],
            ["FNC2", $1.fn2],
            ["FNC3", $1.fn3]
        ]); //#12862
        $1.fncvals = _2V; //#12864
        $k[$j++] = 'msg'; //#12865
        $k[$j++] = $1.barcode; //#12865
        $k[$j++] = $1.fncvals; //#12865
        bwipp_parseinput(); //#12865
        var _2Y = $k[--$j]; //#12865
        $1[$k[--$j]] = _2Y; //#12865
        $1.msglen = $1.msg.length; //#12866
        $1.text = $s($1.msglen); //#12868
        for (var _2f = 0, _2e = $1.msglen - 1; _2f <= _2e; _2f += 1) { //#12872
            $1.i = _2f; //#12870
            var _2k = $get($1.msg, $1.i); //#12871
            $k[$j++] = $1.text; //#12871
            $k[$j++] = $1.i; //#12871
            $k[$j++] = _2k; //#12871
            if (_2k < 0) { //#12871
                $j--; //#12871
                $k[$j++] = 32; //#12871
            } //#12871
            var _2l = $k[--$j]; //#12871
            var _2m = $k[--$j]; //#12871
            $put($k[--$j], _2m, _2l); //#12871
        } //#12871
        $k[$j++] = Infinity; //#12875
        for (var _2p = 0, _2q = $1.msglen; _2p < _2q; _2p++) { //#12875
            $k[$j++] = 0; //#12875
        } //#12875
        $k[$j++] = 0; //#12875
        $1.numSA = $a(); //#12875
        $k[$j++] = Infinity; //#12876
        for (var _2t = 0, _2u = $1.msglen; _2t < _2u; _2t++) { //#12876
            $k[$j++] = 0; //#12876
        } //#12876
        $k[$j++] = 0; //#12876
        $1.numEA = $a(); //#12876
        for (var _2x = $1.msglen - 1; _2x >= 0; _2x -= 1) { //#12886
            $1.i = _2x; //#12878
            if ($get($1.msg, $1.i) >= 0) { //#12885
                if ($get($1.msg, $1.i) >= 128) { //#12883
                    $put($1.numEA, $1.i, $f($get($1.numEA, $1.i + 1) + 1)); //#12881
                } else { //#12883
                    $put($1.numSA, $1.i, $f($get($1.numSA, $1.i + 1) + 1)); //#12883
                } //#12883
            } //#12883
        } //#12883
        $1.ea = false; //#12889
        $1.msgtmp = $a([]); //#12889
        for (var _3H = 0, _3G = $1.msglen - 1; _3H <= _3G; _3H += 1) { //#12904
            $1.i = _3H; //#12891
            $1.c = $get($1.msg, $1.i); //#12892
            if ((!$xo($1.ea, $1.c < 128)) && ($1.c >= 0)) { //#12902
                if ($1.ea) { //#12894
                    $k[$j++] = $1.numSA; //#12894
                } else { //#12894
                    $k[$j++] = $1.numEA; //#12894
                } //#12894
                var _3T = $get($k[--$j], $1.i); //#12894
                var _3W = ($f(_3T + $1.i) == $1.msglen) ? 3 : 5; //#12895
                if (_3T < _3W) { //#12900
                    $k[$j++] = Infinity; //#12897
                    $aload($1.msgtmp); //#12897
                    $k[$j++] = $1.fn4; //#12897
                    $1.msgtmp = $a(); //#12897
                } else { //#12900
                    $k[$j++] = Infinity; //#12899
                    $aload($1.msgtmp); //#12899
                    $k[$j++] = $1.fn4; //#12899
                    $k[$j++] = $1.fn4; //#12899
                    $1.msgtmp = $a(); //#12899
                    $1.ea = !$1.ea; //#12900
                } //#12900
            } //#12900
            $k[$j++] = Infinity; //#12903
            $aload($1.msgtmp); //#12903
            if ($1.c >= 0) { //#12903
                $k[$j++] = $1.c & 127; //#12903
            } else { //#12903
                $k[$j++] = $1.c; //#12903
            } //#12903
            $1.msgtmp = $a(); //#12903
        } //#12903
        $1.msg = $1.msgtmp; //#12905
        $1.msglen = $1.msg.length; //#12906
        $1.enc = function() {
            var _3m = $k[--$j]; //#12910
            $put($1.cws, $1.j, $get(_3m, $k[--$j])); //#12910
            $1.j = $1.j + 1; //#12911
        }; //#12911
        $1.cws = $a($1.msglen * 2); //#12914
        $1.i = 0; //#12915
        $1.j = 0; //#12915
        $1.cset = "set0"; //#12915
        for (;;) { //#12965
            if ($1.i == $1.msglen) { //#12917
                break; //#12917
            } //#12917
            for (;;) { //#12963
                $1.char1 = $get($1.msg, $1.i); //#12922
                $k[$j++] = 'char2'; //#12923
                if (($1.i + 1) < $1.msglen) { //#12923
                    $k[$j++] = $get($1.msg, $1.i + 1); //#12923
                } else { //#12923
                    $k[$j++] = -99; //#12923
                } //#12923
                var _44 = $k[--$j]; //#12923
                $1[$k[--$j]] = _44; //#12923
                var _49 = $get($1[$1.cset], $1.char1) !== undefined; //#12926
                if (_49) { //#12930
                    $k[$j++] = $1.char1; //#12927
                    $k[$j++] = $1[$1.cset]; //#12927
                    $1.enc(); //#12927
                    $1.i = $1.i + 1; //#12928
                    break; //#12929
                } //#12929
                var _4G = $get($1.set2, $1.char1) !== undefined; //#12933
                if (_4G) { //#12938
                    $k[$j++] = $1.sf2; //#12934
                    $k[$j++] = $1[$1.cset]; //#12934
                    $1.enc(); //#12934
                    $k[$j++] = $1.char1; //#12935
                    $k[$j++] = $1.set2; //#12935
                    $1.enc(); //#12935
                    $1.i = $1.i + 1; //#12936
                    break; //#12937
                } //#12937
                var _4Q = $get($1[$1.cset], $1.char2) !== undefined; //#12941
                if (!_4Q) { //#12959
                    if ($eq($1.cset, "set0")) { //#12947
                        $k[$j++] = $1.la1; //#12943
                        $k[$j++] = $1[$1.cset]; //#12943
                        $1.enc(); //#12943
                        $1.cset = "set1"; //#12944
                    } else { //#12947
                        $k[$j++] = $1.la0; //#12946
                        $k[$j++] = $1[$1.cset]; //#12946
                        $1.enc(); //#12946
                        $1.cset = "set0"; //#12947
                    } //#12947
                    break; //#12949
                } else { //#12959
                    if ($eq($1.cset, "set0")) { //#12956
                        $k[$j++] = $1.sf1; //#12952
                        $k[$j++] = $1[$1.cset]; //#12952
                        $1.enc(); //#12952
                        $k[$j++] = $1.char1; //#12953
                        $k[$j++] = $1.set1; //#12953
                        $1.enc(); //#12953
                    } else { //#12956
                        $k[$j++] = $1.sf0; //#12955
                        $k[$j++] = $1[$1.cset]; //#12955
                        $1.enc(); //#12955
                        $k[$j++] = $1.char1; //#12956
                        $k[$j++] = $1.set0; //#12956
                        $1.enc(); //#12956
                    } //#12956
                    $1.i = $1.i + 1; //#12958
                    break; //#12959
                } //#12959
                break; //#12962
            } //#12962
        } //#12962
        $1.cws = $geti($1.cws, 0, $1.j); //#12966
    } //#12966
    var _4r = new Map([
        ["a", $a(["141112", "131212", "121312", "111412", "131113", "121213", "111313", "121114", "111214", "111115", "181111", "171211", "161311", "151411", "141511", "131611", "121711", "111811", "171112", "161212", "151312", "141412", "131512", "121612", "111712", "161113", "151213", "141313", "131413", "121513", "111613", "151114", "141214", "131314", "121414", "111514", "141115", "131215", "121315", "111415", "131116", "121216", "111316", "121117", "111217", "111118", "1<111112", "111111111;1"])],
        ["b", $a(["151213", "141313", "131413", "121513", "141214", "131314", "121414", "131215", "121315", "121216", "191212", "181312", "171412", "161512", "151612", "141712", "131812", "121912", "181213", "171313", "161413", "151513", "141613", "131713", "121813", "171214", "161314", "151414", "141514", "131614", "121714", "161215", "151315", "141415", "131515", "121615", "151216", "141316", "131416", "121516", "141217", "131317", "121417", "131218", "121318", "121219", "1<121312", "121212121<1"])],
        ["limiteda", $a(["111411", "111312", "111213", "111114", "121311", "121212", "121113", "141111", "131211", "131112", "171111", "161211", "151311", "141411", "131511", "121611", "111711", "161112", "151212", "141312", "131412", "121512", "111612", "151113", "141213", "131313", "121413", "111513", "141114", "131214", "121314", "111414", "131115", "121215", "111315", "121116", "111216", "111117", "151111", "1"])],
        ["limitedb", $a(["121512", "121413", "121314", "121215", "131412", "131313", "131214", "151212", "141312", "141213", "181212", "171312", "161412", "151512", "141612", "131712", "121812", "171213", "161313", "151413", "141513", "131613", "121713", "161214", "151314", "141414", "131514", "121614", "151215", "141315", "131415", "121515", "141216", "131316", "121416", "131217", "121317", "121218", "141212", "1"])]
    ]); //#13014
    $1.encmaps = _4r; //#13016
    $1.encs = $get($1.encmaps, $1.version); //#13018
    $1.c2w = $a([$a([495, 330, 210, 126, 70, 35, 15, 5]), $a([165, 120, 84, 56, 35, 20, 10, 4]), $a([45, 36, 28, 21, 15, 10, 6, 3]), $a([9, 8, 7, 6, 5, 4, 3, 2]), $a([1, 1, 1, 1, 1, 1, 1, 1])]); //#13027
    $1.v = 0; //#13029
    var _51 = $1.cws; //#13030
    for (var _52 = 0, _53 = _51.length; _52 < _53; _52++) { //#13039
        $1.cw = $get(_51, _52); //#13031
        for (var _55 = 0, _56 = 6; _55 < _56; _55++) { //#13038
            if ((($1.cw ^ $1.v) & 1) != 0) { //#13035
                $1.v = $1.v ^ 7682; //#13034
            } //#13034
            $1.v = $1.v >>> 1; //#13036
            $1.cw = $1.cw >>> 1; //#13037
        } //#13037
    } //#13037
    $1.v = $1.v + $1.checkoffset; //#13040
    if ($eq($1.version, "limiteda") || $eq($1.version, "limitedb")) { //#13048
        $1.v = $1.v & 1023; //#13043
        if (($1.v > 824) && ($1.v < 853)) { //#13046
            $1.v = $1.v + 292; //#13045
        } //#13045
    } else { //#13048
        $1.v = ($1.v & 1023) + 45; //#13048
    } //#13048
    $1.d = $a([2, 2, 2, 2, 2, 2]); //#13051
    $1.r = 0; //#13052
    $1.c = 0; //#13052
    $1.w = 0; //#13052
    $1.sum = 0; //#13052
    for (;;) { //#13071
        if ($1.sum == $1.v) { //#13054
            break; //#13054
        } //#13054
        $1.t = $f($1.sum + $get($get($1.c2w, $1.r), $1.c)); //#13055
        if ($1.t == $1.v) { //#13060
            $1.w = $1.w + 1; //#13057
            $put($1.d, $1.r, $1.w + 2); //#13058
            $1.sum = $1.t; //#13059
        } //#13059
        if ($1.t > $1.v) { //#13065
            $put($1.d, $1.r, $1.w + 2); //#13062
            $1.r = $1.r + 1; //#13063
            $1.w = 0; //#13064
        } //#13064
        if ($1.t < $1.v) { //#13070
            $1.c = $1.c + 1; //#13067
            $1.w = $1.w + 1; //#13068
            $1.sum = $1.t; //#13069
        } //#13069
    } //#13069
    $k[$j++] = 20; //#13072
    for (var _5m = 0; _5m <= 4; _5m += 1) { //#13072
        var _5p = $k[--$j]; //#13072
        $k[$j++] = $f(_5p - $get($1.d, _5m)); //#13072
    } //#13072
    $put($1.d, 5, $k[--$j]); //#13073
    if ($eq($1.version, "b") || $eq($1.version, "limitedb")) { //#13076
        $k[$j++] = Infinity; //#13075
        var _5u = $1.d; //#13075
        for (var _5v = 0, _5w = _5u.length; _5v < _5w; _5v++) { //#13075
            $k[$j++] = $f($get(_5u, _5v) + 1); //#13075
        } //#13075
        $1.d = $a(); //#13075
    } //#13075
    $1.cbs = $strcpy($s(12), "111111111111"); //#13077
    for (var _61 = 5; _61 >= 0; _61 -= 1) { //#13081
        $1.i = _61; //#13079
        $put($1.cbs, ((5 - $1.i) * 2) + 1, $f($get($1.d, $1.i) + 47)); //#13080
    } //#13080
    $1.sbs = $s(($1.cws.length * 6) + 31); //#13084
    var _6B = $get($1.encs, $1.encs.length - 2); //#13085
    $puti($1.sbs, 0, _6B); //#13086
    $1.j = _6B.length; //#13087
    for (var _6F = 0, _6E = $1.cws.length - 1; _6F <= _6E; _6F += 1) { //#13092
        $1.i = _6F; //#13089
        $puti($1.sbs, $1.j, $get($1.encs, $get($1.cws, $1.i))); //#13090
        $1.j = $1.j + 6; //#13091
    } //#13091
    $puti($1.sbs, $1.j, $1.cbs); //#13093
    $1.j = $1.j + 12; //#13094
    var _6U = $get($1.encs, $1.encs.length - 1); //#13095
    $puti($1.sbs, $1.j, _6U); //#13096
    $1.j = _6U.length + $1.j; //#13097
    $1.sbs = $geti($1.sbs, 0, $1.j); //#13098
    $k[$j++] = Infinity; //#13108
    $k[$j++] = Infinity; //#13103
    var _6b = $1.sbs; //#13103
    for (var _6c = 0, _6d = _6b.length; _6c < _6d; _6c++) { //#13103
        $k[$j++] = $f($get(_6b, _6c) - 48); //#13103
    } //#13103
    var _6f = $a(); //#13103
    $k[$j++] = Infinity; //#13104
    for (var _6h = 0, _6i = ~~(($1.sbs.length + 1) / 2); _6h < _6i; _6h++) { //#13104
        $k[$j++] = $1.height; //#13104
    } //#13104
    var _6k = $a(); //#13104
    $k[$j++] = Infinity; //#13105
    for (var _6m = 0, _6n = ~~(($1.sbs.length + 1) / 2); _6m < _6n; _6m++) { //#13105
        $k[$j++] = 0; //#13105
    } //#13105
    var _6o = $a(); //#13105
    $k[$j++] = 'ren'; //#13108
    $k[$j++] = bwipp_renlinear; //#13108
    $k[$j++] = 'sbs'; //#13108
    $k[$j++] = _6f; //#13108
    $k[$j++] = 'bhs'; //#13108
    $k[$j++] = _6k; //#13108
    $k[$j++] = 'bbs'; //#13108
    $k[$j++] = _6o; //#13108
    $k[$j++] = 'txt'; //#13108
    $k[$j++] = $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])]); //#13108
    $k[$j++] = 'textxalign'; //#13108
    $k[$j++] = "center"; //#13108
    $k[$j++] = 'opt'; //#13108
    $k[$j++] = $1.options; //#13108
    var _6x = $d(); //#13108
    $k[$j++] = _6x; //#13111
    if (!$1.dontdraw) { //#13111
        bwipp_renlinear(); //#13111
    } //#13111
}

function bwipp_codablockf() {
    var $1 = {}; //#13146
    $1.ctx = null; //#13148
    $1.dontdraw = false; //#13149
    $1.rows = -1; //#13150
    $1.columns = 8; //#13151
    $1.rowheight = 10; //#13152
    $1.sepheight = 1; //#13153
    $1.parse = false; //#13154
    $1.parsefnc = false; //#13155
    $k[$j++] = $1; //#13157
    bwipp_processoptions(); //#13157
    $1.options = $k[--$j]; //#13157
    $1.barcode = $k[--$j]; //#13158
    $k[$j++] = 'c'; //#13160
    if (($1.columns >= 4) && ($1.columns <= 62)) { //#13160
        $k[$j++] = $1.columns; //#13160
    } else { //#13160
        $k[$j++] = 8; //#13160
    } //#13160
    var _5 = $k[--$j]; //#13160
    $1[$k[--$j]] = _5; //#13160
    $k[$j++] = 'rows'; //#13161
    if (($1.rows >= 2) && ($1.rows <= 44)) { //#13161
        $k[$j++] = $1.rows; //#13161
    } else { //#13161
        $k[$j++] = -1; //#13161
    } //#13161
    var _A = $k[--$j]; //#13161
    $1[$k[--$j]] = _A; //#13161
    $1.swa = -1; //#13166
    $1.swb = -2; //#13166
    $1.swc = -3; //#13166
    $1.sft = -4; //#13166
    $1.fn1 = -5; //#13167
    $1.fn2 = -6; //#13167
    $1.fn3 = -7; //#13167
    $1.fn4 = -8; //#13167
    $1.sta = -9; //#13168
    $1.stp = -10; //#13168
    var _G = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["FNC1", $1.fn1],
        ["FNC3", $1.fn3]
    ]); //#13176
    $1.fncvals = _G; //#13178
    $k[$j++] = 'msg'; //#13179
    $k[$j++] = $1.barcode; //#13179
    $k[$j++] = $1.fncvals; //#13179
    bwipp_parseinput(); //#13179
    var _J = $k[--$j]; //#13179
    $1[$k[--$j]] = _J; //#13179
    $1.msglen = $1.msg.length; //#13180
    $1.msgtmp = $a([]); //#13183
    var _N = $1.msg; //#13184
    for (var _O = 0, _P = _N.length; _O < _P; _O++) { //#13187
        $1.char = $get(_N, _O); //#13185
        $k[$j++] = Infinity; //#13186
        $aload($1.msgtmp); //#13186
        if ($1.char < 128) { //#13186
            $k[$j++] = $1.char; //#13186
        } else { //#13186
            $k[$j++] = $1.fn4; //#13186
            $k[$j++] = $1.char & 127; //#13186
        } //#13186
        $1.msgtmp = $a(); //#13186
    } //#13186
    $1.kmsg = $1.msg; //#13188
    $1.msg = $1.msgtmp; //#13189
    $1.msglen = $1.msg.length; //#13190
    $1.charmaps = $a([$a([32, 32, "00"]), $a(["!", "!", "01"]), $a(["\"", "\"", "02"]), $a(["#", "#", "03"]), $a(["$", "$", "04"]), $a(["%", "%", "05"]), $a(["&", "&", "06"]), $a(["'", "'", "07"]), $a([40, 40, "08"]), $a([41, 41, "09"]), $a(["*", "*", "10"]), $a(["+", "+", "11"]), $a([",", ",", "12"]), $a(["-", "-", "13"]), $a([".", ".", "14"]), $a(["/", "/", "15"]), $a(["0", "0", "16"]), $a(["1", "1", "17"]), $a(["2", "2", "18"]), $a(["3", "3", "19"]), $a(["4", "4", "20"]), $a(["5", "5", "21"]), $a(["6", "6", "22"]), $a(["7", "7", "23"]), $a(["8", "8", "24"]), $a(["9", "9", "25"]), $a([":", ":", "26"]), $a([";", ";", "27"]), $a(["<", "<", "28"]), $a(["=", "=", "29"]), $a([">", ">", "30"]), $a(["?", "?", "31"]), $a(["@", "@", "32"]), $a(["A", "A", "33"]), $a(["B", "B", "34"]), $a(["C", "C", "35"]), $a(["D", "D", "36"]), $a(["E", "E", "37"]), $a(["F", "F", "38"]), $a(["G", "G", "39"]), $a(["H", "H", "40"]), $a(["I", "I", "41"]), $a(["J", "J", "42"]), $a(["K", "K", "43"]), $a(["L", "L", "44"]), $a(["M", "M", "45"]), $a(["N", "N", "46"]), $a(["O", "O", "47"]), $a(["P", "P", "48"]), $a(["Q", "Q", "49"]), $a(["R", "R", "50"]), $a(["S", "S", "51"]), $a(["T", "T", "52"]), $a(["U", "U", "53"]), $a(["V", "V", "54"]), $a(["W", "W", "55"]), $a(["X", "X", "56"]), $a(["Y", "Y", "57"]), $a(["Z", "Z", "58"]), $a(["[", "[", "59"]), $a([92, 92, "60"]), $a(["]", "]", "61"]), $a(["^", "^", "62"]), $a(["_", "_", "63"]), $a([0, "`", "64"]), $a([1, "a", "65"]), $a([2, "b", "66"]), $a([3, "c", "67"]), $a([4, "d", "68"]), $a([5, "e", "69"]), $a([6, "f", "70"]), $a([7, "g", "71"]), $a([8, "h", "72"]), $a([9, "i", "73"]), $a([10, "j", "74"]), $a([11, "k", "75"]), $a([12, "l", "76"]), $a([13, "m", "77"]), $a([14, "n", "78"]), $a([15, "o", "79"]), $a([16, "p", "80"]), $a([17, "q", "81"]), $a([18, "r", "82"]), $a([19, "s", "83"]), $a([20, "t", "84"]), $a([21, "u", "85"]), $a([22, "v", "86"]), $a([23, "w", "87"]), $a([24, "x", "88"]), $a([25, "y", "89"]), $a([26, "z", "90"]), $a([27, "{", "91"]), $a([28, "|", "92"]), $a([29, "}", "93"]), $a([30, "~", "94"]), $a([31, 127, "95"]), $a([$1.fn3, $1.fn3, "96"]), $a([$1.fn2, $1.fn2, "97"]), $a([$1.sft, $1.sft, "98"]), $a([$1.swc, $1.swc, "99"]), $a([$1.swb, $1.fn4, $1.swb]), $a([$1.fn4, $1.swa, $1.swa]), $a([$1.fn1, $1.fn1, $1.fn1]), $a([$1.sta, $1.sta, $1.sta]), $a([$1.stp, $1.stp, $1.stp])]); //#13231
    $1.charvals = $a([new Map, new Map, new Map]); //#13234
    for (var _2i = 0, _2h = $1.charmaps.length - 1; _2i <= _2h; _2i += 1) { //#13243
        $1.i = _2i; //#13236
        $1.encs = $get($1.charmaps, $1.i); //#13237
        for (var _2m = 0; _2m <= 2; _2m += 1) { //#13242
            $1.j = _2m; //#13239
            var _2p = $get($1.encs, $1.j); //#13240
            $k[$j++] = _2p; //#13240
            if ($eq($type(_2p), 'stringtype')) { //#13240
                var _2s = $get($k[--$j], 0); //#13240
                $k[$j++] = _2s; //#13240
            } //#13240
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#13241
        } //#13241
    } //#13241
    $1.seta = $get($1.charvals, 0); //#13244
    $1.setb = $get($1.charvals, 1); //#13245
    $1.setc = $get($1.charvals, 2); //#13246
    $1.numsscr = function() {
        $1.n = 0; //#13251
        $1.s = 0; //#13251
        $1.p = $k[--$j]; //#13252
        for (;;) { //#13263
            if ($1.p >= $1.msglen) { //#13253
                break; //#13253
            } //#13253
            var _39 = $get($1.msg, $1.p); //#13254
            var _3B = $get($1.setc, _39) !== undefined; //#13255
            $k[$j++] = _39; //#13255
            if (!_3B) { //#13255
                $j--; //#13255
                break; //#13255
            } //#13255
            if ($k[--$j] == $1.fn1) { //#13259
                if (($1.s % 2) == 0) { //#13258
                    $1.s = $1.s + 1; //#13258
                } else { //#13258
                    break; //#13258
                } //#13258
            } //#13258
            $1.n = $1.n + 1; //#13260
            $1.s = $1.s + 1; //#13261
            $1.p = $f($1.p + 1); //#13262
        } //#13262
        $k[$j++] = $1.n; //#13264
        $k[$j++] = $1.s; //#13264
    }; //#13264
    $1.enca = function() {
        $put($1.cws, $1.j, $get($1.seta, $k[--$j])); //#13269
        $1.j = $1.j + 1; //#13270
    }; //#13270
    $1.encb = function() {
        $put($1.cws, $1.j, $get($1.setb, $k[--$j])); //#13273
        $1.j = $1.j + 1; //#13274
    }; //#13274
    $1.encc = function() {
        var _3X = $k[--$j]; //#13277
        $k[$j++] = _3X; //#13281
        if ($ne($type(_3X), 'arraytype')) { //#13280
            var _3b = $get($1.setc, $k[--$j]); //#13278
            $k[$j++] = _3b; //#13278
        } else { //#13280
            $aload($k[--$j]); //#13280
            var _3d = $k[--$j]; //#13280
            var _3e = $k[--$j]; //#13280
            $k[$j++] = $f($f(_3d - 48) + ($f(_3e - 48) * 10)); //#13280
        } //#13280
        $put($1.cws, $1.j, $k[--$j]); //#13282
        $1.j = $1.j + 1; //#13283
    }; //#13283
    $1.anotb = function() {
        var _3j = $k[--$j]; //#13287
        var _3l = $get($1.seta, _3j) !== undefined; //#13287
        var _3n = $get($1.setb, _3j) !== undefined; //#13287
        $k[$j++] = _3l && (!_3n); //#13287
    }; //#13287
    $1.bnota = function() {
        var _3o = $k[--$j]; //#13288
        var _3q = $get($1.setb, _3o) !== undefined; //#13288
        var _3s = $get($1.seta, _3o) !== undefined; //#13288
        $k[$j++] = _3q && (!_3s); //#13288
    }; //#13288
    $k[$j++] = Infinity; //#13291
    for (var _3u = 0, _3v = $1.msg.length; _3u < _3v; _3u++) { //#13291
        $k[$j++] = 0; //#13291
    } //#13291
    $k[$j++] = 9999; //#13291
    $1.nextanotb = $a(); //#13291
    $k[$j++] = Infinity; //#13292
    for (var _3y = 0, _3z = $1.msg.length; _3y < _3z; _3y++) { //#13292
        $k[$j++] = 0; //#13292
    } //#13292
    $k[$j++] = 9999; //#13292
    $1.nextbnota = $a(); //#13292
    for (var _42 = $1.msg.length - 1; _42 >= 0; _42 -= 1) { //#13305
        $1.i = _42; //#13294
        $k[$j++] = $get($1.msg, $1.i); //#13295
        $1.anotb(); //#13295
        if ($k[--$j]) { //#13298
            $put($1.nextanotb, $1.i, 0); //#13296
        } else { //#13298
            $put($1.nextanotb, $1.i, $f($get($1.nextanotb, $1.i + 1) + 1)); //#13298
        } //#13298
        $k[$j++] = $get($1.msg, $1.i); //#13300
        $1.bnota(); //#13300
        if ($k[--$j]) { //#13303
            $put($1.nextbnota, $1.i, 0); //#13301
        } else { //#13303
            $put($1.nextbnota, $1.i, $f($get($1.nextbnota, $1.i + 1) + 1)); //#13303
        } //#13303
    } //#13303
    $1.abeforeb = function() {
        var _4P = $k[--$j]; //#13308
        $k[$j++] = $lt($get($1.nextanotb, _4P), $get($1.nextbnota, _4P)); //#13308
    }; //#13308
    $1.bbeforea = function() {
        var _4U = $k[--$j]; //#13309
        $k[$j++] = $lt($get($1.nextbnota, _4U), $get($1.nextanotb, _4U)); //#13309
    }; //#13309
    $1.padrow = function() {
        for (var _4a = 0, _4b = $k[--$j]; _4a < _4b; _4a++) { //#13319
            for (;;) { //#13318
                if ($eq($1.cset, "seta")) { //#13315
                    $k[$j++] = $1.swc; //#13315
                    $1.enca(); //#13315
                    $1.cset = "setc"; //#13315
                    break; //#13315
                } //#13315
                if ($eq($1.cset, "setb")) { //#13316
                    $k[$j++] = $1.swc; //#13316
                    $1.encb(); //#13316
                    $1.cset = "setc"; //#13316
                    break; //#13316
                } //#13316
                if ($eq($1.cset, "setc")) { //#13317
                    $k[$j++] = $1.swb; //#13317
                    $1.encc(); //#13317
                    $1.cset = "setb"; //#13317
                    break; //#13317
                } //#13317
            } //#13317
        } //#13317
    }; //#13317
    $1.encafitsrow = function() {
        if (($1.rem <= 2) && ($get($1.msg, $1.i) == $1.fn4)) { //#13334
            var _4r = ($1.rem == 2) && ($get($1.msg, $1.i + 1) <= 95); //#13326
            $k[$j++] = _4r; //#13330
            if (_4r) { //#13330
                $k[$j++] = $1.fn4; //#13327
                $1.enca(); //#13327
                $k[$j++] = $get($1.msg, $1.i + 1); //#13328
                $1.enca(); //#13328
                $1.i = $1.i + 2; //#13329
            } //#13329
        } else { //#13334
            $k[$j++] = $get($1.msg, $1.i); //#13332
            $1.enca(); //#13332
            $1.i = $1.i + 1; //#13333
            $k[$j++] = true; //#13334
        } //#13334
    }; //#13334
    $1.encbfitsrow = function() {
        if (($1.rem <= 2) && ($get($1.msg, $1.i) == $1.fn4)) { //#13350
            var _5A = ($1.rem == 2) && ($get($1.msg, $1.i + 1) >= 32); //#13342
            $k[$j++] = _5A; //#13346
            if (_5A) { //#13346
                $k[$j++] = $1.fn4; //#13343
                $1.encb(); //#13343
                $k[$j++] = $get($1.msg, $1.i + 1); //#13344
                $1.encb(); //#13344
                $1.i = $1.i + 2; //#13345
            } //#13345
        } else { //#13350
            $k[$j++] = $get($1.msg, $1.i); //#13348
            $1.encb(); //#13348
            $1.i = $1.i + 1; //#13349
            $k[$j++] = true; //#13350
        } //#13350
    }; //#13350
    $1.cws = $a($f($1.c + 5) * 44); //#13355
    $1.i = 0; //#13357
    $1.j = 0; //#13357
    $1.r = 1; //#13357
    $1.lastrow = false; //#13358
    for (;;) { //#13521
        if ($1.lastrow) { //#13360
            break; //#13360
        } //#13360
        $k[$j++] = $1.sta; //#13363
        $1.enca(); //#13363
        if ($1.i < $1.msglen) { //#13364
            $k[$j++] = $1.i; //#13364
            $1.numsscr(); //#13364
        } else { //#13364
            $k[$j++] = -1; //#13364
            $k[$j++] = -1; //#13364
        } //#13364
        $1.nums = $k[--$j]; //#13364
        $1.nchars = $k[--$j]; //#13364
        for (;;) { //#13384
            if ($1.msglen == 0) { //#13370
                $k[$j++] = $1.swb; //#13367
                $1.enca(); //#13367
                $1.cset = "setb"; //#13368
                break; //#13369
            } //#13369
            if ($1.nums >= 2) { //#13375
                $k[$j++] = $1.swc; //#13372
                $1.enca(); //#13372
                $1.cset = "setc"; //#13373
                break; //#13374
            } //#13374
            $k[$j++] = $1.i; //#13376
            $1.abeforeb(); //#13376
            if ($k[--$j]) { //#13380
                $k[$j++] = $1.sft; //#13377
                $1.enca(); //#13377
                $1.cset = "seta"; //#13378
                break; //#13379
            } //#13379
            $k[$j++] = $1.swb; //#13381
            $1.enca(); //#13381
            $1.cset = "setb"; //#13382
            break; //#13383
        } //#13383
        $1.j = $1.j + 1; //#13385
        $1.endofrow = false; //#13388
        for (;;) { //#13506
            $1.rem = $f($f($1.c + 3) - ($1.j % $f($1.c + 5))); //#13389
            if (($1.i == $1.msglen) || $1.endofrow) { //#13391
                break; //#13391
            } //#13391
            $k[$j++] = $1.i; //#13393
            $1.numsscr(); //#13393
            $1.nums = $k[--$j]; //#13393
            $1.nchars = $k[--$j]; //#13393
            $k[$j++] = 'remnums'; //#13394
            if ($1.nums > ($1.rem * 2)) { //#13394
                $k[$j++] = $1.rem * 2; //#13394
            } else { //#13394
                $k[$j++] = $1.nums; //#13394
            } //#13394
            var _5p = $k[--$j]; //#13394
            $1[$k[--$j]] = _5p; //#13394
            for (;;) { //#13504
                if ((($eq($1.cset, "seta") || $eq($1.cset, "setb")) && ($1.remnums >= 4)) && ($get($1.msg, $1.i) != $1.fn1)) { //#13432
                    if ((($1.remnums % 2) == 0) && ($1.rem >= 3)) { //#13414
                        $k[$j++] = $1.swc; //#13402
                        if ($eq($1.cset, "seta")) { //#13402
                            $1.enca(); //#13402
                        } else { //#13402
                            $1.encb(); //#13402
                        } //#13402
                        $1.cset = "setc"; //#13403
                        for (var _62 = 0, _63 = 2; _62 < _63; _62++) { //#13412
                            if ($get($1.msg, $1.i) == $1.fn1) { //#13410
                                $k[$j++] = $1.fn1; //#13406
                                $1.encc(); //#13406
                                $1.i = $1.i + 1; //#13407
                            } else { //#13410
                                $k[$j++] = $geti($1.msg, $1.i, 2); //#13409
                                $1.encc(); //#13409
                                $1.i = $1.i + 2; //#13410
                            } //#13410
                        } //#13410
                        break; //#13413
                    } //#13413
                    if ((($1.remnums % 2) != 0) && ($1.rem >= 4)) { //#13431
                        $k[$j++] = $get($1.msg, $1.i); //#13417
                        if ($eq($1.cset, "seta")) { //#13417
                            $1.enca(); //#13417
                        } else { //#13417
                            $1.encb(); //#13417
                        } //#13417
                        $1.i = $1.i + 1; //#13418
                        $k[$j++] = $1.swc; //#13419
                        if ($eq($1.cset, "seta")) { //#13419
                            $1.enca(); //#13419
                        } else { //#13419
                            $1.encb(); //#13419
                        } //#13419
                        $1.cset = "setc"; //#13420
                        for (var _6N = 0, _6O = 2; _6N < _6O; _6N++) { //#13429
                            if ($get($1.msg, $1.i) == $1.fn1) { //#13427
                                $k[$j++] = $1.fn1; //#13423
                                $1.encc(); //#13423
                                $1.i = $1.i + 1; //#13424
                            } else { //#13427
                                $k[$j++] = $geti($1.msg, $1.i, 2); //#13426
                                $1.encc(); //#13426
                                $1.i = $1.i + 2; //#13427
                            } //#13427
                        } //#13427
                        break; //#13430
                    } //#13430
                } //#13430
                $k[$j++] = $eq($1.cset, "setb"); //#13433
                $k[$j++] = $get($1.msg, $1.i); //#13433
                $1.anotb(); //#13433
                var _6d = $k[--$j]; //#13433
                var _6e = $k[--$j]; //#13433
                if ((_6e && _6d) && ($1.rem >= 2)) { //#13448
                    if ($1.i < ($1.msglen - 1)) { //#13442
                        $k[$j++] = $1.i + 1; //#13436
                        $1.bbeforea(); //#13436
                        if ($k[--$j]) { //#13441
                            $k[$j++] = $1.sft; //#13437
                            $1.encb(); //#13437
                            $k[$j++] = $get($1.msg, $1.i); //#13438
                            $1.enca(); //#13438
                            $1.i = $1.i + 1; //#13439
                            break; //#13440
                        } //#13440
                    } //#13440
                    $k[$j++] = $1.swa; //#13443
                    $1.encb(); //#13443
                    $1.cset = "seta"; //#13444
                    $k[$j++] = $get($1.msg, $1.i); //#13445
                    $1.enca(); //#13445
                    $1.i = $1.i + 1; //#13446
                    break; //#13447
                } //#13447
                $k[$j++] = $eq($1.cset, "seta"); //#13449
                $k[$j++] = $get($1.msg, $1.i); //#13449
                $1.bnota(); //#13449
                var _6y = $k[--$j]; //#13449
                var _6z = $k[--$j]; //#13449
                if ((_6z && _6y) && ($1.rem >= 2)) { //#13464
                    if ($1.i < ($1.msglen - 1)) { //#13458
                        $k[$j++] = $1.i + 1; //#13452
                        $1.abeforeb(); //#13452
                        if ($k[--$j]) { //#13457
                            $k[$j++] = $1.sft; //#13453
                            $1.enca(); //#13453
                            $k[$j++] = $get($1.msg, $1.i); //#13454
                            $1.encb(); //#13454
                            $1.i = $1.i + 1; //#13455
                            break; //#13456
                        } //#13456
                    } //#13456
                    $k[$j++] = $1.swb; //#13459
                    $1.enca(); //#13459
                    $1.cset = "setb"; //#13460
                    $k[$j++] = $get($1.msg, $1.i); //#13461
                    $1.encb(); //#13461
                    $1.i = $1.i + 1; //#13462
                    break; //#13463
                } //#13463
                if (($eq($1.cset, "setc") && ($1.remnums < 2)) && ($1.rem >= 2)) { //#13477
                    $1.rem = $f($1.rem - 1); //#13467
                    $k[$j++] = $1.i; //#13468
                    $1.abeforeb(); //#13468
                    if ($k[--$j]) { //#13475
                        $k[$j++] = $1.swa; //#13469
                        $1.encc(); //#13469
                        $1.cset = "seta"; //#13470
                        $1.encafitsrow(); //#13471
                        if ($k[--$j]) { //#13471
                            break; //#13471
                        } //#13471
                    } else { //#13475
                        $k[$j++] = $1.swb; //#13473
                        $1.encc(); //#13473
                        $1.cset = "setb"; //#13474
                        $1.encbfitsrow(); //#13475
                        if ($k[--$j]) { //#13475
                            break; //#13475
                        } //#13475
                    } //#13475
                } //#13475
                var _7U = $get($1.seta, $get($1.msg, $1.i)) !== undefined; //#13480
                if (($eq($1.cset, "seta") && _7U) && ($1.rem >= 1)) { //#13483
                    $1.encafitsrow(); //#13482
                    if ($k[--$j]) { //#13482
                        break; //#13482
                    } //#13482
                } //#13482
                var _7c = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#13484
                if (($eq($1.cset, "setb") && _7c) && ($1.rem >= 1)) { //#13487
                    $1.encbfitsrow(); //#13486
                    if ($k[--$j]) { //#13486
                        break; //#13486
                    } //#13486
                } //#13486
                if (($eq($1.cset, "setc") && ($1.remnums >= 2)) && ($1.rem >= 1)) { //#13498
                    if ($get($1.msg, $1.i) == $1.fn1) { //#13495
                        $k[$j++] = $1.fn1; //#13491
                        $1.encc(); //#13491
                        $1.i = $1.i + 1; //#13492
                    } else { //#13495
                        $k[$j++] = $geti($1.msg, $1.i, 2); //#13494
                        $1.encc(); //#13494
                        $1.i = $1.i + 2; //#13495
                    } //#13495
                    break; //#13497
                } //#13497
                $1.endofrow = true; //#13501
                break; //#13502
            } //#13502
        } //#13502
        if ((((($1.r >= $1.rows) || ($1.rows == -1)) && ($1.r > 1)) && ($1.i == $1.msglen)) && ($1.rem >= 2)) { //#13518
            $k[$j++] = $f($1.rem - 2); //#13510
            $1.padrow(); //#13510
            $1.j = $1.j + 3; //#13511
            $k[$j++] = $1.stp; //#13512
            $1.enca(); //#13512
            $1.lastrow = true; //#13513
        } else { //#13518
            $k[$j++] = $1.rem; //#13515
            $1.padrow(); //#13515
            $1.j = $1.j + 1; //#13516
            $k[$j++] = $1.stp; //#13517
            $1.enca(); //#13517
            $1.r = $1.r + 1; //#13518
        } //#13518
    } //#13518
    $1.cws = $geti($1.cws, 0, $1.j); //#13522
    $k[$j++] = Infinity; //#13529
    for (var _89 = 64; _89 <= 95; _89 += 1) { //#13527
        $k[$j++] = _89; //#13527
    } //#13527
    for (var _8A = 0; _8A <= 15; _8A += 1) { //#13528
        $k[$j++] = _8A; //#13528
    } //#13528
    for (var _8B = 26; _8B <= 63; _8B += 1) { //#13529
        $k[$j++] = _8B; //#13529
    } //#13529
    $1.abmap = $a(); //#13529
    $k[$j++] = Infinity; //#13531
    for (var _8D = 0; _8D <= 85; _8D += 1) { //#13531
        $k[$j++] = _8D; //#13531
    } //#13531
    $1.cmap = $a(); //#13531
    $1.chkmsg = $a($1.kmsg.length); //#13535
    $1.j = 0; //#13536
    for (var _8J = 0, _8I = $1.kmsg.length - 1; _8J <= _8I; _8J += 1) { //#13542
        $1.i = _8J; //#13538
        $1.char = $get($1.kmsg, $1.i); //#13539
        if ($1.char >= 0) { //#13540
            $put($1.chkmsg, $1.j, $1.char); //#13540
            $1.j = $1.j + 1; //#13540
        } //#13540
        if (($1.char == $1.fn1) && ($1.i != 0)) { //#13541
            $put($1.chkmsg, $1.j, 29); //#13541
            $1.j = $1.j + 1; //#13541
        } //#13541
    } //#13541
    $1.t1 = 0; //#13543
    $1.t2 = 0; //#13543
    $1.k1 = 0; //#13543
    $1.k2 = 0; //#13543
    for (var _8a = 0, _8Z = $1.j - 1; _8a <= _8Z; _8a += 1) { //#13550
        $1.i = _8a; //#13545
        $1.t1 = ($get($1.chkmsg, $1.i) * $1.i) % 86; //#13546
        $1.t2 = $f($1.t1 + $get($1.chkmsg, $1.i)) % 86; //#13547
        $1.k1 = $f($1.k1 + $1.t2) % 86; //#13548
        $1.k2 = $f($1.k2 + $1.t1) % 86; //#13549
    } //#13549
    $k[$j++] = $1.cws; //#13551
    $k[$j++] = $1.cws.length - 4; //#13551
    if ($ne($1.cset, "setc")) { //#13551
        $k[$j++] = $1.abmap; //#13551
    } else { //#13551
        $k[$j++] = $1.cmap; //#13551
    } //#13551
    var _8u = $get($k[--$j], $1.k1); //#13551
    var _8v = $k[--$j]; //#13551
    $put($k[--$j], _8v, _8u); //#13551
    $k[$j++] = $1.cws; //#13552
    $k[$j++] = $1.cws.length - 3; //#13552
    if ($ne($1.cset, "setc")) { //#13552
        $k[$j++] = $1.abmap; //#13552
    } else { //#13552
        $k[$j++] = $1.cmap; //#13552
    } //#13552
    var _94 = $get($k[--$j], $1.k2); //#13552
    var _95 = $k[--$j]; //#13552
    $put($k[--$j], _95, _94); //#13552
    var _97 = $1.cws; //#13555
    $k[$j++] = _97; //#13555
    $k[$j++] = 2; //#13555
    if ($get(_97, 2 - 1) != 99) { //#13555
        $k[$j++] = $1.abmap; //#13555
    } else { //#13555
        $k[$j++] = $1.cmap; //#13555
    } //#13555
    var _9D = $get($k[--$j], $1.r - 2); //#13555
    var _9E = $k[--$j]; //#13555
    $put($k[--$j], _9E, _9D); //#13555
    for (var _9I = 1, _9H = $1.r - 1; _9I <= _9H; _9I += 1) { //#13559
        $1.i = _9I; //#13557
        var _9J = $1.cws; //#13558
        var _9K = $1.i; //#13558
        var _9L = $1.c; //#13558
        $k[$j++] = _9J; //#13558
        $k[$j++] = $f((_9K * $f(_9L + 5)) + 2); //#13558
        if ($get(_9J, $f(($f((_9K * $f(_9L + 5)) + 2)) - 1)) != 99) { //#13558
            $k[$j++] = $1.abmap; //#13558
        } else { //#13558
            $k[$j++] = $1.cmap; //#13558
        } //#13558
        var _9R = $get($k[--$j], $1.i + 42); //#13558
        var _9S = $k[--$j]; //#13558
        $put($k[--$j], _9S, _9R); //#13558
    } //#13558
    for (var _9W = 0, _9V = $1.r - 1; _9W <= _9V; _9W += 1) { //#13570
        $1.rcws = $geti($1.cws, _9W * $f($1.c + 5), $f($1.c + 4)); //#13563
        $1.csum = $get($1.rcws, 0); //#13564
        for (var _9f = 1, _9e = $1.rcws.length - 2; _9f <= _9e; _9f += 1) { //#13568
            $1.i = _9f; //#13566
            $1.csum = $f($1.csum + ($get($1.rcws, $1.i) * $1.i)); //#13567
        } //#13567
        $put($1.rcws, $1.rcws.length - 1, $1.csum % 103); //#13569
    } //#13569
    var _9p = $get($1.options, 'debugcws') !== undefined; //#13572
    if (_9p) { //#13572
        $k[$j++] = 'bwipp.debugcws'; //#13572
        $k[$j++] = $1.cws; //#13572
        bwipp_raiseerror(); //#13572
    } //#13572
    $1.encs = $a(["212222", "222122", "222221", "121223", "121322", "131222", "122213", "122312", "132212", "221213", "221312", "231212", "112232", "122132", "122231", "113222", "123122", "123221", "223211", "221132", "221231", "213212", "223112", "312131", "311222", "321122", "321221", "312212", "322112", "322211", "212123", "212321", "232121", "111323", "131123", "131321", "112313", "132113", "132311", "211313", "231113", "231311", "112133", "112331", "132131", "113123", "113321", "133121", "313121", "211331", "231131", "213113", "213311", "213131", "311123", "311321", "331121", "312113", "312311", "332111", "314111", "221411", "431111", "111224", "111422", "121124", "121421", "141122", "141221", "112214", "112412", "122114", "122411", "142112", "142211", "241211", "221114", "413111", "241112", "134111", "111242", "121142", "121241", "114212", "124112", "124211", "411212", "421112", "421211", "212141", "214121", "412121", "111143", "111341", "131141", "114113", "114311", "411113", "411311", "113141", "114131", "311141", "411131", "211412", "2331112"]); //#13592
    $1.rowbits = $a($1.r); //#13596
    for (var _9w = 0, _9v = $1.r - 1; _9w <= _9v; _9w += 1) { //#13608
        $1.i = _9w; //#13598
        $k[$j++] = Infinity; //#13601
        var _A1 = $geti($1.cws, $1.i * $f($1.c + 5), $f($1.c + 5)); //#13600
        for (var _A2 = 0, _A3 = _A1.length; _A2 < _A3; _A2++) { //#13602
            $forall($get($1.encs, $get(_A1, _A2)), function() { //#13601
                var _A7 = $k[--$j]; //#13601
                $k[$j++] = $f(_A7 - 48); //#13601
            }); //#13601
        } //#13601
        $1.sbs = $a(); //#13601
        $k[$j++] = Infinity; //#13604
        var _A9 = $1.sbs; //#13605
        $k[$j++] = 0; //#13605
        for (var _AA = 0, _AB = _A9.length; _AA < _AB; _AA++) { //#13605
            var _AD = $k[--$j]; //#13605
            var _AE = (_AD == 1) ? 0 : 1; //#13605
            $k[$j++] = _AD; //#13605
            for (var _AF = 0, _AG = $get(_A9, _AA); _AF < _AG; _AF++) { //#13605
                $k[$j++] = _AE //#13605
            } //#13605
        } //#13605
        $astore($a($counttomark() - 1)); //#13606
        var _AJ = $k[--$j]; //#13606
        var _AK = $k[--$j]; //#13606
        $k[$j++] = _AJ; //#13606
        $k[$j++] = _AK; //#13606
        $j--; //#13606
        var _AL = $k[--$j]; //#13606
        var _AM = $k[--$j]; //#13606
        $k[$j++] = _AL; //#13606
        $k[$j++] = _AM; //#13606
        $j--; //#13606
        $put($1.rowbits, $1.i, $k[--$j]); //#13607
    } //#13607
    $1.symwid = $f(($1.c * 11) + 57); //#13611
    $k[$j++] = Infinity; //#13624
    for (var _AT = 0, _AU = $1.symwid * $1.sepheight; _AT < _AU; _AT++) { //#13613
        $k[$j++] = 1; //#13613
    } //#13613
    for (var _AX = 0, _AW = $1.r - 2; _AX <= _AW; _AX += 1) { //#13622
        $1.i = _AX; //#13615
        for (var _AZ = 0, _Aa = $1.rowheight; _AZ < _Aa; _AZ++) { //#13616
            $aload($get($1.rowbits, $1.i)); //#13616
        } //#13616
        for (var _Af = 0, _Ag = $1.sepheight; _Af < _Ag; _Af++) { //#13621
            $k[$j++] = 1; //#13619
            $k[$j++] = 1; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 1; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 1; //#13619
            $k[$j++] = 0; //#13619
            $k[$j++] = 0; //#13619
            for (var _Ai = 0, _Aj = $f($1.symwid - 24); _Ai < _Aj; _Ai++) { //#13619
                $k[$j++] = 1; //#13619
            } //#13619
            $k[$j++] = 1; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 0; //#13620
            $k[$j++] = 0; //#13620
            $k[$j++] = 0; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 0; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 0; //#13620
            $k[$j++] = 1; //#13620
            $k[$j++] = 1; //#13620
        } //#13620
    } //#13620
    for (var _Al = 0, _Am = $1.rowheight; _Al < _Am; _Al++) { //#13623
        $aload($get($1.rowbits, $1.r - 1)); //#13623
    } //#13623
    for (var _As = 0, _At = $1.symwid * $1.sepheight; _As < _At; _As++) { //#13624
        $k[$j++] = 1; //#13624
    } //#13624
    $1.pixs = $a(); //#13624
    var _B3 = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.symwid],
        ["pixy", ~~($1.pixs.length / $1.symwid)],
        ["height", (~~($1.pixs.length / $1.symwid)) / 72],
        ["width", $1.symwid / 72],
        ["opt", $1.options]
    ]); //#13635
    $k[$j++] = _B3; //#13638
    if (!$1.dontdraw) { //#13638
        bwipp_renmatrix(); //#13638
    } //#13638
}

function bwipp_code16k() {
    var $1 = {}; //#13673
    $1.ctx = null; //#13675
    $1.dontdraw = false; //#13676
    $1.mode = -1; //#13677
    $1.pos = -1; //#13678
    $1.rows = 0; //#13679
    $1.rowheight = 8; //#13680
    $1.sepheight = 1; //#13681
    $1.encoding = "auto"; //#13682
    $1.raw = false; //#13683
    $1.parse = false; //#13684
    $1.parsefnc = false; //#13685
    $k[$j++] = $1; //#13687
    bwipp_processoptions(); //#13687
    $1.options = $k[--$j]; //#13687
    $1.barcode = $k[--$j]; //#13688
    if ($1.pos != -1) { //#13692
        $1.rows = 16; //#13692
    } //#13692
    $1.swa = -1; //#13696
    $1.swb = -2; //#13696
    $1.swc = -3; //#13696
    $1.sa1 = -4; //#13697
    $1.sb1 = -5; //#13697
    $1.sc1 = -6; //#13697
    $1.sa2 = -7; //#13698
    $1.sb2 = -8; //#13698
    $1.sc2 = -9; //#13698
    $1.pad = -10; //#13699
    $1.sb3 = -11; //#13699
    $1.sc3 = -12; //#13699
    $1.fn1 = -13; //#13700
    $1.fn2 = -14; //#13700
    $1.fn3 = -15; //#13700
    $1.fn4 = -16; //#13700
    $1.charmaps = $a([$a([32, 32, "00"]), $a(["!", "!", "01"]), $a(["\"", "\"", "02"]), $a(["#", "#", "03"]), $a(["$", "$", "04"]), $a(["%", "%", "05"]), $a(["&", "&", "06"]), $a(["'", "'", "07"]), $a([40, 40, "08"]), $a([41, 41, "09"]), $a(["*", "*", "10"]), $a(["+", "+", "11"]), $a([",", ",", "12"]), $a(["-", "-", "13"]), $a([".", ".", "14"]), $a(["/", "/", "15"]), $a(["0", "0", "16"]), $a(["1", "1", "17"]), $a(["2", "2", "18"]), $a(["3", "3", "19"]), $a(["4", "4", "20"]), $a(["5", "5", "21"]), $a(["6", "6", "22"]), $a(["7", "7", "23"]), $a(["8", "8", "24"]), $a(["9", "9", "25"]), $a([":", ":", "26"]), $a([";", ";", "27"]), $a(["<", "<", "28"]), $a(["=", "=", "29"]), $a([">", ">", "30"]), $a(["?", "?", "31"]), $a(["@", "@", "32"]), $a(["A", "A", "33"]), $a(["B", "B", "34"]), $a(["C", "C", "35"]), $a(["D", "D", "36"]), $a(["E", "E", "37"]), $a(["F", "F", "38"]), $a(["G", "G", "39"]), $a(["H", "H", "40"]), $a(["I", "I", "41"]), $a(["J", "J", "42"]), $a(["K", "K", "43"]), $a(["L", "L", "44"]), $a(["M", "M", "45"]), $a(["N", "N", "46"]), $a(["O", "O", "47"]), $a(["P", "P", "48"]), $a(["Q", "Q", "49"]), $a(["R", "R", "50"]), $a(["S", "S", "51"]), $a(["T", "T", "52"]), $a(["U", "U", "53"]), $a(["V", "V", "54"]), $a(["W", "W", "55"]), $a(["X", "X", "56"]), $a(["Y", "Y", "57"]), $a(["Z", "Z", "58"]), $a(["[", "[", "59"]), $a([92, 92, "60"]), $a(["]", "]", "61"]), $a(["^", "^", "62"]), $a(["_", "_", "63"]), $a([0, "`", "64"]), $a([1, "a", "65"]), $a([2, "b", "66"]), $a([3, "c", "67"]), $a([4, "d", "68"]), $a([5, "e", "69"]), $a([6, "f", "70"]), $a([7, "g", "71"]), $a([8, "h", "72"]), $a([9, "i", "73"]), $a([10, "j", "74"]), $a([11, "k", "75"]), $a([12, "l", "76"]), $a([13, "m", "77"]), $a([14, "n", "78"]), $a([15, "o", "79"]), $a([16, "p", "80"]), $a([17, "q", "81"]), $a([18, "r", "82"]), $a([19, "s", "83"]), $a([20, "t", "84"]), $a([21, "u", "85"]), $a([22, "v", "86"]), $a([23, "w", "87"]), $a([24, "x", "88"]), $a([25, "y", "89"]), $a([26, "z", "90"]), $a([27, "{", "91"]), $a([28, "|", "92"]), $a([29, "}", "93"]), $a([30, "~", "94"]), $a([31, 127, "95"]), $a([$1.fn3, $1.fn3, "96"]), $a([$1.fn2, $1.fn2, "97"]), $a([$1.sb1, $1.sa1, "98"]), $a([$1.swc, $1.swc, "99"]), $a([$1.swb, $1.fn4, $1.swb]), $a([$1.fn4, $1.swa, $1.swa]), $a([$1.fn1, $1.fn1, $1.fn1]), $a([$1.pad, $1.pad, $1.pad]), $a([$1.sb2, $1.sa2, $1.sb1]), $a([$1.sc2, $1.sc2, $1.sb2]), $a([$1.sc3, $1.sc3, $1.sb3])]); //#13741
    $1.charvals = $a([new Map, new Map, new Map]); //#13744
    for (var _2J = 0, _2I = $1.charmaps.length - 1; _2J <= _2I; _2J += 1) { //#13753
        $1.i = _2J; //#13746
        $1.encs = $get($1.charmaps, $1.i); //#13747
        for (var _2N = 0; _2N <= 2; _2N += 1) { //#13752
            $1.j = _2N; //#13749
            var _2Q = $get($1.encs, $1.j); //#13750
            $k[$j++] = _2Q; //#13750
            if ($eq($type(_2Q), 'stringtype')) { //#13750
                var _2T = $get($k[--$j], 0); //#13750
                $k[$j++] = _2T; //#13750
            } //#13750
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#13751
        } //#13751
    } //#13751
    $1.seta = $get($1.charvals, 0); //#13754
    $1.setb = $get($1.charvals, 1); //#13755
    $1.setc = $get($1.charvals, 2); //#13756
    if ($1.raw) { //#13759
        $1.encoding = "raw"; //#13759
    } //#13759
    if ($eq($1.encoding, "raw")) { //#13772
        $1.cws = $a($1.barcode.length); //#13762
        $1.i = 0; //#13763
        $1.j = 0; //#13763
        for (;;) { //#13770
            if ($1.i == $1.barcode.length) { //#13765
                break; //#13765
            } //#13765
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#13766
            $put($1.cws, $1.j, $1.cw); //#13767
            $1.i = $1.i + 4; //#13768
            $1.j = $1.j + 1; //#13769
        } //#13769
        $1.cws = $geti($1.cws, 0, $1.j); //#13771
    } //#13771
    if ($eq($1.encoding, "auto")) { //#14223
        var _32 = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["eci", true],
            ["FNC1", $1.fn1],
            ["FNC2", $1.fn2],
            ["FNC3", $1.fn3]
        ]); //#13783
        $1.fncvals = _32; //#13785
        $k[$j++] = 'msg'; //#13786
        $k[$j++] = $1.barcode; //#13786
        $k[$j++] = $1.fncvals; //#13786
        bwipp_parseinput(); //#13786
        var _35 = $k[--$j]; //#13786
        $1[$k[--$j]] = _35; //#13786
        $1.msglen = $1.msg.length; //#13787
        $k[$j++] = Infinity; //#13790
        for (var _39 = 0, _3A = $1.msglen; _39 < _3A; _39++) { //#13790
            $k[$j++] = 0; //#13790
        } //#13790
        $k[$j++] = 0; //#13790
        $1.numSA = $a(); //#13790
        $k[$j++] = Infinity; //#13791
        for (var _3D = 0, _3E = $1.msglen; _3D < _3E; _3D++) { //#13791
            $k[$j++] = 0; //#13791
        } //#13791
        $k[$j++] = 0; //#13791
        $1.numEA = $a(); //#13791
        for (var _3H = $1.msglen - 1; _3H >= 0; _3H -= 1) { //#13801
            $1.i = _3H; //#13793
            if ($get($1.msg, $1.i) >= 0) { //#13800
                if ($get($1.msg, $1.i) >= 128) { //#13798
                    $put($1.numEA, $1.i, $f($get($1.numEA, $1.i + 1) + 1)); //#13796
                } else { //#13798
                    $put($1.numSA, $1.i, $f($get($1.numSA, $1.i + 1) + 1)); //#13798
                } //#13798
            } //#13798
        } //#13798
        $1.ea = false; //#13804
        $1.msgtmp = $a([]); //#13804
        for (var _3b = 0, _3a = $1.msglen - 1; _3b <= _3a; _3b += 1) { //#13819
            $1.i = _3b; //#13806
            $1.c = $get($1.msg, $1.i); //#13807
            if ((!$xo($1.ea, $1.c < 128)) && ($1.c >= 0)) { //#13817
                if ($1.ea) { //#13809
                    $k[$j++] = $1.numSA; //#13809
                } else { //#13809
                    $k[$j++] = $1.numEA; //#13809
                } //#13809
                var _3n = $get($k[--$j], $1.i); //#13809
                var _3q = ($f(_3n + $1.i) == $1.msglen) ? 3 : 5; //#13810
                if (_3n < _3q) { //#13815
                    $k[$j++] = Infinity; //#13812
                    $aload($1.msgtmp); //#13812
                    $k[$j++] = $1.fn4; //#13812
                    $1.msgtmp = $a(); //#13812
                } else { //#13815
                    $k[$j++] = Infinity; //#13814
                    $aload($1.msgtmp); //#13814
                    $k[$j++] = $1.fn4; //#13814
                    $k[$j++] = $1.fn4; //#13814
                    $1.msgtmp = $a(); //#13814
                    $1.ea = !$1.ea; //#13815
                } //#13815
            } //#13815
            $k[$j++] = Infinity; //#13818
            $aload($1.msgtmp); //#13818
            if ($1.c >= 0) { //#13818
                $k[$j++] = $1.c & 127; //#13818
            } else { //#13818
                $k[$j++] = $1.c; //#13818
            } //#13818
            $1.msgtmp = $a(); //#13818
        } //#13818
        $1.msg = $1.msgtmp; //#13820
        $1.msglen = $1.msg.length; //#13821
        $1.numsscr = function() {
            $1.n = 0; //#13825
            $1.s = 0; //#13825
            $1.p = $k[--$j]; //#13826
            for (;;) { //#13837
                if ($1.p >= $1.msglen) { //#13827
                    break; //#13827
                } //#13827
                var _4B = $get($1.msg, $1.p); //#13828
                var _4D = $get($1.setc, _4B) !== undefined; //#13829
                $k[$j++] = _4B; //#13829
                if (!_4D) { //#13829
                    $j--; //#13829
                    break; //#13829
                } //#13829
                if ($k[--$j] == $1.fn1) { //#13833
                    if (($1.s % 2) == 0) { //#13832
                        $1.s = $1.s + 1; //#13832
                    } else { //#13832
                        break; //#13832
                    } //#13832
                } //#13832
                $1.n = $1.n + 1; //#13834
                $1.s = $1.s + 1; //#13835
                $1.p = $f($1.p + 1); //#13836
            } //#13836
            $k[$j++] = $1.n; //#13838
            $k[$j++] = $1.s; //#13838
        }; //#13838
        $1.enca = function() {
            $put($1.cws, $1.j, $get($1.seta, $k[--$j])); //#13843
            $1.j = $1.j + 1; //#13844
        }; //#13844
        $1.encb = function() {
            $put($1.cws, $1.j, $get($1.setb, $k[--$j])); //#13847
            $1.j = $1.j + 1; //#13848
        }; //#13848
        $1.encc = function() {
            var _4Z = $k[--$j]; //#13851
            $k[$j++] = _4Z; //#13855
            if ($ne($type(_4Z), 'arraytype')) { //#13854
                var _4d = $get($1.setc, $k[--$j]); //#13852
                $k[$j++] = _4d; //#13852
            } else { //#13854
                $aload($k[--$j]); //#13854
                var _4f = $k[--$j]; //#13854
                var _4g = $k[--$j]; //#13854
                $k[$j++] = $f($f(_4f - 48) + ($f(_4g - 48) * 10)); //#13854
            } //#13854
            $put($1.cws, $1.j, $k[--$j]); //#13856
            $1.j = $1.j + 1; //#13857
        }; //#13857
        $1.anotb = function() {
            var _4l = $k[--$j]; //#13861
            var _4n = $get($1.seta, _4l) !== undefined; //#13861
            var _4p = $get($1.setb, _4l) !== undefined; //#13861
            $k[$j++] = _4n && (!_4p); //#13861
        }; //#13861
        $1.bnota = function() {
            var _4q = $k[--$j]; //#13862
            var _4s = $get($1.setb, _4q) !== undefined; //#13862
            var _4u = $get($1.seta, _4q) !== undefined; //#13862
            $k[$j++] = _4s && (!_4u); //#13862
        }; //#13862
        $k[$j++] = Infinity; //#13865
        for (var _4w = 0, _4x = $1.msg.length; _4w < _4x; _4w++) { //#13865
            $k[$j++] = 0; //#13865
        } //#13865
        $k[$j++] = 9999; //#13865
        $1.nextanotb = $a(); //#13865
        $k[$j++] = Infinity; //#13866
        for (var _50 = 0, _51 = $1.msg.length; _50 < _51; _50++) { //#13866
            $k[$j++] = 0; //#13866
        } //#13866
        $k[$j++] = 9999; //#13866
        $1.nextbnota = $a(); //#13866
        for (var _54 = $1.msg.length - 1; _54 >= 0; _54 -= 1) { //#13879
            $1.i = _54; //#13868
            $k[$j++] = $get($1.msg, $1.i); //#13869
            $1.anotb(); //#13869
            if ($k[--$j]) { //#13872
                $put($1.nextanotb, $1.i, 0); //#13870
            } else { //#13872
                $put($1.nextanotb, $1.i, $f($get($1.nextanotb, $1.i + 1) + 1)); //#13872
            } //#13872
            $k[$j++] = $get($1.msg, $1.i); //#13874
            $1.bnota(); //#13874
            if ($k[--$j]) { //#13877
                $put($1.nextbnota, $1.i, 0); //#13875
            } else { //#13877
                $put($1.nextbnota, $1.i, $f($get($1.nextbnota, $1.i + 1) + 1)); //#13877
            } //#13877
        } //#13877
        $1.abeforeb = function() {
            var _5R = $k[--$j]; //#13882
            $k[$j++] = $lt($get($1.nextanotb, _5R), $get($1.nextbnota, _5R)); //#13882
        }; //#13882
        $1.bbeforea = function() {
            var _5W = $k[--$j]; //#13883
            $k[$j++] = $lt($get($1.nextbnota, _5W), $get($1.nextanotb, _5W)); //#13883
        }; //#13883
        $1.cws = $a(($1.barcode.length * 2) + 3); //#13885
        $1.i = 0; //#13888
        $1.j = 0; //#13888
        for (;;) { //#13978
            if ($1.pos != -1) { //#13899
                $put($1.cws, 0, (~~($1.pos / 10)) - 1); //#13893
                $put($1.cws, 1, ($1.pos % 10) - 1); //#13894
                $1.j = 2; //#13895
                $1.cset = "setb"; //#13896
                $1.mode = 7; //#13897
                break; //#13898
            } //#13898
            if ($1.msglen == 0) { //#13905
                $1.cset = "setb"; //#13902
                $1.mode = 1; //#13903
                break; //#13904
            } //#13904
            if ($1.msglen >= 2) { //#13914
                $k[$j++] = $get($1.msg, 0) == $1.fn1; //#13908
                $k[$j++] = 1; //#13908
                $1.numsscr(); //#13908
                var _5n = $k[--$j]; //#13908
                var _5o = $k[--$j]; //#13908
                $k[$j++] = _5n; //#13908
                $k[$j++] = _5o; //#13908
                $j--; //#13908
                var _5p = $k[--$j]; //#13908
                var _5q = $k[--$j]; //#13908
                if (_5q && (_5p >= 2)) { //#13913
                    $1.cset = "setc"; //#13909
                    $1.mode = 4; //#13910
                    $1.i = 1; //#13911
                    break; //#13912
                } //#13912
            } //#13912
            if ($get($1.msg, 0) == $1.fn1) { //#13921
                $1.cset = "setb"; //#13917
                $1.mode = 3; //#13918
                $1.i = 1; //#13919
                break; //#13920
            } //#13920
            if ($1.msglen >= 2) { //#13967
                $k[$j++] = 0; //#13924
                $1.numsscr(); //#13924
                var _5v = $k[--$j]; //#13924
                var _5w = $k[--$j]; //#13924
                $k[$j++] = _5v; //#13924
                $k[$j++] = _5w; //#13924
                $j--; //#13924
                var _5x = $k[--$j]; //#13924
                if ((_5x >= 2) && ((_5x % 2) == 0)) { //#13928
                    $1.cset = "setc"; //#13925
                    $1.mode = 2; //#13926
                    break; //#13927
                } //#13927
                $k[$j++] = 0; //#13930
                $1.numsscr(); //#13930
                var _5y = $k[--$j]; //#13930
                var _5z = $k[--$j]; //#13930
                $k[$j++] = _5y; //#13930
                $k[$j++] = _5z; //#13930
                $j--; //#13930
                var _60 = $k[--$j]; //#13930
                if ((_60 >= 3) && ((_60 % 2) == 1)) { //#13936
                    $k[$j++] = $get($1.msg, 0); //#13931
                    $1.encb(); //#13931
                    $1.cset = "setc"; //#13932
                    $1.mode = 5; //#13933
                    $1.i = 1; //#13934
                    break; //#13935
                } //#13935
                var _66 = $get($1.setb, $get($1.msg, 0)) !== undefined; //#13938
                $k[$j++] = _66; //#13939
                $k[$j++] = 1; //#13939
                $1.numsscr(); //#13939
                var _67 = $k[--$j]; //#13939
                var _68 = $k[--$j]; //#13939
                $k[$j++] = _67; //#13939
                $k[$j++] = _68; //#13939
                $j--; //#13939
                var _69 = $k[--$j]; //#13939
                var _6A = $k[--$j]; //#13939
                if (_6A && ((_69 >= 2) && ((_69 % 2) == 0))) { //#13945
                    $k[$j++] = $get($1.msg, 0); //#13940
                    $1.encb(); //#13940
                    $1.cset = "setc"; //#13941
                    $1.mode = 5; //#13942
                    $1.i = 1; //#13943
                    break; //#13944
                } //#13944
                var _6G = $get($1.setb, $get($1.msg, 0)) !== undefined; //#13947
                $k[$j++] = _6G; //#13948
                $k[$j++] = 1; //#13948
                $1.numsscr(); //#13948
                var _6H = $k[--$j]; //#13948
                var _6I = $k[--$j]; //#13948
                $k[$j++] = _6H; //#13948
                $k[$j++] = _6I; //#13948
                $j--; //#13948
                var _6J = $k[--$j]; //#13948
                var _6K = $k[--$j]; //#13948
                if (_6K && ((_6J >= 3) && ((_6J % 2) == 1))) { //#13955
                    $k[$j++] = $get($1.msg, 0); //#13949
                    $1.encb(); //#13949
                    $k[$j++] = $get($1.msg, 1); //#13950
                    $1.encb(); //#13950
                    $1.cset = "setc"; //#13951
                    $1.mode = 6; //#13952
                    $1.i = 2; //#13953
                    break; //#13954
                } //#13954
                var _6S = $get($1.setb, $get($1.msg, 0)) !== undefined; //#13957
                var _6W = $get($1.setb, $get($1.msg, 1)) !== undefined; //#13958
                $k[$j++] = _6S && _6W; //#13959
                $k[$j++] = 2; //#13959
                $1.numsscr(); //#13959
                var _6X = $k[--$j]; //#13959
                var _6Y = $k[--$j]; //#13959
                $k[$j++] = _6X; //#13959
                $k[$j++] = _6Y; //#13959
                $j--; //#13959
                var _6Z = $k[--$j]; //#13959
                var _6a = $k[--$j]; //#13959
                if (_6a && ((_6Z >= 2) && ((_6Z % 2) == 0))) { //#13966
                    $k[$j++] = $get($1.msg, 0); //#13960
                    $1.encb(); //#13960
                    $k[$j++] = $get($1.msg, 1); //#13961
                    $1.encb(); //#13961
                    $1.cset = "setc"; //#13962
                    $1.mode = 6; //#13963
                    $1.i = 2; //#13964
                    break; //#13965
                } //#13965
            } //#13965
            $k[$j++] = 0; //#13969
            $1.abeforeb(); //#13969
            if ($k[--$j]) { //#13973
                $1.cset = "seta"; //#13970
                $1.mode = 0; //#13971
                break; //#13972
            } //#13972
            $1.cset = "setb"; //#13975
            $1.mode = 1; //#13976
            break; //#13977
        } //#13977
        for (;;) { //#14221
            if ($1.i == $1.msglen) { //#13981
                break; //#13981
            } //#13981
            $k[$j++] = $1.i; //#13983
            $1.numsscr(); //#13983
            $1.nums = $k[--$j]; //#13983
            $1.nchars = $k[--$j]; //#13983
            for (;;) { //#14219
                if ($eq($1.cset, "seta")) { //#14060
                    if ($1.i < ($1.msglen - 1)) { //#13997
                        $k[$j++] = $get($1.msg, $1.i); //#13990
                        $1.bnota(); //#13990
                        $k[$j++] = $1.i + 1; //#13991
                        $1.abeforeb(); //#13991
                        var _6s = $k[--$j]; //#13991
                        var _6t = $k[--$j]; //#13991
                        if ((_6t && _6s)) { //#13996
                            $k[$j++] = $1.sb1; //#13992
                            $1.enca(); //#13992
                            $k[$j++] = $get($1.msg, $1.i); //#13993
                            $1.encb(); //#13993
                            $1.i = $1.i + 1; //#13994
                            break; //#13995
                        } //#13995
                    } //#13995
                    if ($1.i < ($1.msglen - 2)) { //#14009
                        $k[$j++] = $get($1.msg, $1.i); //#14000
                        $1.bnota(); //#14000
                        $k[$j++] = $get($1.msg, $1.i + 1); //#14001
                        $1.bnota(); //#14001
                        var _77 = $k[--$j]; //#14001
                        var _78 = $k[--$j]; //#14001
                        $k[$j++] = $an(_78, _77); //#14002
                        $k[$j++] = $1.i + 2; //#14002
                        $1.abeforeb(); //#14002
                        var _7A = $k[--$j]; //#14002
                        var _7B = $k[--$j]; //#14002
                        if ((_7B && _7A)) { //#14008
                            $k[$j++] = $1.sb2; //#14003
                            $1.enca(); //#14003
                            $k[$j++] = $get($1.msg, $1.i); //#14004
                            $1.encb(); //#14004
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14005
                            $1.encb(); //#14005
                            $1.i = $1.i + 2; //#14006
                            break; //#14007
                        } //#14007
                    } //#14007
                    $k[$j++] = $get($1.msg, $1.i); //#14011
                    $1.bnota(); //#14011
                    if ($k[--$j]) { //#14015
                        $k[$j++] = $1.swb; //#14012
                        $1.enca(); //#14012
                        $1.cset = "setb"; //#14013
                        break; //#14014
                    } //#14014
                    if ($1.i < ($1.msglen - 4)) { //#14032
                        var _7W = $get($1.seta, $get($1.msg, $1.i + 4)) !== undefined; //#14019
                        if (($1.nums == 4) && _7W) { //#14031
                            $k[$j++] = $1.sc2; //#14020
                            $1.enca(); //#14020
                            for (var _7Y = 0, _7Z = 2; _7Y < _7Z; _7Y++) { //#14029
                                if ($get($1.msg, $1.i) == $1.fn1) { //#14027
                                    $k[$j++] = $1.fn1; //#14023
                                    $1.encc(); //#14023
                                    $1.i = $1.i + 1; //#14024
                                } else { //#14027
                                    $k[$j++] = $geti($1.msg, $1.i, 2); //#14026
                                    $1.encc(); //#14026
                                    $1.i = $1.i + 2; //#14027
                                } //#14027
                            } //#14027
                            break; //#14030
                        } //#14030
                    } //#14030
                    if ($1.i < ($1.msglen - 6)) { //#14049
                        var _7r = $get($1.seta, $get($1.msg, $1.i + 6)) !== undefined; //#14036
                        if (($1.nums == 6) && _7r) { //#14048
                            $k[$j++] = $1.sc3; //#14037
                            $1.enca(); //#14037
                            for (var _7t = 0, _7u = 3; _7t < _7u; _7t++) { //#14046
                                if ($get($1.msg, $1.i) == $1.fn1) { //#14044
                                    $k[$j++] = $1.fn1; //#14040
                                    $1.encc(); //#14040
                                    $1.i = $1.i + 1; //#14041
                                } else { //#14044
                                    $k[$j++] = $geti($1.msg, $1.i, 2); //#14043
                                    $1.encc(); //#14043
                                    $1.i = $1.i + 2; //#14044
                                } //#14044
                            } //#14044
                            break; //#14047
                        } //#14047
                    } //#14047
                    if (($1.nums >= 4) && (($1.nums % 2) == 0)) { //#14055
                        $k[$j++] = $1.swc; //#14052
                        $1.enca(); //#14052
                        $1.cset = "setc"; //#14053
                        break; //#14054
                    } //#14054
                    $k[$j++] = $get($1.msg, $1.i); //#14057
                    $1.enca(); //#14057
                    $1.i = $1.i + 1; //#14058
                    break; //#14059
                } //#14059
                if ($eq($1.cset, "setb")) { //#14134
                    if ($1.i < ($1.msglen - 1)) { //#14071
                        $k[$j++] = $get($1.msg, $1.i); //#14064
                        $1.anotb(); //#14064
                        $k[$j++] = $1.i + 1; //#14065
                        $1.bbeforea(); //#14065
                        var _8J = $k[--$j]; //#14065
                        var _8K = $k[--$j]; //#14065
                        if ((_8K && _8J)) { //#14070
                            $k[$j++] = $1.sa1; //#14066
                            $1.encb(); //#14066
                            $k[$j++] = $get($1.msg, $1.i); //#14067
                            $1.enca(); //#14067
                            $1.i = $1.i + 1; //#14068
                            break; //#14069
                        } //#14069
                    } //#14069
                    if ($1.i < ($1.msglen - 2)) { //#14083
                        $k[$j++] = $get($1.msg, $1.i); //#14074
                        $1.anotb(); //#14074
                        $k[$j++] = $get($1.msg, $1.i + 1); //#14075
                        $1.anotb(); //#14075
                        var _8Y = $k[--$j]; //#14075
                        var _8Z = $k[--$j]; //#14075
                        $k[$j++] = $an(_8Z, _8Y); //#14076
                        $k[$j++] = $1.i + 2; //#14076
                        $1.bbeforea(); //#14076
                        var _8b = $k[--$j]; //#14076
                        var _8c = $k[--$j]; //#14076
                        if ((_8c && _8b)) { //#14082
                            $k[$j++] = $1.sa2; //#14077
                            $1.encb(); //#14077
                            $k[$j++] = $get($1.msg, $1.i); //#14078
                            $1.enca(); //#14078
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14079
                            $1.enca(); //#14079
                            $1.i = $1.i + 2; //#14080
                            break; //#14081
                        } //#14081
                    } //#14081
                    $k[$j++] = $get($1.msg, $1.i); //#14085
                    $1.anotb(); //#14085
                    if ($k[--$j]) { //#14089
                        $k[$j++] = $1.swa; //#14086
                        $1.encb(); //#14086
                        $1.cset = "seta"; //#14087
                        break; //#14088
                    } //#14088
                    if ($1.i < ($1.msglen - 4)) { //#14106
                        var _8x = $get($1.setb, $get($1.msg, $1.i + 4)) !== undefined; //#14093
                        if (($1.nums == 4) && _8x) { //#14105
                            $k[$j++] = $1.sc2; //#14094
                            $1.encb(); //#14094
                            for (var _8z = 0, _90 = 2; _8z < _90; _8z++) { //#14103
                                if ($get($1.msg, $1.i) == $1.fn1) { //#14101
                                    $k[$j++] = $1.fn1; //#14097
                                    $1.encc(); //#14097
                                    $1.i = $1.i + 1; //#14098
                                } else { //#14101
                                    $k[$j++] = $geti($1.msg, $1.i, 2); //#14100
                                    $1.encc(); //#14100
                                    $1.i = $1.i + 2; //#14101
                                } //#14101
                            } //#14101
                            break; //#14104
                        } //#14104
                    } //#14104
                    if ($1.i < ($1.msglen - 6)) { //#14123
                        var _9I = $get($1.setb, $get($1.msg, $1.i + 6)) !== undefined; //#14110
                        if (($1.nums == 6) && _9I) { //#14122
                            $k[$j++] = $1.sc3; //#14111
                            $1.encb(); //#14111
                            for (var _9K = 0, _9L = 3; _9K < _9L; _9K++) { //#14120
                                if ($get($1.msg, $1.i) == $1.fn1) { //#14118
                                    $k[$j++] = $1.fn1; //#14114
                                    $1.encc(); //#14114
                                    $1.i = $1.i + 1; //#14115
                                } else { //#14118
                                    $k[$j++] = $geti($1.msg, $1.i, 2); //#14117
                                    $1.encc(); //#14117
                                    $1.i = $1.i + 2; //#14118
                                } //#14118
                            } //#14118
                            break; //#14121
                        } //#14121
                    } //#14121
                    if (($1.nums >= 4) && (($1.nums % 2) == 0)) { //#14129
                        $k[$j++] = $1.swc; //#14126
                        $1.encb(); //#14126
                        $1.cset = "setc"; //#14127
                        break; //#14128
                    } //#14128
                    $k[$j++] = $get($1.msg, $1.i); //#14131
                    $1.encb(); //#14131
                    $1.i = $1.i + 1; //#14132
                    break; //#14133
                } //#14133
                if ($eq($1.cset, "setc")) { //#14217
                    if ($1.nums >= 2) { //#14146
                        if ($get($1.msg, $1.i) == $1.fn1) { //#14143
                            $k[$j++] = $1.fn1; //#14139
                            $1.encc(); //#14139
                            $1.i = $1.i + 1; //#14140
                        } else { //#14143
                            $k[$j++] = $geti($1.msg, $1.i, 2); //#14142
                            $1.encc(); //#14142
                            $1.i = $1.i + 2; //#14143
                        } //#14143
                        break; //#14145
                    } //#14145
                    if ($1.i < ($1.msglen - 1)) { //#14156
                        var _9v = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#14149
                        $k[$j++] = _9v; //#14150
                        $k[$j++] = $1.i + 1; //#14150
                        $1.numsscr(); //#14150
                        var _9x = $k[--$j]; //#14150
                        var _9y = $k[--$j]; //#14150
                        $k[$j++] = _9x; //#14150
                        $k[$j++] = _9y; //#14150
                        $j--; //#14150
                        var _9z = $k[--$j]; //#14150
                        var _A0 = $k[--$j]; //#14150
                        if (_A0 && ((_9z >= 2) && ((_9z % 2) == 0))) { //#14155
                            $k[$j++] = $1.sb1; //#14151
                            $1.encc(); //#14151
                            $k[$j++] = $get($1.msg, $1.i); //#14152
                            $1.encb(); //#14152
                            $1.i = $1.i + 1; //#14153
                            break; //#14154
                        } //#14154
                    } //#14154
                    if ($1.i < ($1.msglen - 1)) { //#14167
                        var _AC = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#14159
                        $k[$j++] = _AC; //#14160
                        $k[$j++] = $1.i + 1; //#14160
                        $1.numsscr(); //#14160
                        var _AE = $k[--$j]; //#14160
                        var _AF = $k[--$j]; //#14160
                        $k[$j++] = _AE; //#14160
                        $k[$j++] = _AF; //#14160
                        $j--; //#14160
                        var _AG = $k[--$j]; //#14160
                        var _AH = $k[--$j]; //#14160
                        if (_AH && ((_AG >= 3) && ((_AG % 2) == 1))) { //#14166
                            $k[$j++] = $1.sb2; //#14161
                            $1.encc(); //#14161
                            $k[$j++] = $get($1.msg, $1.i); //#14162
                            $1.encb(); //#14162
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14163
                            $1.encb(); //#14163
                            $1.i = $1.i + 2; //#14164
                            break; //#14165
                        } //#14165
                    } //#14165
                    if ($1.i < ($1.msglen - 2)) { //#14179
                        var _AW = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#14170
                        var _Ab = $get($1.setb, $get($1.msg, $1.i + 1)) !== undefined; //#14171
                        $k[$j++] = _AW && _Ab; //#14172
                        $k[$j++] = $1.i + 2; //#14172
                        $1.numsscr(); //#14172
                        var _Ad = $k[--$j]; //#14172
                        var _Ae = $k[--$j]; //#14172
                        $k[$j++] = _Ad; //#14172
                        $k[$j++] = _Ae; //#14172
                        $j--; //#14172
                        var _Af = $k[--$j]; //#14172
                        var _Ag = $k[--$j]; //#14172
                        if (_Ag && ((_Af >= 2) && ((_Af % 2) == 0))) { //#14178
                            $k[$j++] = $1.sb2; //#14173
                            $1.encc(); //#14173
                            $k[$j++] = $get($1.msg, $1.i); //#14174
                            $1.encb(); //#14174
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14175
                            $1.encb(); //#14175
                            $1.i = $1.i + 2; //#14176
                            break; //#14177
                        } //#14177
                    } //#14177
                    if ($1.i < ($1.msglen - 3)) { //#14192
                        var _Av = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#14182
                        var _B0 = $get($1.setb, $get($1.msg, $1.i + 1)) !== undefined; //#14183
                        $k[$j++] = _Av && _B0; //#14184
                        $k[$j++] = $1.i + 2; //#14184
                        $1.numsscr(); //#14184
                        var _B2 = $k[--$j]; //#14184
                        var _B3 = $k[--$j]; //#14184
                        $k[$j++] = _B2; //#14184
                        $k[$j++] = _B3; //#14184
                        $j--; //#14184
                        var _B4 = $k[--$j]; //#14184
                        var _B5 = $k[--$j]; //#14184
                        if (_B5 && ((_B4 >= 3) && ((_B4 % 2) == 1))) { //#14191
                            $k[$j++] = $1.sb3; //#14185
                            $1.encc(); //#14185
                            $k[$j++] = $get($1.msg, $1.i); //#14186
                            $1.encb(); //#14186
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14187
                            $1.encb(); //#14187
                            $k[$j++] = $get($1.msg, $1.i + 2); //#14188
                            $1.encb(); //#14188
                            $1.i = $1.i + 3; //#14189
                            break; //#14190
                        } //#14190
                    } //#14190
                    if ($1.i < ($1.msglen - 3)) { //#14206
                        var _BN = $get($1.setb, $get($1.msg, $1.i)) !== undefined; //#14195
                        var _BS = $get($1.setb, $get($1.msg, $1.i + 1)) !== undefined; //#14196
                        var _BX = $get($1.setb, $get($1.msg, $1.i + 2)) !== undefined; //#14197
                        $k[$j++] = (_BN && _BS) && _BX; //#14198
                        $k[$j++] = $1.i + 3; //#14198
                        $1.numsscr(); //#14198
                        var _BZ = $k[--$j]; //#14198
                        var _Ba = $k[--$j]; //#14198
                        $k[$j++] = _BZ; //#14198
                        $k[$j++] = _Ba; //#14198
                        $j--; //#14198
                        var _Bb = $k[--$j]; //#14198
                        var _Bc = $k[--$j]; //#14198
                        if (_Bc && ((_Bb >= 2) && ((_Bb % 2) == 0))) { //#14205
                            $k[$j++] = $1.sb3; //#14199
                            $1.encc(); //#14199
                            $k[$j++] = $get($1.msg, $1.i); //#14200
                            $1.encb(); //#14200
                            $k[$j++] = $get($1.msg, $1.i + 1); //#14201
                            $1.encb(); //#14201
                            $k[$j++] = $get($1.msg, $1.i + 2); //#14202
                            $1.encb(); //#14202
                            $1.i = $1.i + 3; //#14203
                            break; //#14204
                        } //#14204
                    } //#14204
                    $k[$j++] = $1.i; //#14208
                    $1.abeforeb(); //#14208
                    if ($k[--$j]) { //#14212
                        $k[$j++] = $1.swa; //#14209
                        $1.encc(); //#14209
                        $1.cset = "seta"; //#14210
                        break; //#14211
                    } //#14211
                    $k[$j++] = $1.swb; //#14214
                    $1.encc(); //#14214
                    $1.cset = "setb"; //#14215
                    break; //#14216
                } //#14216
                break; //#14218
            } //#14218
        } //#14218
        $1.cws = $geti($1.cws, 0, $1.j); //#14222
    } //#14222
    $1.metrics = $a([$a([2, 7]), $a([3, 12]), $a([4, 17]), $a([5, 22]), $a([6, 27]), $a([7, 32]), $a([8, 37]), $a([9, 42]), $a([10, 47]), $a([11, 52]), $a([12, 57]), $a([13, 62]), $a([14, 67]), $a([15, 72]), $a([16, 77])]); //#14244
    $1.urows = $1.rows; //#14248
    for (var _CE = 0, _CD = $1.metrics.length - 1; _CE <= _CD; _CE += 1) { //#14258
        $1.i = _CE; //#14250
        $1.m = $get($1.metrics, $1.i); //#14251
        $1.r = $get($1.m, 0); //#14252
        $1.dcws = $get($1.m, 1); //#14253
        $1.okay = true; //#14254
        if (($1.urows != 0) && ($1.urows != $1.r)) { //#14255
            $1.okay = false; //#14255
        } //#14255
        if ($1.cws.length > $1.dcws) { //#14256
            $1.okay = false; //#14256
        } //#14256
        if ($1.okay) { //#14257
            break; //#14257
        } //#14257
    } //#14257
    if (!$1.okay) { //#14262
        $k[$j++] = 'bwipp.code16kNoValidSymbol'; //#14261
        $k[$j++] = "Maximum length exceeded or data too large for given options"; //#14261
        bwipp_raiseerror(); //#14261
    } //#14261
    $k[$j++] = Infinity; //#14265
    $aload($1.cws); //#14265
    for (var _CW = 0, _CX = $f($1.dcws - $1.cws.length); _CW < _CX; _CW++) { //#14265
        $k[$j++] = 103; //#14265
    } //#14265
    $1.cws = $a(); //#14265
    $k[$j++] = Infinity; //#14268
    $k[$j++] = $f(($f($1.r - 2) * 7) + $1.mode); //#14268
    $aload($1.cws); //#14268
    $1.cws = $a(); //#14268
    $k[$j++] = 0; //#14271
    for (var _Cf = 0, _Ce = $1.dcws; _Cf <= _Ce; _Cf += 1) { //#14271
        var _Ci = $k[--$j]; //#14271
        $k[$j++] = $f(_Ci + ((_Cf + 2) * $get($1.cws, _Cf))); //#14271
    } //#14271
    $1.c1 = $k[--$j] % 107; //#14272
    $k[$j++] = 0; //#14273
    for (var _Cm = 0, _Cl = $1.dcws; _Cm <= _Cl; _Cm += 1) { //#14273
        var _Cp = $k[--$j]; //#14273
        $k[$j++] = $f(_Cp + ((_Cm + 1) * $get($1.cws, _Cm))); //#14273
    } //#14273
    $1.c2 = ($f($k[--$j] + ($1.c1 * $f($1.dcws + 2)))) % 107; //#14274
    $k[$j++] = Infinity; //#14275
    $aload($1.cws); //#14275
    $k[$j++] = $1.c1; //#14275
    $k[$j++] = $1.c2; //#14275
    $1.cws = $a(); //#14275
    var _Cy = $get($1.options, 'debugcws') !== undefined; //#14277
    if (_Cy) { //#14277
        $k[$j++] = 'bwipp.debugcws'; //#14277
        $k[$j++] = $1.cws; //#14277
        bwipp_raiseerror(); //#14277
    } //#14277
    $1.encs = $a(["212222", "222122", "222221", "121223", "121322", "131222", "122213", "122312", "132212", "221213", "221312", "231212", "112232", "122132", "122231", "113222", "123122", "123221", "223211", "221132", "221231", "213212", "223112", "312131", "311222", "321122", "321221", "312212", "322112", "322211", "212123", "212321", "232121", "111323", "131123", "131321", "112313", "132113", "132311", "211313", "231113", "231311", "112133", "112331", "132131", "113123", "113321", "133121", "313121", "211331", "231131", "213113", "213311", "213131", "311123", "311321", "331121", "312113", "312311", "332111", "314111", "221411", "431111", "111224", "111422", "121124", "121421", "141122", "141221", "112214", "112412", "122114", "122411", "142112", "142211", "241211", "221114", "413111", "241112", "134111", "111242", "121142", "121241", "114212", "124112", "124211", "411212", "421112", "421211", "212141", "214121", "412121", "111143", "111341", "131141", "114113", "114311", "411113", "411311", "113141", "114131", "311141", "411131", "211412", "211214", "211232", "211133"]); //#14298
    $1.startencs = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "3112", "3211", "2221", "2122", "1411", "1132", "1231", "1114", "3112"]); //#14304
    $1.stopencsodd = $a(["3211", "2221", "2122", "1411", "1132", "1231", "1114", "3112", "1132", "1231", "1114", "3112", "3211", "2221", "2122", "1411"]); //#14308
    $1.stopencseven = $a(["2122", "1411", "1132", "1231", "1114", "3112", "1132", "1231", "1114", "3112", "3211", "2221", "2122", "1411", "3211", "2221"]); //#14312
    if (($1.pos == -1) || (((~~($1.pos / 10)) % 2) == 1)) { //#14318
        $1.stopencs = $1.stopencsodd; //#14316
    } else { //#14318
        $1.stopencs = $1.stopencseven; //#14318
    } //#14318
    $1.rowbits = $a($1.r); //#14322
    for (var _DC = 0, _DB = $f($1.r - 1); _DC <= _DB; _DC += 1) { //#14339
        $1.i = _DC; //#14324
        $k[$j++] = Infinity; //#14333
        $k[$j++] = 10; //#14327
        $forall($get($1.startencs, $1.i), function() { //#14327
            var _DG = $k[--$j]; //#14327
            $k[$j++] = $f(_DG - 48); //#14327
        }); //#14327
        var _DJ = $geti($1.cws, $1.i * 5, 5); //#14329
        $k[$j++] = 1; //#14331
        for (var _DK = 0, _DL = _DJ.length; _DK < _DL; _DK++) { //#14331
            $forall($get($1.encs, $get(_DJ, _DK)), function() { //#14330
                var _DP = $k[--$j]; //#14330
                $k[$j++] = $f(_DP - 48); //#14330
            }); //#14330
        } //#14330
        $forall($get($1.stopencs, $1.i), function() { //#14332
            var _DT = $k[--$j]; //#14332
            $k[$j++] = $f(_DT - 48); //#14332
        }); //#14332
        $k[$j++] = 1; //#14333
        $1.sbs = $a(); //#14333
        $k[$j++] = Infinity; //#14335
        var _DV = $1.sbs; //#14336
        $k[$j++] = 1; //#14336
        for (var _DW = 0, _DX = _DV.length; _DW < _DX; _DW++) { //#14336
            var _DZ = $k[--$j]; //#14336
            var _Da = (_DZ == 0) ? 1 : 0; //#14336
            $k[$j++] = _DZ; //#14336
            for (var _Db = 0, _Dc = $get(_DV, _DW); _Db < _Dc; _Db++) { //#14336
                $k[$j++] = _Da //#14336
            } //#14336
        } //#14336
        $astore($a($counttomark() - 1)); //#14337
        var _Df = $k[--$j]; //#14337
        var _Dg = $k[--$j]; //#14337
        $k[$j++] = _Df; //#14337
        $k[$j++] = _Dg; //#14337
        $j--; //#14337
        var _Dh = $k[--$j]; //#14337
        var _Di = $k[--$j]; //#14337
        $k[$j++] = _Dh; //#14337
        $k[$j++] = _Di; //#14337
        $j--; //#14337
        $put($1.rowbits, $1.i, $k[--$j]); //#14338
    } //#14338
    $k[$j++] = Infinity; //#14350
    for (var _Dn = 0, _Do = 81 * $1.sepheight; _Dn < _Do; _Dn++) { //#14343
        $k[$j++] = 1; //#14343
    } //#14343
    for (var _Dr = 0, _Dq = $f($1.r - 2); _Dr <= _Dq; _Dr += 1) { //#14348
        $1.i = _Dr; //#14345
        for (var _Dt = 0, _Du = $1.rowheight; _Dt < _Du; _Dt++) { //#14346
            $aload($get($1.rowbits, $1.i)); //#14346
        } //#14346
        for (var _Dz = 0, _E0 = $1.sepheight; _Dz < _E0; _Dz++) { //#14347
            for (var _E1 = 0, _E2 = 10; _E1 < _E2; _E1++) { //#14347
                $k[$j++] = 0; //#14347
            } //#14347
            for (var _E3 = 0, _E4 = 70; _E3 < _E4; _E3++) { //#14347
                $k[$j++] = 1; //#14347
            } //#14347
            $k[$j++] = 0; //#14347
        } //#14347
    } //#14347
    for (var _E6 = 0, _E7 = $1.rowheight; _E6 < _E7; _E6++) { //#14349
        $aload($get($1.rowbits, $f($1.r - 1))); //#14349
    } //#14349
    for (var _EC = 0, _ED = 81 * $1.sepheight; _EC < _ED; _EC++) { //#14350
        $k[$j++] = 1; //#14350
    } //#14350
    $1.pixs = $a(); //#14350
    var _EJ = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", 81],
        ["pixy", ~~($1.pixs.length / 81)],
        ["height", (~~($1.pixs.length / 81)) / 72],
        ["width", 81 / 72],
        ["opt", $1.options]
    ]); //#14361
    $k[$j++] = _EJ; //#14364
    if (!$1.dontdraw) { //#14364
        bwipp_renmatrix(); //#14364
    } //#14364
}

function bwipp_code49() {
    var $1 = {}; //#14399
    $1.ctx = null; //#14401
    $1.dontdraw = false; //#14402
    $1.mode = -1; //#14403
    $1.pos = -1; //#14404
    $1.rows = 0; //#14405
    $1.rowheight = 8; //#14406
    $1.sepheight = 1; //#14407
    $1.parse = false; //#14408
    $1.parsefnc = false; //#14409
    $k[$j++] = $1; //#14411
    bwipp_processoptions(); //#14411
    $1.options = $k[--$j]; //#14411
    $1.barcode = $k[--$j]; //#14412
    $1.s1 = -1; //#14417
    $1.s2 = -2; //#14417
    $1.fn1 = -3; //#14417
    $1.fn2 = -4; //#14417
    $1.fn3 = -5; //#14417
    $1.ns = -6; //#14417
    var _7 = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["FNC1", $1.fn1],
        ["FNC2", $1.fn2],
        ["FNC3", $1.fn3]
    ]); //#14426
    $1.fncvals = _7; //#14427
    $k[$j++] = 'msg'; //#14428
    $k[$j++] = $1.barcode; //#14428
    $k[$j++] = $1.fncvals; //#14428
    bwipp_parseinput(); //#14428
    var _A = $k[--$j]; //#14428
    $1[$k[--$j]] = _A; //#14428
    $1.msglen = $1.msg.length; //#14429
    $1.charmap = $a(["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "-", ".", " ", "$", "/", "+", "%", $1.s1, $1.s2, $1.fn1, $1.fn2, $1.fn3, $1.ns]); //#14439
    $1.charvals = new Map; //#14442
    for (var _K = 0; _K <= 48; _K += 1) { //#14448
        $1.i = _K; //#14444
        var _N = $get($1.charmap, $1.i); //#14445
        $k[$j++] = _N; //#14446
        if ($eq($type(_N), 'stringtype')) { //#14446
            var _Q = $get($k[--$j], 0); //#14446
            $k[$j++] = _Q; //#14446
        } //#14446
        $put($1.charvals, $k[--$j], $1.i); //#14447
    } //#14447
    $1.combos = $a(["1 ", "1A", "1B", "1C", "1D", "1E", "1F", "1G", "1H", "1I", "1J", "1K", "1L", "1M", "1N", "1O", "1P", "1Q", "1R", "1S", "1T", "1U", "1V", "1W", "1X", "1Y", "1Z", "11", "12", "13", "14", "15", "  ", "16", "17", "18", " $", " %", "19", "10", "1-", "1.", "1$", " +", "1/", " -", " .", " /", " 0", " 1", " 2", " 3", " 4", " 5", " 6", " 7", " 8", " 9", "1+", "21", "22", "23", "24", "25", "26", " A", " B", " C", " D", " E", " F", " G", " H", " I", " J", " K", " L", " M", " N", " O", " P", " Q", " R", " S", " T", " U", " V", " W", " X", " Y", " Z", "27", "28", "29", "20", "2-", "2.", "2A", "2B", "2C", "2D", "2E", "2F", "2G", "2H", "2I", "2J", "2K", "2L", "2M", "2N", "2O", "2P", "2Q", "2R", "2S", "2T", "2U", "2V", "2W", "2X", "2Y", "2Z", "2$", "2/", "2+", "2%", "2 "]); //#14460
    for (var _V = 0; _V <= 127; _V += 1) { //#14470
        $1.i = _V; //#14462
        var _Y = $get($1.combos, $1.i); //#14463
        $1.c1 = $get(_Y, 0); //#14463
        $1.c2 = $get(_Y, 1); //#14463
        if ($1.c1 == 49) { //#14466
            $put($1.charvals, $1.i, $a([$get($1.charvals, $1.s1), $get($1.charvals, $1.c2)])); //#14465
        } //#14465
        if ($1.c1 == 50) { //#14469
            $put($1.charvals, $1.i, $a([$get($1.charvals, $1.s2), $get($1.charvals, $1.c2)])); //#14468
        } //#14468
    } //#14468
    $1.encodealpha = function() {
        var _x = $get($1.charvals, $k[--$j]); //#14474
        $k[$j++] = _x; //#14475
        if ($ne($type(_x), 'arraytype')) { //#14475
            $astore($a(1)); //#14475
        } //#14475
        var _10 = $k[--$j]; //#14476
        $puti($1.cws, $1.j, _10); //#14476
        $1.j = _10.length + $1.j; //#14477
    }; //#14477
    $1.base48 = function() {
        var _14 = $k[--$j]; //#14481
        $k[$j++] = 0; //#14481
        $forall(_14, function() { //#14481
            var _15 = $k[--$j]; //#14481
            var _16 = $k[--$j]; //#14481
            $k[$j++] = $f($f(_15 - 48) + (_16 * 10)); //#14481
        }); //#14481
        $k[$j++] = Infinity; //#14482
        var _17 = $k[--$j]; //#14482
        var _18 = $k[--$j]; //#14482
        var _19 = $k[--$j]; //#14482
        $k[$j++] = _17; //#14482
        $k[$j++] = _18; //#14482
        for (var _1A = 0, _1B = $f(_19 - 1); _1A < _1B; _1A++) { //#14482
            var _1C = $k[--$j]; //#14482
            $k[$j++] = _1C % 48; //#14482
            $k[$j++] = ~~(_1C / 48); //#14482
        } //#14482
        var _1D = $a(); //#14482
        $k[$j++] = _1D; //#14483
        $k[$j++] = Infinity; //#14483
        var _1E = $k[--$j]; //#14483
        var _1F = $k[--$j]; //#14483
        $k[$j++] = _1E; //#14483
        $k[$j++] = _1F; //#14483
        for (var _1G = _1F.length - 1; _1G >= 0; _1G -= 1) { //#14483
            var _1H = $k[--$j]; //#14483
            $k[$j++] = $get(_1H, _1G); //#14483
            $k[$j++] = _1H; //#14483
        } //#14483
        $j--; //#14483
        var _1J = $a(); //#14483
        $puti($1.cws, $1.j, _1J); //#14484
        $1.j = _1J.length + $1.j; //#14485
    }; //#14485
    $1.encodenumeric = function() {
        $1.nums = $k[--$j]; //#14489
        var _1P = $1.nums.length; //#14490
        var _1Q = _1P % 5; //#14490
        $k[$j++] = 'pre'; //#14490
        $k[$j++] = _1P; //#14490
        $k[$j++] = _1Q; //#14490
        if (_1Q != 2) { //#14490
            var _1R = $k[--$j]; //#14490
            var _1S = $k[--$j]; //#14490
            $k[$j++] = $f(_1S - _1R); //#14490
        } else { //#14490
            var _1T = $k[--$j]; //#14490
            var _1U = $k[--$j]; //#14490
            $k[$j++] = $f($f(_1U - _1T) - 5); //#14490
        } //#14490
        var _1V = $k[--$j]; //#14490
        $1[$k[--$j]] = _1V; //#14490
        for (var _1Z = 0, _1Y = $f($1.pre - 1); _1Z <= _1Y; _1Z += 5) { //#14491
            $k[$j++] = 3; //#14491
            $k[$j++] = $geti($1.nums, _1Z, 5); //#14491
            $1.base48(); //#14491
        } //#14491
        $1.nums = $geti($1.nums, $1.pre, $f($1.nums.length - $1.pre)); //#14492
        var _1i = $1.nums.length; //#14494
        $k[$j++] = _1i; //#14494
        if (_1i == 1) { //#14494
            $k[$j++] = $get($1.nums, $1.i); //#14494
            $1.encodealpha(); //#14494
        } //#14494
        var _1m = $k[--$j]; //#14495
        $k[$j++] = _1m; //#14495
        if (_1m == 3) { //#14495
            $k[$j++] = 2; //#14495
            $k[$j++] = $1.nums; //#14495
            $1.base48(); //#14495
        } //#14495
        var _1o = $k[--$j]; //#14496
        $k[$j++] = _1o; //#14496
        if (_1o == 4) { //#14496
            $k[$j++] = 3; //#14496
            $k[$j++] = Infinity; //#14496
            $k[$j++] = 49; //#14496
            $k[$j++] = 48; //#14496
            $aload($1.nums); //#14496
            var _1q = $a(); //#14496
            $k[$j++] = _1q; //#14496
            $1.base48(); //#14496
        } //#14496
        if ($k[--$j] == 7) { //#14500
            $k[$j++] = 3; //#14498
            $k[$j++] = Infinity; //#14498
            $k[$j++] = 49; //#14498
            $k[$j++] = 48; //#14498
            $aload($geti($1.nums, 0, 4)); //#14498
            var _1u = $a(); //#14498
            $k[$j++] = _1u; //#14498
            $1.base48(); //#14498
            $k[$j++] = 2; //#14499
            $k[$j++] = $geti($1.nums, 4, 3); //#14499
            $1.base48(); //#14499
        } //#14499
    }; //#14499
    $k[$j++] = Infinity; //#14504
    for (var _1y = 0, _1z = $1.msglen; _1y < _1z; _1y++) { //#14504
        $k[$j++] = 0; //#14504
    } //#14504
    $k[$j++] = 0; //#14504
    $1.numericruns = $a(); //#14504
    for (var _22 = $1.msglen - 1; _22 >= 0; _22 -= 1) { //#14513
        $1.i = _22; //#14506
        var _25 = $get($1.msg, $1.i); //#14507
        if ((_25 >= 48) && (_25 <= 57)) { //#14511
            $put($1.numericruns, $1.i, $f($get($1.numericruns, $1.i + 1) + 1)); //#14509
        } else { //#14511
            $put($1.numericruns, $1.i, 0); //#14511
        } //#14511
    } //#14511
    if ($1.mode == -1) { //#14525
        for (;;) { //#14524
            if ($1.pos != -1) { //#14518
                $1.mode = 3; //#14518
                break; //#14518
            } //#14518
            if ($get($1.numericruns, 0) >= 5) { //#14519
                $1.mode = 2; //#14519
                break; //#14519
            } //#14519
            var _2K = $get($1.charvals, $get($1.msg, 0)); //#14520
            $k[$j++] = _2K; //#14521
            if ($ne($type(_2K), 'arraytype')) { //#14521
                $j--; //#14521
                $1.mode = 0; //#14521
                break; //#14521
            } //#14521
            var _2O = ($get($k[--$j], 0) == 43) ? 4 : 5; //#14522
            $1.mode = _2O; //#14522
            break; //#14523
        } //#14523
    } //#14523
    $1.cws = $a(($1.msglen * 2) + 1); //#14527
    $1.method = "alpha"; //#14528
    $1.i = -1; //#14528
    $1.j = -1; //#14528
    $1.posval = $a([12, 22, 13, 23, 33, 14, 24, 34, 44, 15, 25, 35, 45, 55, 16, 26, 36, 46, 56, 66, 17, 27, 37, 47, 57, 67, 77, 18, 28, 38, 48, 58, 68, 78, 88, 19, 29, 39, 49, 59, 69, 79, 89, 99]); //#14540
    if (($1.mode == 0) || ($1.mode == 1)) { //#14544
        $1.method = "alpha"; //#14544
        $1.i = 0; //#14544
        $1.j = 0; //#14544
    } //#14544
    if ($1.mode == 2) { //#14545
        $1.method = "numeric"; //#14545
        $1.i = 0; //#14545
        $1.j = 0; //#14545
    } //#14545
    if ($1.mode == 3) { //#14549
        $k[$j++] = $1.cws; //#14547
        $k[$j++] = 0; //#14547
        for (var _2X = 0; _2X <= 43; _2X += 1) { //#14547
            $k[$j++] = _2X; //#14547
            if ($get($1.posval, _2X) != $1.pos) { //#14547
                $j--; //#14547
            } //#14547
        } //#14547
        var _2b = $k[--$j]; //#14547
        var _2c = $k[--$j]; //#14547
        $put($k[--$j], _2c, $f(_2b + 1)); //#14547
        $1.method = "alpha"; //#14548
        $1.i = 0; //#14548
        $1.j = 1; //#14548
    } //#14548
    if (($1.mode == 4) || ($1.mode == 5)) { //#14553
        $put($1.cws, 0, $get($get($1.charvals, $get($1.msg, 0)), 1)); //#14551
        $1.method = "alpha"; //#14552
        $1.i = 1; //#14552
        $1.j = 1; //#14552
    } //#14552
    for (;;) { //#14580
        if ($1.i == $1.msglen) { //#14557
            break; //#14557
        } //#14557
        for (;;) { //#14579
            if ($eq($1.method, "alpha")) { //#14568
                if ($get($1.numericruns, $1.i) >= 5) { //#14564
                    $k[$j++] = $1.ns; //#14561
                    $1.encodealpha(); //#14561
                    $1.method = "numeric"; //#14562
                    break; //#14563
                } //#14563
                $k[$j++] = $get($1.msg, $1.i); //#14565
                $1.encodealpha(); //#14565
                $1.i = $1.i + 1; //#14566
                break; //#14567
            } //#14567
            if ($eq($1.method, "numeric")) { //#14578
                if ($get($1.numericruns, $1.i) < 5) { //#14574
                    $k[$j++] = $1.ns; //#14571
                    $1.encodealpha(); //#14571
                    $1.method = "alpha"; //#14572
                    break; //#14573
                } //#14573
                $k[$j++] = $geti($1.msg, $1.i, $get($1.numericruns, $1.i)); //#14575
                $1.encodenumeric(); //#14575
                $1.i = $f($1.i + $get($1.numericruns, $1.i)); //#14576
                break; //#14577
            } //#14577
        } //#14577
    } //#14577
    $1.cws = $geti($1.cws, 0, $1.j); //#14581
    $1.metrics = $a([$a([2, 9]), $a([3, 16]), $a([4, 23]), $a([5, 30]), $a([6, 37]), $a([7, 42]), $a([8, 49])]); //#14594
    $1.urows = $1.rows; //#14598
    $1.i = 0; //#14599
    for (;;) { //#14609
        $1.m = $get($1.metrics, $1.i); //#14601
        $1.r = $get($1.m, 0); //#14602
        $1.dcws = $get($1.m, 1); //#14603
        $1.okay = true; //#14604
        if (($1.urows != 0) && ($1.urows != $1.r)) { //#14605
            $1.okay = false; //#14605
        } //#14605
        if ($1.cws.length > $1.dcws) { //#14606
            $1.okay = false; //#14606
        } //#14606
        if ($1.okay) { //#14607
            break; //#14607
        } //#14607
        $1.i = $1.i + 1; //#14608
    } //#14608
    $k[$j++] = Infinity; //#14612
    $aload($1.cws); //#14612
    for (var _3f = 0, _3g = $f($1.dcws - $1.cws.length); _3f < _3g; _3f++) { //#14612
        $k[$j++] = 48; //#14612
    } //#14612
    $1.cws = $a(); //#14612
    $1.ccs = $a($1.r * 8); //#14615
    $1.j = 0; //#14616
    for (var _3m = 0, _3l = $f($1.r - 2); _3m <= _3l; _3m += 1) { //#14623
        $1.i = _3m; //#14618
        $1.cc = $geti($1.cws, $1.j, 7); //#14619
        $puti($1.ccs, $1.i * 8, $1.cc); //#14620
        var _3v = $1.cc; //#14621
        $k[$j++] = $1.ccs; //#14621
        $k[$j++] = ($1.i * 8) + 7; //#14621
        $k[$j++] = 0; //#14621
        for (var _3w = 0, _3x = _3v.length; _3w < _3x; _3w++) { //#14621
            var _3z = $k[--$j]; //#14621
            $k[$j++] = $f(_3z + $get(_3v, _3w)); //#14621
        } //#14621
        var _40 = $k[--$j]; //#14621
        var _41 = $k[--$j]; //#14621
        $put($k[--$j], _41, _40 % 49); //#14621
        $1.j = $1.j + 7; //#14622
    } //#14622
    if ($1.j < $1.dcws) { //#14626
        $puti($1.ccs, $1.ccs.length - 8, $geti($1.cws, $1.j, $f($1.dcws - $1.j))); //#14625
    } //#14625
    $1.cr7 = $f(($f($1.r - 2) * 7) + $1.mode); //#14629
    $put($1.ccs, $1.ccs.length - 2, $1.cr7); //#14630
    var _4I = $a([1, 9, 31, 26, 2, 12, 17, 23, 37, 18, 22, 6, 27, 44, 15, 43, 39, 11, 13, 5, 41, 33, 36, 8, 4, 32, 3, 19, 40, 25, 29, 10, 24, 30]); //#14635
    $k[$j++] = _4I; //#14636
    $k[$j++] = _4I; //#14636
    $k[$j++] = Infinity; //#14636
    var _4J = $k[--$j]; //#14636
    var _4L = $geti($k[--$j], 0, 32); //#14636
    $k[$j++] = _4J; //#14636
    $k[$j++] = 20; //#14636
    $aload(_4L); //#14636
    $1.weightx = $a(); //#14636
    var _4N = $k[--$j]; //#14637
    $k[$j++] = _4N; //#14637
    $k[$j++] = _4N; //#14637
    $k[$j++] = Infinity; //#14637
    var _4O = $k[--$j]; //#14637
    var _4Q = $geti($k[--$j], 1, 32); //#14637
    $k[$j++] = _4O; //#14637
    $k[$j++] = 16; //#14637
    $aload(_4Q); //#14637
    $1.weighty = $a(); //#14637
    $k[$j++] = Infinity; //#14638
    var _4S = $k[--$j]; //#14638
    var _4U = $geti($k[--$j], 2, 32); //#14638
    $k[$j++] = _4S; //#14638
    $k[$j++] = 38; //#14638
    $aload(_4U); //#14638
    $1.weightz = $a(); //#14638
    $1.calccheck = function() {
        $1.weights = $k[--$j]; //#14641
        $1.score = 0; //#14642
        for (var _4Z = 0, _4Y = (~~(($f($1.r - 1) * 8) / 2)) - 1; _4Z <= _4Y; _4Z += 1) { //#14647
            $1.i = _4Z; //#14644
            $1.score = $f((($f(($get($1.ccs, $1.i * 2) * 49) + $get($1.ccs, ($1.i * 2) + 1))) * $get($1.weights, $1.i + 1)) + $1.score); //#14646
        } //#14646
        $k[$j++] = $1.score; //#14648
    }; //#14648
    $1.lastrow = $geti($1.ccs, $1.ccs.length - 8, 8); //#14650
    if ($1.r >= 7) { //#14657
        $k[$j++] = $1.cr7 * $get($1.weightz, 0); //#14654
        $k[$j++] = $1.weightz; //#14654
        $1.calccheck(); //#14654
        var _4t = $k[--$j]; //#14654
        var _4v = $f($k[--$j] + _4t) % 2401; //#14655
        $k[$j++] = ~~(_4v / 49); //#14655
        $k[$j++] = _4v % 49; //#14655
        $astore($a(2)); //#14655
        $puti($1.lastrow, 0, $k[--$j]); //#14656
    } //#14656
    $1.wr1 = $f(($get($1.lastrow, 0) * 49) + $get($1.lastrow, 1)); //#14658
    $k[$j++] = $1.cr7 * $get($1.weighty, 0); //#14661
    $k[$j++] = $1.weighty; //#14661
    $1.calccheck(); //#14661
    var _57 = $k[--$j]; //#14661
    var _5D = ($f($f($k[--$j] + _57) + ($1.wr1 * $get($1.weighty, $f(($1.r * 4) - 3))))) % 2401; //#14663
    $1.wr2 = _5D; //#14663
    $k[$j++] = ~~(_5D / 49); //#14664
    $k[$j++] = _5D % 49; //#14664
    $astore($a(2)); //#14664
    $puti($1.lastrow, 2, $k[--$j]); //#14665
    $k[$j++] = $1.cr7 * $get($1.weightx, 0); //#14668
    $k[$j++] = $1.weightx; //#14668
    $1.calccheck(); //#14668
    var _5L = $k[--$j]; //#14668
    var _5V = ($f(($f($f($k[--$j] + _5L) + ($1.wr1 * $get($1.weightx, $f(($1.r * 4) - 3))))) + ($1.wr2 * $get($1.weightx, $f(($1.r * 4) - 2))))) % 2401; //#14672
    $k[$j++] = ~~(_5V / 49); //#14672
    $k[$j++] = _5V % 49; //#14672
    $astore($a(2)); //#14672
    $puti($1.lastrow, 4, $k[--$j]); //#14673
    var _5b = $geti($1.ccs, $1.ccs.length - 8, 7); //#14676
    $k[$j++] = 0; //#14676
    for (var _5c = 0, _5d = _5b.length; _5c < _5d; _5c++) { //#14676
        var _5f = $k[--$j]; //#14676
        $k[$j++] = $f(_5f + $get(_5b, _5c)); //#14676
    } //#14676
    $put($1.ccs, $1.ccs.length - 1, $k[--$j] % 49); //#14677
    $1.patterns = $a([$a(["11521132", "25112131", "14212132", "25121221", "14221222", "12412132", "23321221", "12421222", "21521221", "15112222", "15121312", "13312222", "24221311", "13321312", "11512222", "22421311", "11521312", "25112311", "14212312", "23312311", "12412312", "21512311", "16121131", "14321131", "12521131", "15212131", "15221221", "13412131", "13421221", "11612131", "16112221", "16121311", "14312221", "14321311", "12512221", "12521311", "15212311", "13412311", "11612311", "11131135", "31131133", "51131131", "21122134", "41122132", "21131224", "41131222", "11113135", "31113133", "51113131", "11122225", "31122223", "51122221", "11131315", "31131313", "51131311", "21113224", "41113222", "21122314", "41122312", "11113315", "31113313", "51113311", "12131134", "32131132", "21231133", "41231131", "22122133", "42122131", "11222134", "22131223", "42131221", "11231224", "31231222", "12113134", "32113132", "12122224", "32122222", "12131314", "32131312", "21231313", "41231311", "22113223", "42113221", "11213224", "22122313", "42122311", "11222314", "31222312", "12113314", "32113312", "21213313", "41213311", "13131133", "33131131", "22231132", "11331133", "31331131", "23122132", "12222133", "23131222", "12231223", "32231221", "21331222", "13113133", "33113131", "13122223", "33122221", "11313133", "13131313", "33131311", "11322223", "22231312", "11331313", "31331311", "23113222", "12213223", "23122312", "12222313", "32222311", "21322312", "13113313", "33113311", "22213312", "11313313", "31313311", "14131132", "23231131", "12331132", "21431131", "24122131", "13222132", "24131221", "13231222", "11422132", "22331221", "11431222", "14113132", "14122222", "12313132", "14131312", "12322222", "23231311", "12331312", "21431311", "24113221", "13213222", "24122311", "13222312", "11413222", "22322311", "11422312", "14113312", "23213311", "12313312", "21413311", "15131131", "13331131", "14222131", "14231221", "12422131", "12431221", "15113131", "15122221", "13313131", "15131311", "13322221", "11513131", "13331311", "11522221", "14213221", "14222311", "12413221", "12422311", "15113311", "13313311", "11513311", "11141134", "31141132", "21132133", "41132131", "21141223", "41141221", "11123134", "31123132", "11132224", "31132222", "11141314", "31141312", "21114133", "41114131", "21123223", "41123221", "21132313", "41132311", "11114224", "31114222", "11123314", "31123312", "21114313", "41114311", "12141133", "32141131", "21241132", "22132132", "11232133", "22141222", "11241223", "31241221", "12123133", "32123131", "12132223", "32132221", "12141313", "32141311", "21241312", "22114132", "11214133", "22123222", "11223223", "22132312", "11232313", "31232311", "12114223", "32114221", "12123313", "32123311", "21223312", "22114312", "11214313", "31214311", "13141132", "22241131", "11341132", "23132131", "12232132", "23141221", "12241222", "21341221", "13123132", "13132222", "11323132", "13141312", "11332222", "22241311", "11341312", "23114131", "12214132", "23123221", "12223222", "23132311", "12232312", "21332311", "13114222", "13123312", "11314222", "22223311", "11323312", "23114311", "12214312", "21314311", "14141131", "12341131", "13232131", "13241221", "11432131", "14123131", "14132221", "12323131", "14141311", "12332221", "12341311", "13214131", "13223221", "11414131", "13232311", "11423221", "11432311", "14114221", "14123311", "12314221", "12323311", "13214311", "11414311", "11151133", "31151131", "21142132", "21151222", "11133133", "31133131", "11142223", "31142221", "11151313", "31151311", "21124132", "21133222", "21142312", "11115133", "31115131", "11124223", "31124221", "11133313", "31133311", "21115222", "21124312", "12151132", "21251131", "22142131", "11242132", "22151221", "11251222", "12133132", "12142222", "12151312", "21251311", "22124131", "11224132", "22133221", "11233222", "22142311", "11242312", "12115132", "12124222", "12133312", "21233311", "22115221", "11215222", "22124311", "11224312", "13151131", "12242131", "12251221", "13133131", "13142221", "11333131", "13151311", "11342221", "12224131", "12233221", "12242311", "13115131", "13124221", "11315131", "13133311", "11324221", "11333311", "12215221", "12224311", "11161132", "21152131", "21161221", "11143132", "11152222", "11161312", "21134131", "21143221", "21152311", "11125132", "11134222", "11143312", "21116131", "21125221", "21134311", "12161131", "11252131", "12143131", "12152221", "12161311", "11234131", "11243221", "11252311", "12125131", "12134221", "12143311", "11216131", "11225221", "11234311", "11111236", "31111234", "51111232", "21111325", "41111323", "61111321", "11111416", "31111414", "51111412", "31211143", "51211141", "12111235", "32111233", "52111231", "21211234", "41211232", "22111324", "42111322", "11211325", "31211323", "51211321", "12111415", "32111413", "52111411", "21211414", "41211412", "12211144", "32211142", "21311143", "41311141", "13111234", "33111232", "22211233", "42211231", "11311234", "31311232", "23111323", "43111321", "12211324", "32211322", "21311323", "41311321", "13111414", "33111412", "22211413", "42211411", "11311414", "31311412", "13211143", "33211141", "22311142", "11411143", "31411141", "14111233", "34111231", "23211232", "12311233", "32311231", "21411232", "24111322", "13211323", "33211321", "22311322", "11411323", "31411321", "14111413", "34111411", "23211412", "12311413", "32311411", "21411412", "14211142", "23311141", "12411142", "21511141", "15111232", "24211231", "13311232", "22411231", "11511232", "25111321", "14211322", "23311321", "12411322", "21511321", "15111412", "24211411", "13311412", "22411411", "11511412", "15211141", "13411141", "11611141", "16111231", "14311231", "12511231", "15211321", "13411321", "11611321", "16111411", "14311411", "12511411", "21121144", "41121142", "11112145", "31112143", "51112141", "11121235", "31121233", "51121231", "21112234", "41112232", "21121324", "41121322", "11112325", "31112323", "51112321", "11121415", "31121413", "51121411", "21112414", "41112412", "22121143", "42121141", "11221144", "31221142", "12112144", "32112142", "12121234", "32121232", "21221233", "41221231", "22112233", "42112231", "11212234", "22121323", "42121321", "11221324", "31221322", "12112324", "32112322", "12121414", "32121412", "21221413", "41221411", "22112413", "42112411", "11212414", "31212412", "23121142", "12221143", "32221141", "21321142", "13112143", "33112141", "13121233", "33121231", "11312143", "22221232", "11321233", "31321231", "23112232", "12212233", "23121322", "12221323", "32221321", "21321322", "13112323", "33112321", "13121413", "33121411", "11312323", "22221412", "11321413", "31321411", "23112412", "12212413", "32212411", "21312412", "24121141", "13221142", "22321141", "11421142", "14112142", "14121232", "12312142", "23221231", "12321232", "21421231", "24112231", "13212232", "24121321", "13221322", "11412232", "22321321", "11421322", "14112322", "14121412", "12312322", "23221411", "12321412", "21421411", "24112411", "13212412", "22312411", "11412412", "14221141", "12421141", "15112141", "15121231", "13312141", "13321231", "11512141", "11521231", "14212231", "14221321", "12412231", "12421321", "15112321", "15121411", "13312321", "13321411", "11512321", "11521411", "14212411", "12412411", "21131143", "41131141", "11122144", "31122142", "11131234", "31131232", "21113143", "41113141", "21122233", "41122231", "21131323", "41131321", "11113234", "31113232", "11122324", "31122322", "11131414", "31131412", "21113323", "41113321", "21122413", "41122411", "11113414", "31113412", "22131142", "11231143", "31231141", "12122143", "32122141", "12131233", "32131231", "21231232", "22113142", "11213143", "22122232", "11222233", "22131322", "11231323", "31231321", "12113233", "32113231", "12122323", "32122321", "12131413", "32131411", "21231412", "22113322", "11213323", "22122412", "11222413", "31222411", "12113413", "32113411", "21213412", "23131141", "12231142", "21331141", "13122142", "13131232", "11322142", "22231231", "11331232", "23113141", "12213142", "23122231", "12222232", "23131321", "12231322", "21331321", "13113232", "13122322", "11313232", "13131412", "11322322", "22231411", "11331412", "23113321", "12213322", "23122411", "12222412", "21322411", "13113412", "22213411", "11313412", "13231141", "11431141", "14122141", "14131231", "12322141", "12331231", "13213141", "13222231", "11413141", "13231321", "11422231", "11431321", "14113231", "14122321", "12313231", "14131411", "12322321", "12331411", "13213321", "13222411", "11413321", "11422411", "14113411", "12313411", "21141142", "11132143", "31132141", "11141233", "31141231", "21123142", "21132232", "21141322", "11114143", "31114141", "11123233", "31123231", "11132323", "31132321", "11141413", "31141411", "21114232", "21123322", "21132412", "11114323", "31114321", "11123413", "31123411", "22141141", "11241142", "12132142", "12141232", "21241231", "22123141", "11223142", "22132231", "11232232", "22141321", "11241322", "12114142", "12123232", "12132322", "12141412", "21241411", "22114231", "11214232", "22123321", "11223322", "22132411", "11232412", "12114322", "12123412", "21223411", "12241141", "13132141", "13141231", "11332141", "11341231", "12223141", "12232231", "12241321", "13114141", "13123231", "11314141", "13132321", "11323231", "13141411", "11332321", "11341411", "12214231", "12223321", "12232411", "13114321", "13123411", "11314321", "11323411", "21151141", "11142142", "11151232", "21133141", "21142231", "21151321", "11124142", "11133232", "11142322", "11151412", "21115141", "21124231", "21133321", "21142411", "11115232", "11124322", "11133412", "11251141", "12142141", "12151231", "11233141", "11242231", "11251321", "12124141", "12133231", "12142321", "12151411", "11215141", "11224231", "11233321", "11242411", "12115231", "12124321", "12133411", "11152141", "11161231", "11134141", "11143231", "11152321", "11161411", "11116141", "11125231", "11134321", "11143411", "21111244", "41111242", "11111335", "31111333", "51111331", "21111424", "41111422", "11111515", "31111513", "51111511", "21211153", "41211151", "22111243", "42111241", "11211244", "31211242", "12111334", "32111332", "21211333", "41211331", "22111423", "42111421", "11211424", "31211422", "12111514", "32111512", "21211513", "41211511", "22211152", "11311153", "31311151", "23111242", "12211243", "32211241", "21311242", "13111333", "33111331", "22211332", "11311333", "31311331", "23111422", "12211423", "32211421", "21311422", "13111513", "33111511", "22211512", "11311513", "31311511", "23211151", "12311152", "21411151", "24111241", "13211242", "22311241", "11411242", "14111332", "23211331", "12311332", "21411331", "24111421", "13211422", "22311421", "11411422", "14111512", "23211511", "12311512", "21411511", "13311151", "11511151", "14211241", "12411241", "15111331", "13311331", "11511331", "14211421", "12411421", "15111511", "13311511", "11511511", "31121152", "21112153", "41112151", "21121243", "41121241", "11112244", "31112242", "11121334", "31121332", "21112333", "41112331", "21121423", "41121421", "11112424", "31112422", "11121514", "31121512", "21112513", "41112511", "12121153", "32121151", "21221152", "22112152", "11212153", "22121242", "11221243", "31221241", "12112243", "32112241", "12121333", "32121331", "21221332", "22112332", "11212333", "22121422", "11221423", "31221421", "12112423", "32112421", "12121513", "32121511", "21221512", "22112512", "11212513", "31212511", "13121152", "22221151", "11321152", "23112151", "12212152", "23121241", "12221242", "21321241", "13112242", "13121332", "11312242", "22221331", "11321332", "23112331", "12212332", "23121421", "12221422", "21321421", "13112422", "13121512", "11312422", "22221511", "11321512", "23112511", "12212512", "21312511", "14121151", "12321151", "13212151", "13221241", "11412151", "11421241", "14112241", "14121331", "12312241", "12321331", "13212331", "13221421", "11412331", "11421421", "14112421", "14121511", "12312421", "12321511", "13212511", "11412511", "11131153", "31131151", "21122152", "21131242", "11113153", "31113151", "11122243", "31122241", "11131333", "31131331", "21113242", "21122332", "21131422", "11113333", "31113331", "11122423", "31122421", "11131513", "31131511", "21113422", "21122512", "12131152", "21231151", "22122151", "11222152", "22131241", "11231242", "12113152", "12122242", "12131332", "21231331", "22113241", "11213242", "22122331", "11222332", "22131421", "11231422", "12113332", "12122422", "12131512", "21231511", "22113421", "11213422", "22122511", "11222512", "13131151", "11331151", "12222151", "12231241", "13113151", "13122241", "11313151", "13131331", "11322241", "11331331", "12213241", "12222331", "12231421", "13113331", "13122421", "11313331", "13131511", "11322421", "11331511", "12213421", "12222511", "11141152", "21132151", "21141241", "11123152", "11132242", "11141332", "21114151", "21123241", "21132331", "21141421", "11114242", "11123332", "11132422", "11141512", "21114331", "21123421", "21132511", "12141151", "11232151", "11241241", "12123151", "12132241", "12141331", "11214151", "11223241", "11232331", "11241421", "12114241", "12123331", "12132421", "12141511", "11214331", "11223421", "11232511", "11151151", "11133151", "11142241", "11151331", "11115151", "11124241", "11133331", "11142421", "11151511", "11111254", "31111252", "21111343", "41111341", "11111434", "31111432", "21111523", "41111521", "11111614", "31111612", "31211161", "12111253", "32111251", "21211252", "22111342", "11211343", "31211341", "12111433", "32111431", "21211432", "22111522", "11211523", "31211521", "12111613", "32111611", "21211612", "12211162", "21311161", "13111252", "22211251", "11311252", "23111341", "12211342", "21311341", "13111432", "22211431", "11311432", "23111521", "12211522", "21311521", "13111612", "22211611", "11311612", "13211161", "11411161", "14111251", "12311251", "13211341", "11411341", "14111431", "12311431", "13211521", "11411521", "14111611", "12311611", "21121162", "11112163", "31112161", "11121253", "31121251", "21112252", "21121342", "11112343", "31112341", "11121433", "31121431", "21112432", "21121522", "11112523", "31112521", "11121613", "31121611", "22121161", "11221162", "12112162", "12121252", "21221251", "22112251", "11212252", "22121341", "11221342", "12112342", "12121432", "21221431", "22112431", "11212432", "22121521", "11221522", "12112522", "12121612", "21221611", "12221161", "13112161", "13121251", "11312161", "11321251", "32121115", "52121113", "21221116", "41221114", "61221112", "22112116", "42112114", "31212115", "51212113", "13121116", "33121114", "22221115", "42221113", "11321116", "31321114", "51321112", "23112115", "43112113", "12212116", "32212114", "52212112", "21312115", "41312113", "61312111", "14121115", "34121113", "23221114", "43221112", "12321115", "32321113", "52321111", "21421114", "41421112", "24112114", "13212115", "33212113", "22312114", "42312112", "11412115", "31412113", "51412111", "15121114", "24221113", "13321114", "33321112", "22421113", "42421111", "11521114", "31521112", "25112113", "14212114", "34212112", "23312113", "43312111", "12412114", "32412112", "21512113", "41512111", "16121113", "25221112", "14321113", "34321111", "23421112", "12521113", "32521111", "15212113", "24312112", "13412113", "33412111", "22512112", "11612113", "31612111", "31131115", "51131113", "21122116", "41122114", "61122112", "31113115", "51113113", "12131116", "32131114", "52131112", "21231115", "41231113", "61231111", "22122115", "42122113", "11222116", "31222114", "51222112", "12113116", "32113114", "52113112", "21213115", "41213113", "61213111", "13131115", "33131113", "22231114", "42231112", "11331115", "31331113", "51331111", "23122114", "43122112", "12222115", "32222113", "52222111", "21322114", "41322112", "13113115", "33113113", "22213114", "42213112", "11313115", "31313113", "51313111", "14131114", "34131112", "23231113", "43231111", "12331114", "32331112", "21431113", "41431111", "24122113", "13222114", "33222112", "22322113", "42322111", "11422114", "31422112", "14113114", "34113112", "23213113", "43213111", "12313114", "32313112", "21413113", "41413111", "15131113", "24231112", "13331113", "33331111", "22431112", "25122112", "14222113", "34222111", "23322112", "12422113", "32422111", "21522112", "15113113", "24213112", "13313113", "33313111", "22413112", "11513113", "31513111", "16131112", "25231111", "14331112", "23431111", "15222112", "24322111", "13422112", "22522111", "16113112", "25213111", "14313112", "23413111", "12513112", "21613111", "11141116", "31141114", "51141112", "21132115", "41132113", "61132111", "11123116", "31123114", "51123112", "21114115", "41114113", "61114111", "12141115", "32141113", "52141111", "21241114", "41241112", "22132114", "42132112", "11232115", "31232113", "51232111", "12123115", "32123113", "52123111", "21223114", "41223112", "22114114", "42114112", "11214115", "31214113", "51214111", "13141114", "33141112", "22241113", "42241111", "11341114", "31341112", "23132113", "43132111", "12232114", "32232112", "21332113", "41332111", "13123114", "33123112", "22223113", "42223111", "11323114", "31323112", "23114113", "43114111", "12214114", "32214112", "21314113", "41314111", "14141113", "34141111", "23241112", "12341113", "32341111", "24132112", "13232113", "33232111", "22332112", "11432113", "31432111", "14123113", "34123111", "23223112", "12323113", "32323111", "21423112", "24114112", "13214113", "33214111", "22314112", "11414113", "31414111", "15141112", "24241111", "13341112", "25132111", "14232112", "23332111", "12432112", "15123112", "24223111", "13323112", "22423111", "11523112", "25114111", "14214112", "23314111", "12414112", "21514111", "16141111", "14341111", "15232111", "13432111", "16123111", "14323111", "12523111", "15214111", "13414111", "11614111", "11151115", "31151113", "51151111", "21142114", "41142112", "11133115", "31133113", "51133111", "21124114", "41124112", "11115115", "31115113", "51115111", "12151114", "32151112", "21251113", "41251111", "22142113", "42142111", "11242114", "31242112", "12133114", "32133112", "21233113", "41233111", "22124113", "42124111", "11224114", "31224112", "12115114", "32115112", "21215113", "41215111", "13151113", "33151111", "22251112", "23142112", "12242113", "32242111", "21342112", "13133113", "33133111", "22233112", "11333113", "31333111", "23124112", "12224113", "32224111", "21324112", "13115113", "33115111", "22215112", "11315113", "31315111", "14151112", "23251111", "24142111", "13242112", "22342111", "14133112", "23233111", "12333112", "21433111", "24124111", "13224112", "22324111", "11424112", "14115112", "23215111", "12315112", "21415111", "15151111", "14242111", "15133111", "13333111", "14224111", "12424111", "15115111", "13315111", "11515111", "11161114", "31161112", "21152113", "41152111", "11143114", "31143112", "21134113", "41134111", "11125114", "31125112", "21116113", "41116111", "12161113", "32161111", "22152112", "11252113", "31252111", "12143113", "32143111", "21243112", "22134112", "11234113", "31234111", "12125113", "32125111", "21225112", "22116112", "11216113", "31216111", "13161112", "23152111", "12252112", "13143112", "22243111", "11343112", "23134111", "12234112", "21334111", "13125112", "22225111", "11325112", "23116111", "12216112", "21316111", "14161111", "13252111", "14143111", "12343111", "13234111", "11434111", "14125111", "12325111", "13216111", "11416111", "31111216", "51111214", "31211125", "51211123", "32111215", "52111213", "21211216", "41211214", "61211212", "12211126", "32211124", "52211122", "21311125", "41311123", "61311121", "13111216", "33111214", "22211215", "42211213", "11311216", "31311214", "51311212", "13211125", "33211123", "22311124", "42311122", "11411125", "31411123", "51411121", "14111215", "34111213", "23211214", "43211212", "12311215", "32311213", "52311211", "21411214", "41411212", "14211124", "34211122", "23311123", "43311121", "12411124", "32411122", "21511123", "41511121", "15111214", "24211213", "13311214", "33311212", "22411213", "42411211", "11511214", "31511212", "15211123", "24311122", "13411123", "33411121", "22511122", "11611123", "31611121", "16111213", "25211212", "14311213", "34311211", "23411212", "12511213", "32511211", "21611212", "21121126", "41121124", "61121122", "31112125", "51112123", "31121215", "51121213", "21112216", "41112214", "61112212", "22121125", "42121123", "11221126", "31221124", "51221122", "12112126", "32112124", "52112122", "12121216", "32121214", "52121212", "21221215", "41221213", "61221211", "22112215", "42112213", "11212216", "31212214", "51212212", "23121124", "43121122", "12221125", "32221123", "52221121", "21321124", "41321122", "13112125", "33112123", "13121215", "33121213", "11312125", "22221214", "42221212", "11321215", "31321213", "51321211", "23112214", "43112212", "12212215", "32212213", "52212211", "21312214", "41312212", "24121123", "13221124", "33221122", "22321123", "42321121", "11421124", "31421122", "14112124", "34112122", "14121214", "34121212", "12312124", "23221213", "43221211", "12321214", "32321212", "21421213", "41421211", "24112213", "13212214", "33212212", "22312213", "42312211", "11412214", "31412212", "25121122", "14221123", "34221121", "23321122", "12421123", "32421121", "21521122", "15112123", "15121213", "13312123", "24221212", "13321213", "33321211", "11512123", "22421212", "11521213", "31521211", "25112212", "14212213", "34212211", "23312212", "12412213", "32412211", "21512212", "15221122", "24321121", "13421122", "22521121", "16112122", "16121212", "14312122", "25221211", "14321212", "12512122", "23421211", "12521212", "15212212", "24312211", "13412212", "22512211", "11612212", "21131125", "41131123", "61131121", "11122126", "31122124", "51122122", "11131216", "31131214", "51131212", "21113125", "41113123", "61113121", "21122215", "41122213", "61122211", "11113216", "31113214", "51113212", "22131124", "42131122", "11231125", "31231123", "51231121", "12122125", "32122123", "52122121", "12131215", "32131213", "52131211", "21231214", "41231212", "22113124", "42113122", "11213125", "22122214", "42122212", "11222215", "31222213", "51222211", "12113215", "32113213", "52113211", "21213214", "41213212", "23131123", "43131121", "12231124", "32231122", "21331123", "41331121", "13122124", "33122122", "13131214", "33131212", "11322124", "22231213", "42231211", "11331214", "31331212", "23113123", "43113121", "12213124", "23122213", "43122211", "12222214", "32222212", "21322213", "41322211", "13113214", "33113212", "22213213", "42213211", "11313214", "31313212", "24131122", "13231123", "33231121", "22331122", "11431123", "31431121", "14122123", "34122121", "14131213", "34131211", "12322123", "23231212", "12331213", "32331211", "21431212", "24113122", "13213123", "24122212", "13222213", "33222211", "11413123", "22322212", "11422213", "31422211", "14113213", "34113211", "23213212", "12313213", "32313211", "21413212", "25131121", "14231122", "23331121", "12431122", "15122122", "15131212", "13322122", "24231211", "13331212", "11522122", "22431211", "25113121", "14213122", "25122211", "14222212", "12413122", "23322211", "12422212", "21522211", "15113212", "24213211", "13313212", "22413211", "11513212", "15231121", "13431121", "16122121", "16131211", "14322121", "14331211", "12522121", "15213121", "15222211", "13413121", "13422211", "11613121", "16113211", "14313211", "12513211", "21141124", "41141122", "11132125", "31132123", "51132121", "11141215", "31141213", "51141211", "21123124", "41123122", "21132214", "41132212", "11114125", "31114123", "51114121", "11123215", "31123213", "51123211", "21114214", "41114212", "22141123", "42141121", "11241124", "31241122", "12132124", "32132122", "12141214", "32141212", "21241213", "41241211", "22123123", "42123121", "11223124", "22132213", "42132211", "11232214", "31232212", "12114124", "32114122", "12123214", "32123212", "21223213", "41223211", "22114213", "42114211", "11214214", "31214212", "23141122", "12241123", "32241121", "21341122", "13132123", "33132121", "13141213", "33141211", "11332123", "22241212", "11341213", "31341211", "23123122", "12223123", "23132212", "12232213", "32232211", "21332212", "13114123", "33114121", "13123213", "33123211", "11314123", "22223212", "11323213", "31323211", "23114212", "12214213", "32214211", "21314212", "24141121", "13241122", "22341121", "14132122", "14141212", "12332122", "23241211", "12341212", "24123121", "13223122", "24132211", "13232212", "11423122", "22332211", "11432212", "14114122", "14123212", "12314122", "23223211", "12323212", "21423211", "24114211", "13214212", "22314211", "11414212", "14241121", "15132121", "15141211", "13332121", "13341211", "14223121", "14232211", "12423121", "12432211", "15114121", "15123211", "13314121", "13323211", "11514121", "11523211", "14214211", "12414211", "21151123", "41151121", "11142124", "31142122", "11151214", "31151212", "21133123", "41133121", "21142213", "41142211", "11124124", "31124122", "11133214", "31133212", "21115123", "41115121", "21124213", "41124211", "11115214", "31115212", "22151122", "11251123", "31251121", "12142123", "32142121", "12151213", "32151211", "21251212", "22133122", "11233123", "22142212", "11242213", "31242211", "12124123", "32124121", "12133213", "32133211", "21233212", "22115122", "11215123", "22124212", "11224213", "31224211", "12115213", "32115211", "21215212", "23151121", "12251122", "13142122", "13151212", "11342122", "22251211", "23133121", "12233122", "23142211", "12242212", "21342211", "13124122", "13133212", "11324122", "22233211", "11333212", "23115121", "12215122", "23124211", "12224212", "21324211", "13115212", "22215211", "11315212", "13251121", "14142121", "14151211", "12342121", "13233121", "13242211", "11433121", "14124121", "14133211", "12324121", "12333211", "13215121", "13224211", "11415121", "11424211", "14115211", "12315211", "21161122", "11152123", "31152121", "11161213", "31161211", "21143122", "21152212", "11134123", "31134121", "11143213", "31143211", "21125122", "21134212", "11116123", "31116121", "11125213", "31125211", "22161121", "12152122", "12161212", "22143121", "11243122", "22152211", "11252212", "12134122", "12143212", "21243211", "22125121", "11225122", "22134211", "11234212", "12116122", "12125212", "21225211", "13152121", "13161211", "12243121", "12252211", "13134121", "13143211", "11334121", "11343211", "12225121", "12234211", "13116121", "13125211", "11316121", "11325211", "21111226", "41111224", "61111222", "31111315", "51111313", "21211135", "41211133", "61211131", "22111225", "42111223", "11211226", "31211224", "51211222", "12111316", "32111314", "52111312", "21211315", "41211313", "61211311", "22211134", "42211132", "11311135", "31311133", "51311131", "23111224", "43111222", "12211225", "32211223", "52211221", "21311224", "41311222", "13111315", "33111313", "22211314", "42211312", "11311315", "31311313", "51311311", "23211133", "43211131", "12311134", "32311132", "21411133", "41411131", "24111223", "13211224", "33211222", "22311223", "42311221", "11411224", "31411222", "14111314", "34111312", "23211313", "43211311", "12311314", "32311312", "21411313", "41411311", "24211132", "13311133", "33311131", "22411132", "11511133", "31511131", "25111222", "14211223", "34211221", "23311222", "12411223", "32411221", "21511222", "15111313", "24211312", "13311313", "33311311", "22411312", "11511313", "31511311", "25211131", "14311132", "23411131", "12511132", "21611131", "15211222", "24311221", "13411222", "22511221", "11611222", "16111312", "25211311", "14311312", "23411311", "12511312", "21611311", "31121134", "51121132", "21112135", "41112133", "61112131", "21121225", "41121223", "61121221", "11112226", "31112224", "51112222", "11121316", "31121314", "51121312", "21112315", "41112313", "61112311", "12121135", "32121133", "52121131", "21221134", "41221132", "22112134", "42112132", "11212135", "22121224", "42121222", "11221225", "31221223", "51221221", "12112225", "32112223", "52112221", "12121315", "32121313", "52121311", "21221314", "41221312", "22112314", "42112312", "11212315", "31212313", "51212311", "13121134", "33121132", "22221133", "42221131", "11321134", "31321132", "23112133", "43112131", "12212134", "23121223", "43121221", "12221224", "32221222", "21321223", "41321221", "13112224", "33112222", "13121314", "33121312", "11312224", "22221313", "42221311", "11321314", "31321312", "23112313", "43112311", "12212314", "32212312", "21312313", "41312311", "14121133", "34121131", "23221132", "12321133", "32321131", "21421132", "24112132", "13212133", "24121222", "13221223", "33221221", "11412133", "22321222", "11421223", "31421221", "14112223", "34112221", "14121313", "34121311", "12312223", "23221312", "12321313", "32321311", "21421312", "24112312", "13212313", "33212311", "22312312", "11412313", "31412311", "15121132", "24221131", "13321132", "22421131"]), $a(["22121116", "42121114", "31221115", "51221113", "32112115", "52112113", "21212116", "41212114", "61212112", "23121115", "43121113", "12221116", "32221114", "52221112", "21321115", "41321113", "61321111", "13112116", "33112114", "22212115", "42212113", "11312116", "31312114", "51312112", "24121114", "13221115", "33221113", "22321114", "42321112", "11421115", "31421113", "51421111", "14112115", "34112113", "23212114", "43212112", "12312115", "32312113", "52312111", "21412114", "41412112", "25121113", "14221114", "34221112", "23321113", "43321111", "12421114", "32421112", "21521113", "41521111", "15112114", "24212113", "13312114", "33312112", "22412113", "42412111", "11512114", "31512112", "15221113", "24321112", "13421113", "33421111", "22521112", "16112113", "25212112", "14312113", "34312111", "23412112", "12512113", "32512111", "21612112", "21131116", "41131114", "61131112", "31122115", "51122113", "21113116", "41113114", "61113112", "22131115", "42131113", "11231116", "31231114", "51231112", "12122116", "32122114", "52122112", "21222115", "41222113", "61222111", "22113115", "42113113", "11213116", "31213114", "51213112", "23131114", "43131112", "12231115", "32231113", "52231111", "21331114", "41331112", "13122115", "33122113", "22222114", "42222112", "11322115", "31322113", "51322111", "23113114", "43113112", "12213115", "32213113", "52213111", "21313114", "41313112", "24131113", "13231114", "33231112", "22331113", "42331111", "11431114", "31431112", "14122114", "34122112", "23222113", "43222111", "12322114", "32322112", "21422113", "41422111", "24113113", "13213114", "33213112", "22313113", "42313111", "11413114", "31413112", "25131112", "14231113", "34231111", "23331112", "12431113", "32431111", "15122113", "24222112", "13322113", "33322111", "22422112", "11522113", "31522111", "25113112", "14213113", "34213111", "23313112", "12413113", "32413111", "21513112", "15231112", "24331111", "13431112", "16122112", "25222111", "14322112", "23422111", "12522112", "15213112", "24313111", "13413112", "22513111", "11613112", "21141115", "41141113", "61141111", "11132116", "31132114", "51132112", "21123115", "41123113", "61123111", "11114116", "31114114", "51114112", "22141114", "42141112", "11241115", "31241113", "51241111", "12132115", "32132113", "52132111", "21232114", "41232112", "22123114", "42123112", "11223115", "31223113", "51223111", "12114115", "32114113", "52114111", "21214114", "41214112", "23141113", "43141111", "12241114", "32241112", "21341113", "41341111", "13132114", "33132112", "22232113", "42232111", "11332114", "31332112", "23123113", "43123111", "12223114", "32223112", "21323113", "41323111", "13114114", "33114112", "22214113", "42214111", "11314114", "31314112", "24141112", "13241113", "33241111", "22341112", "14132113", "34132111", "23232112", "12332113", "32332111", "21432112", "24123112", "13223113", "33223111", "22323112", "11423113", "31423111", "14114113", "34114111", "23214112", "12314113", "32314111", "21414112", "25141111", "14241112", "23341111", "15132112", "24232111", "13332112", "22432111", "25123111", "14223112", "23323111", "12423112", "21523111", "15114112", "24214111", "13314112", "22414111", "11514112", "15241111", "16132111", "14332111", "15223111", "13423111", "16114111", "14314111", "12514111", "21151114", "41151112", "11142115", "31142113", "51142111", "21133114", "41133112", "11124115", "31124113", "51124111", "21115114", "41115112", "22151113", "42151111", "11251114", "31251112", "12142114", "32142112", "21242113", "41242111", "22133113", "42133111", "11233114", "31233112", "12124114", "32124112", "21224113", "41224111", "22115113", "42115111", "11215114", "31215112", "23151112", "12251113", "32251111", "13142113", "33142111", "22242112", "11342113", "31342111", "23133112", "12233113", "32233111", "21333112", "13124113", "33124111", "22224112", "11324113", "31324111", "23115112", "12215113", "32215111", "21315112", "24151111", "13251112", "14142112", "23242111", "12342112", "24133111", "13233112", "22333111", "11433112", "14124112", "23224111", "12324112", "21424111", "24115111", "13215112", "22315111", "11415112", "14251111", "15142111", "13342111", "14233111", "12433111", "15124111", "13324111", "11524111", "14215111", "12415111", "21161113", "41161111", "11152114", "31152112", "21143113", "41143111", "11134114", "31134112", "21125113", "41125111", "11116114", "31116112", "22161112", "12152113", "32152111", "21252112", "22143112", "11243113", "31243111", "12134113", "32134111", "21234112", "22125112", "11225113", "31225111", "12116113", "32116111", "21216112", "23161111", "13152112", "22252111", "23143111", "12243112", "21343111", "13134112", "22234111", "11334112", "23125111", "12225112", "21325111", "13116112", "22216111", "11316112", "14152111", "13243111", "14134111", "12334111", "13225111", "11425111", "14116111", "12316111", "41111215", "61111213", "21211126", "41211124", "61211122", "22111216", "42111214", "31211215", "51211213", "22211125", "42211123", "11311126", "31311124", "51311122", "23111215", "43111213", "12211216", "32211214", "52211212", "21311215", "41311213", "61311211", "23211124", "43211122", "12311125", "32311123", "52311121", "21411124", "41411122", "24111214", "13211215", "33211213", "22311214", "42311212", "11411215", "31411213", "51411211", "24211123", "13311124", "33311122", "22411123", "42411121", "11511124", "31511122", "25111213", "14211214", "34211212", "23311213", "43311211", "12411214", "32411212", "21511213", "41511211", "25211122", "14311123", "34311121", "23411122", "12511123", "32511121", "21611122", "15211213", "24311212", "13411213", "33411211", "22511212", "11611213", "31611211", "31121125", "51121123", "21112126", "41112124", "61112122", "21121216", "41121214", "61121212", "31112215", "51112213", "12121126", "32121124", "52121122", "21221125", "41221123", "61221121", "22112125", "42112123", "11212126", "22121215", "42121213", "11221216", "31221214", "51221212", "12112216", "32112214", "52112212", "21212215", "41212213", "61212211", "13121125", "33121123", "22221124", "42221122", "11321125", "31321123", "51321121", "23112124", "43112122", "12212125", "23121214", "43121212", "12221215", "32221213", "52221211", "21321214", "41321212", "13112215", "33112213", "22212214", "42212212", "11312215", "31312213", "51312211", "14121124", "34121122", "23221123", "43221121", "12321124", "32321122", "21421123", "41421121", "24112123", "13212124", "24121213", "13221214", "33221212", "11412124", "22321213", "42321211", "11421214", "31421212", "14112214", "34112212", "23212213", "43212211", "12312214", "32312212", "21412213", "41412211", "15121123", "24221122", "13321123", "33321121", "22421122", "11521123", "31521121", "25112122", "14212123", "25121212", "14221213", "34221211", "12412123", "23321212", "12421213", "32421211", "21521212", "15112213", "24212212", "13312213", "33312211", "22412212", "11512213", "31512211", "16121122", "25221121", "14321122", "23421121", "12521122", "15212122", "15221212", "13412122", "24321211", "13421212", "11612122", "22521211", "16112212", "25212211", "14312212", "23412211", "12512212", "21612211", "11131126", "31131124", "51131122", "21122125", "41122123", "61122121", "21131215", "41131213", "61131211", "11113126", "31113124", "51113122", "11122216", "31122214", "51122212", "21113215", "41113213", "61113211", "12131125", "32131123", "52131121", "21231124", "41231122", "22122124", "42122122", "11222125", "22131214", "42131212", "11231215", "31231213", "51231211", "12113125", "32113123", "52113121", "12122215", "32122213", "52122211", "21222214", "41222212", "22113214", "42113212", "11213215", "31213213", "51213211", "13131124", "33131122", "22231123", "42231121", "11331124", "31331122", "23122123", "43122121", "12222124", "23131213", "43131211", "12231214", "32231212", "21331213", "41331211", "13113124", "33113122", "13122214", "33122212", "11313124", "22222213", "42222211", "11322214", "31322212", "23113213", "43113211", "12213214", "32213212", "21313213", "41313211", "14131123", "34131121", "23231122", "12331123", "32331121", "21431122", "24122122", "13222123", "24131212", "13231213", "33231211", "11422123", "22331212", "11431213", "31431211", "14113123", "34113121", "14122213", "34122211", "12313123", "23222212", "12322213", "32322211", "21422212", "24113212", "13213213", "33213211", "22313212", "11413213", "31413211", "15131122", "24231121", "13331122", "22431121", "25122121", "14222122", "25131211", "14231212", "12422122", "23331211", "12431212", "15113122", "15122212", "13313122", "24222211", "13322212", "11513122", "22422211", "11522212", "25113211", "14213212", "23313211", "12413212", "21513211", "16131121", "14331121", "15222121", "15231211", "13422121", "13431211", "16113121", "16122211", "14313121", "14322211", "12513121", "12522211", "15213211", "13413211", "11613211", "11141125", "31141123", "51141121", "21132124", "41132122", "21141214", "41141212", "11123125", "31123123", "51123121", "11132215", "31132213", "51132211", "21114124", "41114122", "21123214", "41123212", "11114215", "31114213", "51114211", "12141124", "32141122", "21241123", "41241121", "22132123", "42132121", "11232124", "22141213", "42141211", "11241214", "31241212", "12123124", "32123122", "12132214", "32132212", "21232213", "41232211", "22114123", "42114121", "11214124", "22123213", "42123211", "11223214", "31223212", "12114214", "32114212", "21214213", "41214211", "13141123", "33141121", "22241122", "11341123", "31341121", "23132122", "12232123", "23141212", "12241213", "32241211", "21341212", "13123123", "33123121", "13132213", "33132211", "11323123", "22232212", "11332213", "31332211", "23114122", "12214123", "23123212", "12223213", "32223211", "21323212", "13114213", "33114211", "22214212", "11314213", "31314211", "14141122", "23241121", "12341122", "24132121", "13232122", "24141211", "13241212", "11432122", "22341211", "14123122", "14132212", "12323122", "23232211", "12332212", "21432211", "24114121", "13214122", "24123211", "13223212", "11414122", "22323211", "11423212", "14114212", "23214211", "12314212", "21414211", "15141121", "13341121", "14232121", "14241211", "12432121", "15123121", "15132211", "13323121", "13332211", "11523121", "14214121", "14223211", "12414121", "12423211", "15114211", "13314211", "11514211", "11151124", "31151122", "21142123", "41142121", "21151213", "41151211", "11133124", "31133122", "11142214", "31142212", "21124123", "41124121", "21133213", "41133211", "11115124", "31115122", "11124214", "31124212", "21115213", "41115211", "12151123", "32151121", "21251122", "22142122", "11242123", "22151212", "11251213", "31251211", "12133123", "32133121", "12142213", "32142211", "21242212", "22124122", "11224123", "22133212", "11233213", "31233211", "12115123", "32115121", "12124213", "32124211", "21224212", "22115212", "11215213", "31215211", "13151122", "22251121", "23142121", "12242122", "23151211", "12251212", "13133122", "13142212", "11333122", "22242211", "11342212", "23124121", "12224122", "23133211", "12233212", "21333211", "13115122", "13124212", "11315122", "22224211", "11324212", "23115211", "12215212", "21315211", "14151121", "13242121", "13251211", "14133121", "14142211", "12333121", "12342211", "13224121", "13233211", "11424121", "11433211", "14115121", "14124211", "12315121", "12324211", "13215211", "11415211", "11161123", "31161121", "21152122", "21161212", "11143123", "31143121", "11152213", "31152211", "21134122", "21143212", "11125123", "31125121", "11134213", "31134211", "21116122", "21125212", "12161122", "22152121", "11252122", "22161211", "12143122", "12152212", "21252211", "22134121", "11234122", "22143211", "11243212", "12125122", "12134212", "21234211", "22116121", "11216122", "22125211", "11225212", "13161121", "12252121", "13143121", "13152211", "11343121", "12234121", "12243211", "13125121", "13134211", "11325121", "11334211", "12216121", "12225211", "31111225", "51111223", "21111316", "41111314", "61111312", "31211134", "51211132", "12111226", "32111224", "52111222", "21211225", "41211223", "61211221", "22111315", "42111313", "11211316", "31211314", "51211312", "12211135", "32211133", "52211131", "21311134", "41311132", "13111225", "33111223", "22211224", "42211222", "11311225", "31311223", "51311221", "23111314", "43111312", "12211315", "32211313", "52211311", "21311314", "41311312", "13211134", "33211132", "22311133", "42311131", "11411134", "31411132", "14111224", "34111222", "23211223", "43211221", "12311224", "32311222", "21411223", "41411221", "24111313", "13211314", "33211312", "22311313", "42311311", "11411314", "31411312", "14211133", "34211131", "23311132", "12411133", "32411131", "21511132", "15111223", "24211222", "13311223", "33311221", "22411222", "11511223", "31511221", "25111312", "14211313", "34211311", "23311312", "12411313", "32411311", "21511312", "15211132", "24311131", "13411132", "22511131", "11611132", "16111222", "25211221", "14311222", "23411221", "12511222", "21611221", "15211312", "24311311", "13411312", "22511311", "11611312", "21121135", "41121133", "61121131", "11112136", "31112134", "51112132", "11121226", "31121224", "51121222", "21112225", "41112223", "61112221", "21121315", "41121313", "61121311", "11112316", "31112314", "51112312", "22121134", "42121132", "11221135", "31221133", "51221131", "12112135", "32112133", "52112131", "12121225", "32121223", "52121221", "21221224", "41221222", "22112224", "42112222", "11212225", "22121314", "42121312", "11221315", "31221313", "51221311", "12112315", "32112313", "52112311", "21212314", "41212312", "23121133", "43121131", "12221134", "32221132", "21321133", "41321131", "13112134", "33112132", "13121224", "33121222", "11312134", "22221223", "42221221", "11321224", "31321222", "23112223", "43112221", "12212224", "23121313", "43121311", "12221314", "32221312", "21321313", "41321311", "13112314", "33112312", "22212313", "42212311", "11312314", "31312312", "24121132", "13221133", "33221131", "22321132", "11421133", "31421131", "14112133", "34112131", "14121223", "34121221", "12312133", "23221222", "12321223", "32321221", "21421222", "24112222", "13212223", "24121312", "13221313", "33221311", "11412223", "22321312", "11421313", "31421311", "14112313", "34112311", "23212312", "12312313", "32312311", "21412312", "25121131", "14221132", "23321131", "12421132", "21521131", "15112132", "15121222", "13312132", "24221221", "13321222", "11512132", "22421221", "11521222", "25112221", "14212222", "25121311", "14221312", "12412222", "23321311", "12421312", "21521311", "15112312", "24212311", "13312312", "22412311", "11512312", "15221131", "13421131", "16112131", "16121221", "14312131", "14321221", "12512131", "12521221", "15212221", "15221311", "13412221", "13421311", "11612221", "16112311", "14312311", "12512311", "21131134", "41131132", "11122135", "31122133", "51122131", "11131225", "31131223", "51131221", "21113134", "41113132", "21122224", "41122222", "21131314", "41131312", "11113225", "31113223", "51113221", "11122315", "31122313", "51122311", "21113314", "41113312", "22131133", "42131131", "11231134", "31231132", "12122134", "32122132", "12131224", "32131222", "21231223", "41231221", "22113133", "42113131", "11213134", "22122223", "42122221", "11222224", "22131313", "42131311", "11231314", "31231312", "12113224", "32113222", "12122314", "32122312", "21222313", "41222311", "22113313", "42113311", "11213314", "31213312", "23131132", "12231133", "32231131", "21331132", "13122133", "33122131", "13131223", "33131221", "11322133", "22231222", "11331223", "31331221", "23113132", "12213133", "23122222", "12222223", "23131312", "12231313", "32231311", "21331312", "13113223", "33113221", "13122313", "33122311", "11313223", "22222312", "11322313", "31322311", "23113312", "12213313", "32213311", "21313312", "24131131", "13231132", "22331131", "11431132", "14122132", "14131222", "12322132", "23231221", "12331222", "21431221", "24113131", "13213132", "24122221", "13222222", "24131311", "11413132", "13231312", "11422222", "22331311", "11431312", "14113222", "14122312", "12313222", "23222311", "12322312", "21422311", "24113311", "13213312", "22313311", "11413312", "14231131", "12431131", "15122131", "15131221", "13322131", "13331221", "11522131", "14213131", "14222221", "12413131", "14231311", "12422221", "12431311", "15113221", "15122311", "13313221", "13322311", "11513221", "11522311", "14213311", "12413311", "21141133", "41141131", "11132134", "31132132", "11141224", "31141222", "21123133", "41123131", "21132223", "41132221", "21141313", "41141311", "11114134", "31114132", "11123224", "31123222", "11132314", "31132312", "21114223", "41114221", "21123313", "41123311", "11114314", "31114312", "22141132", "11241133", "31241131", "12132133", "32132131", "12141223", "32141221", "21241222", "22123132", "11223133", "22132222", "11232223", "22141312", "11241313", "31241311", "12114133", "32114131", "12123223", "32123221", "12132313", "32132311", "21232312", "22114222", "11214223", "22123312", "11223313", "31223311", "12114313", "32114311", "21214312", "23141131", "12241132", "21341131", "13132132", "13141222", "11332132", "22241221", "11341222", "23123131", "12223132", "23132221", "12232222", "23141311", "12241312", "21341311", "13114132", "13123222", "11314132", "13132312", "11323222", "22232311", "11332312", "23114221", "12214222", "23123311", "12223312", "21323311", "13114312", "22214311", "11314312", "13241131", "14132131", "14141221", "12332131", "12341221", "13223131", "13232221", "11423131", "13241311", "11432221", "14114131", "14123221", "12314131", "14132311", "12323221", "12332311", "13214221", "13223311", "11414221", "11423311", "14114311", "12314311", "21151132", "11142133", "31142131", "11151223", "31151221", "21133132", "21142222", "21151312", "11124133", "31124131", "11133223", "31133221", "11142313", "31142311", "21115132", "21124222", "21133312", "11115223", "31115221", "11124313", "31124311", "22151131", "11251132", "12142132", "12151222", "21251221", "22133131", "11233132", "22142221", "11242222", "22151311", "11251312", "12124132", "12133222", "12142312", "21242311", "22115131", "11215132", "22124221", "11224222", "22133311", "11233312", "12115222", "12124312", "21224311", "12251131", "13142131", "13151221", "11342131", "12233131", "12242221", "12251311", "13124131", "13133221", "11324131", "13142311", "11333221", "11342311", "12215131", "12224221", "12233311", "13115221", "13124311", "11315221", "11324311", "21161131", "11152132", "11161222", "21143131", "21152221", "21161311", "11134132", "11143222", "11152312", "21125131", "21134221", "21143311", "11116132", "11125222", "11134312", "12152131", "12161221", "11243131", "11252221", "12134131", "12143221", "12152311", "11225131", "11234221", "11243311", "12116131", "12125221", "12134311", "21111235", "41111233", "61111231", "11111326", "31111324", "51111322", "21111415", "41111413", "61111411", "21211144", "41211142", "22111234", "42111232", "11211235", "31211233", "51211231", "12111325", "32111323", "52111321", "21211324", "41211322", "22111414", "42111412", "11211415", "31211413", "51211411", "22211143", "42211141", "11311144", "31311142", "23111233", "43111231", "12211234", "32211232", "21311233", "41311231", "13111324", "33111322", "22211323", "42211321", "11311324", "31311322", "23111413", "43111411", "12211414", "32211412", "21311413", "41311411", "23211142", "12311143", "32311141", "21411142", "24111232", "13211233", "33211231", "22311232", "11411233", "31411231", "14111323", "34111321", "23211322", "12311323", "32311321", "21411322", "24111412", "13211413", "33211411", "22311412", "11411413", "31411411", "24211141", "13311142", "22411141", "11511142", "25111231", "14211232", "23311231", "12411232", "21511231", "15111322", "24211321", "13311322", "22411321", "11511322", "25111411", "14211412", "23311411", "12411412", "21511411", "14311141", "12511141", "15211231", "13411231", "11611231", "16111321", "14311321", "12511321", "15211411", "13411411", "11611411", "31121143", "51121141", "21112144", "41112142", "21121234", "41121232", "11112235", "31112233", "51112231", "11121325", "31121323", "51121321", "21112324", "41112322", "21121414", "41121412", "11112415", "31112413", "51112411", "12121144", "32121142", "21221143", "41221141", "22112143", "42112141", "11212144", "22121233", "42121231", "11221234", "31221232", "12112234", "32112232", "12121324", "32121322", "21221323", "41221321", "22112323", "42112321", "11212324", "22121413", "42121411", "11221414", "31221412", "12112414", "32112412", "21212413", "41212411", "13121143", "33121141", "22221142", "11321143", "31321141", "23112142", "12212143", "23121232", "12221233", "32221231", "21321232", "13112233", "33112231", "13121323", "33121321", "11312233", "22221322", "11321323", "31321321", "23112322", "12212323", "23121412", "12221413", "32221411", "21321412", "13112413", "33112411", "22212412", "11312413", "31312411", "14121142", "23221141", "12321142", "21421141", "24112141", "13212142", "24121231", "13221232", "11412142", "22321231", "11421232", "14112232", "14121322", "12312232", "23221321", "12321322", "21421321", "24112321", "13212322", "24121411", "13221412", "11412322", "22321411", "11421412", "14112412", "23212411", "12312412", "21412411", "15121141", "13321141", "11521141", "14212141", "14221231", "12412141", "12421231", "15112231", "15121321", "13312231", "13321321", "11512231", "11521321", "14212321", "14221411", "12412321", "12421411", "15112411", "13312411", "11512411", "11131144", "31131142", "21122143", "41122141", "21131233", "41131231", "11113144", "31113142", "11122234", "31122232", "11131324", "31131322", "21113233", "41113231", "21122323", "41122321", "21131413", "41131411", "11113324", "31113322", "11122414", "31122412", "21113413", "41113411", "12131143", "32131141", "21231142", "22122142", "11222143", "22131232", "11231233", "31231231", "12113143", "32113141", "12122233", "32122231", "12131323", "32131321", "21231322", "22113232", "11213233", "22122322", "11222323", "22131412", "11231413", "31231411", "12113323", "32113321", "12122413", "32122411", "21222412", "22113412", "11213413", "31213411", "13131142", "22231141", "11331142", "23122141", "12222142", "23131231", "12231232", "21331231", "13113142", "13122232", "11313142", "13131322", "11322232", "22231321", "11331322", "23113231", "12213232", "23122321", "12222322", "23131411", "12231412", "21331411", "13113322", "13122412", "11313322", "22222411", "11322412", "23113411", "12213412", "21313411", "14131141", "12331141", "13222141", "13231231", "11422141", "11431231", "14113141", "14122231", "12313141", "14131321", "12322231", "12331321", "13213231", "13222321", "11413231", "13231411", "11422321", "11431411", "14113321", "14122411", "12313321", "12322411", "13213411", "11413411", "11141143", "31141141", "21132142", "21141232", "11123143", "31123141", "11132233", "31132231", "11141323", "31141321", "21114142", "21123232", "21132322", "21141412", "11114233", "31114231", "11123323", "31123321", "11132413", "31132411", "21114322", "21123412", "12141142", "21241141", "22132141", "11232142", "22141231", "11241232", "12123142", "12132232", "12141322", "21241321", "22114141", "11214142", "22123231", "11223232", "22132321", "11232322", "22141411", "11241412", "12114232", "12123322", "12132412", "21232411", "22114321", "11214322", "22123411", "11223412", "13141141", "11341141", "12232141", "12241231", "13123141", "13132231", "11323141", "13141321", "11332231", "11341321", "12214141", "12223231", "12232321", "12241411", "13114231", "13123321", "11314231", "13132411", "11323321", "11332411", "12214321", "12223411", "11151142", "21142141", "21151231", "11133142", "11142232", "11151322", "21124141", "21133231", "21142321", "21151411", "11115142", "11124232", "11133322", "11142412", "21115231", "21124321", "21133411", "12151141", "11242141", "11251231", "12133141", "12142231", "12151321", "11224141", "11233231", "11242321", "11251411", "12115141", "12124231", "12133321", "12142411", "11215231", "11224321", "11233411", "11161141", "11143141", "11152231", "11161321", "11125141", "11134231", "11143321", "11152411", "11111245", "31111243", "51111241", "21111334", "41111332", "11111425", "31111423", "51111421", "21111514", "41111512", "31211152", "12111244", "32111242", "21211243", "41211241", "22111333", "42111331", "11211334", "31211332", "12111424", "32111422", "21211423", "41211421", "22111513", "42111511", "11211514", "31211512", "12211153", "32211151", "21311152", "13111243", "33111241", "22211242", "11311243", "31311241", "23111332", "12211333", "32211331", "21311332", "13111423", "33111421", "22211422", "11311423", "31311421", "23111512", "12211513", "32211511", "21311512", "13211152", "22311151", "11411152", "14111242", "23211241", "12311242", "21411241", "24111331", "13211332", "22311331", "11411332", "14111422", "23211421", "12311422", "21411421", "24111511", "13211512", "22311511", "11411512", "14211151", "12411151", "15111241", "13311241", "11511241", "14211331", "12411331", "15111421", "13311421", "11511421", "14211511", "12411511", "21121153", "41121151", "11112154", "31112152", "11121244", "31121242", "21112243", "41112241", "21121333", "41121331", "11112334", "31112332", "11121424", "31121422", "21112423", "41112421", "21121513", "41121511", "11112514", "31112512", "22121152", "11221153", "31221151", "12112153", "32112151", "12121243", "32121241", "21221242", "22112242", "11212243", "22121332", "11221333", "31221331", "12112333", "32112331", "12121423", "32121421", "21221422", "22112422", "11212423", "22121512", "11221513", "31221511", "12112513", "32112511", "21212512", "23121151", "12221152", "21321151", "13112152", "13121242", "11312152", "22221241", "11321242", "23112241", "12212242", "23121331", "12221332", "21321331", "13112332", "13121422", "11312332", "22221421", "11321422", "23112421", "12212422", "23121511", "12221512", "21321511", "13112512", "22212511", "11312512", "13221151", "11421151", "14112151", "14121241", "12312151", "12321241", "13212241", "13221331", "11412241", "11421331", "14112331", "14121421", "12312331", "12321421", "13212421", "13221511", "11412421", "11421511", "14112511", "12312511", "21131152", "11122153", "31122151", "11131243", "31131241", "21113152", "21122242", "21131332", "11113243", "31113241", "11122333", "31122331", "11131423", "31131421", "21113332", "21122422", "21131512", "11113423", "31113421", "11122513", "31122511", "22131151", "11231152", "12122152", "12131242", "21231241", "22113151", "11213152", "22122241", "11222242", "22131331", "11231332", "12113242", "12122332", "12131422", "21231421", "22113331", "11213332", "22122421", "11222422", "22131511", "11231512", "12113422", "12122512", "21222511", "12231151", "13122151", "13131241", "11322151", "11331241", "12213151", "12222241", "12231331", "13113241", "13122331", "11313241", "13131421", "11322331", "11331421", "12213331", "12222421", "12231511", "13113421", "13122511", "11313421", "11322511", "21141151", "11132152", "11141242", "21123151", "21132241", "21141331", "11114152", "11123242", "11132332", "11141422", "21114241", "21123331", "21132421", "21141511", "11114332", "11123422", "11132512", "11241151", "12132151", "12141241", "11223151", "11232241", "11241331", "12114151", "12123241", "12132331", "12141421", "11214241", "11223331", "11232421", "11241511", "12114331", "12123421", "12132511", "11142151", "11151241", "11124151", "11133241", "11142331", "11151421", "11115241", "11124331", "11133421", "11142511", "21111253", "41111251", "11111344", "31111342", "21111433", "41111431", "11111524", "31111522", "21111613", "41111611", "21211162", "22111252", "11211253", "31211251", "12111343", "32111341", "21211342", "22111432", "11211433", "31211431", "12111523", "32111521", "21211522", "22111612", "11211613", "31211611", "22211161", "11311162", "23111251", "12211252", "21311251", "13111342", "22211341", "11311342", "23111431", "12211432", "21311431", "13111522", "22211521", "11311522", "23111611", "12211612", "21311611", "12311161", "13211251", "11411251", "14111341", "12311341", "13211431", "11411431", "14111521", "12311521", "13211611", "11411611", "31121161", "21112162", "21121252", "11112253", "31112251", "11121343", "31121341", "21112342", "21121432", "11112433", "31112431", "11121523", "31121521", "21112522", "21121612", "12121162", "21221161", "22112161", "11212162", "22121251", "11221252", "12112252", "12121342", "21221341", "22112341", "11212342", "22121431", "11221432", "12112432", "12121522", "21221521", "22112521", "11212522", "22121611", "11221612", "13121161", "11321161", "12212161", "12221251", "13112251", "13121341", "11312251", "11321341", "12212341", "12221431", "13112431", "13121521", "11312431", "11321521", "12212521", "12221611", "11131162", "21122161", "21131251", "11113162"])]); //#15370
    $1.parity = $a(["1001", "0101", "1100", "0011", "1010", "0110", "1111", "0000"]); //#15374
    $1.rowbits = $a($1.r); //#15378
    for (var _5r = 0, _5q = $f($1.r - 1); _5r <= _5q; _5r += 1) { //#15398
        $1.i = _5r; //#15380
        $k[$j++] = 'p'; //#15381
        if ($1.i != $f($1.r - 1)) { //#15381
            $k[$j++] = $get($1.parity, $1.i); //#15381
        } else { //#15381
            $k[$j++] = "0000"; //#15381
        } //#15381
        var _5x = $k[--$j]; //#15381
        $1[$k[--$j]] = _5x; //#15381
        $1.ccrow = $geti($1.ccs, $1.i * 8, 8); //#15382
        $k[$j++] = Infinity; //#15384
        for (var _62 = 0; _62 <= 7; _62 += 2) { //#15384
            $aload($geti($1.ccrow, _62, 2)); //#15384
            var _65 = $k[--$j]; //#15384
            var _66 = $k[--$j]; //#15384
            $k[$j++] = $f(_65 + (_66 * 49)); //#15384
        } //#15384
        $1.scrow = $a(); //#15384
        $k[$j++] = Infinity; //#15392
        $k[$j++] = 10; //#15391
        $k[$j++] = 1; //#15391
        $k[$j++] = 1; //#15391
        for (var _68 = 0; _68 <= 3; _68 += 1) { //#15391
            $1.j = _68; //#15389
            $forall($get($get($1.patterns, $f($get($1.p, $1.j) - 48)), $get($1.scrow, $1.j)), function() { //#15390
                var _6I = $k[--$j]; //#15390
                $k[$j++] = $f(_6I - 48); //#15390
            }); //#15390
        } //#15390
        $k[$j++] = 4; //#15392
        $k[$j++] = 1; //#15392
        $1.sbs = $a(); //#15392
        $k[$j++] = Infinity; //#15394
        var _6K = $1.sbs; //#15395
        $k[$j++] = 1; //#15395
        for (var _6L = 0, _6M = _6K.length; _6L < _6M; _6L++) { //#15395
            var _6O = $k[--$j]; //#15395
            var _6P = (_6O == 0) ? 1 : 0; //#15395
            $k[$j++] = _6O; //#15395
            for (var _6Q = 0, _6R = $get(_6K, _6L); _6Q < _6R; _6Q++) { //#15395
                $k[$j++] = _6P //#15395
            } //#15395
        } //#15395
        $astore($a($counttomark() - 1)); //#15396
        var _6U = $k[--$j]; //#15396
        var _6V = $k[--$j]; //#15396
        $k[$j++] = _6U; //#15396
        $k[$j++] = _6V; //#15396
        $j--; //#15396
        var _6W = $k[--$j]; //#15396
        var _6X = $k[--$j]; //#15396
        $k[$j++] = _6W; //#15396
        $k[$j++] = _6X; //#15396
        $j--; //#15396
        $put($1.rowbits, $1.i, $k[--$j]); //#15397
    } //#15397
    $k[$j++] = Infinity; //#15409
    for (var _6c = 0, _6d = 81 * $1.sepheight; _6c < _6d; _6c++) { //#15402
        $k[$j++] = 1; //#15402
    } //#15402
    for (var _6g = 0, _6f = $f($1.r - 2); _6g <= _6f; _6g += 1) { //#15407
        $1.i = _6g; //#15404
        for (var _6i = 0, _6j = $1.rowheight; _6i < _6j; _6i++) { //#15405
            $aload($get($1.rowbits, $1.i)); //#15405
        } //#15405
        for (var _6o = 0, _6p = $1.sepheight; _6o < _6p; _6o++) { //#15406
            for (var _6q = 0, _6r = 10; _6q < _6r; _6q++) { //#15406
                $k[$j++] = 0; //#15406
            } //#15406
            for (var _6s = 0, _6t = 70; _6s < _6t; _6s++) { //#15406
                $k[$j++] = 1; //#15406
            } //#15406
            $k[$j++] = 0; //#15406
        } //#15406
    } //#15406
    for (var _6v = 0, _6w = $1.rowheight; _6v < _6w; _6v++) { //#15408
        $aload($get($1.rowbits, $f($1.r - 1))); //#15408
    } //#15408
    for (var _71 = 0, _72 = 81 * $1.sepheight; _71 < _72; _71++) { //#15409
        $k[$j++] = 1; //#15409
    } //#15409
    $1.pixs = $a(); //#15409
    var _78 = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", 81],
        ["pixy", ~~($1.pixs.length / 81)],
        ["height", (~~($1.pixs.length / 81)) / 72],
        ["width", 81 / 72],
        ["opt", $1.options]
    ]); //#15420
    $k[$j++] = _78; //#15423
    if (!$1.dontdraw) { //#15423
        bwipp_renmatrix(); //#15423
    } //#15423
}

function bwipp_flattermarken() {
    var $1 = {}; //#15719
    $1.ctx = null; //#15721
    $1.dontdraw = false; //#15722
    $1.includetext = false; //#15723
    $1.textfont = "OCR-B"; //#15724
    $1.textsize = 10; //#15725
    $1.textyoffset = -8; //#15726
    $1.height = 0.3; //#15727
    $k[$j++] = $1; //#15729
    bwipp_processoptions(); //#15729
    $1.options = $k[--$j]; //#15729
    $1.barcode = $k[--$j]; //#15730
    $forall($1.barcode, function() { //#15739
        var _3 = $k[--$j]; //#15736
        if ((_3 < 48) || (_3 > 57)) { //#15738
            $k[$j++] = 'bwipp.flattermarkenBadCharacter'; //#15737
            $k[$j++] = "Flattermarken must contain only digits"; //#15737
            bwipp_raiseerror(); //#15737
        } //#15737
    }); //#15737
    $1.encs = $a(["0018", "0117", "0216", "0315", "0414", "0513", "0612", "0711", "0810", "0900"]); //#15746
    $1.barchars = "1234567890"; //#15749
    $1.barlen = $1.barcode.length; //#15752
    $1.sbs = $s($1.barlen * 4); //#15754
    $1.txt = $a($1.barlen); //#15755
    for (var _C = 0, _B = $1.barlen - 1; _C <= _B; _C += 1) { //#15767
        $1.i = _C; //#15758
        $search($1.barchars, $geti($1.barcode, $1.i, 1)); //#15760
        $j--; //#15761
        $1.indx = $k[--$j].length; //#15762
        $j -= 2; //#15763
        $1.enc = $get($1.encs, $1.indx); //#15764
        $puti($1.sbs, $1.i * 4, $1.enc); //#15765
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), $1.i * 9, $1.textyoffset, $1.textfont, $1.textsize])); //#15766
    } //#15766
    $k[$j++] = Infinity; //#15776
    $k[$j++] = Infinity; //#15772
    var _Y = $1.sbs; //#15772
    for (var _Z = 0, _a = _Y.length; _Z < _a; _Z++) { //#15772
        $k[$j++] = $get(_Y, _Z) - 48; //#15772
    } //#15772
    var _c = $a(); //#15772
    $k[$j++] = Infinity; //#15773
    for (var _e = 0, _f = ~~(($1.sbs.length + 1) / 2); _e < _f; _e++) { //#15773
        $k[$j++] = $1.height; //#15773
    } //#15773
    var _h = $a(); //#15773
    $k[$j++] = Infinity; //#15774
    for (var _j = 0, _k = ~~(($1.sbs.length + 1) / 2); _j < _k; _j++) { //#15774
        $k[$j++] = 0; //#15774
    } //#15774
    var _l = $a(); //#15774
    $k[$j++] = 'ren'; //#15776
    $k[$j++] = bwipp_renlinear; //#15776
    $k[$j++] = 'sbs'; //#15776
    $k[$j++] = _c; //#15776
    $k[$j++] = 'bhs'; //#15776
    $k[$j++] = _h; //#15776
    $k[$j++] = 'bbs'; //#15776
    $k[$j++] = _l; //#15776
    $k[$j++] = 'txt'; //#15776
    $k[$j++] = $1.txt; //#15776
    $k[$j++] = 'opt'; //#15776
    $k[$j++] = $1.options; //#15776
    var _o = $d(); //#15776
    $k[$j++] = _o; //#15779
    if (!$1.dontdraw) { //#15779
        bwipp_renlinear(); //#15779
    } //#15779
}

function bwipp_raw() {
    var $1 = {}; //#15811
    $1.ctx = null; //#15813
    $1.dontdraw = false; //#15814
    $1.height = 1; //#15815
    $k[$j++] = $1; //#15817
    bwipp_processoptions(); //#15817
    $1.options = $k[--$j]; //#15817
    $1.barcode = $k[--$j]; //#15818
    $forall($1.barcode, function() { //#15825
        var _3 = $k[--$j]; //#15822
        if ((_3 < 49) || (_3 > 57)) { //#15824
            $k[$j++] = 'bwipp.rawBadCharacter'; //#15823
            $k[$j++] = "Raw must contain only digits 1 to 9"; //#15823
            bwipp_raiseerror(); //#15823
        } //#15823
    }); //#15823
    $k[$j++] = Infinity; //#15833
    $k[$j++] = Infinity; //#15830
    $forall($1.barcode, function() { //#15830
        var _5 = $k[--$j]; //#15830
        $k[$j++] = $f(_5 - 48); //#15830
    }); //#15830
    var _6 = $a(); //#15830
    $k[$j++] = Infinity; //#15831
    for (var _8 = 0, _9 = ~~(($1.barcode.length + 1) / 2); _8 < _9; _8++) { //#15831
        $k[$j++] = $1.height; //#15831
    } //#15831
    var _B = $a(); //#15831
    $k[$j++] = Infinity; //#15832
    for (var _D = 0, _E = ~~(($1.barcode.length + 1) / 2); _D < _E; _D++) { //#15832
        $k[$j++] = 0; //#15832
    } //#15832
    var _F = $a(); //#15832
    $k[$j++] = 'ren'; //#15833
    $k[$j++] = bwipp_renlinear; //#15833
    $k[$j++] = 'sbs'; //#15833
    $k[$j++] = _6; //#15833
    $k[$j++] = 'bhs'; //#15833
    $k[$j++] = _B; //#15833
    $k[$j++] = 'bbs'; //#15833
    $k[$j++] = _F; //#15833
    $k[$j++] = 'opt'; //#15833
    $k[$j++] = $1.options; //#15833
    var _H = $d(); //#15833
    $k[$j++] = _H; //#15836
    if (!$1.dontdraw) { //#15836
        bwipp_renlinear(); //#15836
    } //#15836
}

function bwipp_daft() {
    var $1 = {}; //#15866
    $1.ctx = null; //#15868
    $1.dontdraw = false; //#15869
    $1.height = 0.175; //#15870
    $k[$j++] = $1; //#15872
    bwipp_processoptions(); //#15872
    $1.options = $k[--$j]; //#15872
    $1.barcode = $k[--$j]; //#15873
    $forall($1.barcode, function() { //#15879
        var _3 = $k[--$j]; //#15876
        if ((_3 != 68) && ((_3 != 65) && ((_3 != 70) && (_3 != 84)))) { //#15878
            $k[$j++] = 'bwipp.daftBadCharacter'; //#15877
            $k[$j++] = "DAFT must contain only characters D, A, F and T"; //#15877
            bwipp_raiseerror(); //#15877
        } //#15877
    }); //#15877
    $1.barlen = $1.barcode.length; //#15881
    $1.bbs = $a($1.barlen); //#15883
    $1.bhs = $a($1.barlen); //#15884
    for (var _B = 0, _A = $1.barlen - 1; _B <= _A; _B += 1) { //#15904
        $1.i = _B; //#15886
        $1.enc = $geti($1.barcode, $1.i, 1); //#15887
        if ($eq($1.enc, "D")) { //#15891
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#15889
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#15890
        } //#15890
        if ($eq($1.enc, "A")) { //#15895
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#15893
            $put($1.bhs, $1.i, (5 * $1.height) / 8); //#15894
        } //#15894
        if ($eq($1.enc, "F")) { //#15899
            $put($1.bbs, $1.i, (0 * $1.height) / 8); //#15897
            $put($1.bhs, $1.i, (8 * $1.height) / 8); //#15898
        } //#15898
        if ($eq($1.enc, "T")) { //#15903
            $put($1.bbs, $1.i, (3 * $1.height) / 8); //#15901
            $put($1.bhs, $1.i, (2 * $1.height) / 8); //#15902
        } //#15902
    } //#15902
    $k[$j++] = Infinity; //#15912
    var _h = $1.bbs; //#15909
    var _i = $1.bhs; //#15910
    $k[$j++] = Infinity; //#15911
    for (var _k = 0, _l = $1.bhs.length - 1; _k < _l; _k++) { //#15911
        $k[$j++] = 1.44; //#15911
        $k[$j++] = 1.872; //#15911
    } //#15911
    $k[$j++] = 1.44; //#15911
    var _m = $a(); //#15911
    $k[$j++] = 'ren'; //#15912
    $k[$j++] = bwipp_renlinear; //#15912
    $k[$j++] = 'bbs'; //#15912
    $k[$j++] = _h; //#15912
    $k[$j++] = 'bhs'; //#15912
    $k[$j++] = _i; //#15912
    $k[$j++] = 'sbs'; //#15912
    $k[$j++] = _m; //#15912
    $k[$j++] = 'opt'; //#15912
    $k[$j++] = $1.options; //#15912
    var _o = $d(); //#15912
    $k[$j++] = _o; //#15915
    if (!$1.dontdraw) { //#15915
        bwipp_renlinear(); //#15915
    } //#15915
}

function bwipp_symbol() {
    var $1 = {}; //#15945
    $1.ctx = null; //#15947
    $1.dontdraw = false; //#15948
    $k[$j++] = $1; //#15950
    bwipp_processoptions(); //#15950
    $1.options = $k[--$j]; //#15950
    $1.barcode = $k[--$j]; //#15951
    var _H = new Map([
        ["fima", function() {
            $1.sbs = $a([2.25, 2.25, 2.25, 11.25, 2.25, 11.25, 2.25, 2.25, 2.25]); //#15955
            $1.bhs = $a([0.625, 0.625, 0.625, 0.625, 0.625]); //#15956
            $1.bbs = $a([0, 0, 0, 0, 0]); //#15957
        }],
        ["fimb", function() {
            $1.sbs = $a([2.25, 6.75, 2.25, 2.25, 2.25, 6.25, 2.25, 2.25, 2.25, 6.75, 2.25]); //#15960
            $1.bhs = $a([0.625, 0.625, 0.625, 0.625, 0.625, 0.625]); //#15961
            $1.bbs = $a([0, 0, 0, 0, 0, 0]); //#15962
        }],
        ["fimc", function() {
            $1.sbs = $a([2.25, 2.25, 2.25, 6.75, 2.25, 6.75, 2.25, 6.75, 2.25, 2.25, 2.25]); //#15965
            $1.bhs = $a([0.625, 0.625, 0.625, 0.625, 0.625, 0.625]); //#15966
            $1.bbs = $a([0, 0, 0, 0, 0, 0]); //#15967
        }],
        ["fimd", function() {
            $1.sbs = $a([2.25, 2.25, 2.25, 2.25, 2.25, 6.75, 2.25, 6.75, 2.25, 2.25, 2.25, 2.25, 2.25]); //#15970
            $1.bhs = $a([0.625, 0.625, 0.625, 0.625, 0.625, 0.625, 0.625]); //#15971
            $1.bbs = $a([0, 0, 0, 0, 0, 0, 0]); //#15972
        }],
        ["fime", function() {
            $1.sbs = $a([2.25, 6.75, 2.25, 15.75, 2.25, 6.75, 2.25]); //#15975
            $1.bhs = $a([0.625, 0.625, 0.625, 0.625, 0.625, 0.625, 0.625]); //#15976
            $1.bbs = $a([0, 0, 0, 0, 0, 0, 0]); //#15977
        }]
    ]); //#15977
    $1.symbols = _H; //#15979
    var _K = $get($1.symbols, $1.barcode) !== undefined; //#15982
    if (!_K) { //#15984
        $k[$j++] = 'bwipp.symbolUnknownSymbol'; //#15983
        $k[$j++] = "Unknown symbol name provided"; //#15983
        bwipp_raiseerror(); //#15983
    } //#15983
    if ($get($1.symbols, $1.barcode)() === true) {
        return true;
    } //#15986
    var _S = new Map([
        ["ren", bwipp_renlinear],
        ["sbs", $1.sbs],
        ["bhs", $1.bhs],
        ["bbs", $1.bbs],
        ["opt", $1.options]
    ]); //#15994
    $k[$j++] = _S; //#15997
    if (!$1.dontdraw) { //#15997
        bwipp_renlinear(); //#15997
    } //#15997
}

function bwipp_pdf417() {
    var $1 = {}; //#16030
    $1.ctx = null; //#16032
    $1.dontdraw = false; //#16033
    $1.compact = false; //#16034
    $1.eclevel = -1; //#16035
    $1.columns = 0; //#16036
    $1.rows = 0; //#16037
    $1.rowmult = 3; //#16038
    $1.encoding = "auto"; //#16039
    $1.ccc = false; //#16040
    $1.raw = false; //#16041
    $1.parse = false; //#16042
    $1.parsefnc = false; //#16043
    $k[$j++] = $1; //#16045
    bwipp_processoptions(); //#16045
    $1.options = $k[--$j]; //#16045
    $1.barcode = $k[--$j]; //#16046
    $1.T = 0; //#16052
    $1.N = 1; //#16052
    $1.B = 2; //#16052
    $1.A = 0; //#16053
    $1.L = 1; //#16053
    $1.M = 2; //#16053
    $1.P = 3; //#16053
    $1.tl = -1; //#16056
    $1.nl = -2; //#16056
    $1.bl = -3; //#16056
    $1.bl6 = -4; //#16056
    $1.bs = -5; //#16056
    $1.al = -6; //#16059
    $1.ll = -7; //#16059
    $1.ml = -8; //#16059
    $1.pl = -9; //#16059
    $1.as = -10; //#16059
    $1.ps = -11; //#16059
    $1.charmaps = $a([$a(["A", "a", "0", ";"]), $a(["B", "b", "1", "<"]), $a(["C", "c", "2", ">"]), $a(["D", "d", "3", "@"]), $a(["E", "e", "4", "["]), $a(["F", "f", "5", 92]), $a(["G", "g", "6", "]"]), $a(["H", "h", "7", "_"]), $a(["I", "i", "8", "`"]), $a(["J", "j", "9", "~"]), $a(["K", "k", "&", "!"]), $a(["L", "l", 13, 13]), $a(["M", "m", 9, 9]), $a(["N", "n", ",", ","]), $a(["O", "o", ":", ":"]), $a(["P", "p", "#", 10]), $a(["Q", "q", "-", "-"]), $a(["R", "r", ".", "."]), $a(["S", "s", "$", "$"]), $a(["T", "t", "/", "/"]), $a(["U", "u", "+", "\""]), $a(["V", "v", "%", "|"]), $a(["W", "w", "*", "*"]), $a(["X", "x", "=", 40]), $a(["Y", "y", "^", 41]), $a(["Z", "z", $1.pl, "?"]), $a([" ", " ", " ", "{"]), $a([$1.ll, $1.as, $1.ll, "}"]), $a([$1.ml, $1.ml, $1.al, "'"]), $a([$1.ps, $1.ps, $1.ps, $1.al])]); //#16094
    $1.charvals = $a([new Map, new Map, new Map, new Map]); //#16097
    $1.alltext = new Map; //#16098
    for (var _l = 0, _k = $1.charmaps.length - 1; _l <= _k; _l += 1) { //#16108
        $1.i = _l; //#16100
        $1.encs = $get($1.charmaps, $1.i); //#16101
        for (var _p = 0; _p <= 3; _p += 1) { //#16107
            $1.j = _p; //#16103
            var _s = $get($1.encs, $1.j); //#16104
            $k[$j++] = _s; //#16104
            if ($eq($type(_s), 'stringtype')) { //#16104
                var _v = $get($k[--$j], 0); //#16104
                $k[$j++] = _v; //#16104
            } //#16104
            var _w = $k[--$j]; //#16105
            $put($get($1.charvals, $1.j), _w, $1.i); //#16105
            $put($1.alltext, _w, -1); //#16106
        } //#16106
    } //#16106
    $1.e = 10000; //#16110
    $1.latlen = $a([$a([0, 1, 1, 2]), $a([2, 0, 1, 2]), $a([1, 1, 0, 1]), $a([1, 2, 2, 0])]); //#16118
    $1.latseq = $a([$a([$a([]), $a([$1.ll]), $a([$1.ml]), $a([$1.ml, $1.pl])]), $a([$a([$1.ml, $1.al]), $a([]), $a([$1.ml]), $a([$1.ml, $1.pl])]), $a([$a([$1.al]), $a([$1.ll]), $a([]), $a([$1.pl])]), $a([$a([$1.al]), $a([$1.al, $1.ll]), $a([$1.al, $1.ml]), $a([])])]); //#16126
    $1.shftlen = $a([$a([$1.e, $1.e, $1.e, 1]), $a([1, $1.e, $1.e, 1]), $a([$1.e, $1.e, $1.e, 1]), $a([$1.e, $1.e, $1.e, $1.e])]); //#16134
    $k[$j++] = Infinity; //#16137
    $k[$j++] = $1.tl; //#16137
    $k[$j++] = 900; //#16137
    $k[$j++] = $1.bl; //#16137
    $k[$j++] = 901; //#16137
    $k[$j++] = $1.bl6; //#16137
    $k[$j++] = 924; //#16137
    $k[$j++] = $1.nl; //#16137
    $k[$j++] = 902; //#16137
    $k[$j++] = $1.bs; //#16137
    $k[$j++] = 913; //#16137
    $1.latchcws = $d(); //#16138
    if ($1.raw) { //#16141
        $1.encoding = "raw"; //#16141
    } //#16141
    if ($eq($1.encoding, "raw")) { //#16155
        $1.datcws = $a($1.barcode.length); //#16145
        $1.i = 0; //#16146
        $1.j = 0; //#16146
        for (;;) { //#16153
            if ($1.i == $1.barcode.length) { //#16148
                break; //#16148
            } //#16148
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#16149
            $put($1.datcws, $1.j, $1.cw); //#16150
            $1.i = $1.i + 4; //#16151
            $1.j = $1.j + 1; //#16152
        } //#16152
        $1.datcws = $geti($1.datcws, 0, $1.j); //#16154
    } //#16154
    if ($1.ccc) { //#16157
        $1.encoding = "ccc"; //#16157
    } //#16157
    $1.encb = function() {
        $1.in = $k[--$j]; //#16160
        $1.inlen = $1.in.length; //#16161
        $1.out = $a(((~~($1.inlen / 6)) * 5) + ($1.inlen % 6)); //#16162
        for (var _2V = 0, _2U = (~~($1.inlen / 6)) - 1; _2V <= _2U; _2V += 1) { //#16185
            $1.k = _2V; //#16164
            $k[$j++] = Infinity; //#16165
            $aload($geti($1.in, $1.k * 6, 3)); //#16165
            $1.msbs = $a(); //#16165
            $k[$j++] = Infinity; //#16168
            $aload($1.msbs); //#16167
            var _2b = $k[--$j]; //#16167
            var _2c = $k[--$j]; //#16167
            var _2d = $k[--$j]; //#16167
            $k[$j++] = $f(($f(_2b + (_2c * 256))) + (_2d * 65536)); //#16168
            for (var _2e = 0, _2f = 3; _2e < _2f; _2e++) { //#16168
                var _2g = $k[--$j]; //#16168
                $k[$j++] = _2g % 900; //#16168
                $k[$j++] = ~~(_2g / 900); //#16168
            } //#16168
            $1.mscs = $a(); //#16168
            $k[$j++] = Infinity; //#16170
            $aload($geti($1.in, ($1.k * 6) + 3, 3)); //#16170
            $1.lsbs = $a(); //#16170
            $k[$j++] = Infinity; //#16173
            $aload($1.lsbs); //#16172
            var _2n = $k[--$j]; //#16172
            var _2o = $k[--$j]; //#16172
            var _2p = $k[--$j]; //#16172
            $k[$j++] = $f(($f(_2n + (_2o * 256))) + (_2p * 65536)); //#16173
            for (var _2q = 0, _2r = 3; _2q < _2r; _2q++) { //#16173
                var _2s = $k[--$j]; //#16173
                $k[$j++] = _2s % 900; //#16173
                $k[$j++] = ~~(_2s / 900); //#16173
            } //#16173
            $1.lscs = $a(); //#16173
            var _2v = $get($1.lscs, 0); //#16175
            var _2x = $get($1.mscs, 0); //#16175
            $put($1.out, ($1.k * 5) + 4, ($f(_2v + (_2x * 316))) % 900); //#16176
            var _31 = $get($1.lscs, 1); //#16177
            var _33 = $get($1.mscs, 0); //#16177
            var _35 = $get($1.mscs, 1); //#16177
            $put($1.out, ($1.k * 5) + 3, ($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) % 900); //#16178
            var _39 = $get($1.lscs, 2); //#16179
            var _3B = $get($1.mscs, 0); //#16179
            var _3D = $get($1.mscs, 1); //#16179
            var _3F = $get($1.mscs, 2); //#16179
            $put($1.out, ($1.k * 5) + 2, ($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) % 900); //#16180
            var _3J = $get($1.lscs, 3); //#16181
            var _3L = $get($1.mscs, 1); //#16181
            var _3N = $get($1.mscs, 2); //#16181
            $put($1.out, ($1.k * 5) + 1, ($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) / 900)) + _3J)) + (_3L * 20))) + (_3N * 641))) % 900); //#16182
            $put($1.out, $1.k * 5, ($f((~~(($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) / 900)) + _3J)) + (_3L * 20))) + (_3N * 641))) / 900)) + ($get($1.mscs, 2) * 20))) % 900); //#16184
        } //#16184
        $1.rem = $1.inlen % 6; //#16186
        if ($1.rem != 0) { //#16191
            $k[$j++] = $1.out; //#16189
            $k[$j++] = $1.out.length - $1.rem; //#16189
            $k[$j++] = Infinity; //#16189
            $aload($geti($1.in, $1.inlen - $1.rem, $1.rem)); //#16189
            var _3e = $a(); //#16189
            var _3f = $k[--$j]; //#16190
            $puti($k[--$j], _3f, _3e); //#16190
        } //#16190
        $k[$j++] = $1.out; //#16192
    }; //#16192
    if ($eq($1.encoding, "byte") || $eq($1.encoding, "ccc")) { //#16201
        $1.barlen = $1.barcode.length; //#16196
        $1.datcws = $a((((~~($1.barlen / 6)) * 5) + ($1.barlen % 6)) + 1); //#16197
        var _3q = (($1.barlen % 6) == 0) ? 924 : 901; //#16198
        $put($1.datcws, 0, _3q); //#16198
        $k[$j++] = $1.datcws; //#16199
        $k[$j++] = 1; //#16199
        $k[$j++] = Infinity; //#16199
        $forall($1.barcode); //#16199
        var _3t = $a(); //#16199
        $k[$j++] = _3t; //#16199
        $1.encb(); //#16199
        var _3u = $k[--$j]; //#16199
        var _3v = $k[--$j]; //#16199
        $puti($k[--$j], _3v, _3u); //#16199
        if ($eq($1.encoding, "ccc")) { //#16200
            $k[$j++] = Infinity; //#16200
            $k[$j++] = 920; //#16200
            $aload($1.datcws); //#16200
            $1.datcws = $a(); //#16200
        } //#16200
    } //#16200
    if ($eq($1.encoding, "auto")) { //#16515
        var _43 = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["eci", true]
        ]); //#16209
        $1.fncvals = _43; //#16211
        $k[$j++] = 'msg'; //#16212
        $k[$j++] = $1.barcode; //#16212
        $k[$j++] = $1.fncvals; //#16212
        bwipp_parseinput(); //#16212
        var _46 = $k[--$j]; //#16212
        $1[$k[--$j]] = _46; //#16212
        $1.msglen = $1.msg.length; //#16213
        $k[$j++] = Infinity; //#16216
        for (var _4A = 0, _4B = $1.msglen; _4A < _4B; _4A++) { //#16216
            $k[$j++] = 0; //#16216
        } //#16216
        $k[$j++] = 0; //#16216
        $1.numdigits = $a(); //#16216
        $k[$j++] = Infinity; //#16217
        for (var _4E = 0, _4F = $1.msglen; _4E < _4F; _4E++) { //#16217
            $k[$j++] = 0; //#16217
        } //#16217
        $k[$j++] = 0; //#16217
        $1.numtext = $a(); //#16217
        $k[$j++] = Infinity; //#16218
        for (var _4I = 0, _4J = $1.msglen; _4I < _4J; _4I++) { //#16218
            $k[$j++] = 0; //#16218
        } //#16218
        $k[$j++] = 0; //#16218
        $1.numbytes = $a(); //#16218
        $k[$j++] = Infinity; //#16219
        for (var _4M = 0, _4N = $1.msglen; _4M < _4N; _4M++) { //#16219
            $k[$j++] = 0; //#16219
        } //#16219
        $k[$j++] = 0; //#16219
        $1.iseci = $a(); //#16219
        for (var _4Q = $1.msglen - 1; _4Q >= 0; _4Q -= 1) { //#16232
            $1.i = _4Q; //#16221
            var _4T = $get($1.msg, $1.i); //#16222
            if ((_4T >= 48) && (_4T <= 57)) { //#16224
                $put($1.numdigits, $1.i, $f($get($1.numdigits, $1.i + 1) + 1)); //#16223
            } //#16223
            var _4d = $get($1.alltext, $get($1.msg, $1.i)) !== undefined; //#16225
            if (_4d && ($get($1.numdigits, $1.i) < 13)) { //#16227
                $put($1.numtext, $1.i, $f($get($1.numtext, $1.i + 1) + 1)); //#16226
            } //#16226
            if ((($get($1.msg, $1.i) >= 0) && ($get($1.numtext, $1.i) < 5)) && ($get($1.numdigits, $1.i) < 13)) { //#16230
                $put($1.numbytes, $1.i, $f($get($1.numbytes, $1.i + 1) + 1)); //#16229
            } //#16229
            $put($1.iseci, $1.i, $get($1.msg, $1.i) <= -1000000); //#16231
        } //#16231
        $1.numdigits = $geti($1.numdigits, 0, $1.msglen); //#16233
        $1.numtext = $geti($1.numtext, 0, $1.msglen); //#16234
        $1.numbytes = $geti($1.numbytes, 0, $1.msglen); //#16235
        $1.seq = $a([]); //#16237
        $1.seqlen = 0; //#16237
        $1.state = $1.T; //#16237
        $1.p = 0; //#16237
        for (;;) { //#16291
            if ($1.p == $1.msglen) { //#16238
                break; //#16238
            } //#16238
            if ($get($1.iseci, $1.p)) { //#16289
                $1.eci = $get($1.msg, $1.p); //#16240
                $k[$j++] = Infinity; //#16243
                $aload($1.seq); //#16242
                $k[$j++] = $a([$1.eci]); //#16243
                $1.seq = $a(); //#16243
                $1.p = $1.p + 1; //#16245
                $k[$j++] = 'seqlen'; //#16246
                $k[$j++] = $1.seqlen; //#16246
                if ($1.eci <= -1810900) { //#16246
                    $k[$j++] = 2; //#16246
                } else { //#16246
                    var _5W = ($1.eci <= -1000900) ? 3 : 2; //#16246
                    $k[$j++] = _5W; //#16246
                } //#16246
                var _5X = $k[--$j]; //#16246
                var _5Y = $k[--$j]; //#16246
                $1[$k[--$j]] = $f(_5Y + _5X); //#16246
            } else { //#16289
                $1.n = $get($1.numdigits, $1.p); //#16248
                if ($1.n >= 13) { //#16289
                    $k[$j++] = Infinity; //#16253
                    $aload($1.seq); //#16251
                    $k[$j++] = $1.nl; //#16253
                    $k[$j++] = Infinity; //#16253
                    $aload($geti($1.msg, $1.p, $1.n)); //#16253
                    var _5k = $a(); //#16253
                    $k[$j++] = _5k; //#16253
                    $1.seq = $a(); //#16253
                    $1.state = $1.N; //#16255
                    $1.p = $f($1.p + $1.n); //#16256
                    $1.seqlen = $f(($1.seqlen + 1) + $1.n); //#16257
                } else { //#16289
                    $1.t = $get($1.numtext, $1.p); //#16259
                    if ($1.t >= 5) { //#16289
                        $k[$j++] = Infinity; //#16266
                        $aload($1.seq); //#16262
                        if ($1.state != $1.T) { //#16265
                            $k[$j++] = $1.tl; //#16264
                        } //#16264
                        $k[$j++] = Infinity; //#16266
                        $aload($geti($1.msg, $1.p, $1.t)); //#16266
                        var _63 = $a(); //#16266
                        $k[$j++] = _63; //#16266
                        $1.seq = $a(); //#16266
                        $1.state = $1.T; //#16268
                        $1.p = $f($1.p + $1.t); //#16269
                        $1.seqlen = $f($f($1.seqlen + 1) + $1.t); //#16270
                    } else { //#16289
                        $1.b = $get($1.numbytes, $1.p); //#16272
                        if (($1.b == 1) && ($1.state == $1.T)) { //#16289
                            $k[$j++] = Infinity; //#16277
                            $aload($1.seq); //#16275
                            $k[$j++] = $1.bs; //#16277
                            $k[$j++] = $a([$get($1.msg, $1.p)]); //#16277
                            $1.seq = $a(); //#16277
                            $1.p = $f($1.p + $1.b); //#16279
                            $1.seqlen = $f($1.seqlen + 2); //#16280
                        } else { //#16289
                            $k[$j++] = Infinity; //#16285
                            $aload($1.seq); //#16283
                            var _6S = (($1.b % 6) != 0) ? $1.bl : $1.bl6; //#16284
                            $k[$j++] = _6S; //#16285
                            $k[$j++] = Infinity; //#16285
                            $aload($geti($1.msg, $1.p, $1.b)); //#16285
                            var _6X = $a(); //#16285
                            $k[$j++] = _6X; //#16285
                            $1.seq = $a(); //#16285
                            $1.state = $1.B; //#16287
                            $1.p = $f($1.p + $1.b); //#16288
                            $1.seqlen = $f($f($1.seqlen + 1) + $1.b); //#16289
                        } //#16289
                    } //#16289
                } //#16289
            } //#16289
        } //#16289
        $1.enca = function() {
            var _6i = $get($get($1.charvals, $1.A), $k[--$j]); //#16294
            $k[$j++] = _6i; //#16294
        }; //#16294
        $1.encl = function() {
            var _6n = $get($get($1.charvals, $1.L), $k[--$j]); //#16295
            $k[$j++] = _6n; //#16295
        }; //#16295
        $1.encm = function() {
            var _6s = $get($get($1.charvals, $1.M), $k[--$j]); //#16296
            $k[$j++] = _6s; //#16296
        }; //#16296
        $1.encp = function() {
            var _6x = $get($get($1.charvals, $1.P), $k[--$j]); //#16297
            $k[$j++] = _6x; //#16297
        }; //#16297
        $1.textencfuncs = $a(['enca', 'encl', 'encm', 'encp']); //#16298
        $1.addtotext = function() {
            $put($1.text, $1.l, $k[--$j]); //#16301
            $1.l = $1.l + 1; //#16302
        }; //#16302
        $1.enct = function() {
            $1.in = $k[--$j]; //#16306
            $1.curlen = $a([$1.e, $1.e, $1.e, $1.e]); //#16308
            $put($1.curlen, $1.submode, 0); //#16309
            $1.curseq = $a([$a([]), $a([]), $a([]), $a([])]); //#16310
            $forall($1.in, function() { //#16380
                $1.char = $k[--$j]; //#16315
                for (;;) { //#16336
                    $1.imp = false; //#16319
                    var _7M = $a([$1.A, $1.L, $1.M, $1.P]); //#16320
                    for (var _7N = 0, _7O = _7M.length; _7N < _7O; _7N++) { //#16334
                        $1.x = $get(_7M, _7N); //#16321
                        var _7U = $a([$1.A, $1.L, $1.M, $1.P]); //#16322
                        for (var _7V = 0, _7W = _7U.length; _7V < _7W; _7V++) { //#16333
                            $1.y = $get(_7U, _7V); //#16323
                            $1.cost = $f($get($1.curlen, $1.x) + $get($get($1.latlen, $1.x), $1.y)); //#16324
                            if ($1.cost < $get($1.curlen, $1.y)) { //#16332
                                $put($1.curlen, $1.y, $1.cost); //#16326
                                $k[$j++] = $1.curseq; //#16329
                                $k[$j++] = $1.y; //#16329
                                $k[$j++] = Infinity; //#16329
                                $aload($get($1.curseq, $1.x)); //#16328
                                $aload($get($get($1.latseq, $1.x), $1.y)); //#16329
                                var _7x = $a(); //#16329
                                var _7y = $k[--$j]; //#16330
                                $put($k[--$j], _7y, _7x); //#16330
                                $1.imp = true; //#16331
                            } //#16331
                        } //#16331
                    } //#16331
                    if (!$1.imp) { //#16335
                        break; //#16335
                    } //#16335
                } //#16335
                $1.nxtlen = $a([$1.e, $1.e, $1.e, $1.e]); //#16339
                $1.nxtseq = $a(4); //#16340
                var _8B = $a([$1.A, $1.L, $1.M, $1.P]); //#16342
                for (var _8C = 0, _8D = _8B.length; _8C < _8D; _8C++) { //#16375
                    $1.x = $get(_8B, _8C); //#16343
                    for (;;) { //#16373
                        var _8J = $get($get($1.charvals, $1.x), $1.char) !== undefined; //#16347
                        if (!_8J) { //#16347
                            break; //#16347
                        } //#16347
                        $1.cost = $f($get($1.curlen, $1.x) + 1); //#16350
                        if ($1.cost < $get($1.nxtlen, $1.x)) { //#16354
                            $put($1.nxtlen, $1.x, $1.cost); //#16352
                            $k[$j++] = $1.nxtseq; //#16353
                            $k[$j++] = $1.x; //#16353
                            $k[$j++] = Infinity; //#16353
                            $aload($get($1.curseq, $1.x)); //#16353
                            $k[$j++] = $1.char; //#16353
                            var _8a = $a(); //#16353
                            var _8b = $k[--$j]; //#16353
                            $put($k[--$j], _8b, _8a); //#16353
                        } //#16353
                        var _8h = $a([$1.A, $1.L, $1.M, $1.P]); //#16357
                        for (var _8i = 0, _8j = _8h.length; _8i < _8j; _8i++) { //#16370
                            $1.y = $get(_8h, _8i); //#16358
                            if ($ne($1.x, $1.y)) { //#16369
                                $1.cost = $f($f($get($1.curlen, $1.y) + $get($get($1.shftlen, $1.y), $1.x)) + 1); //#16360
                                if ($1.cost < $get($1.nxtlen, $1.y)) { //#16368
                                    $put($1.nxtlen, $1.y, $1.cost); //#16362
                                    $k[$j++] = $1.nxtseq; //#16366
                                    $k[$j++] = $1.y; //#16366
                                    $k[$j++] = Infinity; //#16366
                                    $aload($get($1.curseq, $1.y)); //#16364
                                    var _99 = ($1.x == $1.A) ? $1.as : $1.ps; //#16365
                                    $k[$j++] = _99; //#16366
                                    $k[$j++] = $1.char; //#16366
                                    var _9B = $a(); //#16366
                                    var _9C = $k[--$j]; //#16367
                                    $put($k[--$j], _9C, _9B); //#16367
                                } //#16367
                            } //#16367
                        } //#16367
                        break; //#16372
                    } //#16372
                } //#16372
                $1.curlen = $1.nxtlen; //#16377
                $1.curseq = $1.nxtseq; //#16378
            }); //#16378
            $1.minseq = $1.e; //#16383
            var _9L = $a([$1.A, $1.L, $1.M, $1.P]); //#16384
            for (var _9M = 0, _9N = _9L.length; _9M < _9N; _9M++) { //#16390
                $1.k = $get(_9L, _9M); //#16385
                if ($get($1.curlen, $1.k) < $1.minseq) { //#16389
                    $1.minseq = $get($1.curlen, $1.k); //#16387
                    $1.txtseq = $get($1.curseq, $1.k); //#16388
                } //#16388
            } //#16388
            $1.text = $a($1.minseq); //#16393
            $1.k = 0; //#16394
            $1.l = 0; //#16394
            for (;;) { //#16414
                if ($1.k >= $1.txtseq.length) { //#16395
                    break; //#16395
                } //#16395
                $1.char = $get($1.txtseq, $1.k); //#16397
                $k[$j++] = $1.char; //#16400
                if ($1[$get($1.textencfuncs, $1.submode)]() === true) {
                    break;
                } //#16400
                $1.addtotext(); //#16400
                $1.k = $1.k + 1; //#16401
                if (($1.char == $1.as) || ($1.char == $1.ps)) { //#16407
                    $k[$j++] = $get($1.txtseq, $1.k); //#16405
                    if ($1.char == $1.as) { //#16405
                        $1.enca(); //#16405
                    } else { //#16405
                        $1.encp(); //#16405
                    } //#16405
                    $1.addtotext(); //#16405
                    $1.k = $1.k + 1; //#16406
                } //#16406
                if ($1.char == $1.al) { //#16410
                    $1.submode = $1.A; //#16410
                } //#16410
                if ($1.char == $1.ll) { //#16411
                    $1.submode = $1.L; //#16411
                } //#16411
                if ($1.char == $1.ml) { //#16412
                    $1.submode = $1.M; //#16412
                } //#16412
                if ($1.char == $1.pl) { //#16413
                    $1.submode = $1.P; //#16413
                } //#16413
            } //#16413
            if (($1.text.length % 2) == 1) { //#16424
                if ($1.submode == $1.P) { //#16421
                    $k[$j++] = 'pad'; //#16418
                    $k[$j++] = $1.al; //#16418
                    $1.encp(); //#16418
                    var _AC = $k[--$j]; //#16418
                    $1[$k[--$j]] = _AC; //#16418
                    $1.submode = $1.A; //#16419
                } else { //#16421
                    $k[$j++] = 'pad'; //#16421
                    $k[$j++] = $1.ps; //#16421
                    if ($1[$get($1.textencfuncs, $1.submode)]() === true) {
                        return true;
                    } //#16421
                    var _AK = $k[--$j]; //#16421
                    $1[$k[--$j]] = _AK; //#16421
                } //#16421
                $k[$j++] = Infinity; //#16423
                $aload($1.text); //#16423
                $k[$j++] = $1.pad; //#16423
                $1.text = $a(); //#16423
            } //#16423
            $1.out = $a(~~($1.text.length / 2)); //#16426
            for (var _AT = 0, _AS = $1.out.length - 1; _AT <= _AS; _AT += 1) { //#16430
                $1.k = _AT; //#16428
                $put($1.out, $1.k, $f(($get($1.text, $1.k * 2) * 30) + $get($1.text, ($1.k * 2) + 1))); //#16429
            } //#16429
            $k[$j++] = $1.out; //#16432
        }; //#16432
        $1.encn = function() {
            $1.in = $k[--$j]; //#16437
            $1.out = $a([]); //#16438
            for (var _Ah = 0, _Ag = $1.in.length - 1; _Ah <= _Ag; _Ah += 44) { //#16466
                $1.k = _Ah; //#16440
                $k[$j++] = Infinity; //#16443
                var _Am = $1.in.length - $1.k; //#16442
                $k[$j++] = 1; //#16442
                $k[$j++] = $1.in; //#16442
                $k[$j++] = $1.k; //#16442
                $k[$j++] = _Am; //#16442
                if (_Am > 44) { //#16442
                    $j--; //#16442
                    $k[$j++] = 44; //#16442
                } //#16442
                var _An = $k[--$j]; //#16442
                var _Ao = $k[--$j]; //#16442
                var _Aq = $geti($k[--$j], _Ao, _An); //#16442
                for (var _Ar = 0, _As = _Aq.length; _Ar < _As; _Ar++) { //#16443
                    $k[$j++] = $f($get(_Aq, _Ar) - 48); //#16443
                } //#16443
                $1.gmod = $a(); //#16443
                $1.cwn = $a([]); //#16445
                for (;;) { //#16464
                    $1.dv = 900; //#16446
                    $1.gmul = $a([]); //#16447
                    $1.val = 0; //#16447
                    for (;;) { //#16459
                        if ($1.gmod.length == 0) { //#16448
                            break; //#16448
                        } //#16448
                        $1.val = $f(($1.val * 10) + $get($1.gmod, 0)); //#16449
                        $1.gmod = $geti($1.gmod, 1, $1.gmod.length - 1); //#16450
                        if ($1.val < $1.dv) { //#16456
                            if ($1.gmul.length != 0) { //#16454
                                $k[$j++] = Infinity; //#16453
                                $aload($1.gmul); //#16453
                                $k[$j++] = 0; //#16453
                                $1.gmul = $a(); //#16453
                            } //#16453
                        } else { //#16456
                            $k[$j++] = Infinity; //#16456
                            $aload($1.gmul); //#16456
                            $k[$j++] = ~~($1.val / $1.dv); //#16456
                            $1.gmul = $a(); //#16456
                        } //#16456
                        $1.val = $1.val % $1.dv; //#16458
                    } //#16458
                    $1.dv = $1.val; //#16460
                    $k[$j++] = Infinity; //#16461
                    $k[$j++] = $1.dv; //#16461
                    $aload($1.cwn); //#16461
                    $1.cwn = $a(); //#16461
                    $1.gmod = $1.gmul; //#16462
                    if ($1.gmul.length == 0) { //#16463
                        break; //#16463
                    } //#16463
                } //#16463
                $k[$j++] = Infinity; //#16465
                $aload($1.out); //#16465
                $aload($1.cwn); //#16465
                $1.out = $a(); //#16465
            } //#16465
            $k[$j++] = $1.out; //#16467
        }; //#16467
        $1.ence = function() {
            var _BR = $f((-$get($k[--$j], 0)) - 1000000); //#16472
            $k[$j++] = _BR; //#16480
            if (_BR <= 899) { //#16479
                var _BS = $k[--$j]; //#16473
                $k[$j++] = 927; //#16473
                $k[$j++] = _BS; //#16473
                $astore($a(2)); //#16473
            } else { //#16479
                var _BU = $k[--$j]; //#16474
                $k[$j++] = _BU; //#16480
                if (_BU <= 810899) { //#16479
                    var _BV = $k[--$j]; //#16475
                    $k[$j++] = 926; //#16475
                    $k[$j++] = (~~(_BV / 900)) - 1; //#16475
                    $k[$j++] = _BV % 900; //#16475
                    $astore($a(3)); //#16475
                } else { //#16479
                    var _BX = $k[--$j]; //#16476
                    $k[$j++] = _BX; //#16480
                    if (_BX <= 811799) { //#16479
                        var _BY = $k[--$j]; //#16477
                        $k[$j++] = 925; //#16477
                        $k[$j++] = $f(_BY - 810900); //#16477
                        $astore($a(2)); //#16477
                    } else { //#16479
                        $k[$j++] = 'bwipp.pdf417badECI'; //#16479
                        $k[$j++] = "PDF417 supports ECIs 000000 to 811799"; //#16479
                        bwipp_raiseerror(); //#16479
                    } //#16479
                } //#16479
            } //#16479
        }; //#16479
        $1.encfuncs = $a(['enct', 'encn', 'encb']); //#16483
        $1.addtocws = function() {
            var _Bb = $k[--$j]; //#16486
            $puti($1.datcws, $1.j, _Bb); //#16486
            $1.j = _Bb.length + $1.j; //#16487
        }; //#16487
        $1.state = $1.T; //#16491
        $1.submode = $1.A; //#16491
        $1.datcws = $a($1.seqlen); //#16492
        $1.i = 0; //#16493
        $1.j = 0; //#16493
        for (;;) { //#16513
            if ($1.i >= $1.seq.length) { //#16494
                break; //#16494
            } //#16494
            $1.chars = $get($1.seq, $1.i); //#16495
            if ($eq($type($1.chars), 'arraytype')) { //#16509
                if ($get($1.chars, 0) <= -1000000) { //#16500
                    $k[$j++] = $1.chars; //#16498
                    $1.ence(); //#16498
                    $1.addtocws(); //#16498
                } else { //#16500
                    $k[$j++] = $1.chars; //#16500
                    if ($1[$get($1.encfuncs, $1.state)]() === true) {
                        break;
                    } //#16500
                    $1.addtocws(); //#16500
                } //#16500
            } else { //#16509
                $k[$j++] = $a([$get($1.latchcws, $1.chars)]); //#16503
                $1.addtocws(); //#16503
                if ($1.chars == $1.tl) { //#16504
                    $1.state = $1.T; //#16504
                    $1.submode = $1.A; //#16504
                } //#16504
                if ($1.chars == $1.nl) { //#16505
                    $1.state = $1.N; //#16505
                } //#16505
                if (($1.chars == $1.bl) || ($1.chars == $1.bl6)) { //#16506
                    $1.state = $1.B; //#16506
                } //#16506
                if ($1.chars == $1.bs) { //#16510
                    $1.i = $1.i + 1; //#16508
                    $k[$j++] = $get($1.seq, $1.i); //#16509
                    $1.encb(); //#16509
                    $1.addtocws(); //#16509
                } //#16509
            } //#16509
            $1.i = $1.i + 1; //#16512
        } //#16512
        $1.datcws = $geti($1.datcws, 0, $1.j); //#16514
    } //#16514
    $1.m = $1.datcws.length; //#16518
    if ($1.eclevel == -1) { //#16524
        if ($1.m <= 40) { //#16520
            $1.eclevel = 2; //#16520
        } //#16520
        if (($1.m >= 41) && ($1.m <= 160)) { //#16521
            $1.eclevel = 3; //#16521
        } //#16521
        if (($1.m >= 161) && ($1.m <= 320)) { //#16522
            $1.eclevel = 4; //#16522
        } //#16522
        if ($1.m >= 321) { //#16523
            $1.eclevel = 5; //#16523
        } //#16523
    } //#16523
    $1.maxeclevel = (~~((Math.log((928 - 1) - $1.m)) / Math.log(2))) - 1; //#16527
    if ($1.eclevel > $1.maxeclevel) { //#16528
        $1.eclevel = $1.maxeclevel; //#16528
    } //#16528
    $1.k = ~~Math.pow(2, $1.eclevel + 1); //#16529
    if ($1.columns == 0) { //#16532
        $1.columns = ~~(Math.round(Math.sqrt(($1.m + $1.k) / 3))); //#16532
    } //#16532
    $k[$j++] = 'c'; //#16533
    if ($1.columns >= 1) { //#16533
        $k[$j++] = $1.columns; //#16533
    } else { //#16533
        $k[$j++] = 1; //#16533
    } //#16533
    var _Cg = $k[--$j]; //#16533
    $1[$k[--$j]] = _Cg; //#16533
    $1.r = ~~(Math.ceil((($1.m + $1.k) + 1) / $1.columns)); //#16536
    if (($1.r < $1.rows) && ($1.rows <= 90)) { //#16537
        $1.r = $1.rows; //#16537
    } //#16537
    if ($1.r < 3) { //#16538
        $1.r = 3; //#16538
    } //#16538
    if ($1.r > 90) { //#16543
        $k[$j++] = 'bwipp.pdf417insufficientCapacity'; //#16542
        $k[$j++] = "Insufficient capacity in the symbol"; //#16542
        bwipp_raiseerror(); //#16542
    } //#16542
    var _Cr = $1.c; //#16546
    var _Cs = $1.r; //#16546
    var _Ct = $1.m; //#16546
    var _Cu = 8; //#16546
    var _Cv = (~~((Math.log($f(($f((_Cr * _Cs) - 1)) - _Ct))) / Math.log(2))) - 1; //#16546
    if (((~~((Math.log($f(($f((_Cr * _Cs) - 1)) - _Ct))) / Math.log(2))) - 1) > 8) { //#16546
        var _ = _Cu; //#16546
        _Cu = _Cv; //#16546
        _Cv = _; //#16546
    } //#16546
    $1.maxeclevel = _Cv; //#16546
    if ($1.maxeclevel > $1.eclevel) { //#16550
        $1.eclevel = $1.maxeclevel; //#16548
        $1.k = ~~Math.pow(2, $1.eclevel + 1); //#16549
    } //#16549
    $1.n = $f(($1.c * $1.r) - $1.k); //#16553
    $1.cws = $a($f(($1.c * $1.r) + 1)); //#16554
    $put($1.cws, 0, $1.n); //#16555
    $puti($1.cws, 1, $1.datcws); //#16556
    $k[$j++] = $1.cws; //#16557
    $k[$j++] = $1.m + 1; //#16557
    $k[$j++] = Infinity; //#16557
    for (var _DE = 0, _DF = $f($f($1.n - $1.m) - 1); _DE < _DF; _DE++) { //#16557
        $k[$j++] = 900; //#16557
    } //#16557
    var _DG = $a(); //#16557
    var _DH = $k[--$j]; //#16557
    $puti($k[--$j], _DH, _DG); //#16557
    $k[$j++] = $1.cws; //#16558
    $k[$j++] = $1.n; //#16558
    $k[$j++] = Infinity; //#16558
    for (var _DM = 0, _DN = $1.k; _DM < _DN; _DM++) { //#16558
        $k[$j++] = 0; //#16558
    } //#16558
    $k[$j++] = 0; //#16558
    var _DO = $a(); //#16558
    var _DP = $k[--$j]; //#16558
    $puti($k[--$j], _DP, _DO); //#16558
    $k[$j++] = Infinity; //#16561
    $k[$j++] = 1; //#16561
    for (var _DR = 0, _DS = 928; _DR < _DS; _DR++) { //#16561
        var _DT = $k[--$j]; //#16561
        $k[$j++] = _DT; //#16561
        $k[$j++] = (_DT * 3) % 929; //#16561
    } //#16561
    $1.rsalog = $a(); //#16561
    $1.rslog = $a(929); //#16562
    for (var _DW = 1; _DW <= 928; _DW += 1) { //#16563
        $put($1.rslog, $get($1.rsalog, _DW), _DW); //#16563
    } //#16563
    $1.rsprod = function() {
        var _Da = $k[--$j]; //#16567
        var _Db = $k[--$j]; //#16567
        $k[$j++] = _Db; //#16571
        $k[$j++] = _Da; //#16571
        if ((_Da != 0) && (_Db != 0)) { //#16570
            var _De = $get($1.rslog, $k[--$j]); //#16568
            var _Dj = $get($1.rsalog, $f(_De + $get($1.rslog, $k[--$j])) % 928); //#16568
            $k[$j++] = _Dj; //#16568
        } else { //#16570
            $j -= 2; //#16570
            $k[$j++] = 0; //#16570
        } //#16570
    }; //#16570
    $k[$j++] = Infinity; //#16575
    $k[$j++] = 1; //#16575
    for (var _Dl = 0, _Dm = $1.k; _Dl < _Dm; _Dl++) { //#16575
        $k[$j++] = 0; //#16575
    } //#16575
    $1.coeffs = $a(); //#16575
    for (var _Dq = 1, _Dp = $1.k; _Dq <= _Dp; _Dq += 1) { //#16584
        $1.i = _Dq; //#16577
        $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#16578
        for (var _Dx = $1.i - 1; _Dx >= 1; _Dx -= 1) { //#16582
            $1.j = _Dx; //#16580
            $k[$j++] = $1.coeffs; //#16581
            $k[$j++] = $1.j; //#16581
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#16581
            $k[$j++] = $get($1.coeffs, $1.j); //#16581
            $k[$j++] = $get($1.rsalog, $1.i); //#16581
            $1.rsprod(); //#16581
            var _E9 = $k[--$j]; //#16581
            var _EA = $k[--$j]; //#16581
            var _EB = $k[--$j]; //#16581
            $put($k[--$j], _EB, $f(_EA + _E9) % 929); //#16581
        } //#16581
        $k[$j++] = $1.coeffs; //#16583
        $k[$j++] = 0; //#16583
        $k[$j++] = $get($1.coeffs, 0); //#16583
        $k[$j++] = $get($1.rsalog, $1.i); //#16583
        $1.rsprod(); //#16583
        var _EJ = $k[--$j]; //#16583
        var _EK = $k[--$j]; //#16583
        $put($k[--$j], _EK, _EJ); //#16583
    } //#16583
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#16585
    for (var _EQ = $1.coeffs.length - 1; _EQ >= 0; _EQ -= 2) { //#16586
        var _ER = $1.coeffs; //#16586
        $put(_ER, _EQ, $f(929 - $get(_ER, _EQ))); //#16586
    } //#16586
    for (var _EV = 0, _EU = $f($1.n - 1); _EV <= _EU; _EV += 1) { //#16595
        $1.t = $f($get($1.cws, _EV) + $get($1.cws, $1.n)) % 929; //#16590
        for (var _Ed = 0, _Ec = $1.k - 1; _Ed <= _Ec; _Ed += 1) { //#16594
            $1.j = _Ed; //#16592
            $put($1.cws, $f($1.n + $1.j), ($f($get($1.cws, $f($f($1.n + $1.j) + 1)) + ($f(929 - (($1.t * $get($1.coeffs, ($1.k - $1.j) - 1)) % 929))))) % 929); //#16593
        } //#16593
    } //#16593
    for (var _Eu = $1.n, _Et = $f($1.n + $1.k); _Eu <= _Et; _Eu += 1) { //#16596
        $put($1.cws, _Eu, $f(929 - $get($1.cws, _Eu)) % 929); //#16596
    } //#16596
    $1.cws = $geti($1.cws, 0, $1.cws.length - 1); //#16599
    var _F2 = $get($1.options, 'debugcws') !== undefined; //#16601
    if (_F2) { //#16601
        $k[$j++] = 'bwipp.debugcws'; //#16601
        $k[$j++] = $1.cws; //#16601
        bwipp_raiseerror(); //#16601
    } //#16601
    $1.clusters = $a([$a([120256, 125680, 128380, 120032, 125560, 128318, 108736, 119920, 108640, 86080, 108592, 86048, 110016, 120560, 125820, 109792, 120440, 125758, 88256, 109680, 88160, 89536, 110320, 120700, 89312, 110200, 120638, 89200, 110140, 89840, 110460, 89720, 110398, 89980, 128506, 119520, 125304, 128190, 107712, 119408, 125244, 107616, 119352, 84032, 107568, 119324, 84000, 107544, 83984, 108256, 119672, 125374, 85184, 108144, 119612, 85088, 108088, 119582, 85040, 108060, 85728, 108408, 119742, 85616, 108348, 85560, 108318, 85880, 108478, 85820, 85790, 107200, 119152, 125116, 107104, 119096, 125086, 83008, 107056, 119068, 82976, 107032, 82960, 82952, 83648, 107376, 119228, 83552, 107320, 119198, 83504, 107292, 83480, 83468, 83824, 107452, 83768, 107422, 83740, 83900, 106848, 118968, 125022, 82496, 106800, 118940, 82464, 106776, 118926, 82448, 106764, 82440, 106758, 82784, 106936, 119006, 82736, 106908, 82712, 106894, 82700, 82694, 106974, 82830, 82240, 106672, 118876, 82208, 106648, 118862, 82192, 106636, 82184, 106630, 82180, 82352, 82328, 82316, 82080, 118830, 106572, 106566, 82050, 117472, 124280, 127678, 103616, 117360, 124220, 103520, 117304, 124190, 75840, 103472, 75808, 104160, 117624, 124350, 76992, 104048, 117564, 76896, 103992, 76848, 76824, 77536, 104312, 117694, 77424, 104252, 77368, 77340, 77688, 104382, 77628, 77758, 121536, 126320, 128700, 121440, 126264, 128670, 111680, 121392, 126236, 111648, 121368, 126222, 111632, 121356, 103104, 117104, 124092, 112320, 103008, 117048, 124062, 112224, 121656, 126366, 93248, 74784, 102936, 117006, 93216, 112152, 93200, 75456, 103280, 117180, 93888, 75360, 103224, 117150, 93792, 112440, 121758, 93744, 75288, 93720, 75632, 103356, 94064, 75576, 103326, 94008, 112542, 93980, 75708, 94140, 75678, 94110, 121184, 126136, 128606, 111168, 121136, 126108, 111136, 121112, 126094, 111120, 121100, 111112, 111108, 102752, 116920, 123998, 111456, 102704, 116892, 91712, 74272, 121244, 116878, 91680, 74256, 102668, 91664, 111372, 102662, 74244, 74592, 102840, 116958, 92000, 74544, 102812, 91952, 111516, 102798, 91928, 74508, 74502, 74680, 102878, 92088, 74652, 92060, 74638, 92046, 92126, 110912, 121008, 126044, 110880, 120984, 126030, 110864, 120972, 110856, 120966, 110852, 110850, 74048, 102576, 116828, 90944, 74016, 102552, 116814, 90912, 111000, 121038, 90896, 73992, 102534, 90888, 110982, 90884, 74160, 102620, 91056, 74136, 102606, 91032, 111054, 91020, 74118, 91014, 91100, 91086, 110752, 120920, 125998, 110736, 120908, 110728, 120902, 110724, 110722, 73888, 102488, 116782, 90528, 73872, 102476, 90512, 110796, 102470, 90504, 73860, 90500, 73858, 73944, 90584, 90572, 90566, 120876, 120870, 110658, 102444, 73800, 90312, 90308, 90306, 101056, 116080, 123580, 100960, 116024, 70720, 100912, 115996, 70688, 100888, 70672, 70664, 71360, 101232, 116156, 71264, 101176, 116126, 71216, 101148, 71192, 71180, 71536, 101308, 71480, 101278, 71452, 71612, 71582, 118112, 124600, 127838, 105024, 118064, 124572, 104992, 118040, 124558, 104976, 118028, 104968, 118022, 100704, 115896, 123486, 105312, 100656, 115868, 79424, 70176, 118172, 115854, 79392, 105240, 100620, 79376, 70152, 79368, 70496, 100792, 115934, 79712, 70448, 118238, 79664, 105372, 100750, 79640, 70412, 79628, 70584, 100830, 79800, 70556, 79772, 70542, 70622, 79838, 122176, 126640, 128860, 122144, 126616, 128846, 122128, 126604, 122120, 126598, 122116, 104768, 117936, 124508, 113472, 104736, 126684, 124494, 113440, 122264, 126670, 113424, 104712, 117894, 113416, 122246, 104706, 69952, 100528, 115804, 78656, 69920, 100504, 115790, 96064, 78624, 104856, 117966, 96032, 113560, 122318, 100486, 96016, 78600, 104838, 96008, 69890, 70064, 100572, 78768, 70040, 100558, 96176, 78744, 104910, 96152, 113614, 70022, 78726, 70108, 78812, 70094, 96220, 78798, 122016, 126552, 128814, 122000, 126540, 121992, 126534, 121988, 121986, 104608, 117848, 124462, 113056, 104592, 126574, 113040, 122060, 117830, 113032, 104580, 113028, 104578, 113026, 69792, 100440, 115758, 78240, 69776, 100428, 95136, 78224, 104652, 100422, 95120, 113100, 69764, 95112, 78212, 69762, 78210, 69848, 100462, 78296, 69836, 95192, 78284, 69830, 95180, 78278, 69870, 95214, 121936, 126508, 121928, 126502, 121924, 121922, 104528, 117804, 112848, 104520, 117798, 112840, 121958, 112836, 104514, 112834, 69712, 100396, 78032, 69704, 100390, 94672, 78024, 104550, 94664, 112870, 69698, 94660, 78018, 94658, 78060, 94700, 94694, 126486, 121890, 117782, 104484, 104482, 69672, 77928, 94440, 69666, 77922, 99680, 68160, 99632, 68128, 99608, 115342, 68112, 99596, 68104, 99590, 68448, 99768, 115422, 68400, 99740, 68376, 99726, 68364, 68358, 68536, 99806, 68508, 68494, 68574, 101696, 116400, 123740, 101664, 116376, 101648, 116364, 101640, 116358, 101636, 67904, 99504, 115292, 72512, 67872, 116444, 115278, 72480, 101784, 116430, 72464, 67848, 99462, 72456, 101766, 67842, 68016, 99548, 72624, 67992, 99534, 72600, 101838, 72588, 67974, 68060, 72668, 68046, 72654, 118432, 124760, 127918, 118416, 124748, 118408, 124742, 118404, 118402, 101536, 116312, 105888, 101520, 116300, 105872, 118476, 116294, 105864, 101508, 105860, 101506, 105858, 67744, 99416, 72096, 67728, 116334, 80800, 72080, 101580, 99398, 80784, 105932, 67716, 80776, 72068, 67714, 72066, 67800, 99438, 72152, 67788, 80856, 72140, 67782, 80844, 72134, 67822, 72174, 80878, 126800, 128940, 126792, 128934, 126788, 126786, 118352, 124716, 122576, 126828, 124710, 122568, 126822, 122564, 118338, 122562, 101456, 116268, 105680, 101448, 116262, 114128, 105672, 118374, 114120, 122598, 101442, 114116, 105666, 114114, 67664, 99372, 71888, 67656, 99366, 80336, 71880, 101478, 97232, 80328, 105702, 67650, 97224, 114150, 71874, 97220, 67692, 71916, 67686, 80364, 71910, 97260, 80358, 97254, 126760, 128918, 126756, 126754, 118312, 124694, 122472, 126774, 122468, 118306, 122466, 101416, 116246, 105576, 101412, 113896, 105572, 101410, 113892, 105570, 113890, 67624, 99350, 71784, 101430, 80104, 71780, 67618, 96744, 80100, 71778, 96740, 80098, 96738, 71798, 96758, 126738, 122420, 122418, 105524, 113780, 113778, 71732, 79988, 96500, 96498, 66880, 66848, 98968, 66832, 66824, 66820, 66992, 66968, 66956, 66950, 67036, 67022, 100000, 99984, 115532, 99976, 115526, 99972, 99970, 66720, 98904, 69024, 100056, 98892, 69008, 100044, 69000, 100038, 68996, 66690, 68994, 66776, 98926, 69080, 100078, 69068, 66758, 69062, 66798, 69102, 116560, 116552, 116548, 116546, 99920, 102096, 116588, 115494, 102088, 116582, 102084, 99906, 102082, 66640, 68816, 66632, 98854, 73168, 68808, 66628, 73160, 68804, 66626, 73156, 68802, 66668, 68844, 66662, 73196, 68838, 73190, 124840, 124836, 124834, 116520, 118632, 124854, 118628, 116514, 118626, 99880, 115478, 101992, 116534, 106216, 101988, 99874, 106212, 101986, 106210, 66600, 98838, 68712, 99894, 72936, 68708, 66594, 81384, 72932, 68706, 81380, 72930, 66614, 68726, 72950, 81398, 128980, 128978, 124820, 126900, 124818, 126898, 116500, 118580, 116498, 122740, 118578, 122738, 99860, 101940, 99858, 106100, 101938, 114420]), $a([128352, 129720, 125504, 128304, 129692, 125472, 128280, 129678, 125456, 128268, 125448, 128262, 125444, 125792, 128440, 129758, 120384, 125744, 128412, 120352, 125720, 128398, 120336, 125708, 120328, 125702, 120324, 120672, 125880, 128478, 110144, 120624, 125852, 110112, 120600, 125838, 110096, 120588, 110088, 120582, 110084, 110432, 120760, 125918, 89664, 110384, 120732, 89632, 110360, 120718, 89616, 110348, 89608, 110342, 89952, 110520, 120798, 89904, 110492, 89880, 110478, 89868, 90040, 110558, 90012, 89998, 125248, 128176, 129628, 125216, 128152, 129614, 125200, 128140, 125192, 128134, 125188, 125186, 119616, 125360, 128220, 119584, 125336, 128206, 119568, 125324, 119560, 125318, 119556, 119554, 108352, 119728, 125404, 108320, 119704, 125390, 108304, 119692, 108296, 119686, 108292, 108290, 85824, 108464, 119772, 85792, 108440, 119758, 85776, 108428, 85768, 108422, 85764, 85936, 108508, 85912, 108494, 85900, 85894, 85980, 85966, 125088, 128088, 129582, 125072, 128076, 125064, 128070, 125060, 125058, 119200, 125144, 128110, 119184, 125132, 119176, 125126, 119172, 119170, 107424, 119256, 125166, 107408, 119244, 107400, 119238, 107396, 107394, 83872, 107480, 119278, 83856, 107468, 83848, 107462, 83844, 83842, 83928, 107502, 83916, 83910, 83950, 125008, 128044, 125000, 128038, 124996, 124994, 118992, 125036, 118984, 125030, 118980, 118978, 106960, 119020, 106952, 119014, 106948, 106946, 82896, 106988, 82888, 106982, 82884, 82882, 82924, 82918, 124968, 128022, 124964, 124962, 118888, 124982, 118884, 118882, 106728, 118902, 106724, 106722, 82408, 106742, 82404, 82402, 124948, 124946, 118836, 118834, 106612, 106610, 124224, 127664, 129372, 124192, 127640, 129358, 124176, 127628, 124168, 127622, 124164, 124162, 117568, 124336, 127708, 117536, 124312, 127694, 117520, 124300, 117512, 124294, 117508, 117506, 104256, 117680, 124380, 104224, 117656, 124366, 104208, 117644, 104200, 117638, 104196, 104194, 77632, 104368, 117724, 77600, 104344, 117710, 77584, 104332, 77576, 104326, 77572, 77744, 104412, 77720, 104398, 77708, 77702, 77788, 77774, 128672, 129880, 93168, 128656, 129868, 92664, 128648, 129862, 92412, 128644, 128642, 124064, 127576, 129326, 126368, 124048, 129902, 126352, 128716, 127558, 126344, 124036, 126340, 124034, 126338, 117152, 124120, 127598, 121760, 117136, 124108, 121744, 126412, 124102, 121736, 117124, 121732, 117122, 121730, 103328, 117208, 124142, 112544, 103312, 117196, 112528, 121804, 117190, 112520, 103300, 112516, 103298, 112514, 75680, 103384, 117230, 94112, 75664, 103372, 94096, 112588, 103366, 94088, 75652, 94084, 75650, 75736, 103406, 94168, 75724, 94156, 75718, 94150, 75758, 128592, 129836, 91640, 128584, 129830, 91388, 128580, 91262, 128578, 123984, 127532, 126160, 123976, 127526, 126152, 128614, 126148, 123970, 126146, 116944, 124012, 121296, 116936, 124006, 121288, 126182, 121284, 116930, 121282, 102864, 116972, 111568, 102856, 116966, 111560, 121318, 111556, 102850, 111554, 74704, 102892, 92112, 74696, 102886, 92104, 111590, 92100, 74690, 92098, 74732, 92140, 74726, 92134, 128552, 129814, 90876, 128548, 90750, 128546, 123944, 127510, 126056, 128566, 126052, 123938, 126050, 116840, 123958, 121064, 116836, 121060, 116834, 121058, 102632, 116854, 111080, 121078, 111076, 102626, 111074, 74216, 102646, 91112, 74212, 91108, 74210, 91106, 74230, 91126, 128532, 90494, 128530, 123924, 126004, 123922, 126002, 116788, 120948, 116786, 120946, 102516, 110836, 102514, 110834, 73972, 90612, 73970, 90610, 128522, 123914, 125978, 116762, 120890, 102458, 110714, 123552, 127320, 129198, 123536, 127308, 123528, 127302, 123524, 123522, 116128, 123608, 127342, 116112, 123596, 116104, 123590, 116100, 116098, 101280, 116184, 123630, 101264, 116172, 101256, 116166, 101252, 101250, 71584, 101336, 116206, 71568, 101324, 71560, 101318, 71556, 71554, 71640, 101358, 71628, 71622, 71662, 127824, 129452, 79352, 127816, 129446, 79100, 127812, 78974, 127810, 123472, 127276, 124624, 123464, 127270, 124616, 127846, 124612, 123458, 124610, 115920, 123500, 118224, 115912, 123494, 118216, 124646, 118212, 115906, 118210, 100816, 115948, 105424, 100808, 115942, 105416, 118246, 105412, 100802, 105410, 70608, 100844, 79824, 70600, 100838, 79816, 105446, 79812, 70594, 79810, 70636, 79852, 70630, 79846, 129960, 95728, 113404, 129956, 95480, 113278, 129954, 95356, 95294, 127784, 129430, 78588, 128872, 129974, 95996, 78462, 128868, 127778, 95870, 128866, 123432, 127254, 124520, 123428, 126696, 128886, 123426, 126692, 124514, 126690, 115816, 123446, 117992, 115812, 122344, 117988, 115810, 122340, 117986, 122338, 100584, 115830, 104936, 100580, 113640, 104932, 100578, 113636, 104930, 113634, 70120, 100598, 78824, 70116, 96232, 78820, 70114, 96228, 78818, 96226, 70134, 78838, 129940, 94968, 113022, 129938, 94844, 94782, 127764, 78206, 128820, 127762, 95102, 128818, 123412, 124468, 123410, 126580, 124466, 126578, 115764, 117876, 115762, 122100, 117874, 122098, 100468, 104692, 100466, 113140, 104690, 113138, 69876, 78324, 69874, 95220, 78322, 95218, 129930, 94588, 94526, 127754, 128794, 123402, 124442, 126522, 115738, 117818, 121978, 100410, 104570, 112890, 69754, 78074, 94714, 94398, 123216, 127148, 123208, 127142, 123204, 123202, 115408, 123244, 115400, 123238, 115396, 115394, 99792, 115436, 99784, 115430, 99780, 99778, 68560, 99820, 68552, 99814, 68548, 68546, 68588, 68582, 127400, 129238, 72444, 127396, 72318, 127394, 123176, 127126, 123752, 123172, 123748, 123170, 123746, 115304, 123190, 116456, 115300, 116452, 115298, 116450, 99560, 115318, 101864, 99556, 101860, 99554, 101858, 68072, 99574, 72680, 68068, 72676, 68066, 72674, 68086, 72694, 129492, 80632, 105854, 129490, 80508, 80446, 127380, 72062, 127924, 127378, 80766, 127922, 123156, 123700, 123154, 124788, 123698, 124786, 115252, 116340, 115250, 118516, 116338, 118514, 99444, 101620, 99442, 105972, 101618, 105970, 67828, 72180, 67826, 80884, 72178, 80882, 97008, 114044, 96888, 113982, 96828, 96798, 129482, 80252, 130010, 97148, 80190, 97086, 127370, 127898, 128954, 123146, 123674, 124730, 126842, 115226, 116282, 118394, 122618, 99386, 101498, 105722, 114170, 67706, 71930, 80378, 96632, 113854, 96572, 96542, 80062, 96702, 96444, 96414, 96350, 123048, 123044, 123042, 115048, 123062, 115044, 115042, 99048, 115062, 99044, 99042, 67048, 99062, 67044, 67042, 67062, 127188, 68990, 127186, 123028, 123316, 123026, 123314, 114996, 115572, 114994, 115570, 98932, 100084, 98930, 100082, 66804, 69108, 66802, 69106, 129258, 73084, 73022, 127178, 127450, 123018, 123290, 123834, 114970, 115514, 116602, 98874, 99962, 102138, 66682, 68858, 73210, 81272, 106174, 81212, 81182, 72894, 81342, 97648, 114364, 97592, 114334, 97564, 97550, 81084, 97724, 81054, 97694, 97464, 114270, 97436, 97422, 80990, 97502, 97372, 97358, 97326, 114868, 114866, 98676, 98674, 66292, 66290, 123098, 114842, 115130, 98618, 99194, 66170, 67322, 69310, 73404, 73374, 81592, 106334, 81564, 81550, 73310, 81630, 97968, 114524, 97944, 114510, 97932, 97926, 81500, 98012, 81486, 97998, 97880, 114478, 97868, 97862, 81454, 97902, 97836, 97830, 69470, 73564, 73550, 81752, 106414, 81740, 81734, 73518, 81774, 81708, 81702]), $a([109536, 120312, 86976, 109040, 120060, 86496, 108792, 119934, 86256, 108668, 86136, 129744, 89056, 110072, 129736, 88560, 109820, 129732, 88312, 109694, 129730, 88188, 128464, 129772, 89592, 128456, 129766, 89340, 128452, 89214, 128450, 125904, 128492, 125896, 128486, 125892, 125890, 120784, 125932, 120776, 125926, 120772, 120770, 110544, 120812, 110536, 120806, 110532, 84928, 108016, 119548, 84448, 107768, 119422, 84208, 107644, 84088, 107582, 84028, 129640, 85488, 108284, 129636, 85240, 108158, 129634, 85116, 85054, 128232, 129654, 85756, 128228, 85630, 128226, 125416, 128246, 125412, 125410, 119784, 125430, 119780, 119778, 108520, 119798, 108516, 108514, 83424, 107256, 119166, 83184, 107132, 83064, 107070, 83004, 82974, 129588, 83704, 107390, 129586, 83580, 83518, 128116, 83838, 128114, 125172, 125170, 119284, 119282, 107508, 107506, 82672, 106876, 82552, 106814, 82492, 82462, 129562, 82812, 82750, 128058, 125050, 119034, 82296, 106686, 82236, 82206, 82366, 82108, 82078, 76736, 103920, 117500, 76256, 103672, 117374, 76016, 103548, 75896, 103486, 75836, 129384, 77296, 104188, 129380, 77048, 104062, 129378, 76924, 76862, 127720, 129398, 77564, 127716, 77438, 127714, 124392, 127734, 124388, 124386, 117736, 124406, 117732, 117730, 104424, 117750, 104420, 104418, 112096, 121592, 126334, 92608, 111856, 121468, 92384, 111736, 121406, 92272, 111676, 92216, 111646, 92188, 75232, 103160, 117118, 93664, 74992, 103036, 93424, 112252, 102974, 93304, 74812, 93244, 74782, 93214, 129332, 75512, 103294, 129908, 129330, 93944, 75388, 129906, 93820, 75326, 93758, 127604, 75646, 128756, 127602, 94078, 128754, 124148, 126452, 124146, 126450, 117236, 121844, 117234, 121842, 103412, 103410, 91584, 111344, 121212, 91360, 111224, 121150, 91248, 111164, 91192, 111134, 91164, 91150, 74480, 102780, 91888, 74360, 102718, 91768, 111422, 91708, 74270, 91678, 129306, 74620, 129850, 92028, 74558, 91966, 127546, 128634, 124026, 126202, 116986, 121338, 102906, 90848, 110968, 121022, 90736, 110908, 90680, 110878, 90652, 90638, 74104, 102590, 91000, 74044, 90940, 74014, 90910, 74174, 91070, 90480, 110780, 90424, 110750, 90396, 90382, 73916, 90556, 73886, 90526, 90296, 110686, 90268, 90254, 73822, 90334, 90204, 90190, 71136, 101112, 116094, 70896, 100988, 70776, 100926, 70716, 70686, 129204, 71416, 101246, 129202, 71292, 71230, 127348, 71550, 127346, 123636, 123634, 116212, 116210, 101364, 101362, 79296, 105200, 118140, 79072, 105080, 118078, 78960, 105020, 78904, 104990, 78876, 78862, 70384, 100732, 79600, 70264, 100670, 79480, 105278, 79420, 70174, 79390, 129178, 70524, 129466, 79740, 70462, 79678, 127290, 127866, 123514, 124666, 115962, 118266, 100858, 113376, 122232, 126654, 95424, 113264, 122172, 95328, 113208, 122142, 95280, 113180, 95256, 113166, 95244, 78560, 104824, 117950, 95968, 78448, 104764, 95856, 113468, 104734, 95800, 78364, 95772, 78350, 95758, 70008, 100542, 78712, 69948, 96120, 78652, 69918, 96060, 78622, 96030, 70078, 78782, 96190, 94912, 113008, 122044, 94816, 112952, 122014, 94768, 112924, 94744, 112910, 94732, 94726, 78192, 104636, 95088, 78136, 104606, 95032, 113054, 95004, 78094, 94990, 69820, 78268, 69790, 95164, 78238, 95134, 94560, 112824, 121950, 94512, 112796, 94488, 112782, 94476, 94470, 78008, 104542, 94648, 77980, 94620, 77966, 94606, 69726, 78046, 94686, 94384, 112732, 94360, 112718, 94348, 94342, 77916, 94428, 77902, 94414, 94296, 112686, 94284, 94278, 77870, 94318, 94252, 94246, 68336, 99708, 68216, 99646, 68156, 68126, 68476, 68414, 127162, 123258, 115450, 99834, 72416, 101752, 116414, 72304, 101692, 72248, 101662, 72220, 72206, 67960, 99518, 72568, 67900, 72508, 67870, 72478, 68030, 72638, 80576, 105840, 118460, 80480, 105784, 118430, 80432, 105756, 80408, 105742, 80396, 80390, 72048, 101564, 80752, 71992, 101534, 80696, 71964, 80668, 71950, 80654, 67772, 72124, 67742, 80828, 72094, 80798, 114016, 122552, 126814, 96832, 113968, 122524, 96800, 113944, 122510, 96784, 113932, 96776, 113926, 96772, 80224, 105656, 118366, 97120, 80176, 105628, 97072, 114076, 105614, 97048, 80140, 97036, 80134, 97030, 71864, 101470, 80312, 71836, 97208, 80284, 71822, 97180, 80270, 97166, 67678, 71902, 80350, 97246, 96576, 113840, 122460, 96544, 113816, 122446, 96528, 113804, 96520, 113798, 96516, 96514, 80048, 105564, 96688, 80024, 105550, 96664, 113870, 96652, 80006, 96646, 71772, 80092, 71758, 96732, 80078, 96718, 96416, 113752, 122414, 96400, 113740, 96392, 113734, 96388, 96386, 79960, 105518, 96472, 79948, 96460, 79942, 96454, 71726, 79982, 96494, 96336, 113708, 96328, 113702, 96324, 96322, 79916, 96364, 79910, 96358, 96296, 113686, 96292, 96290, 79894, 96310, 66936, 99006, 66876, 66846, 67006, 68976, 100028, 68920, 99998, 68892, 68878, 66748, 69052, 66718, 69022, 73056, 102072, 116574, 73008, 102044, 72984, 102030, 72972, 72966, 68792, 99934, 73144, 68764, 73116, 68750, 73102, 66654, 68830, 73182, 81216, 106160, 118620, 81184, 106136, 118606, 81168, 106124, 81160, 106118, 81156, 81154, 72880, 101980, 81328, 72856, 101966, 81304, 106190, 81292, 72838, 81286, 68700, 72924, 68686, 81372, 72910, 81358, 114336, 122712, 126894, 114320, 122700, 114312, 122694, 114308, 114306, 81056, 106072, 118574, 97696, 81040, 106060, 97680, 114380, 106054, 97672, 81028, 97668, 81026, 97666, 72792, 101934, 81112, 72780, 97752, 81100, 72774, 97740, 81094, 97734, 68654, 72814, 81134, 97774, 114256, 122668, 114248, 122662, 114244, 114242, 80976, 106028, 97488, 80968, 106022, 97480, 114278, 97476, 80962, 97474, 72748, 81004, 72742, 97516, 80998, 97510, 114216, 122646, 114212, 114210, 80936, 106006, 97384, 80932, 97380, 80930, 97378, 72726, 80950, 97398, 114196, 114194, 80916, 97332, 80914, 97330, 66236, 66206, 67256, 99166, 67228, 67214, 66142, 67294, 69296, 100188, 69272, 100174, 69260, 69254, 67164, 69340, 67150, 69326, 73376, 102232, 116654, 73360, 102220, 73352, 102214, 73348, 73346, 69208, 100142, 73432, 102254, 73420, 69190, 73414, 67118, 69230, 73454, 106320, 118700, 106312, 118694, 106308, 106306, 73296, 102188, 81616, 106348, 102182, 81608, 73284, 81604, 73282, 81602, 69164, 73324, 69158, 81644, 73318, 81638, 122792, 126934, 122788, 122786, 106280, 118678, 114536, 106276, 114532, 106274, 114530, 73256, 102166, 81512, 73252, 98024, 81508, 73250, 98020, 81506, 98018, 69142, 73270, 81526, 98038, 122772, 122770, 106260, 114484, 106258, 114482, 73236, 81460, 73234, 97908, 81458, 97906, 122762, 106250, 114458, 73226, 81434, 97850, 66396, 66382, 67416, 99246, 67404, 67398, 66350, 67438, 69456, 100268, 69448, 100262, 69444, 69442, 67372, 69484, 67366, 69478, 102312, 116694, 102308, 102306, 69416, 100246, 73576, 102326, 73572, 69410, 73570, 67350, 69430, 73590, 118740, 118738, 102292, 106420, 102290, 106418, 69396, 73524, 69394, 81780, 73522, 81778, 118730, 102282, 106394, 69386, 73498, 81722, 66476, 66470, 67496, 99286, 67492, 67490, 66454, 67510, 100308, 100306, 67476, 69556, 67474, 69554, 116714])]); //#16844
    $1.cwtobits = function() {
        var _FA = $get($1.clusters, $k[--$j]); //#16849
        $1.v = $get(_FA, $k[--$j]); //#16849
        $k[$j++] = Infinity; //#16850
        for (var _FD = 0, _FE = 17; _FD < _FE; _FD++) { //#16850
            $k[$j++] = 0; //#16850
        } //#16850
        var _FH = $cvrs($s(17), $1.v, 2); //#16850
        for (var _FI = 0, _FJ = _FH.length; _FI < _FJ; _FI++) { //#16850
            $k[$j++] = $get(_FH, _FI) - 48; //#16850
        } //#16850
        var _FL = $a(); //#16850
        $k[$j++] = $geti(_FL, _FL.length - 17, 17); //#16851
    }; //#16851
    if ($1.compact) { //#16858
        $1.rwid = $f(($f(($f((17 * $1.c) + 17)) + 17)) + 1); //#16856
    } else { //#16858
        $1.rwid = $f(($f(($f(($f((17 * $1.c) + 17)) + 17)) + 17)) + 18); //#16858
    } //#16858
    $1.pixs = $a($1.rwid * $1.r); //#16860
    for (var _FV = 0, _FU = $1.r - 1; _FV <= _FU; _FV += 1) { //#16890
        $1.i = _FV; //#16863
        if (($1.i % 3) == 0) { //#16868
            $1.lcw = ((~~($1.i / 3)) * 30) + (~~(($1.r - 1) / 3)); //#16866
            $1.rcw = $f(($f(((~~($1.i / 3)) * 30) + $1.c)) - 1); //#16867
        } //#16867
        if (($1.i % 3) == 1) { //#16872
            $1.lcw = (((~~($1.i / 3)) * 30) + ($1.eclevel * 3)) + (($1.r - 1) % 3); //#16870
            $1.rcw = ((~~($1.i / 3)) * 30) + (~~(($1.r - 1) / 3)); //#16871
        } //#16871
        if (($1.i % 3) == 2) { //#16876
            $1.lcw = $f(($f(((~~($1.i / 3)) * 30) + $1.c)) - 1); //#16874
            $1.rcw = (((~~($1.i / 3)) * 30) + ($1.eclevel * 3)) + (($1.r - 1) % 3); //#16875
        } //#16875
        $k[$j++] = $1.pixs; //#16886
        $k[$j++] = $1.rwid * $1.i; //#16886
        $k[$j++] = Infinity; //#16886
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = 1; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = 0; //#16880
        $k[$j++] = $1.lcw; //#16880
        $k[$j++] = $1.i % 3; //#16880
        $1.cwtobits(); //#16880
        $forall($k[--$j]); //#16880
        var _Fx = $geti($1.cws, $1.c * $1.i, $1.c); //#16881
        for (var _Fy = 0, _Fz = _Fx.length; _Fy < _Fz; _Fy++) { //#16881
            $k[$j++] = $get(_Fx, _Fy); //#16881
            $k[$j++] = $1.i % 3; //#16881
            $1.cwtobits(); //#16881
            $forall($k[--$j]); //#16881
        } //#16881
        if ($1.compact) { //#16886
            $k[$j++] = 1; //#16883
        } else { //#16886
            $k[$j++] = $1.rcw; //#16885
            $k[$j++] = $1.i % 3; //#16885
            $1.cwtobits(); //#16885
            $forall($k[--$j]); //#16885
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 1; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 0; //#16886
            $k[$j++] = 1; //#16886
        } //#16886
        var _G7 = $a(); //#16886
        var _G8 = $k[--$j]; //#16888
        $puti($k[--$j], _G8, _G7); //#16888
    } //#16888
    var _GH = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.rwid],
        ["pixy", $1.r],
        ["height", ($1.r / 72) * $1.rowmult],
        ["width", $1.rwid / 72],
        ["opt", $1.options]
    ]); //#16900
    $k[$j++] = _GH; //#16903
    if (!$1.dontdraw) { //#16903
        bwipp_renmatrix(); //#16903
    } //#16903
}

function bwipp_pdf417compact() {
    var $1 = {}; //#16936
    $1.ctx = null; //#16938
    $1.dontdraw = false; //#16939
    $k[$j++] = $1; //#16941
    bwipp_processoptions(); //#16941
    $1.options = $k[--$j]; //#16941
    $1.barcode = $k[--$j]; //#16942
    $put($1.options, "dontdraw", true); //#16945
    $put($1.options, "compact", true); //#16946
    $k[$j++] = 'args'; //#16948
    $k[$j++] = $1.barcode; //#16948
    $k[$j++] = $1.options; //#16948
    bwipp_pdf417(); //#16948
    var _6 = $k[--$j]; //#16948
    $1[$k[--$j]] = _6; //#16948
    $put($1.args, "opt", $1.options); //#16950
    $k[$j++] = $1.args; //#16953
    if (!$1.dontdraw) { //#16953
        bwipp_renmatrix(); //#16953
    } //#16953
}

function bwipp_micropdf417() {
    var $1 = {}; //#16986
    $1.ctx = null; //#16988
    $1.dontdraw = false; //#16989
    $1.version = "unset"; //#16990
    $1.columns = 0; //#16991
    $1.rows = 0; //#16992
    $1.rowmult = 2; //#16993
    $1.encoding = "auto"; //#16994
    $1.cca = false; //#16995
    $1.ccb = false; //#16996
    $1.raw = false; //#16997
    $1.parse = false; //#16998
    $1.parsefnc = false; //#16999
    $k[$j++] = $1; //#17001
    bwipp_processoptions(); //#17001
    $1.options = $k[--$j]; //#17001
    $1.barcode = $k[--$j]; //#17002
    if ($ne($1.version, "unset")) { //#17008
        $search($1.version, "x"); //#17005
        $j--; //#17006
        $1.columns = $cvi($k[--$j]); //#17006
        $j--; //#17007
        $1.rows = $cvi($k[--$j]); //#17007
    } //#17007
    $1.T = 0; //#17014
    $1.N = 1; //#17014
    $1.B = 2; //#17014
    $1.A = 0; //#17015
    $1.L = 1; //#17015
    $1.M = 2; //#17015
    $1.P = 3; //#17015
    $1.tl = -1; //#17018
    $1.nl = -2; //#17018
    $1.bl = -3; //#17018
    $1.bl6 = -4; //#17018
    $1.bs = -5; //#17018
    $1.al = -6; //#17021
    $1.ll = -7; //#17021
    $1.ml = -8; //#17021
    $1.pl = -9; //#17021
    $1.as = -10; //#17021
    $1.ps = -11; //#17021
    $1.charmaps = $a([$a(["A", "a", "0", ";"]), $a(["B", "b", "1", "<"]), $a(["C", "c", "2", ">"]), $a(["D", "d", "3", "@"]), $a(["E", "e", "4", "["]), $a(["F", "f", "5", 92]), $a(["G", "g", "6", "]"]), $a(["H", "h", "7", "_"]), $a(["I", "i", "8", "`"]), $a(["J", "j", "9", "~"]), $a(["K", "k", "&", "!"]), $a(["L", "l", 13, 13]), $a(["M", "m", 9, 9]), $a(["N", "n", ",", ","]), $a(["O", "o", ":", ":"]), $a(["P", "p", "#", 10]), $a(["Q", "q", "-", "-"]), $a(["R", "r", ".", "."]), $a(["S", "s", "$", "$"]), $a(["T", "t", "/", "/"]), $a(["U", "u", "+", "\""]), $a(["V", "v", "%", "|"]), $a(["W", "w", "*", "*"]), $a(["X", "x", "=", 40]), $a(["Y", "y", "^", 41]), $a(["Z", "z", $1.pl, "?"]), $a([" ", " ", " ", "{"]), $a([$1.ll, $1.as, $1.ll, "}"]), $a([$1.ml, $1.ml, $1.al, "'"]), $a([$1.ps, $1.ps, $1.ps, $1.al])]); //#17056
    $1.charvals = $a([new Map, new Map, new Map, new Map]); //#17059
    $1.alltext = new Map; //#17060
    for (var _p = 0, _o = $1.charmaps.length - 1; _p <= _o; _p += 1) { //#17070
        $1.i = _p; //#17062
        $1.encs = $get($1.charmaps, $1.i); //#17063
        for (var _t = 0; _t <= 3; _t += 1) { //#17069
            $1.j = _t; //#17065
            var _w = $get($1.encs, $1.j); //#17066
            $k[$j++] = _w; //#17066
            if ($eq($type(_w), 'stringtype')) { //#17066
                var _z = $get($k[--$j], 0); //#17066
                $k[$j++] = _z; //#17066
            } //#17066
            var _10 = $k[--$j]; //#17067
            $put($get($1.charvals, $1.j), _10, $1.i); //#17067
            $put($1.alltext, _10, -1); //#17068
        } //#17068
    } //#17068
    $1.e = 10000; //#17072
    $1.latlen = $a([$a([0, 1, 1, 2]), $a([2, 0, 1, 2]), $a([1, 1, 0, 1]), $a([1, 2, 2, 0])]); //#17080
    $1.latseq = $a([$a([$a([]), $a([$1.ll]), $a([$1.ml]), $a([$1.ml, $1.pl])]), $a([$a([$1.ml, $1.al]), $a([]), $a([$1.ml]), $a([$1.ml, $1.pl])]), $a([$a([$1.al]), $a([$1.ll]), $a([]), $a([$1.pl])]), $a([$a([$1.al]), $a([$1.al, $1.ll]), $a([$1.al, $1.ml]), $a([])])]); //#17088
    $1.shftlen = $a([$a([$1.e, $1.e, $1.e, 1]), $a([1, $1.e, $1.e, 1]), $a([$1.e, $1.e, $1.e, 1]), $a([$1.e, $1.e, $1.e, $1.e])]); //#17096
    if ($1.raw) { //#17099
        $1.encoding = "raw"; //#17099
    } //#17099
    if ($1.cca) { //#17100
        $1.encoding = "cca"; //#17100
    } //#17100
    if ($eq($1.encoding, "raw") || $eq($1.encoding, "cca")) { //#17114
        $1.datcws = $a($1.barcode.length); //#17104
        $1.i = 0; //#17105
        $1.j = 0; //#17105
        for (;;) { //#17112
            if ($1.i == $1.barcode.length) { //#17107
                break; //#17107
            } //#17107
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#17108
            $put($1.datcws, $1.j, $1.cw); //#17109
            $1.i = $1.i + 4; //#17110
            $1.j = $1.j + 1; //#17111
        } //#17111
        $1.datcws = $geti($1.datcws, 0, $1.j); //#17113
    } //#17113
    if ($1.ccb) { //#17116
        $1.encoding = "ccb"; //#17116
    } //#17116
    $1.encb = function() {
        $1.in = $k[--$j]; //#17119
        $1.inlen = $1.in.length; //#17120
        $1.out = $a(((~~($1.inlen / 6)) * 5) + ($1.inlen % 6)); //#17121
        for (var _2V = 0, _2U = (~~($1.inlen / 6)) - 1; _2V <= _2U; _2V += 1) { //#17144
            $1.k = _2V; //#17123
            $k[$j++] = Infinity; //#17124
            $aload($geti($1.in, $1.k * 6, 3)); //#17124
            $1.msbs = $a(); //#17124
            $k[$j++] = Infinity; //#17127
            $aload($1.msbs); //#17126
            var _2b = $k[--$j]; //#17126
            var _2c = $k[--$j]; //#17126
            var _2d = $k[--$j]; //#17126
            $k[$j++] = $f(($f(_2b + (_2c * 256))) + (_2d * 65536)); //#17127
            for (var _2e = 0, _2f = 3; _2e < _2f; _2e++) { //#17127
                var _2g = $k[--$j]; //#17127
                $k[$j++] = _2g % 900; //#17127
                $k[$j++] = ~~(_2g / 900); //#17127
            } //#17127
            $1.mscs = $a(); //#17127
            $k[$j++] = Infinity; //#17129
            $aload($geti($1.in, ($1.k * 6) + 3, 3)); //#17129
            $1.lsbs = $a(); //#17129
            $k[$j++] = Infinity; //#17132
            $aload($1.lsbs); //#17131
            var _2n = $k[--$j]; //#17131
            var _2o = $k[--$j]; //#17131
            var _2p = $k[--$j]; //#17131
            $k[$j++] = $f(($f(_2n + (_2o * 256))) + (_2p * 65536)); //#17132
            for (var _2q = 0, _2r = 3; _2q < _2r; _2q++) { //#17132
                var _2s = $k[--$j]; //#17132
                $k[$j++] = _2s % 900; //#17132
                $k[$j++] = ~~(_2s / 900); //#17132
            } //#17132
            $1.lscs = $a(); //#17132
            var _2v = $get($1.lscs, 0); //#17134
            var _2x = $get($1.mscs, 0); //#17134
            $put($1.out, ($1.k * 5) + 4, ($f(_2v + (_2x * 316))) % 900); //#17135
            var _31 = $get($1.lscs, 1); //#17136
            var _33 = $get($1.mscs, 0); //#17136
            var _35 = $get($1.mscs, 1); //#17136
            $put($1.out, ($1.k * 5) + 3, ($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) % 900); //#17137
            var _39 = $get($1.lscs, 2); //#17138
            var _3B = $get($1.mscs, 0); //#17138
            var _3D = $get($1.mscs, 1); //#17138
            var _3F = $get($1.mscs, 2); //#17138
            $put($1.out, ($1.k * 5) + 2, ($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) % 900); //#17139
            var _3J = $get($1.lscs, 3); //#17140
            var _3L = $get($1.mscs, 1); //#17140
            var _3N = $get($1.mscs, 2); //#17140
            $put($1.out, ($1.k * 5) + 1, ($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) / 900)) + _3J)) + (_3L * 20))) + (_3N * 641))) % 900); //#17141
            $put($1.out, $1.k * 5, ($f((~~(($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_2v + (_2x * 316))) / 900)) + _31)) + (_33 * 641))) + (_35 * 316))) / 900)) + _39)) + (_3B * 20))) + (_3D * 641))) + (_3F * 316))) / 900)) + _3J)) + (_3L * 20))) + (_3N * 641))) / 900)) + ($get($1.mscs, 2) * 20))) % 900); //#17143
        } //#17143
        $1.rem = $1.inlen % 6; //#17145
        if ($1.rem != 0) { //#17150
            $k[$j++] = $1.out; //#17148
            $k[$j++] = $1.out.length - $1.rem; //#17148
            $k[$j++] = Infinity; //#17148
            $aload($geti($1.in, $1.inlen - $1.rem, $1.rem)); //#17148
            var _3e = $a(); //#17148
            var _3f = $k[--$j]; //#17149
            $puti($k[--$j], _3f, _3e); //#17149
        } //#17149
        $k[$j++] = $1.out; //#17151
    }; //#17151
    if ($eq($1.encoding, "byte") || $eq($1.encoding, "ccb")) { //#17160
        $1.barlen = $1.barcode.length; //#17155
        $1.datcws = $a((((~~($1.barlen / 6)) * 5) + ($1.barlen % 6)) + 1); //#17156
        var _3q = (($1.barlen % 6) == 0) ? 924 : 901; //#17157
        $put($1.datcws, 0, _3q); //#17157
        $k[$j++] = $1.datcws; //#17158
        $k[$j++] = 1; //#17158
        $k[$j++] = Infinity; //#17158
        $forall($1.barcode); //#17158
        var _3t = $a(); //#17158
        $k[$j++] = _3t; //#17158
        $1.encb(); //#17158
        var _3u = $k[--$j]; //#17158
        var _3v = $k[--$j]; //#17158
        $puti($k[--$j], _3v, _3u); //#17158
        if ($eq($1.encoding, "ccb")) { //#17159
            $k[$j++] = Infinity; //#17159
            $k[$j++] = 920; //#17159
            $aload($1.datcws); //#17159
            $1.datcws = $a(); //#17159
        } //#17159
    } //#17159
    if ($eq($1.encoding, "auto")) { //#17479
        var _43 = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["eci", true]
        ]); //#17168
        $1.fncvals = _43; //#17170
        $k[$j++] = 'msg'; //#17171
        $k[$j++] = $1.barcode; //#17171
        $k[$j++] = $1.fncvals; //#17171
        bwipp_parseinput(); //#17171
        var _46 = $k[--$j]; //#17171
        $1[$k[--$j]] = _46; //#17171
        $1.msglen = $1.msg.length; //#17172
        $k[$j++] = Infinity; //#17175
        for (var _4A = 0, _4B = $1.msglen; _4A < _4B; _4A++) { //#17175
            $k[$j++] = 0; //#17175
        } //#17175
        $k[$j++] = 0; //#17175
        $1.numdigits = $a(); //#17175
        $k[$j++] = Infinity; //#17176
        for (var _4E = 0, _4F = $1.msglen; _4E < _4F; _4E++) { //#17176
            $k[$j++] = 0; //#17176
        } //#17176
        $k[$j++] = 0; //#17176
        $1.numtext = $a(); //#17176
        $k[$j++] = Infinity; //#17177
        for (var _4I = 0, _4J = $1.msglen; _4I < _4J; _4I++) { //#17177
            $k[$j++] = 0; //#17177
        } //#17177
        $k[$j++] = 0; //#17177
        $1.numbytes = $a(); //#17177
        $k[$j++] = Infinity; //#17178
        for (var _4M = 0, _4N = $1.msglen; _4M < _4N; _4M++) { //#17178
            $k[$j++] = 0; //#17178
        } //#17178
        $1.iseci = $a(); //#17178
        for (var _4Q = $1.msglen - 1; _4Q >= 0; _4Q -= 1) { //#17191
            $1.i = _4Q; //#17180
            var _4T = $get($1.msg, $1.i); //#17181
            if ((_4T >= 48) && (_4T <= 57)) { //#17183
                $put($1.numdigits, $1.i, $f($get($1.numdigits, $1.i + 1) + 1)); //#17182
            } //#17182
            var _4d = $get($1.alltext, $get($1.msg, $1.i)) !== undefined; //#17184
            if (_4d && ($get($1.numdigits, $1.i) < 13)) { //#17186
                $put($1.numtext, $1.i, $f($get($1.numtext, $1.i + 1) + 1)); //#17185
            } //#17185
            if ((($get($1.msg, $1.i) >= 0) && ($get($1.numtext, $1.i) < 5)) && ($get($1.numdigits, $1.i) < 13)) { //#17189
                $put($1.numbytes, $1.i, $f($get($1.numbytes, $1.i + 1) + 1)); //#17188
            } //#17188
            $put($1.iseci, $1.i, $get($1.msg, $1.i) <= -1000000); //#17190
        } //#17190
        $1.numdigits = $geti($1.numdigits, 0, $1.msglen); //#17192
        $1.numtext = $geti($1.numtext, 0, $1.msglen); //#17193
        $1.numbytes = $geti($1.numbytes, 0, $1.msglen); //#17194
        $1.seq = $a([]); //#17196
        $1.seqlen = 0; //#17196
        $1.state = $1.B; //#17196
        $1.p = 0; //#17196
        for (;;) { //#17250
            if ($1.p == $1.msglen) { //#17197
                break; //#17197
            } //#17197
            if ($get($1.iseci, $1.p)) { //#17248
                $1.eci = $get($1.msg, $1.p); //#17199
                $k[$j++] = Infinity; //#17202
                $aload($1.seq); //#17201
                $k[$j++] = $a([$1.eci]); //#17202
                $1.seq = $a(); //#17202
                $1.p = $1.p + 1; //#17204
                $k[$j++] = 'seqlen'; //#17205
                $k[$j++] = $1.seqlen; //#17205
                if ($1.eci <= -1810900) { //#17205
                    $k[$j++] = 2; //#17205
                } else { //#17205
                    var _5W = ($1.eci <= -1000900) ? 3 : 2; //#17205
                    $k[$j++] = _5W; //#17205
                } //#17205
                var _5X = $k[--$j]; //#17205
                var _5Y = $k[--$j]; //#17205
                $1[$k[--$j]] = $f(_5Y + _5X); //#17205
            } else { //#17248
                $1.n = $get($1.numdigits, $1.p); //#17207
                if ($1.n >= 13) { //#17248
                    $k[$j++] = Infinity; //#17212
                    $aload($1.seq); //#17210
                    $k[$j++] = $1.nl; //#17212
                    $k[$j++] = Infinity; //#17212
                    $aload($geti($1.msg, $1.p, $1.n)); //#17212
                    var _5k = $a(); //#17212
                    $k[$j++] = _5k; //#17212
                    $1.seq = $a(); //#17212
                    $1.state = $1.N; //#17214
                    $1.p = $f($1.p + $1.n); //#17215
                    $1.seqlen = $f(($1.seqlen + 1) + $1.n); //#17216
                } else { //#17248
                    $1.t = $get($1.numtext, $1.p); //#17218
                    if ($1.t >= 5) { //#17248
                        $k[$j++] = Infinity; //#17225
                        $aload($1.seq); //#17221
                        if ($1.state != $1.T) { //#17224
                            $k[$j++] = $1.tl; //#17223
                        } //#17223
                        $k[$j++] = Infinity; //#17225
                        $aload($geti($1.msg, $1.p, $1.t)); //#17225
                        var _63 = $a(); //#17225
                        $k[$j++] = _63; //#17225
                        $1.seq = $a(); //#17225
                        $1.state = $1.T; //#17227
                        $1.p = $f($1.p + $1.t); //#17228
                        $1.seqlen = $f($f($1.seqlen + 1) + $1.t); //#17229
                    } else { //#17248
                        $1.b = $get($1.numbytes, $1.p); //#17231
                        if (($1.b == 1) && ($1.state == $1.T)) { //#17248
                            $k[$j++] = Infinity; //#17236
                            $aload($1.seq); //#17234
                            $k[$j++] = $1.bs; //#17236
                            $k[$j++] = $a([$get($1.msg, $1.p)]); //#17236
                            $1.seq = $a(); //#17236
                            $1.p = $f($1.p + $1.b); //#17238
                            $1.seqlen = $f($1.seqlen + 2); //#17239
                        } else { //#17248
                            $k[$j++] = Infinity; //#17244
                            $aload($1.seq); //#17242
                            var _6S = (($1.b % 6) != 0) ? $1.bl : $1.bl6; //#17243
                            $k[$j++] = _6S; //#17244
                            $k[$j++] = Infinity; //#17244
                            $aload($geti($1.msg, $1.p, $1.b)); //#17244
                            var _6X = $a(); //#17244
                            $k[$j++] = _6X; //#17244
                            $1.seq = $a(); //#17244
                            $1.state = $1.B; //#17246
                            $1.p = $f($1.p + $1.b); //#17247
                            $1.seqlen = $f($f($1.seqlen + 1) + $1.b); //#17248
                        } //#17248
                    } //#17248
                } //#17248
            } //#17248
        } //#17248
        $k[$j++] = Infinity; //#17253
        $k[$j++] = $1.tl; //#17253
        $k[$j++] = 900; //#17253
        $k[$j++] = $1.bl; //#17253
        $k[$j++] = 901; //#17253
        $k[$j++] = $1.bl6; //#17253
        $k[$j++] = 924; //#17253
        $k[$j++] = $1.nl; //#17253
        $k[$j++] = 902; //#17253
        $k[$j++] = $1.bs; //#17253
        $k[$j++] = 913; //#17253
        $1.latchcws = $d(); //#17254
        $1.enca = function() {
            var _6o = $get($get($1.charvals, $1.A), $k[--$j]); //#17257
            $k[$j++] = _6o; //#17257
        }; //#17257
        $1.encl = function() {
            var _6t = $get($get($1.charvals, $1.L), $k[--$j]); //#17258
            $k[$j++] = _6t; //#17258
        }; //#17258
        $1.encm = function() {
            var _6y = $get($get($1.charvals, $1.M), $k[--$j]); //#17259
            $k[$j++] = _6y; //#17259
        }; //#17259
        $1.encp = function() {
            var _73 = $get($get($1.charvals, $1.P), $k[--$j]); //#17260
            $k[$j++] = _73; //#17260
        }; //#17260
        $1.textencfuncs = $a(['enca', 'encl', 'encm', 'encp']); //#17261
        $1.addtotext = function() {
            $put($1.text, $1.l, $k[--$j]); //#17264
            $1.l = $1.l + 1; //#17265
        }; //#17265
        $1.enct = function() {
            $1.in = $k[--$j]; //#17270
            $1.curlen = $a([$1.e, $1.e, $1.e, $1.e]); //#17272
            $put($1.curlen, $1.submode, 0); //#17273
            $1.curseq = $a([$a([]), $a([]), $a([]), $a([])]); //#17274
            $forall($1.in, function() { //#17344
                $1.char = $k[--$j]; //#17279
                for (;;) { //#17300
                    $1.imp = false; //#17283
                    var _7S = $a([$1.A, $1.L, $1.M, $1.P]); //#17284
                    for (var _7T = 0, _7U = _7S.length; _7T < _7U; _7T++) { //#17298
                        $1.x = $get(_7S, _7T); //#17285
                        var _7a = $a([$1.A, $1.L, $1.M, $1.P]); //#17286
                        for (var _7b = 0, _7c = _7a.length; _7b < _7c; _7b++) { //#17297
                            $1.y = $get(_7a, _7b); //#17287
                            $1.cost = $f($get($1.curlen, $1.x) + $get($get($1.latlen, $1.x), $1.y)); //#17288
                            if ($1.cost < $get($1.curlen, $1.y)) { //#17296
                                $put($1.curlen, $1.y, $1.cost); //#17290
                                $k[$j++] = $1.curseq; //#17293
                                $k[$j++] = $1.y; //#17293
                                $k[$j++] = Infinity; //#17293
                                $aload($get($1.curseq, $1.x)); //#17292
                                $aload($get($get($1.latseq, $1.x), $1.y)); //#17293
                                var _83 = $a(); //#17293
                                var _84 = $k[--$j]; //#17294
                                $put($k[--$j], _84, _83); //#17294
                                $1.imp = true; //#17295
                            } //#17295
                        } //#17295
                    } //#17295
                    if (!$1.imp) { //#17299
                        break; //#17299
                    } //#17299
                } //#17299
                $1.nxtlen = $a([$1.e, $1.e, $1.e, $1.e]); //#17303
                $1.nxtseq = $a(4); //#17304
                var _8H = $a([$1.A, $1.L, $1.M, $1.P]); //#17306
                for (var _8I = 0, _8J = _8H.length; _8I < _8J; _8I++) { //#17339
                    $1.x = $get(_8H, _8I); //#17307
                    for (;;) { //#17337
                        var _8P = $get($get($1.charvals, $1.x), $1.char) !== undefined; //#17311
                        if (!_8P) { //#17311
                            break; //#17311
                        } //#17311
                        $1.cost = $f($get($1.curlen, $1.x) + 1); //#17314
                        if ($1.cost < $get($1.nxtlen, $1.x)) { //#17318
                            $put($1.nxtlen, $1.x, $1.cost); //#17316
                            $k[$j++] = $1.nxtseq; //#17317
                            $k[$j++] = $1.x; //#17317
                            $k[$j++] = Infinity; //#17317
                            $aload($get($1.curseq, $1.x)); //#17317
                            $k[$j++] = $1.char; //#17317
                            var _8g = $a(); //#17317
                            var _8h = $k[--$j]; //#17317
                            $put($k[--$j], _8h, _8g); //#17317
                        } //#17317
                        var _8n = $a([$1.A, $1.L, $1.M, $1.P]); //#17321
                        for (var _8o = 0, _8p = _8n.length; _8o < _8p; _8o++) { //#17334
                            $1.y = $get(_8n, _8o); //#17322
                            if ($ne($1.x, $1.y)) { //#17333
                                $1.cost = $f($f($get($1.curlen, $1.y) + $get($get($1.shftlen, $1.y), $1.x)) + 1); //#17324
                                if ($1.cost < $get($1.nxtlen, $1.y)) { //#17332
                                    $put($1.nxtlen, $1.y, $1.cost); //#17326
                                    $k[$j++] = $1.nxtseq; //#17330
                                    $k[$j++] = $1.y; //#17330
                                    $k[$j++] = Infinity; //#17330
                                    $aload($get($1.curseq, $1.y)); //#17328
                                    var _9F = ($1.x == $1.A) ? $1.as : $1.ps; //#17329
                                    $k[$j++] = _9F; //#17330
                                    $k[$j++] = $1.char; //#17330
                                    var _9H = $a(); //#17330
                                    var _9I = $k[--$j]; //#17331
                                    $put($k[--$j], _9I, _9H); //#17331
                                } //#17331
                            } //#17331
                        } //#17331
                        break; //#17336
                    } //#17336
                } //#17336
                $1.curlen = $1.nxtlen; //#17341
                $1.curseq = $1.nxtseq; //#17342
            }); //#17342
            $1.minseq = $1.e; //#17347
            var _9R = $a([$1.A, $1.L, $1.M, $1.P]); //#17348
            for (var _9S = 0, _9T = _9R.length; _9S < _9T; _9S++) { //#17354
                $1.k = $get(_9R, _9S); //#17349
                if ($get($1.curlen, $1.k) < $1.minseq) { //#17353
                    $1.minseq = $get($1.curlen, $1.k); //#17351
                    $1.txtseq = $get($1.curseq, $1.k); //#17352
                } //#17352
            } //#17352
            $1.text = $a($1.minseq); //#17357
            $1.k = 0; //#17358
            $1.l = 0; //#17358
            for (;;) { //#17378
                if ($1.k >= $1.txtseq.length) { //#17359
                    break; //#17359
                } //#17359
                $1.char = $get($1.txtseq, $1.k); //#17361
                $k[$j++] = $1.char; //#17364
                if ($1[$get($1.textencfuncs, $1.submode)]() === true) {
                    break;
                } //#17364
                $1.addtotext(); //#17364
                $1.k = $1.k + 1; //#17365
                if (($1.char == $1.as) || ($1.char == $1.ps)) { //#17371
                    $k[$j++] = $get($1.txtseq, $1.k); //#17369
                    if ($1.char == $1.as) { //#17369
                        $1.enca(); //#17369
                    } else { //#17369
                        $1.encp(); //#17369
                    } //#17369
                    $1.addtotext(); //#17369
                    $1.k = $1.k + 1; //#17370
                } //#17370
                if ($1.char == $1.al) { //#17374
                    $1.submode = $1.A; //#17374
                } //#17374
                if ($1.char == $1.ll) { //#17375
                    $1.submode = $1.L; //#17375
                } //#17375
                if ($1.char == $1.ml) { //#17376
                    $1.submode = $1.M; //#17376
                } //#17376
                if ($1.char == $1.pl) { //#17377
                    $1.submode = $1.P; //#17377
                } //#17377
            } //#17377
            if (($1.text.length % 2) == 1) { //#17388
                if ($1.submode == $1.P) { //#17385
                    $k[$j++] = 'pad'; //#17382
                    $k[$j++] = $1.al; //#17382
                    $1.encp(); //#17382
                    var _AI = $k[--$j]; //#17382
                    $1[$k[--$j]] = _AI; //#17382
                    $1.submode = $1.A; //#17383
                } else { //#17385
                    $k[$j++] = 'pad'; //#17385
                    $k[$j++] = $1.ps; //#17385
                    if ($1[$get($1.textencfuncs, $1.submode)]() === true) {
                        return true;
                    } //#17385
                    var _AQ = $k[--$j]; //#17385
                    $1[$k[--$j]] = _AQ; //#17385
                } //#17385
                $k[$j++] = Infinity; //#17387
                $aload($1.text); //#17387
                $k[$j++] = $1.pad; //#17387
                $1.text = $a(); //#17387
            } //#17387
            $1.out = $a(~~($1.text.length / 2)); //#17390
            for (var _AZ = 0, _AY = $1.out.length - 1; _AZ <= _AY; _AZ += 1) { //#17394
                $1.k = _AZ; //#17392
                $put($1.out, $1.k, $f(($get($1.text, $1.k * 2) * 30) + $get($1.text, ($1.k * 2) + 1))); //#17393
            } //#17393
            $k[$j++] = $1.out; //#17396
        }; //#17396
        $1.encn = function() {
            $1.in = $k[--$j]; //#17401
            $1.out = $a([]); //#17402
            for (var _An = 0, _Am = $1.in.length - 1; _An <= _Am; _An += 44) { //#17430
                $1.k = _An; //#17404
                $k[$j++] = Infinity; //#17407
                var _As = $1.in.length - $1.k; //#17406
                $k[$j++] = 1; //#17406
                $k[$j++] = $1.in; //#17406
                $k[$j++] = $1.k; //#17406
                $k[$j++] = _As; //#17406
                if (_As > 44) { //#17406
                    $j--; //#17406
                    $k[$j++] = 44; //#17406
                } //#17406
                var _At = $k[--$j]; //#17406
                var _Au = $k[--$j]; //#17406
                var _Aw = $geti($k[--$j], _Au, _At); //#17406
                for (var _Ax = 0, _Ay = _Aw.length; _Ax < _Ay; _Ax++) { //#17407
                    $k[$j++] = $f($get(_Aw, _Ax) - 48); //#17407
                } //#17407
                $1.gmod = $a(); //#17407
                $1.cwn = $a([]); //#17409
                for (;;) { //#17428
                    $1.dv = 900; //#17410
                    $1.gmul = $a([]); //#17411
                    $1.val = 0; //#17411
                    for (;;) { //#17423
                        if ($1.gmod.length == 0) { //#17412
                            break; //#17412
                        } //#17412
                        $1.val = $f(($1.val * 10) + $get($1.gmod, 0)); //#17413
                        $1.gmod = $geti($1.gmod, 1, $1.gmod.length - 1); //#17414
                        if ($1.val < $1.dv) { //#17420
                            if ($1.gmul.length != 0) { //#17418
                                $k[$j++] = Infinity; //#17417
                                $aload($1.gmul); //#17417
                                $k[$j++] = 0; //#17417
                                $1.gmul = $a(); //#17417
                            } //#17417
                        } else { //#17420
                            $k[$j++] = Infinity; //#17420
                            $aload($1.gmul); //#17420
                            $k[$j++] = ~~($1.val / $1.dv); //#17420
                            $1.gmul = $a(); //#17420
                        } //#17420
                        $1.val = $1.val % $1.dv; //#17422
                    } //#17422
                    $1.dv = $1.val; //#17424
                    $k[$j++] = Infinity; //#17425
                    $k[$j++] = $1.dv; //#17425
                    $aload($1.cwn); //#17425
                    $1.cwn = $a(); //#17425
                    $1.gmod = $1.gmul; //#17426
                    if ($1.gmul.length == 0) { //#17427
                        break; //#17427
                    } //#17427
                } //#17427
                $k[$j++] = Infinity; //#17429
                $aload($1.out); //#17429
                $aload($1.cwn); //#17429
                $1.out = $a(); //#17429
            } //#17429
            $k[$j++] = $1.out; //#17431
        }; //#17431
        $1.ence = function() {
            var _BX = $f((-$get($k[--$j], 0)) - 1000000); //#17436
            $k[$j++] = _BX; //#17444
            if (_BX <= 899) { //#17443
                var _BY = $k[--$j]; //#17437
                $k[$j++] = 927; //#17437
                $k[$j++] = _BY; //#17437
                $astore($a(2)); //#17437
            } else { //#17443
                var _Ba = $k[--$j]; //#17438
                $k[$j++] = _Ba; //#17444
                if (_Ba <= 810899) { //#17443
                    var _Bb = $k[--$j]; //#17439
                    $k[$j++] = 926; //#17439
                    $k[$j++] = (~~(_Bb / 900)) - 1; //#17439
                    $k[$j++] = _Bb % 900; //#17439
                    $astore($a(3)); //#17439
                } else { //#17443
                    var _Bd = $k[--$j]; //#17440
                    $k[$j++] = _Bd; //#17444
                    if (_Bd <= 811799) { //#17443
                        var _Be = $k[--$j]; //#17441
                        $k[$j++] = 925; //#17441
                        $k[$j++] = $f(_Be - 810900); //#17441
                        $astore($a(2)); //#17441
                    } else { //#17443
                        $k[$j++] = 'bwipp.pdf417badECI'; //#17443
                        $k[$j++] = "PDF417 supports ECIs 000000 to 811799"; //#17443
                        bwipp_raiseerror(); //#17443
                    } //#17443
                } //#17443
            } //#17443
        }; //#17443
        $1.encfuncs = $a(['enct', 'encn', 'encb']); //#17447
        $1.addtocws = function() {
            var _Bh = $k[--$j]; //#17450
            $puti($1.datcws, $1.j, _Bh); //#17450
            $1.j = _Bh.length + $1.j; //#17451
        }; //#17451
        $1.datcws = $a($1.seqlen); //#17456
        $1.i = 0; //#17457
        $1.j = 0; //#17457
        for (;;) { //#17477
            if ($1.i >= $1.seq.length) { //#17458
                break; //#17458
            } //#17458
            $1.chars = $get($1.seq, $1.i); //#17459
            if ($eq($type($1.chars), 'arraytype')) { //#17473
                if ($get($1.chars, 0) <= -1000000) { //#17464
                    $k[$j++] = $1.chars; //#17462
                    $1.ence(); //#17462
                    $1.addtocws(); //#17462
                } else { //#17464
                    $k[$j++] = $1.chars; //#17464
                    if ($1[$get($1.encfuncs, $1.state)]() === true) {
                        break;
                    } //#17464
                    $1.addtocws(); //#17464
                } //#17464
            } else { //#17473
                $k[$j++] = $a([$get($1.latchcws, $1.chars)]); //#17467
                $1.addtocws(); //#17467
                if ($1.chars == $1.tl) { //#17468
                    $1.state = $1.T; //#17468
                    $1.submode = $1.A; //#17468
                } //#17468
                if ($1.chars == $1.nl) { //#17469
                    $1.state = $1.N; //#17469
                } //#17469
                if (($1.chars == $1.bl) || ($1.chars == $1.bl6)) { //#17470
                    $1.state = $1.B; //#17470
                } //#17470
                if ($1.chars == $1.bs) { //#17474
                    $1.i = $1.i + 1; //#17472
                    $k[$j++] = $get($1.seq, $1.i); //#17473
                    $1.encb(); //#17473
                    $1.addtocws(); //#17473
                } //#17473
            } //#17473
            $1.i = $1.i + 1; //#17476
        } //#17476
        $1.datcws = $geti($1.datcws, 0, $1.j); //#17478
    } //#17478
    $1.ccametrics = $a([$a([2, 5, 4, 39, 0, 19]), $a([2, 6, 4, 1, 0, 33]), $a([2, 7, 5, 32, 0, 12]), $a([2, 8, 5, 8, 0, 40]), $a([2, 9, 6, 14, 0, 46]), $a([2, 10, 6, 43, 0, 23]), $a([2, 12, 7, 20, 0, 52]), $a([3, 4, 4, 11, 43, 23]), $a([3, 5, 5, 1, 33, 13]), $a([3, 6, 6, 5, 37, 17]), $a([3, 7, 7, 15, 47, 27]), $a([3, 8, 7, 21, 1, 33]), $a([4, 3, 4, 40, 20, 52]), $a([4, 4, 5, 43, 23, 3]), $a([4, 5, 6, 46, 26, 6]), $a([4, 6, 7, 34, 14, 46]), $a([4, 7, 8, 29, 9, 41])]); //#17502
    $1.nonccametrics = $a([$a([1, 11, 7, 1, 0, 9]), $a([1, 14, 7, 8, 0, 8]), $a([1, 17, 7, 36, 0, 36]), $a([1, 20, 8, 19, 0, 19]), $a([1, 24, 8, 9, 0, 17]), $a([1, 28, 8, 25, 0, 33]), $a([2, 8, 8, 1, 0, 1]), $a([2, 11, 9, 1, 0, 9]), $a([2, 14, 9, 8, 0, 8]), $a([2, 17, 10, 36, 0, 36]), $a([2, 20, 11, 19, 0, 19]), $a([2, 23, 13, 9, 0, 17]), $a([2, 26, 15, 27, 0, 35]), $a([3, 6, 12, 1, 1, 1]), $a([3, 8, 14, 7, 7, 7]), $a([3, 10, 16, 15, 15, 15]), $a([3, 12, 18, 25, 25, 25]), $a([3, 15, 21, 37, 37, 37]), $a([3, 20, 26, 1, 17, 33]), $a([3, 26, 32, 1, 9, 17]), $a([3, 32, 38, 21, 29, 37]), $a([3, 38, 44, 15, 31, 47]), $a([3, 44, 50, 1, 25, 49]), $a([4, 4, 8, 47, 19, 43]), $a([4, 6, 12, 1, 1, 1]), $a([4, 8, 14, 7, 7, 7]), $a([4, 10, 16, 15, 15, 15]), $a([4, 12, 18, 25, 25, 25]), $a([4, 15, 21, 37, 37, 37]), $a([4, 20, 26, 1, 17, 33]), $a([4, 26, 32, 1, 9, 17]), $a([4, 32, 38, 21, 29, 37]), $a([4, 38, 44, 15, 31, 47]), $a([4, 44, 50, 1, 25, 49])]); //#17541
    $k[$j++] = 'metrics'; //#17544
    if ($1.cca) { //#17544
        $k[$j++] = $1.ccametrics; //#17544
    } else { //#17544
        $k[$j++] = $1.nonccametrics; //#17544
    } //#17544
    var _DM = $k[--$j]; //#17544
    $1[$k[--$j]] = _DM; //#17544
    $1.urows = $1.rows; //#17547
    $1.ucols = $1.columns; //#17548
    $1.i = 0; //#17549
    for (;;) { //#17565
        $1.m = $get($1.metrics, $1.i); //#17551
        $1.c = $get($1.m, 0); //#17552
        $1.r = $get($1.m, 1); //#17553
        $1.k = $get($1.m, 2); //#17554
        $1.rapl = $get($1.m, 3); //#17555
        $1.rapc = $get($1.m, 4); //#17556
        $1.rapr = $get($1.m, 5); //#17557
        $1.ncws = $f(($1.r * $1.c) - $1.k); //#17558
        $1.okay = true; //#17559
        if ($1.datcws.length > $1.ncws) { //#17560
            $1.okay = false; //#17560
        } //#17560
        if (($1.urows != 0) && ($1.urows != $1.r)) { //#17561
            $1.okay = false; //#17561
        } //#17561
        if (($1.ucols != 0) && ($1.ucols != $1.c)) { //#17562
            $1.okay = false; //#17562
        } //#17562
        if ($1.okay) { //#17563
            break; //#17563
        } //#17563
        $1.i = $1.i + 1; //#17564
    } //#17564
    $1.m = $1.datcws.length; //#17566
    $1.n = $f(($1.c * $1.r) - $1.k); //#17569
    $1.cws = $a($f(($1.c * $1.r) + 1)); //#17570
    $puti($1.cws, 0, $1.datcws); //#17571
    $k[$j++] = $1.cws; //#17572
    $k[$j++] = $1.m; //#17572
    $k[$j++] = Infinity; //#17572
    for (var _E5 = 0, _E6 = $f($1.n - $1.m); _E5 < _E6; _E5++) { //#17572
        $k[$j++] = 900; //#17572
    } //#17572
    var _E7 = $a(); //#17572
    var _E8 = $k[--$j]; //#17572
    $puti($k[--$j], _E8, _E7); //#17572
    $k[$j++] = $1.cws; //#17573
    $k[$j++] = $1.n; //#17573
    $k[$j++] = Infinity; //#17573
    for (var _ED = 0, _EE = $1.k; _ED < _EE; _ED++) { //#17573
        $k[$j++] = 0; //#17573
    } //#17573
    $k[$j++] = 0; //#17573
    var _EF = $a(); //#17573
    var _EG = $k[--$j]; //#17573
    $puti($k[--$j], _EG, _EF); //#17573
    $k[$j++] = Infinity; //#17577
    $k[$j++] = 1; //#17577
    for (var _EI = 0, _EJ = 928; _EI < _EJ; _EI++) { //#17577
        var _EK = $k[--$j]; //#17577
        $k[$j++] = _EK; //#17577
        $k[$j++] = (_EK * 3) % 929; //#17577
    } //#17577
    $1.rsalog = $a(); //#17577
    $1.rslog = $a(929); //#17578
    for (var _EN = 1; _EN <= 928; _EN += 1) { //#17579
        $put($1.rslog, $get($1.rsalog, _EN), _EN); //#17579
    } //#17579
    $1.rsprod = function() {
        var _ER = $k[--$j]; //#17584
        var _ES = $k[--$j]; //#17584
        $k[$j++] = _ES; //#17588
        $k[$j++] = _ER; //#17588
        if ((_ER != 0) && (_ES != 0)) { //#17587
            var _EV = $get($1.rslog, $k[--$j]); //#17585
            var _Ea = $get($1.rsalog, $f(_EV + $get($1.rslog, $k[--$j])) % 928); //#17585
            $k[$j++] = _Ea; //#17585
        } else { //#17587
            $j -= 2; //#17587
            $k[$j++] = 0; //#17587
        } //#17587
    }; //#17587
    $k[$j++] = Infinity; //#17592
    $k[$j++] = 1; //#17592
    for (var _Ec = 0, _Ed = $1.k; _Ec < _Ed; _Ec++) { //#17592
        $k[$j++] = 0; //#17592
    } //#17592
    $1.coeffs = $a(); //#17592
    for (var _Eh = 1, _Eg = $1.k; _Eh <= _Eg; _Eh += 1) { //#17601
        $1.i = _Eh; //#17594
        $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#17595
        for (var _Eo = $1.i - 1; _Eo >= 1; _Eo -= 1) { //#17599
            $1.j = _Eo; //#17597
            $k[$j++] = $1.coeffs; //#17598
            $k[$j++] = $1.j; //#17598
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#17598
            $k[$j++] = $get($1.coeffs, $1.j); //#17598
            $k[$j++] = $get($1.rsalog, $1.i); //#17598
            $1.rsprod(); //#17598
            var _F0 = $k[--$j]; //#17598
            var _F1 = $k[--$j]; //#17598
            var _F2 = $k[--$j]; //#17598
            $put($k[--$j], _F2, $f(_F1 + _F0) % 929); //#17598
        } //#17598
        $k[$j++] = $1.coeffs; //#17600
        $k[$j++] = 0; //#17600
        $k[$j++] = $get($1.coeffs, 0); //#17600
        $k[$j++] = $get($1.rsalog, $1.i); //#17600
        $1.rsprod(); //#17600
        var _FA = $k[--$j]; //#17600
        var _FB = $k[--$j]; //#17600
        $put($k[--$j], _FB, _FA); //#17600
    } //#17600
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#17602
    for (var _FH = $1.coeffs.length - 1; _FH >= 0; _FH -= 2) { //#17603
        var _FI = $1.coeffs; //#17603
        $put(_FI, _FH, $f(929 - $get(_FI, _FH))); //#17603
    } //#17603
    for (var _FM = 0, _FL = $f($1.n - 1); _FM <= _FL; _FM += 1) { //#17612
        $1.t = $f($get($1.cws, _FM) + $get($1.cws, $1.n)) % 929; //#17607
        for (var _FU = 0, _FT = $f($1.k - 1); _FU <= _FT; _FU += 1) { //#17611
            $1.j = _FU; //#17609
            $put($1.cws, $f($1.n + $1.j), ($f($get($1.cws, $f($f($1.n + $1.j) + 1)) + ($f(929 - (($1.t * $get($1.coeffs, $f($f($1.k - $1.j) - 1))) % 929))))) % 929); //#17610
        } //#17610
    } //#17610
    for (var _Fl = $1.n, _Fk = $f($1.n + $1.k); _Fl <= _Fk; _Fl += 1) { //#17613
        $put($1.cws, _Fl, $f(929 - $get($1.cws, _Fl)) % 929); //#17613
    } //#17613
    $1.cws = $geti($1.cws, 0, $1.cws.length - 1); //#17616
    var _Ft = $get($1.options, 'debugcws') !== undefined; //#17618
    if (_Ft) { //#17618
        $k[$j++] = 'bwipp.debugcws'; //#17618
        $k[$j++] = $1.cws; //#17618
        bwipp_raiseerror(); //#17618
    } //#17618
    $1.clusters = $a([$a([120256, 125680, 128380, 120032, 125560, 128318, 108736, 119920, 108640, 86080, 108592, 86048, 110016, 120560, 125820, 109792, 120440, 125758, 88256, 109680, 88160, 89536, 110320, 120700, 89312, 110200, 120638, 89200, 110140, 89840, 110460, 89720, 110398, 89980, 128506, 119520, 125304, 128190, 107712, 119408, 125244, 107616, 119352, 84032, 107568, 119324, 84000, 107544, 83984, 108256, 119672, 125374, 85184, 108144, 119612, 85088, 108088, 119582, 85040, 108060, 85728, 108408, 119742, 85616, 108348, 85560, 108318, 85880, 108478, 85820, 85790, 107200, 119152, 125116, 107104, 119096, 125086, 83008, 107056, 119068, 82976, 107032, 82960, 82952, 83648, 107376, 119228, 83552, 107320, 119198, 83504, 107292, 83480, 83468, 83824, 107452, 83768, 107422, 83740, 83900, 106848, 118968, 125022, 82496, 106800, 118940, 82464, 106776, 118926, 82448, 106764, 82440, 106758, 82784, 106936, 119006, 82736, 106908, 82712, 106894, 82700, 82694, 106974, 82830, 82240, 106672, 118876, 82208, 106648, 118862, 82192, 106636, 82184, 106630, 82180, 82352, 82328, 82316, 82080, 118830, 106572, 106566, 82050, 117472, 124280, 127678, 103616, 117360, 124220, 103520, 117304, 124190, 75840, 103472, 75808, 104160, 117624, 124350, 76992, 104048, 117564, 76896, 103992, 76848, 76824, 77536, 104312, 117694, 77424, 104252, 77368, 77340, 77688, 104382, 77628, 77758, 121536, 126320, 128700, 121440, 126264, 128670, 111680, 121392, 126236, 111648, 121368, 126222, 111632, 121356, 103104, 117104, 124092, 112320, 103008, 117048, 124062, 112224, 121656, 126366, 93248, 74784, 102936, 117006, 93216, 112152, 93200, 75456, 103280, 117180, 93888, 75360, 103224, 117150, 93792, 112440, 121758, 93744, 75288, 93720, 75632, 103356, 94064, 75576, 103326, 94008, 112542, 93980, 75708, 94140, 75678, 94110, 121184, 126136, 128606, 111168, 121136, 126108, 111136, 121112, 126094, 111120, 121100, 111112, 111108, 102752, 116920, 123998, 111456, 102704, 116892, 91712, 74272, 121244, 116878, 91680, 74256, 102668, 91664, 111372, 102662, 74244, 74592, 102840, 116958, 92000, 74544, 102812, 91952, 111516, 102798, 91928, 74508, 74502, 74680, 102878, 92088, 74652, 92060, 74638, 92046, 92126, 110912, 121008, 126044, 110880, 120984, 126030, 110864, 120972, 110856, 120966, 110852, 110850, 74048, 102576, 116828, 90944, 74016, 102552, 116814, 90912, 111000, 121038, 90896, 73992, 102534, 90888, 110982, 90884, 74160, 102620, 91056, 74136, 102606, 91032, 111054, 91020, 74118, 91014, 91100, 91086, 110752, 120920, 125998, 110736, 120908, 110728, 120902, 110724, 110722, 73888, 102488, 116782, 90528, 73872, 102476, 90512, 110796, 102470, 90504, 73860, 90500, 73858, 73944, 90584, 90572, 90566, 120876, 120870, 110658, 102444, 73800, 90312, 90308, 90306, 101056, 116080, 123580, 100960, 116024, 70720, 100912, 115996, 70688, 100888, 70672, 70664, 71360, 101232, 116156, 71264, 101176, 116126, 71216, 101148, 71192, 71180, 71536, 101308, 71480, 101278, 71452, 71612, 71582, 118112, 124600, 127838, 105024, 118064, 124572, 104992, 118040, 124558, 104976, 118028, 104968, 118022, 100704, 115896, 123486, 105312, 100656, 115868, 79424, 70176, 118172, 115854, 79392, 105240, 100620, 79376, 70152, 79368, 70496, 100792, 115934, 79712, 70448, 118238, 79664, 105372, 100750, 79640, 70412, 79628, 70584, 100830, 79800, 70556, 79772, 70542, 70622, 79838, 122176, 126640, 128860, 122144, 126616, 128846, 122128, 126604, 122120, 126598, 122116, 104768, 117936, 124508, 113472, 104736, 126684, 124494, 113440, 122264, 126670, 113424, 104712, 117894, 113416, 122246, 104706, 69952, 100528, 115804, 78656, 69920, 100504, 115790, 96064, 78624, 104856, 117966, 96032, 113560, 122318, 100486, 96016, 78600, 104838, 96008, 69890, 70064, 100572, 78768, 70040, 100558, 96176, 78744, 104910, 96152, 113614, 70022, 78726, 70108, 78812, 70094, 96220, 78798, 122016, 126552, 128814, 122000, 126540, 121992, 126534, 121988, 121986, 104608, 117848, 124462, 113056, 104592, 126574, 113040, 122060, 117830, 113032, 104580, 113028, 104578, 113026, 69792, 100440, 115758, 78240, 69776, 100428, 95136, 78224, 104652, 100422, 95120, 113100, 69764, 95112, 78212, 69762, 78210, 69848, 100462, 78296, 69836, 95192, 78284, 69830, 95180, 78278, 69870, 95214, 121936, 126508, 121928, 126502, 121924, 121922, 104528, 117804, 112848, 104520, 117798, 112840, 121958, 112836, 104514, 112834, 69712, 100396, 78032, 69704, 100390, 94672, 78024, 104550, 94664, 112870, 69698, 94660, 78018, 94658, 78060, 94700, 94694, 126486, 121890, 117782, 104484, 104482, 69672, 77928, 94440, 69666, 77922, 99680, 68160, 99632, 68128, 99608, 115342, 68112, 99596, 68104, 99590, 68448, 99768, 115422, 68400, 99740, 68376, 99726, 68364, 68358, 68536, 99806, 68508, 68494, 68574, 101696, 116400, 123740, 101664, 116376, 101648, 116364, 101640, 116358, 101636, 67904, 99504, 115292, 72512, 67872, 116444, 115278, 72480, 101784, 116430, 72464, 67848, 99462, 72456, 101766, 67842, 68016, 99548, 72624, 67992, 99534, 72600, 101838, 72588, 67974, 68060, 72668, 68046, 72654, 118432, 124760, 127918, 118416, 124748, 118408, 124742, 118404, 118402, 101536, 116312, 105888, 101520, 116300, 105872, 118476, 116294, 105864, 101508, 105860, 101506, 105858, 67744, 99416, 72096, 67728, 116334, 80800, 72080, 101580, 99398, 80784, 105932, 67716, 80776, 72068, 67714, 72066, 67800, 99438, 72152, 67788, 80856, 72140, 67782, 80844, 72134, 67822, 72174, 80878, 126800, 128940, 126792, 128934, 126788, 126786, 118352, 124716, 122576, 126828, 124710, 122568, 126822, 122564, 118338, 122562, 101456, 116268, 105680, 101448, 116262, 114128, 105672, 118374, 114120, 122598, 101442, 114116, 105666, 114114, 67664, 99372, 71888, 67656, 99366, 80336, 71880, 101478, 97232, 80328, 105702, 67650, 97224, 114150, 71874, 97220, 67692, 71916, 67686, 80364, 71910, 97260, 80358, 97254, 126760, 128918, 126756, 126754, 118312, 124694, 122472, 126774, 122468, 118306, 122466, 101416, 116246, 105576, 101412, 113896, 105572, 101410, 113892, 105570, 113890, 67624, 99350, 71784, 101430, 80104, 71780, 67618, 96744, 80100, 71778, 96740, 80098, 96738, 71798, 96758, 126738, 122420, 122418, 105524, 113780, 113778, 71732, 79988, 96500, 96498, 66880, 66848, 98968, 66832, 66824, 66820, 66992, 66968, 66956, 66950, 67036, 67022, 100000, 99984, 115532, 99976, 115526, 99972, 99970, 66720, 98904, 69024, 100056, 98892, 69008, 100044, 69000, 100038, 68996, 66690, 68994, 66776, 98926, 69080, 100078, 69068, 66758, 69062, 66798, 69102, 116560, 116552, 116548, 116546, 99920, 102096, 116588, 115494, 102088, 116582, 102084, 99906, 102082, 66640, 68816, 66632, 98854, 73168, 68808, 66628, 73160, 68804, 66626, 73156, 68802, 66668, 68844, 66662, 73196, 68838, 73190, 124840, 124836, 124834, 116520, 118632, 124854, 118628, 116514, 118626, 99880, 115478, 101992, 116534, 106216, 101988, 99874, 106212, 101986, 106210, 66600, 98838, 68712, 99894, 72936, 68708, 66594, 81384, 72932, 68706, 81380, 72930, 66614, 68726, 72950, 81398, 128980, 128978, 124820, 126900, 124818, 126898, 116500, 118580, 116498, 122740, 118578, 122738, 99860, 101940, 99858, 106100, 101938, 114420]), $a([128352, 129720, 125504, 128304, 129692, 125472, 128280, 129678, 125456, 128268, 125448, 128262, 125444, 125792, 128440, 129758, 120384, 125744, 128412, 120352, 125720, 128398, 120336, 125708, 120328, 125702, 120324, 120672, 125880, 128478, 110144, 120624, 125852, 110112, 120600, 125838, 110096, 120588, 110088, 120582, 110084, 110432, 120760, 125918, 89664, 110384, 120732, 89632, 110360, 120718, 89616, 110348, 89608, 110342, 89952, 110520, 120798, 89904, 110492, 89880, 110478, 89868, 90040, 110558, 90012, 89998, 125248, 128176, 129628, 125216, 128152, 129614, 125200, 128140, 125192, 128134, 125188, 125186, 119616, 125360, 128220, 119584, 125336, 128206, 119568, 125324, 119560, 125318, 119556, 119554, 108352, 119728, 125404, 108320, 119704, 125390, 108304, 119692, 108296, 119686, 108292, 108290, 85824, 108464, 119772, 85792, 108440, 119758, 85776, 108428, 85768, 108422, 85764, 85936, 108508, 85912, 108494, 85900, 85894, 85980, 85966, 125088, 128088, 129582, 125072, 128076, 125064, 128070, 125060, 125058, 119200, 125144, 128110, 119184, 125132, 119176, 125126, 119172, 119170, 107424, 119256, 125166, 107408, 119244, 107400, 119238, 107396, 107394, 83872, 107480, 119278, 83856, 107468, 83848, 107462, 83844, 83842, 83928, 107502, 83916, 83910, 83950, 125008, 128044, 125000, 128038, 124996, 124994, 118992, 125036, 118984, 125030, 118980, 118978, 106960, 119020, 106952, 119014, 106948, 106946, 82896, 106988, 82888, 106982, 82884, 82882, 82924, 82918, 124968, 128022, 124964, 124962, 118888, 124982, 118884, 118882, 106728, 118902, 106724, 106722, 82408, 106742, 82404, 82402, 124948, 124946, 118836, 118834, 106612, 106610, 124224, 127664, 129372, 124192, 127640, 129358, 124176, 127628, 124168, 127622, 124164, 124162, 117568, 124336, 127708, 117536, 124312, 127694, 117520, 124300, 117512, 124294, 117508, 117506, 104256, 117680, 124380, 104224, 117656, 124366, 104208, 117644, 104200, 117638, 104196, 104194, 77632, 104368, 117724, 77600, 104344, 117710, 77584, 104332, 77576, 104326, 77572, 77744, 104412, 77720, 104398, 77708, 77702, 77788, 77774, 128672, 129880, 93168, 128656, 129868, 92664, 128648, 129862, 92412, 128644, 128642, 124064, 127576, 129326, 126368, 124048, 129902, 126352, 128716, 127558, 126344, 124036, 126340, 124034, 126338, 117152, 124120, 127598, 121760, 117136, 124108, 121744, 126412, 124102, 121736, 117124, 121732, 117122, 121730, 103328, 117208, 124142, 112544, 103312, 117196, 112528, 121804, 117190, 112520, 103300, 112516, 103298, 112514, 75680, 103384, 117230, 94112, 75664, 103372, 94096, 112588, 103366, 94088, 75652, 94084, 75650, 75736, 103406, 94168, 75724, 94156, 75718, 94150, 75758, 128592, 129836, 91640, 128584, 129830, 91388, 128580, 91262, 128578, 123984, 127532, 126160, 123976, 127526, 126152, 128614, 126148, 123970, 126146, 116944, 124012, 121296, 116936, 124006, 121288, 126182, 121284, 116930, 121282, 102864, 116972, 111568, 102856, 116966, 111560, 121318, 111556, 102850, 111554, 74704, 102892, 92112, 74696, 102886, 92104, 111590, 92100, 74690, 92098, 74732, 92140, 74726, 92134, 128552, 129814, 90876, 128548, 90750, 128546, 123944, 127510, 126056, 128566, 126052, 123938, 126050, 116840, 123958, 121064, 116836, 121060, 116834, 121058, 102632, 116854, 111080, 121078, 111076, 102626, 111074, 74216, 102646, 91112, 74212, 91108, 74210, 91106, 74230, 91126, 128532, 90494, 128530, 123924, 126004, 123922, 126002, 116788, 120948, 116786, 120946, 102516, 110836, 102514, 110834, 73972, 90612, 73970, 90610, 128522, 123914, 125978, 116762, 120890, 102458, 110714, 123552, 127320, 129198, 123536, 127308, 123528, 127302, 123524, 123522, 116128, 123608, 127342, 116112, 123596, 116104, 123590, 116100, 116098, 101280, 116184, 123630, 101264, 116172, 101256, 116166, 101252, 101250, 71584, 101336, 116206, 71568, 101324, 71560, 101318, 71556, 71554, 71640, 101358, 71628, 71622, 71662, 127824, 129452, 79352, 127816, 129446, 79100, 127812, 78974, 127810, 123472, 127276, 124624, 123464, 127270, 124616, 127846, 124612, 123458, 124610, 115920, 123500, 118224, 115912, 123494, 118216, 124646, 118212, 115906, 118210, 100816, 115948, 105424, 100808, 115942, 105416, 118246, 105412, 100802, 105410, 70608, 100844, 79824, 70600, 100838, 79816, 105446, 79812, 70594, 79810, 70636, 79852, 70630, 79846, 129960, 95728, 113404, 129956, 95480, 113278, 129954, 95356, 95294, 127784, 129430, 78588, 128872, 129974, 95996, 78462, 128868, 127778, 95870, 128866, 123432, 127254, 124520, 123428, 126696, 128886, 123426, 126692, 124514, 126690, 115816, 123446, 117992, 115812, 122344, 117988, 115810, 122340, 117986, 122338, 100584, 115830, 104936, 100580, 113640, 104932, 100578, 113636, 104930, 113634, 70120, 100598, 78824, 70116, 96232, 78820, 70114, 96228, 78818, 96226, 70134, 78838, 129940, 94968, 113022, 129938, 94844, 94782, 127764, 78206, 128820, 127762, 95102, 128818, 123412, 124468, 123410, 126580, 124466, 126578, 115764, 117876, 115762, 122100, 117874, 122098, 100468, 104692, 100466, 113140, 104690, 113138, 69876, 78324, 69874, 95220, 78322, 95218, 129930, 94588, 94526, 127754, 128794, 123402, 124442, 126522, 115738, 117818, 121978, 100410, 104570, 112890, 69754, 78074, 94714, 94398, 123216, 127148, 123208, 127142, 123204, 123202, 115408, 123244, 115400, 123238, 115396, 115394, 99792, 115436, 99784, 115430, 99780, 99778, 68560, 99820, 68552, 99814, 68548, 68546, 68588, 68582, 127400, 129238, 72444, 127396, 72318, 127394, 123176, 127126, 123752, 123172, 123748, 123170, 123746, 115304, 123190, 116456, 115300, 116452, 115298, 116450, 99560, 115318, 101864, 99556, 101860, 99554, 101858, 68072, 99574, 72680, 68068, 72676, 68066, 72674, 68086, 72694, 129492, 80632, 105854, 129490, 80508, 80446, 127380, 72062, 127924, 127378, 80766, 127922, 123156, 123700, 123154, 124788, 123698, 124786, 115252, 116340, 115250, 118516, 116338, 118514, 99444, 101620, 99442, 105972, 101618, 105970, 67828, 72180, 67826, 80884, 72178, 80882, 97008, 114044, 96888, 113982, 96828, 96798, 129482, 80252, 130010, 97148, 80190, 97086, 127370, 127898, 128954, 123146, 123674, 124730, 126842, 115226, 116282, 118394, 122618, 99386, 101498, 105722, 114170, 67706, 71930, 80378, 96632, 113854, 96572, 96542, 80062, 96702, 96444, 96414, 96350, 123048, 123044, 123042, 115048, 123062, 115044, 115042, 99048, 115062, 99044, 99042, 67048, 99062, 67044, 67042, 67062, 127188, 68990, 127186, 123028, 123316, 123026, 123314, 114996, 115572, 114994, 115570, 98932, 100084, 98930, 100082, 66804, 69108, 66802, 69106, 129258, 73084, 73022, 127178, 127450, 123018, 123290, 123834, 114970, 115514, 116602, 98874, 99962, 102138, 66682, 68858, 73210, 81272, 106174, 81212, 81182, 72894, 81342, 97648, 114364, 97592, 114334, 97564, 97550, 81084, 97724, 81054, 97694, 97464, 114270, 97436, 97422, 80990, 97502, 97372, 97358, 97326, 114868, 114866, 98676, 98674, 66292, 66290, 123098, 114842, 115130, 98618, 99194, 66170, 67322, 69310, 73404, 73374, 81592, 106334, 81564, 81550, 73310, 81630, 97968, 114524, 97944, 114510, 97932, 97926, 81500, 98012, 81486, 97998, 97880, 114478, 97868, 97862, 81454, 97902, 97836, 97830, 69470, 73564, 73550, 81752, 106414, 81740, 81734, 73518, 81774, 81708, 81702]), $a([109536, 120312, 86976, 109040, 120060, 86496, 108792, 119934, 86256, 108668, 86136, 129744, 89056, 110072, 129736, 88560, 109820, 129732, 88312, 109694, 129730, 88188, 128464, 129772, 89592, 128456, 129766, 89340, 128452, 89214, 128450, 125904, 128492, 125896, 128486, 125892, 125890, 120784, 125932, 120776, 125926, 120772, 120770, 110544, 120812, 110536, 120806, 110532, 84928, 108016, 119548, 84448, 107768, 119422, 84208, 107644, 84088, 107582, 84028, 129640, 85488, 108284, 129636, 85240, 108158, 129634, 85116, 85054, 128232, 129654, 85756, 128228, 85630, 128226, 125416, 128246, 125412, 125410, 119784, 125430, 119780, 119778, 108520, 119798, 108516, 108514, 83424, 107256, 119166, 83184, 107132, 83064, 107070, 83004, 82974, 129588, 83704, 107390, 129586, 83580, 83518, 128116, 83838, 128114, 125172, 125170, 119284, 119282, 107508, 107506, 82672, 106876, 82552, 106814, 82492, 82462, 129562, 82812, 82750, 128058, 125050, 119034, 82296, 106686, 82236, 82206, 82366, 82108, 82078, 76736, 103920, 117500, 76256, 103672, 117374, 76016, 103548, 75896, 103486, 75836, 129384, 77296, 104188, 129380, 77048, 104062, 129378, 76924, 76862, 127720, 129398, 77564, 127716, 77438, 127714, 124392, 127734, 124388, 124386, 117736, 124406, 117732, 117730, 104424, 117750, 104420, 104418, 112096, 121592, 126334, 92608, 111856, 121468, 92384, 111736, 121406, 92272, 111676, 92216, 111646, 92188, 75232, 103160, 117118, 93664, 74992, 103036, 93424, 112252, 102974, 93304, 74812, 93244, 74782, 93214, 129332, 75512, 103294, 129908, 129330, 93944, 75388, 129906, 93820, 75326, 93758, 127604, 75646, 128756, 127602, 94078, 128754, 124148, 126452, 124146, 126450, 117236, 121844, 117234, 121842, 103412, 103410, 91584, 111344, 121212, 91360, 111224, 121150, 91248, 111164, 91192, 111134, 91164, 91150, 74480, 102780, 91888, 74360, 102718, 91768, 111422, 91708, 74270, 91678, 129306, 74620, 129850, 92028, 74558, 91966, 127546, 128634, 124026, 126202, 116986, 121338, 102906, 90848, 110968, 121022, 90736, 110908, 90680, 110878, 90652, 90638, 74104, 102590, 91000, 74044, 90940, 74014, 90910, 74174, 91070, 90480, 110780, 90424, 110750, 90396, 90382, 73916, 90556, 73886, 90526, 90296, 110686, 90268, 90254, 73822, 90334, 90204, 90190, 71136, 101112, 116094, 70896, 100988, 70776, 100926, 70716, 70686, 129204, 71416, 101246, 129202, 71292, 71230, 127348, 71550, 127346, 123636, 123634, 116212, 116210, 101364, 101362, 79296, 105200, 118140, 79072, 105080, 118078, 78960, 105020, 78904, 104990, 78876, 78862, 70384, 100732, 79600, 70264, 100670, 79480, 105278, 79420, 70174, 79390, 129178, 70524, 129466, 79740, 70462, 79678, 127290, 127866, 123514, 124666, 115962, 118266, 100858, 113376, 122232, 126654, 95424, 113264, 122172, 95328, 113208, 122142, 95280, 113180, 95256, 113166, 95244, 78560, 104824, 117950, 95968, 78448, 104764, 95856, 113468, 104734, 95800, 78364, 95772, 78350, 95758, 70008, 100542, 78712, 69948, 96120, 78652, 69918, 96060, 78622, 96030, 70078, 78782, 96190, 94912, 113008, 122044, 94816, 112952, 122014, 94768, 112924, 94744, 112910, 94732, 94726, 78192, 104636, 95088, 78136, 104606, 95032, 113054, 95004, 78094, 94990, 69820, 78268, 69790, 95164, 78238, 95134, 94560, 112824, 121950, 94512, 112796, 94488, 112782, 94476, 94470, 78008, 104542, 94648, 77980, 94620, 77966, 94606, 69726, 78046, 94686, 94384, 112732, 94360, 112718, 94348, 94342, 77916, 94428, 77902, 94414, 94296, 112686, 94284, 94278, 77870, 94318, 94252, 94246, 68336, 99708, 68216, 99646, 68156, 68126, 68476, 68414, 127162, 123258, 115450, 99834, 72416, 101752, 116414, 72304, 101692, 72248, 101662, 72220, 72206, 67960, 99518, 72568, 67900, 72508, 67870, 72478, 68030, 72638, 80576, 105840, 118460, 80480, 105784, 118430, 80432, 105756, 80408, 105742, 80396, 80390, 72048, 101564, 80752, 71992, 101534, 80696, 71964, 80668, 71950, 80654, 67772, 72124, 67742, 80828, 72094, 80798, 114016, 122552, 126814, 96832, 113968, 122524, 96800, 113944, 122510, 96784, 113932, 96776, 113926, 96772, 80224, 105656, 118366, 97120, 80176, 105628, 97072, 114076, 105614, 97048, 80140, 97036, 80134, 97030, 71864, 101470, 80312, 71836, 97208, 80284, 71822, 97180, 80270, 97166, 67678, 71902, 80350, 97246, 96576, 113840, 122460, 96544, 113816, 122446, 96528, 113804, 96520, 113798, 96516, 96514, 80048, 105564, 96688, 80024, 105550, 96664, 113870, 96652, 80006, 96646, 71772, 80092, 71758, 96732, 80078, 96718, 96416, 113752, 122414, 96400, 113740, 96392, 113734, 96388, 96386, 79960, 105518, 96472, 79948, 96460, 79942, 96454, 71726, 79982, 96494, 96336, 113708, 96328, 113702, 96324, 96322, 79916, 96364, 79910, 96358, 96296, 113686, 96292, 96290, 79894, 96310, 66936, 99006, 66876, 66846, 67006, 68976, 100028, 68920, 99998, 68892, 68878, 66748, 69052, 66718, 69022, 73056, 102072, 116574, 73008, 102044, 72984, 102030, 72972, 72966, 68792, 99934, 73144, 68764, 73116, 68750, 73102, 66654, 68830, 73182, 81216, 106160, 118620, 81184, 106136, 118606, 81168, 106124, 81160, 106118, 81156, 81154, 72880, 101980, 81328, 72856, 101966, 81304, 106190, 81292, 72838, 81286, 68700, 72924, 68686, 81372, 72910, 81358, 114336, 122712, 126894, 114320, 122700, 114312, 122694, 114308, 114306, 81056, 106072, 118574, 97696, 81040, 106060, 97680, 114380, 106054, 97672, 81028, 97668, 81026, 97666, 72792, 101934, 81112, 72780, 97752, 81100, 72774, 97740, 81094, 97734, 68654, 72814, 81134, 97774, 114256, 122668, 114248, 122662, 114244, 114242, 80976, 106028, 97488, 80968, 106022, 97480, 114278, 97476, 80962, 97474, 72748, 81004, 72742, 97516, 80998, 97510, 114216, 122646, 114212, 114210, 80936, 106006, 97384, 80932, 97380, 80930, 97378, 72726, 80950, 97398, 114196, 114194, 80916, 97332, 80914, 97330, 66236, 66206, 67256, 99166, 67228, 67214, 66142, 67294, 69296, 100188, 69272, 100174, 69260, 69254, 67164, 69340, 67150, 69326, 73376, 102232, 116654, 73360, 102220, 73352, 102214, 73348, 73346, 69208, 100142, 73432, 102254, 73420, 69190, 73414, 67118, 69230, 73454, 106320, 118700, 106312, 118694, 106308, 106306, 73296, 102188, 81616, 106348, 102182, 81608, 73284, 81604, 73282, 81602, 69164, 73324, 69158, 81644, 73318, 81638, 122792, 126934, 122788, 122786, 106280, 118678, 114536, 106276, 114532, 106274, 114530, 73256, 102166, 81512, 73252, 98024, 81508, 73250, 98020, 81506, 98018, 69142, 73270, 81526, 98038, 122772, 122770, 106260, 114484, 106258, 114482, 73236, 81460, 73234, 97908, 81458, 97906, 122762, 106250, 114458, 73226, 81434, 97850, 66396, 66382, 67416, 99246, 67404, 67398, 66350, 67438, 69456, 100268, 69448, 100262, 69444, 69442, 67372, 69484, 67366, 69478, 102312, 116694, 102308, 102306, 69416, 100246, 73576, 102326, 73572, 69410, 73570, 67350, 69430, 73590, 118740, 118738, 102292, 106420, 102290, 106418, 69396, 73524, 69394, 81780, 73522, 81778, 118730, 102282, 106394, 69386, 73498, 81722, 66476, 66470, 67496, 99286, 67492, 67490, 66454, 67510, 100308, 100306, 67476, 69556, 67474, 69554, 116714])]); //#17861
    $1.raps = $a([$a([802, 930, 946, 818, 882, 890, 826, 954, 922, 986, 970, 906, 778, 794, 786, 914, 978, 982, 980, 916, 948, 932, 934, 942, 940, 936, 808, 812, 814, 806, 822, 950, 918, 790, 788, 820, 884, 868, 870, 878, 876, 872, 840, 856, 860, 862, 846, 844, 836, 838, 834, 866]), $a([718, 590, 622, 558, 550, 566, 534, 530, 538, 570, 562, 546, 610, 626, 634, 762, 754, 758, 630, 628, 612, 614, 582, 578, 706, 738, 742, 740, 748, 620, 556, 552, 616, 744, 712, 716, 708, 710, 646, 654, 652, 668, 664, 696, 688, 656, 720, 592, 600, 604, 732, 734])]); //#17876
    $1.cwtobits = function() {
        var _G4 = $get($1.clusters, $k[--$j]); //#17881
        $1.v = $get(_G4, $k[--$j]); //#17881
        $k[$j++] = Infinity; //#17882
        for (var _G7 = 0, _G8 = 17; _G7 < _G8; _G7++) { //#17882
            $k[$j++] = 0; //#17882
        } //#17882
        var _GB = $cvrs($s(17), $1.v, 2); //#17882
        for (var _GC = 0, _GD = _GB.length; _GC < _GD; _GC++) { //#17882
            $k[$j++] = $get(_GB, _GC) - 48; //#17882
        } //#17882
        var _GF = $a(); //#17882
        $k[$j++] = $geti(_GF, _GF.length - 17, 17); //#17883
    }; //#17883
    $1.raptobits = function() {
        var _GJ = $get($1.raps, $k[--$j]); //#17888
        $1.v = $get(_GJ, $k[--$j]); //#17888
        $k[$j++] = Infinity; //#17889
        for (var _GM = 0, _GN = 10; _GM < _GN; _GM++) { //#17889
            $k[$j++] = 0; //#17889
        } //#17889
        var _GQ = $cvrs($s(10), $1.v, 2); //#17889
        for (var _GR = 0, _GS = _GQ.length; _GR < _GS; _GR++) { //#17889
            $k[$j++] = $get(_GQ, _GR) - 48; //#17889
        } //#17889
        var _GU = $a(); //#17889
        $k[$j++] = $geti(_GU, _GU.length - 10, 10); //#17890
    }; //#17890
    $1.rwid = $get($a([38, 55, 82, 99]), $f($1.c - 1)); //#17894
    if (($1.c == 3) && $1.cca) { //#17895
        $1.rwid = 72; //#17895
    } //#17895
    $1.pixs = $a($1.rwid * $1.r); //#17896
    for (var _Gg = 0, _Gf = $f($1.r - 1); _Gg <= _Gf; _Gg += 1) { //#17934
        $1.i = _Gg; //#17899
        $1.clst = ($f($f($1.i + $1.rapl) - 1)) % 3; //#17900
        $k[$j++] = $1.pixs; //#17932
        $k[$j++] = $1.rwid * $1.i; //#17932
        $k[$j++] = Infinity; //#17932
        if ($1.c == 1) { //#17906
            $k[$j++] = ($f($f($1.i + $1.rapl) - 1)) % 52; //#17903
            $k[$j++] = 0; //#17903
            $1.raptobits(); //#17903
            $aload($k[--$j]); //#17903
            $k[$j++] = $get($1.cws, $1.i); //#17904
            $k[$j++] = $1.clst; //#17904
            $1.cwtobits(); //#17904
            $aload($k[--$j]); //#17904
            $k[$j++] = ($f($f($1.i + $1.rapr) - 1)) % 52; //#17905
            $k[$j++] = 0; //#17905
            $1.raptobits(); //#17905
            $aload($k[--$j]); //#17905
        } //#17905
        if ($1.c == 2) { //#17912
            $k[$j++] = ($f($f($1.i + $1.rapl) - 1)) % 52; //#17908
            $k[$j++] = 0; //#17908
            $1.raptobits(); //#17908
            $aload($k[--$j]); //#17908
            $k[$j++] = $get($1.cws, $1.i * 2); //#17909
            $k[$j++] = $1.clst; //#17909
            $1.cwtobits(); //#17909
            $aload($k[--$j]); //#17909
            $k[$j++] = $get($1.cws, ($1.i * 2) + 1); //#17910
            $k[$j++] = $1.clst; //#17910
            $1.cwtobits(); //#17910
            $aload($k[--$j]); //#17910
            $k[$j++] = ($f($f($1.i + $1.rapr) - 1)) % 52; //#17911
            $k[$j++] = 0; //#17911
            $1.raptobits(); //#17911
            $aload($k[--$j]); //#17911
        } //#17911
        if ($1.c == 3) { //#17922
            if (!$1.cca) { //#17916
                $k[$j++] = ($f($f($1.i + $1.rapl) - 1)) % 52; //#17915
                $k[$j++] = 0; //#17915
                $1.raptobits(); //#17915
                $aload($k[--$j]); //#17915
            } //#17915
            $k[$j++] = $get($1.cws, $1.i * 3); //#17917
            $k[$j++] = $1.clst; //#17917
            $1.cwtobits(); //#17917
            $aload($k[--$j]); //#17917
            $k[$j++] = ($f($f($1.i + $1.rapc) - 1)) % 52; //#17918
            $k[$j++] = 1; //#17918
            $1.raptobits(); //#17918
            $aload($k[--$j]); //#17918
            $k[$j++] = $get($1.cws, ($1.i * 3) + 1); //#17919
            $k[$j++] = $1.clst; //#17919
            $1.cwtobits(); //#17919
            $aload($k[--$j]); //#17919
            $k[$j++] = $get($1.cws, ($1.i * 3) + 2); //#17920
            $k[$j++] = $1.clst; //#17920
            $1.cwtobits(); //#17920
            $aload($k[--$j]); //#17920
            $k[$j++] = ($f($f($1.i + $1.rapr) - 1)) % 52; //#17921
            $k[$j++] = 0; //#17921
            $1.raptobits(); //#17921
            $aload($k[--$j]); //#17921
        } //#17921
        if ($1.c == 4) { //#17931
            $k[$j++] = ($f($f($1.i + $1.rapl) - 1)) % 52; //#17924
            $k[$j++] = 0; //#17924
            $1.raptobits(); //#17924
            $aload($k[--$j]); //#17924
            $k[$j++] = $get($1.cws, $1.i * 4); //#17925
            $k[$j++] = $1.clst; //#17925
            $1.cwtobits(); //#17925
            $aload($k[--$j]); //#17925
            $k[$j++] = $get($1.cws, ($1.i * 4) + 1); //#17926
            $k[$j++] = $1.clst; //#17926
            $1.cwtobits(); //#17926
            $aload($k[--$j]); //#17926
            $k[$j++] = ($f($f($1.i + $1.rapc) - 1)) % 52; //#17927
            $k[$j++] = 1; //#17927
            $1.raptobits(); //#17927
            $aload($k[--$j]); //#17927
            $k[$j++] = $get($1.cws, ($1.i * 4) + 2); //#17928
            $k[$j++] = $1.clst; //#17928
            $1.cwtobits(); //#17928
            $aload($k[--$j]); //#17928
            $k[$j++] = $get($1.cws, ($1.i * 4) + 3); //#17929
            $k[$j++] = $1.clst; //#17929
            $1.cwtobits(); //#17929
            $aload($k[--$j]); //#17929
            $k[$j++] = ($f($f($1.i + $1.rapr) - 1)) % 52; //#17930
            $k[$j++] = 0; //#17930
            $1.raptobits(); //#17930
            $aload($k[--$j]); //#17930
        } //#17930
        $k[$j++] = 1; //#17932
        var _I9 = $a(); //#17932
        var _IA = $k[--$j]; //#17933
        $puti($k[--$j], _IA, _I9); //#17933
    } //#17933
    var _IJ = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.rwid],
        ["pixy", $1.r],
        ["height", ($1.r / 72) * $1.rowmult],
        ["width", $1.rwid / 72],
        ["opt", $1.options]
    ]); //#17944
    $k[$j++] = _IJ; //#17947
    if (!$1.dontdraw) { //#17947
        bwipp_renmatrix(); //#17947
    } //#17947
}

function bwipp_datamatrix() {
    var $1 = {}; //#17982
    $1.ctx = null; //#17984
    $1.dontdraw = false; //#17985
    $1.columns = 0; //#17986
    $1.rows = 0; //#17987
    $1.format = "unset"; //#17988
    $1.version = "unset"; //#17989
    $1.parse = false; //#17990
    $1.parsefnc = false; //#17991
    $1.encoding = "auto"; //#17992
    $1.mailmark = false; //#17993
    $1.raw = false; //#17994
    $1.dmre = false; //#17995
    $1.dindmre = false; //#17996
    $1.isodmre = false; //#17997
    $k[$j++] = $1; //#17999
    bwipp_processoptions(); //#17999
    $1.options = $k[--$j]; //#17999
    $1.barcode = $k[--$j]; //#18000
    $1.isodmre = $1.dmre; //#18002
    if ($eq($1.format, "unset") && $eq($1.version, "unset")) { //#18006
        $k[$j++] = 'format'; //#18005
        if ($1.isodmre || $1.dindmre) { //#18005
            $k[$j++] = "rectangle"; //#18005
        } else { //#18005
            $k[$j++] = "square"; //#18005
        } //#18005
        var _7 = $k[--$j]; //#18005
        $1[$k[--$j]] = _7; //#18005
    } //#18005
    if ($ne($1.version, "unset")) { //#18012
        $search($1.version, "x"); //#18009
        $j--; //#18010
        $1.rows = $cvi($k[--$j]); //#18010
        $j--; //#18011
        $1.columns = $cvi($k[--$j]); //#18011
    } //#18011
    $k[$j++] = Infinity; //#18072
    $k[$j++] = $a([10, 10, 1, 1, 5, 1]); //#18048
    $k[$j++] = $a([12, 12, 1, 1, 7, 1]); //#18048
    $k[$j++] = $a([14, 14, 1, 1, 10, 1]); //#18048
    $k[$j++] = $a([16, 16, 1, 1, 12, 1]); //#18048
    $k[$j++] = $a([18, 18, 1, 1, 14, 1]); //#18048
    $k[$j++] = $a([20, 20, 1, 1, 18, 1]); //#18048
    $k[$j++] = $a([22, 22, 1, 1, 20, 1]); //#18048
    $k[$j++] = $a([24, 24, 1, 1, 24, 1]); //#18048
    $k[$j++] = $a([26, 26, 1, 1, 28, 1]); //#18048
    $k[$j++] = $a([32, 32, 2, 2, 36, 1]); //#18048
    $k[$j++] = $a([36, 36, 2, 2, 42, 1]); //#18048
    $k[$j++] = $a([40, 40, 2, 2, 48, 1]); //#18048
    $k[$j++] = $a([44, 44, 2, 2, 56, 1]); //#18048
    $k[$j++] = $a([48, 48, 2, 2, 68, 1]); //#18048
    $k[$j++] = $a([52, 52, 2, 2, 84, 2]); //#18048
    $k[$j++] = $a([64, 64, 4, 4, 112, 2]); //#18048
    $k[$j++] = $a([72, 72, 4, 4, 144, 4]); //#18048
    $k[$j++] = $a([80, 80, 4, 4, 192, 4]); //#18048
    $k[$j++] = $a([88, 88, 4, 4, 224, 4]); //#18048
    $k[$j++] = $a([96, 96, 4, 4, 272, 4]); //#18048
    $k[$j++] = $a([104, 104, 4, 4, 336, 6]); //#18048
    $k[$j++] = $a([120, 120, 6, 6, 408, 6]); //#18048
    $k[$j++] = $a([132, 132, 6, 6, 496, 8]); //#18048
    $k[$j++] = $a([144, 144, 6, 6, 620, 10]); //#18048
    $k[$j++] = $a([8, 18, 1, 1, 7, 1]); //#18048
    $k[$j++] = $a([8, 32, 1, 2, 11, 1]); //#18048
    if ($1.dindmre || $1.isodmre) { //#18048
        $k[$j++] = $a([8, 48, 1, 2, 15, 1]); //#18048
    } //#18048
    if ($1.dindmre || $1.isodmre) { //#18049
        $k[$j++] = $a([8, 64, 1, 4, 18, 1]); //#18049
    } //#18049
    if ($1.isodmre) { //#18050
        $k[$j++] = $a([8, 80, 1, 4, 22, 1]); //#18050
    } //#18050
    if ($1.isodmre) { //#18051
        $k[$j++] = $a([8, 96, 1, 4, 28, 1]); //#18051
    } //#18051
    if ($1.isodmre) { //#18052
        $k[$j++] = $a([8, 120, 1, 6, 32, 1]); //#18052
    } //#18052
    if ($1.isodmre) { //#18053
        $k[$j++] = $a([8, 144, 1, 6, 36, 1]); //#18053
    } //#18053
    $k[$j++] = $a([12, 26, 1, 1, 14, 1]); //#18056
    $k[$j++] = $a([12, 36, 1, 2, 18, 1]); //#18056
    if ($1.dindmre || $1.isodmre) { //#18056
        $k[$j++] = $a([12, 64, 1, 4, 27, 1]); //#18056
    } //#18056
    if ($1.isodmre) { //#18057
        $k[$j++] = $a([12, 88, 1, 4, 36, 1]); //#18057
    } //#18057
    $k[$j++] = $a([16, 36, 1, 2, 24, 1]); //#18060
    $k[$j++] = $a([16, 48, 1, 2, 28, 1]); //#18060
    if ($1.dindmre || $1.isodmre) { //#18060
        $k[$j++] = $a([16, 64, 1, 4, 36, 1]); //#18060
    } //#18060
    if ($1.isodmre) { //#18061
        $k[$j++] = $a([20, 36, 1, 2, 28, 1]); //#18061
    } //#18061
    if ($1.isodmre) { //#18062
        $k[$j++] = $a([20, 44, 1, 2, 34, 1]); //#18062
    } //#18062
    if ($1.isodmre) { //#18063
        $k[$j++] = $a([20, 64, 1, 4, 42, 1]); //#18063
    } //#18063
    if ($1.isodmre) { //#18064
        $k[$j++] = $a([22, 48, 1, 2, 38, 1]); //#18064
    } //#18064
    if ($1.dindmre) { //#18065
        $k[$j++] = $a([24, 32, 1, 2, 28, 1]); //#18065
    } //#18065
    if ($1.dindmre) { //#18066
        $k[$j++] = $a([24, 36, 1, 2, 33, 1]); //#18066
    } //#18066
    if ($1.dindmre || $1.isodmre) { //#18067
        $k[$j++] = $a([24, 48, 1, 2, 41, 1]); //#18067
    } //#18067
    if ($1.dindmre || $1.isodmre) { //#18068
        $k[$j++] = $a([24, 64, 1, 4, 46, 1]); //#18068
    } //#18068
    if ($1.dindmre) { //#18069
        $k[$j++] = $a([26, 32, 1, 2, 32, 1]); //#18069
    } //#18069
    if ($1.dindmre || $1.isodmre) { //#18070
        $k[$j++] = $a([26, 40, 1, 2, 38, 1]); //#18070
    } //#18070
    if ($1.dindmre || $1.isodmre) { //#18071
        $k[$j++] = $a([26, 48, 1, 2, 42, 1]); //#18071
    } //#18071
    if ($1.dindmre || $1.isodmre) { //#18072
        $k[$j++] = $a([26, 64, 1, 4, 50, 1]); //#18072
    } //#18072
    $1.metrics = $a(); //#18072
    $1.urows = $1.rows; //#18076
    $1.ucols = $1.columns; //#18077
    $1.fullcws = $a([]); //#18078
    var _1a = $1.metrics; //#18079
    for (var _1b = 0, _1c = _1a.length; _1b < _1c; _1b++) { //#18096
        $1.m = $get(_1a, _1b); //#18080
        $1.rows = $get($1.m, 0); //#18081
        $1.cols = $get($1.m, 1); //#18082
        $1.regh = $get($1.m, 2); //#18083
        $1.regv = $get($1.m, 3); //#18084
        $1.rscw = $get($1.m, 4); //#18085
        $1.rsbl = $get($1.m, 5); //#18086
        $1.mrows = $f($1.rows - (2 * $1.regh)); //#18087
        $1.mcols = $f($1.cols - (2 * $1.regv)); //#18088
        $1.ncws = $f((~~(($1.mrows * $1.mcols) / 8)) - $1.rscw); //#18089
        $1.okay = true; //#18090
        if (($1.urows != 0) && ($1.urows != $1.rows)) { //#18091
            $1.okay = false; //#18091
        } //#18091
        if (($1.ucols != 0) && ($1.ucols != $1.cols)) { //#18092
            $1.okay = false; //#18092
        } //#18092
        if ($eq($1.format, "square") && $ne($1.rows, $1.cols)) { //#18093
            $1.okay = false; //#18093
        } //#18093
        if ($eq($1.format, "rectangle") && $eq($1.rows, $1.cols)) { //#18094
            $1.okay = false; //#18094
        } //#18094
        if ($1.okay) { //#18095
            $k[$j++] = Infinity; //#18095
            $aload($1.fullcws); //#18095
            $k[$j++] = $1.ncws; //#18095
            $1.fullcws = $a(); //#18095
        } //#18095
    } //#18095
    $k[$j++] = Infinity; //#18097
    for (var _2D = 0, _2E = 1558; _2D < _2E; _2D++) { //#18097
        $k[$j++] = 10000; //#18097
    } //#18097
    $1.numremcws = $a(); //#18097
    var _2G = $1.fullcws; //#18098
    for (var _2H = 0, _2I = _2G.length; _2H < _2I; _2H++) { //#18098
        $put($1.numremcws, $f($get(_2G, _2H) - 1), 1); //#18098
    } //#18098
    for (var _2L = 1556; _2L >= 0; _2L -= 1) { //#18104
        $1.i = _2L; //#18100
        if ($get($1.numremcws, $1.i) != 1) { //#18103
            $put($1.numremcws, $1.i, $f($get($1.numremcws, $1.i + 1) + 1)); //#18102
        } //#18102
    } //#18102
    $1.fnc1 = -1; //#18108
    $1.prog = -2; //#18108
    $1.m05 = -3; //#18108
    $1.m06 = -4; //#18108
    $1.lC = -5; //#18109
    $1.lB = -6; //#18109
    $1.lX = -7; //#18109
    $1.lT = -8; //#18109
    $1.lE = -9; //#18109
    $1.unl = -10; //#18109
    $1.sapp = -11; //#18110
    $1.usft = -12; //#18110
    $1.sft1 = -13; //#18110
    $1.sft2 = -14; //#18110
    $1.sft3 = -15; //#18110
    $1.eci = -16; //#18110
    $1.pad = -17; //#18110
    $1.unlcw = 254; //#18111
    $k[$j++] = Infinity; //#18120
    for (var _2U = 0; _2U <= 128; _2U += 1) { //#18114
        $k[$j++] = _2U; //#18114
        $k[$j++] = _2U + 1; //#18114
    } //#18114
    $k[$j++] = $1.pad; //#18119
    $k[$j++] = 129; //#18119
    for (var _2W = 0; _2W <= 99; _2W += 1) { //#18119
        var _2Y = $cvrs($s(2), _2W, 10); //#18117
        var _2a = $strcpy($s(2), "00"); //#18117
        $puti(_2a, 2 - _2Y.length, _2Y); //#18117
        $k[$j++] = _2a; //#18118
        $k[$j++] = _2W + 130; //#18118
    } //#18118
    var _2n = $a([$1.lC, $1.lB, $1.fnc1, $1.sapp, $1.prog, $1.usft, $1.m05, $1.m06, $1.lX, $1.lT, $1.lE, $1.eci]); //#18120
    $k[$j++] = 229; //#18120
    for (var _2o = 0, _2p = _2n.length; _2o < _2p; _2o++) { //#18120
        var _2s = $f($k[--$j] + 1); //#18120
        $k[$j++] = $get(_2n, _2o); //#18120
        $k[$j++] = _2s; //#18120
        $k[$j++] = _2s; //#18120
    } //#18120
    $j--; //#18120
    $1.Avals = $d(); //#18121
    $k[$j++] = Infinity; //#18123
    var _2u = $1.Avals; //#18123
    for (var _2z = _2u.size, _2y = _2u.keys(), _2x = 0; _2x < _2z; _2x++) { //#18123
        var _2v = _2y.next().value; //#18123
        $k[$j++] = _2v; //#18123
        $k[$j++] = _2u.get(_2v); //#18123
        $k[$j++] = Infinity; //#18123
        var _30 = $k[--$j]; //#18123
        var _31 = $k[--$j]; //#18123
        $k[$j++] = _30; //#18123
        $k[$j++] = _31; //#18123
        var _32 = $a(); //#18123
        $k[$j++] = _32; //#18123
    } //#18123
    $1.Avals = $d(); //#18124
    $k[$j++] = Infinity; //#18132
    $k[$j++] = $1.sft1; //#18131
    $k[$j++] = 0; //#18131
    $k[$j++] = $1.sft2; //#18131
    $k[$j++] = 1; //#18131
    $k[$j++] = $1.sft3; //#18131
    $k[$j++] = 2; //#18131
    $k[$j++] = 32; //#18131
    $k[$j++] = 3; //#18131
    for (var _37 = 48; _37 <= 57; _37 += 1) { //#18131
        $k[$j++] = _37; //#18131
        $k[$j++] = _37 - 44; //#18131
    } //#18131
    for (var _38 = 65; _38 <= 90; _38 += 1) { //#18132
        $k[$j++] = _38; //#18132
        $k[$j++] = _38 - 51; //#18132
    } //#18132
    $1.CNvals = $d(); //#18133
    $k[$j++] = Infinity; //#18134
    for (var _3A = 0; _3A <= 31; _3A += 1) { //#18134
        $k[$j++] = _3A; //#18134
        $k[$j++] = _3A; //#18134
    } //#18134
    $1.C1vals = $d(); //#18134
    $k[$j++] = Infinity; //#18140
    for (var _3C = 33; _3C <= 47; _3C += 1) { //#18136
        $k[$j++] = _3C; //#18136
        $k[$j++] = _3C - 33; //#18136
    } //#18136
    for (var _3D = 58; _3D <= 64; _3D += 1) { //#18137
        $k[$j++] = _3D; //#18137
        $k[$j++] = _3D - 43; //#18137
    } //#18137
    for (var _3E = 91; _3E <= 95; _3E += 1) { //#18138
        $k[$j++] = _3E; //#18138
        $k[$j++] = _3E - 69; //#18138
    } //#18138
    $k[$j++] = $1.fnc1; //#18140
    $k[$j++] = 27; //#18140
    $k[$j++] = $1.usft; //#18140
    $k[$j++] = 30; //#18140
    $1.C2vals = $d(); //#18141
    $k[$j++] = Infinity; //#18142
    for (var _3I = 96; _3I <= 127; _3I += 1) { //#18142
        $k[$j++] = _3I; //#18142
        $k[$j++] = _3I - 96; //#18142
    } //#18142
    $1.C3vals = $d(); //#18142
    $k[$j++] = Infinity; //#18147
    var _3K = $1.CNvals; //#18144
    for (var _3P = _3K.size, _3O = _3K.keys(), _3N = 0; _3N < _3P; _3N++) { //#18144
        var _3L = _3O.next().value; //#18144
        $k[$j++] = _3L; //#18144
        $k[$j++] = _3K.get(_3L); //#18144
        $k[$j++] = Infinity; //#18144
        var _3Q = $k[--$j]; //#18144
        var _3R = $k[--$j]; //#18144
        $k[$j++] = _3Q; //#18144
        $k[$j++] = _3R; //#18144
        var _3S = $a(); //#18144
        $k[$j++] = _3S; //#18144
    } //#18144
    var _3T = $1.C1vals; //#18145
    for (var _3Y = _3T.size, _3X = _3T.keys(), _3W = 0; _3W < _3Y; _3W++) { //#18145
        var _3U = _3X.next().value; //#18145
        $k[$j++] = _3U; //#18145
        $k[$j++] = _3T.get(_3U); //#18145
        $k[$j++] = Infinity; //#18145
        var _3Z = $k[--$j]; //#18145
        var _3a = $k[--$j]; //#18145
        $k[$j++] = _3Z; //#18145
        $k[$j++] = $get($1.CNvals, $1.sft1); //#18145
        $k[$j++] = _3a; //#18145
        var _3e = $a(); //#18145
        $k[$j++] = _3e; //#18145
    } //#18145
    var _3f = $1.C2vals; //#18146
    for (var _3k = _3f.size, _3j = _3f.keys(), _3i = 0; _3i < _3k; _3i++) { //#18146
        var _3g = _3j.next().value; //#18146
        $k[$j++] = _3g; //#18146
        $k[$j++] = _3f.get(_3g); //#18146
        $k[$j++] = Infinity; //#18146
        var _3l = $k[--$j]; //#18146
        var _3m = $k[--$j]; //#18146
        $k[$j++] = _3l; //#18146
        $k[$j++] = $get($1.CNvals, $1.sft2); //#18146
        $k[$j++] = _3m; //#18146
        var _3q = $a(); //#18146
        $k[$j++] = _3q; //#18146
    } //#18146
    var _3r = $1.C3vals; //#18147
    for (var _3w = _3r.size, _3v = _3r.keys(), _3u = 0; _3u < _3w; _3u++) { //#18147
        var _3s = _3v.next().value; //#18147
        $k[$j++] = _3s; //#18147
        $k[$j++] = _3r.get(_3s); //#18147
        $k[$j++] = Infinity; //#18147
        var _3x = $k[--$j]; //#18147
        var _3y = $k[--$j]; //#18147
        $k[$j++] = _3x; //#18147
        $k[$j++] = $get($1.CNvals, $1.sft3); //#18147
        $k[$j++] = _3y; //#18147
        var _42 = $a(); //#18147
        $k[$j++] = _42; //#18147
    } //#18147
    $1.Cvals = $d(); //#18148
    $k[$j++] = Infinity; //#18156
    $k[$j++] = $1.sft1; //#18155
    $k[$j++] = 0; //#18155
    $k[$j++] = $1.sft2; //#18155
    $k[$j++] = 1; //#18155
    $k[$j++] = $1.sft3; //#18155
    $k[$j++] = 2; //#18155
    $k[$j++] = 32; //#18155
    $k[$j++] = 3; //#18155
    for (var _47 = 48; _47 <= 57; _47 += 1) { //#18155
        $k[$j++] = _47; //#18155
        $k[$j++] = _47 - 44; //#18155
    } //#18155
    for (var _48 = 97; _48 <= 122; _48 += 1) { //#18156
        $k[$j++] = _48; //#18156
        $k[$j++] = _48 - 83; //#18156
    } //#18156
    $1.TNvals = $d(); //#18157
    $k[$j++] = Infinity; //#18158
    for (var _4A = 0; _4A <= 31; _4A += 1) { //#18158
        $k[$j++] = _4A; //#18158
        $k[$j++] = _4A; //#18158
    } //#18158
    $1.T1vals = $d(); //#18158
    $k[$j++] = Infinity; //#18164
    for (var _4C = 33; _4C <= 47; _4C += 1) { //#18160
        $k[$j++] = _4C; //#18160
        $k[$j++] = _4C - 33; //#18160
    } //#18160
    for (var _4D = 58; _4D <= 64; _4D += 1) { //#18161
        $k[$j++] = _4D; //#18161
        $k[$j++] = _4D - 43; //#18161
    } //#18161
    for (var _4E = 91; _4E <= 95; _4E += 1) { //#18162
        $k[$j++] = _4E; //#18162
        $k[$j++] = _4E - 69; //#18162
    } //#18162
    $k[$j++] = $1.fnc1; //#18164
    $k[$j++] = 27; //#18164
    $k[$j++] = $1.usft; //#18164
    $k[$j++] = 30; //#18164
    $1.T2vals = $d(); //#18165
    $k[$j++] = Infinity; //#18169
    $k[$j++] = 96; //#18168
    $k[$j++] = 0; //#18168
    for (var _4I = 65; _4I <= 90; _4I += 1) { //#18168
        $k[$j++] = _4I; //#18168
        $k[$j++] = _4I - 64; //#18168
    } //#18168
    for (var _4J = 123; _4J <= 127; _4J += 1) { //#18169
        $k[$j++] = _4J; //#18169
        $k[$j++] = _4J - 96; //#18169
    } //#18169
    $1.T3vals = $d(); //#18170
    $k[$j++] = Infinity; //#18175
    var _4L = $1.TNvals; //#18172
    for (var _4Q = _4L.size, _4P = _4L.keys(), _4O = 0; _4O < _4Q; _4O++) { //#18172
        var _4M = _4P.next().value; //#18172
        $k[$j++] = _4M; //#18172
        $k[$j++] = _4L.get(_4M); //#18172
        $k[$j++] = Infinity; //#18172
        var _4R = $k[--$j]; //#18172
        var _4S = $k[--$j]; //#18172
        $k[$j++] = _4R; //#18172
        $k[$j++] = _4S; //#18172
        var _4T = $a(); //#18172
        $k[$j++] = _4T; //#18172
    } //#18172
    var _4U = $1.T1vals; //#18173
    for (var _4Z = _4U.size, _4Y = _4U.keys(), _4X = 0; _4X < _4Z; _4X++) { //#18173
        var _4V = _4Y.next().value; //#18173
        $k[$j++] = _4V; //#18173
        $k[$j++] = _4U.get(_4V); //#18173
        $k[$j++] = Infinity; //#18173
        var _4a = $k[--$j]; //#18173
        var _4b = $k[--$j]; //#18173
        $k[$j++] = _4a; //#18173
        $k[$j++] = $get($1.TNvals, $1.sft1); //#18173
        $k[$j++] = _4b; //#18173
        var _4f = $a(); //#18173
        $k[$j++] = _4f; //#18173
    } //#18173
    var _4g = $1.T2vals; //#18174
    for (var _4l = _4g.size, _4k = _4g.keys(), _4j = 0; _4j < _4l; _4j++) { //#18174
        var _4h = _4k.next().value; //#18174
        $k[$j++] = _4h; //#18174
        $k[$j++] = _4g.get(_4h); //#18174
        $k[$j++] = Infinity; //#18174
        var _4m = $k[--$j]; //#18174
        var _4n = $k[--$j]; //#18174
        $k[$j++] = _4m; //#18174
        $k[$j++] = $get($1.TNvals, $1.sft2); //#18174
        $k[$j++] = _4n; //#18174
        var _4r = $a(); //#18174
        $k[$j++] = _4r; //#18174
    } //#18174
    var _4s = $1.T3vals; //#18175
    for (var _4x = _4s.size, _4w = _4s.keys(), _4v = 0; _4v < _4x; _4v++) { //#18175
        var _4t = _4w.next().value; //#18175
        $k[$j++] = _4t; //#18175
        $k[$j++] = _4s.get(_4t); //#18175
        $k[$j++] = Infinity; //#18175
        var _4y = $k[--$j]; //#18175
        var _4z = $k[--$j]; //#18175
        $k[$j++] = _4y; //#18175
        $k[$j++] = $get($1.TNvals, $1.sft3); //#18175
        $k[$j++] = _4z; //#18175
        var _53 = $a(); //#18175
        $k[$j++] = _53; //#18175
    } //#18175
    $1.Tvals = $d(); //#18176
    for (var _55 = 128; _55 <= 255; _55 += 1) { //#18184
        $1.i = _55; //#18180
        $k[$j++] = $1.Avals; //#18181
        $k[$j++] = $1.i; //#18181
        $k[$j++] = Infinity; //#18181
        $aload($get($1.Avals, $1.usft)); //#18181
        $aload($get($1.Avals, $1.i - 128)); //#18181
        var _5E = $a(); //#18181
        var _5F = $k[--$j]; //#18181
        $put($k[--$j], _5F, _5E); //#18181
        $k[$j++] = $1.Cvals; //#18182
        $k[$j++] = $1.i; //#18182
        $k[$j++] = Infinity; //#18182
        $aload($get($1.Cvals, $1.usft)); //#18182
        $aload($get($1.Cvals, $1.i - 128)); //#18182
        var _5P = $a(); //#18182
        var _5Q = $k[--$j]; //#18182
        $put($k[--$j], _5Q, _5P); //#18182
        $k[$j++] = $1.Tvals; //#18183
        $k[$j++] = $1.i; //#18183
        $k[$j++] = Infinity; //#18183
        $aload($get($1.Tvals, $1.usft)); //#18183
        $aload($get($1.Tvals, $1.i - 128)); //#18183
        var _5a = $a(); //#18183
        var _5b = $k[--$j]; //#18183
        $put($k[--$j], _5b, _5a); //#18183
    } //#18183
    $k[$j++] = Infinity; //#18192
    $k[$j++] = 13; //#18191
    $k[$j++] = 0; //#18191
    $k[$j++] = 42; //#18191
    $k[$j++] = 1; //#18191
    $k[$j++] = 62; //#18191
    $k[$j++] = 2; //#18191
    $k[$j++] = 32; //#18191
    $k[$j++] = 3; //#18191
    for (var _5d = 48; _5d <= 57; _5d += 1) { //#18191
        $k[$j++] = _5d; //#18191
        $k[$j++] = _5d - 44; //#18191
    } //#18191
    for (var _5e = 65; _5e <= 90; _5e += 1) { //#18192
        $k[$j++] = _5e; //#18192
        $k[$j++] = _5e - 51; //#18192
    } //#18192
    $1.Xvals = $d(); //#18193
    $k[$j++] = Infinity; //#18195
    var _5g = $1.Xvals; //#18195
    for (var _5l = _5g.size, _5k = _5g.keys(), _5j = 0; _5j < _5l; _5j++) { //#18195
        var _5h = _5k.next().value; //#18195
        $k[$j++] = _5h; //#18195
        $k[$j++] = _5g.get(_5h); //#18195
        $k[$j++] = Infinity; //#18195
        var _5m = $k[--$j]; //#18195
        var _5n = $k[--$j]; //#18195
        $k[$j++] = _5m; //#18195
        $k[$j++] = _5n; //#18195
        var _5o = $a(); //#18195
        $k[$j++] = _5o; //#18195
    } //#18195
    $1.Xvals = $d(); //#18196
    $k[$j++] = Infinity; //#18201
    for (var _5q = 64; _5q <= 94; _5q += 1) { //#18199
        $k[$j++] = _5q; //#18199
        $k[$j++] = _5q - 64; //#18199
    } //#18199
    $k[$j++] = $1.unl; //#18201
    $k[$j++] = 31; //#18201
    for (var _5s = 32; _5s <= 63; _5s += 1) { //#18201
        $k[$j++] = _5s; //#18201
        $k[$j++] = _5s; //#18201
    } //#18201
    $1.Evals = $d(); //#18202
    $k[$j++] = Infinity; //#18204
    var _5u = $1.Evals; //#18204
    for (var _5z = _5u.size, _5y = _5u.keys(), _5x = 0; _5x < _5z; _5x++) { //#18204
        var _5v = _5y.next().value; //#18204
        $k[$j++] = _5v; //#18204
        $k[$j++] = _5u.get(_5v); //#18204
        $k[$j++] = Infinity; //#18204
        var _60 = $k[--$j]; //#18204
        var _61 = $k[--$j]; //#18204
        $k[$j++] = _60; //#18204
        $k[$j++] = _61; //#18204
        var _62 = $a(); //#18204
        $k[$j++] = _62; //#18204
    } //#18204
    $1.Evals = $d(); //#18205
    $k[$j++] = Infinity; //#18208
    for (var _64 = 0; _64 <= 255; _64 += 1) { //#18208
        $k[$j++] = _64; //#18208
        $k[$j++] = _64; //#18208
    } //#18208
    $1.Bvals = $d(); //#18209
    $k[$j++] = Infinity; //#18211
    var _66 = $1.Bvals; //#18211
    for (var _6B = _66.size, _6A = _66.keys(), _69 = 0; _69 < _6B; _69++) { //#18211
        var _67 = _6A.next().value; //#18211
        $k[$j++] = _67; //#18211
        $k[$j++] = _66.get(_67); //#18211
        $k[$j++] = Infinity; //#18211
        var _6C = $k[--$j]; //#18211
        var _6D = $k[--$j]; //#18211
        $k[$j++] = _6C; //#18211
        $k[$j++] = _6D; //#18211
        var _6E = $a(); //#18211
        $k[$j++] = _6E; //#18211
    } //#18211
    $1.Bvals = $d(); //#18212
    $1.encvals = $a([$1.Avals, $1.Cvals, $1.Tvals, $1.Xvals, $1.Evals, $1.Bvals]); //#18214
    $1.A = 0; //#18216
    $1.C = 1; //#18216
    $1.T = 2; //#18216
    $1.X = 3; //#18216
    $1.E = 4; //#18216
    $1.B = 5; //#18216
    if ($1.raw) { //#18219
        $1.encoding = "raw"; //#18219
    } //#18219
    if ($eq($1.encoding, "raw")) { //#18232
        $1.cws = $a($1.barcode.length); //#18222
        $1.i = 0; //#18223
        $1.j = 0; //#18223
        for (;;) { //#18230
            if ($1.i == $1.barcode.length) { //#18225
                break; //#18225
            } //#18225
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#18226
            $put($1.cws, $1.j, $1.cw); //#18227
            $1.i = $1.i + 4; //#18228
            $1.j = $1.j + 1; //#18229
        } //#18229
        $1.cws = $geti($1.cws, 0, $1.j); //#18231
    } //#18231
    if ($eq($1.encoding, "auto")) { //#18624
        var _6j = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["eci", true],
            ["FNC1", $1.fnc1],
            ["PROG", $1.prog]
        ]); //#18242
        $1.fncvals = _6j; //#18245
        $k[$j++] = 'msg'; //#18246
        $k[$j++] = $1.barcode; //#18246
        $k[$j++] = $1.fncvals; //#18246
        bwipp_parseinput(); //#18246
        var _6m = $k[--$j]; //#18246
        $1[$k[--$j]] = _6m; //#18246
        $1.msglen = $1.msg.length; //#18247
        if ($1.msglen >= 9) { //#18265
            $aload($geti($1.msg, 0, 7)); //#18251
            var _6s = $k[--$j]; //#18252
            var _6t = $k[--$j]; //#18252
            $k[$j++] = _6s == 29; //#18252
            $k[$j++] = _6t; //#18252
            $j--; //#18252
            var _6u = $k[--$j]; //#18252
            var _6v = $k[--$j]; //#18252
            var _6w = $k[--$j]; //#18252
            var _6x = $k[--$j]; //#18253
            var _6y = $k[--$j]; //#18253
            var _6z = $k[--$j]; //#18253
            if (((((_6u && (_6v == 48)) && (_6w == 30)) && (_6x == 62)) && (_6y == 41)) && (_6z == 91)) { //#18264
                $aload($geti($1.msg, $1.msglen - 2, 2)); //#18254
                var _73 = $k[--$j]; //#18255
                var _74 = $k[--$j]; //#18255
                if ((_73 == 4) && (_74 == 30)) { //#18263
                    if ($get($1.msg, 5) == 53) { //#18260
                        $k[$j++] = Infinity; //#18257
                        $k[$j++] = $1.m05; //#18257
                        $aload($geti($1.msg, 7, $1.msg.length - 9)); //#18257
                        $1.msg = $a(); //#18257
                    } else { //#18260
                        if ($get($1.msg, 5) == 54) { //#18261
                            $k[$j++] = Infinity; //#18260
                            $k[$j++] = $1.m06; //#18260
                            $aload($geti($1.msg, 7, $1.msg.length - 9)); //#18260
                            $1.msg = $a(); //#18260
                        } //#18260
                    } //#18260
                } //#18260
            } //#18260
        } //#18260
        $1.msglen = $1.msg.length; //#18266
        $k[$j++] = Infinity; //#18268
        for (var _7L = 0, _7M = $1.msglen; _7L < _7M; _7L++) { //#18268
            $k[$j++] = 0; //#18268
        } //#18268
        $k[$j++] = 0; //#18268
        $1.numD = $a(); //#18268
        $k[$j++] = Infinity; //#18269
        for (var _7P = 0, _7Q = $1.msglen; _7P < _7Q; _7P++) { //#18269
            $k[$j++] = 0; //#18269
        } //#18269
        $k[$j++] = 9999; //#18269
        $1.nextXterm = $a(); //#18269
        $k[$j++] = Infinity; //#18270
        for (var _7T = 0, _7U = $1.msglen; _7T < _7U; _7T++) { //#18270
            $k[$j++] = 0; //#18270
        } //#18270
        $k[$j++] = 9999; //#18270
        $1.nextNonX = $a(); //#18270
        $k[$j++] = Infinity; //#18271
        for (var _7X = 0, _7Y = $1.msglen; _7X < _7Y; _7X++) { //#18271
            $k[$j++] = false; //#18271
        } //#18271
        $k[$j++] = false; //#18271
        $1.isECI = $a(); //#18271
        for (var _7b = $1.msglen - 1; _7b >= 0; _7b -= 1) { //#18289
            $1.i = _7b; //#18273
            $1.barchar = $get($1.msg, $1.i); //#18274
            if (($1.barchar >= 48) && ($1.barchar <= 57)) { //#18277
                $put($1.numD, $1.i, $f($get($1.numD, $1.i + 1) + 1)); //#18276
            } //#18276
            if ((($1.barchar == 13) || ($1.barchar == 42)) || ($1.barchar == 62)) { //#18281
                $put($1.nextXterm, $1.i, 0); //#18279
            } else { //#18281
                $put($1.nextXterm, $1.i, $f($get($1.nextXterm, $1.i + 1) + 1)); //#18281
            } //#18281
            var _7y = $get($1.Xvals, $1.barchar) !== undefined; //#18283
            if (!_7y) { //#18286
                $put($1.nextNonX, $1.i, 0); //#18284
            } else { //#18286
                $put($1.nextNonX, $1.i, $f($get($1.nextNonX, $1.i + 1) + 1)); //#18286
            } //#18286
            $put($1.isECI, $1.i, $1.barchar <= -1000000); //#18288
        } //#18288
        $k[$j++] = Infinity; //#18290
        var _89 = $1.nextXterm; //#18290
        for (var _8A = 0, _8B = _89.length; _8A < _8B; _8A++) { //#18290
            var _8C = $get(_89, _8A); //#18290
            $k[$j++] = _8C; //#18290
            if (_8C > 10000) { //#18290
                $j--; //#18290
                $k[$j++] = 10000; //#18290
            } //#18290
        } //#18290
        $1.nextXterm = $a(); //#18290
        $k[$j++] = Infinity; //#18291
        var _8E = $1.nextNonX; //#18291
        for (var _8F = 0, _8G = _8E.length; _8F < _8G; _8F++) { //#18291
            var _8H = $get(_8E, _8F); //#18291
            $k[$j++] = _8H; //#18291
            if (_8H > 10000) { //#18291
                $j--; //#18291
                $k[$j++] = 10000; //#18291
            } //#18291
        } //#18291
        $1.nextNonX = $a(); //#18291
        $1.isD = function() {
            $k[$j++] = ($1.char >= 48) && ($1.char <= 57); //#18293
        }; //#18293
        $1.isC = function() {
            var _8N = $get($1.CNvals, $1.char) !== undefined; //#18294
            $k[$j++] = _8N; //#18294
        }; //#18294
        $1.isT = function() {
            var _8Q = $get($1.TNvals, $1.char) !== undefined; //#18295
            $k[$j++] = _8Q; //#18295
        }; //#18295
        $1.isX = function() {
            var _8T = $get($1.Xvals, $1.char) !== undefined; //#18296
            $k[$j++] = _8T; //#18296
        }; //#18296
        $1.isE = function() {
            var _8W = $get($1.Evals, $1.char) !== undefined; //#18297
            $k[$j++] = _8W; //#18297
        }; //#18297
        $1.isEA = function() {
            $k[$j++] = $1.char > 127; //#18298
        }; //#18298
        $1.isFN = function() {
            $k[$j++] = $1.char < 0; //#18299
        }; //#18299
        $1.XtermFirst = function() {
            var _8Z = $k[--$j]; //#18300
            $k[$j++] = $lt($get($1.nextXterm, _8Z), $get($1.nextNonX, _8Z)); //#18300
        }; //#18300
        $1.lookup = function() {
            $1.ac = 1; //#18303
            $1.cc = 2; //#18303
            $1.tc = 2; //#18303
            $1.xc = 2; //#18303
            $1.ec = 2; //#18303
            $1.bc = 2.25; //#18303
            if ($1.mode == $1.A) { //#18304
                $1.ac = 0; //#18304
                $1.cc = 1; //#18304
                $1.tc = 1; //#18304
                $1.xc = 1; //#18304
                $1.ec = 1; //#18304
                $1.bc = 1.25; //#18304
            } //#18304
            if ($1.mode == $1.C) { //#18305
                $1.cc = 0; //#18305
            } //#18305
            if ($1.mode == $1.T) { //#18306
                $1.tc = 0; //#18306
            } //#18306
            if ($1.mode == $1.X) { //#18307
                $1.xc = 0; //#18307
            } //#18307
            if ($1.mode == $1.E) { //#18308
                $1.ec = 0; //#18308
            } //#18308
            if ($1.mode == $1.B) { //#18309
                $1.bc = 0; //#18309
            } //#18309
            for (var _8q = 0, _8r = 1; _8q < _8r; _8q++) { //#18344
                if ($get($1.isECI, $1.i)) { //#18311
                    $k[$j++] = $1.A; //#18311
                    break; //#18311
                } //#18311
                if ($1.mailmark && ($1.i < 45)) { //#18312
                    $k[$j++] = $1.C; //#18312
                    break; //#18312
                } //#18312
                $1.k = 0; //#18313
                for (;;) { //#18343
                    if (($1.i + $1.k) == $1.msglen) { //#18322
                        var _92 = $a(['ac', 'cc', 'tc', 'xc', 'ec', 'bc']); //#18315
                        for (var _93 = 0, _94 = _92.length; _93 < _94; _93++) { //#18315
                            var _95 = $get(_92, _93); //#18315
                            $1[_95] = Math.ceil($1[_95]); //#18315
                        } //#18315
                        var _9C = $a([$1.cc, $1.tc, $1.xc, $1.ec, $1.bc]); //#18316
                        $k[$j++] = true; //#18316
                        for (var _9D = 0, _9E = _9C.length; _9D < _9E; _9D++) { //#18316
                            var _9H = $k[--$j]; //#18316
                            $k[$j++] = _9H && ($1.ac <= $get(_9C, _9D)); //#18316
                        } //#18316
                        if ($k[--$j]) { //#18316
                            $k[$j++] = $1.A; //#18316
                            break; //#18316
                        } //#18316
                        var _9P = $a([$1.ac, $1.cc, $1.tc, $1.xc, $1.ec]); //#18317
                        $k[$j++] = true; //#18317
                        for (var _9Q = 0, _9R = _9P.length; _9Q < _9R; _9Q++) { //#18317
                            var _9U = $k[--$j]; //#18317
                            $k[$j++] = _9U && ($1.bc < $get(_9P, _9Q)); //#18317
                        } //#18317
                        if ($k[--$j]) { //#18317
                            $k[$j++] = $1.B; //#18317
                            break; //#18317
                        } //#18317
                        var _9c = $a([$1.ac, $1.cc, $1.tc, $1.xc, $1.bc]); //#18318
                        $k[$j++] = true; //#18318
                        for (var _9d = 0, _9e = _9c.length; _9d < _9e; _9d++) { //#18318
                            var _9h = $k[--$j]; //#18318
                            $k[$j++] = _9h && ($1.ec < $get(_9c, _9d)); //#18318
                        } //#18318
                        if ($k[--$j]) { //#18318
                            $k[$j++] = $1.E; //#18318
                            break; //#18318
                        } //#18318
                        var _9p = $a([$1.ac, $1.cc, $1.xc, $1.ec, $1.bc]); //#18319
                        $k[$j++] = true; //#18319
                        for (var _9q = 0, _9r = _9p.length; _9q < _9r; _9q++) { //#18319
                            var _9u = $k[--$j]; //#18319
                            $k[$j++] = _9u && ($1.tc < $get(_9p, _9q)); //#18319
                        } //#18319
                        if ($k[--$j]) { //#18319
                            $k[$j++] = $1.T; //#18319
                            break; //#18319
                        } //#18319
                        var _A2 = $a([$1.ac, $1.cc, $1.tc, $1.ec, $1.bc]); //#18320
                        $k[$j++] = true; //#18320
                        for (var _A3 = 0, _A4 = _A2.length; _A3 < _A4; _A3++) { //#18320
                            var _A7 = $k[--$j]; //#18320
                            $k[$j++] = _A7 && ($1.xc < $get(_A2, _A3)); //#18320
                        } //#18320
                        if ($k[--$j]) { //#18320
                            $k[$j++] = $1.X; //#18320
                            break; //#18320
                        } //#18320
                        $k[$j++] = $1.C; //#18321
                        break; //#18321
                    } //#18321
                    $1.char = $get($1.msg, $1.i + $1.k); //#18323
                    $k[$j++] = 'ac'; //#18324
                    $k[$j++] = $1.ac; //#18324
                    $1.isD(); //#18324
                    if ($k[--$j]) { //#18324
                        var _AH = $k[--$j]; //#18324
                        $k[$j++] = $f(_AH + (1 / 2)); //#18324
                    } else { //#18324
                        $1.isEA(); //#18324
                        if ($k[--$j]) { //#18324
                            var _AJ = $k[--$j]; //#18324
                            $k[$j++] = Math.ceil(_AJ) + 2; //#18324
                        } else { //#18324
                            var _AK = $k[--$j]; //#18324
                            $k[$j++] = Math.ceil(_AK) + 1; //#18324
                        } //#18324
                    } //#18324
                    var _AL = $k[--$j]; //#18324
                    $1[$k[--$j]] = _AL; //#18324
                    $k[$j++] = 'cc'; //#18325
                    $k[$j++] = $1.cc; //#18325
                    $1.isC(); //#18325
                    if ($k[--$j]) { //#18325
                        var _AP = $k[--$j]; //#18325
                        $k[$j++] = $f(_AP + 0.6666667); //#18325
                    } else { //#18325
                        $1.isEA(); //#18325
                        if ($k[--$j]) { //#18325
                            var _AR = $k[--$j]; //#18325
                            $k[$j++] = $f(_AR + 2.6666667); //#18325
                        } else { //#18325
                            var _AS = $k[--$j]; //#18325
                            $k[$j++] = $f(_AS + 1.3333334); //#18325
                        } //#18325
                    } //#18325
                    var _AT = $k[--$j]; //#18325
                    $1[$k[--$j]] = _AT; //#18325
                    $k[$j++] = 'tc'; //#18326
                    $k[$j++] = $1.tc; //#18326
                    $1.isT(); //#18326
                    if ($k[--$j]) { //#18326
                        var _AX = $k[--$j]; //#18326
                        $k[$j++] = $f(_AX + 0.6666667); //#18326
                    } else { //#18326
                        $1.isEA(); //#18326
                        if ($k[--$j]) { //#18326
                            var _AZ = $k[--$j]; //#18326
                            $k[$j++] = $f(_AZ + 2.6666667); //#18326
                        } else { //#18326
                            var _Aa = $k[--$j]; //#18326
                            $k[$j++] = $f(_Aa + 1.3333334); //#18326
                        } //#18326
                    } //#18326
                    var _Ab = $k[--$j]; //#18326
                    $1[$k[--$j]] = _Ab; //#18326
                    $k[$j++] = 'xc'; //#18327
                    $k[$j++] = $1.xc; //#18327
                    $1.isX(); //#18327
                    if ($k[--$j]) { //#18327
                        var _Af = $k[--$j]; //#18327
                        $k[$j++] = $f(_Af + 0.6666667); //#18327
                    } else { //#18327
                        $1.isEA(); //#18327
                        if ($k[--$j]) { //#18327
                            var _Ah = $k[--$j]; //#18327
                            $k[$j++] = $f(_Ah + 4.3333334); //#18327
                        } else { //#18327
                            var _Ai = $k[--$j]; //#18327
                            $k[$j++] = $f(_Ai + 3.3333334); //#18327
                        } //#18327
                    } //#18327
                    var _Aj = $k[--$j]; //#18327
                    $1[$k[--$j]] = _Aj; //#18327
                    $k[$j++] = 'ec'; //#18328
                    $k[$j++] = $1.ec; //#18328
                    $1.isE(); //#18328
                    if ($k[--$j]) { //#18328
                        var _An = $k[--$j]; //#18328
                        $k[$j++] = $f(_An + (3 / 4)); //#18328
                    } else { //#18328
                        $1.isEA(); //#18328
                        if ($k[--$j]) { //#18328
                            var _Ap = $k[--$j]; //#18328
                            $k[$j++] = $f(_Ap + (17 / 4)); //#18328
                        } else { //#18328
                            var _Aq = $k[--$j]; //#18328
                            $k[$j++] = $f(_Aq + (13 / 4)); //#18328
                        } //#18328
                    } //#18328
                    var _Ar = $k[--$j]; //#18328
                    $1[$k[--$j]] = _Ar; //#18328
                    $k[$j++] = 'bc'; //#18329
                    $k[$j++] = $1.bc; //#18329
                    $1.isFN(); //#18329
                    if ($k[--$j]) { //#18329
                        var _Av = $k[--$j]; //#18329
                        $k[$j++] = $f(_Av + 4); //#18329
                    } else { //#18329
                        var _Aw = $k[--$j]; //#18329
                        $k[$j++] = $f(_Aw + 1); //#18329
                    } //#18329
                    var _Ax = $k[--$j]; //#18329
                    $1[$k[--$j]] = _Ax; //#18329
                    if ($1.k >= 4) { //#18341
                        var _B5 = $a([$1.cc, $1.tc, $1.xc, $1.ec, $1.bc]); //#18331
                        $k[$j++] = true; //#18331
                        for (var _B6 = 0, _B7 = _B5.length; _B6 < _B7; _B6++) { //#18331
                            var _BA = $k[--$j]; //#18331
                            $k[$j++] = _BA && (($1.ac + 1) <= $get(_B5, _B6)); //#18331
                        } //#18331
                        if ($k[--$j]) { //#18331
                            $k[$j++] = $1.A; //#18331
                            break; //#18331
                        } //#18331
                        if (($1.bc + 1) <= $1.ac) { //#18332
                            $k[$j++] = $1.B; //#18332
                            break; //#18332
                        } //#18332
                        var _BK = $a([$1.cc, $1.tc, $1.xc, $1.ec]); //#18333
                        $k[$j++] = true; //#18333
                        for (var _BL = 0, _BM = _BK.length; _BL < _BM; _BL++) { //#18333
                            var _BP = $k[--$j]; //#18333
                            $k[$j++] = _BP && (($1.bc + 1) < $get(_BK, _BL)); //#18333
                        } //#18333
                        if ($k[--$j]) { //#18333
                            $k[$j++] = $1.B; //#18333
                            break; //#18333
                        } //#18333
                        var _BX = $a([$1.ac, $1.cc, $1.tc, $1.xc, $1.bc]); //#18334
                        $k[$j++] = true; //#18334
                        for (var _BY = 0, _BZ = _BX.length; _BY < _BZ; _BY++) { //#18334
                            var _Bc = $k[--$j]; //#18334
                            $k[$j++] = _Bc && (($1.ec + 1) < $get(_BX, _BY)); //#18334
                        } //#18334
                        if ($k[--$j]) { //#18334
                            $k[$j++] = $1.E; //#18334
                            break; //#18334
                        } //#18334
                        var _Bk = $a([$1.ac, $1.cc, $1.xc, $1.ec, $1.bc]); //#18335
                        $k[$j++] = true; //#18335
                        for (var _Bl = 0, _Bm = _Bk.length; _Bl < _Bm; _Bl++) { //#18335
                            var _Bp = $k[--$j]; //#18335
                            $k[$j++] = _Bp && (($1.tc + 1) < $get(_Bk, _Bl)); //#18335
                        } //#18335
                        if ($k[--$j]) { //#18335
                            $k[$j++] = $1.T; //#18335
                            break; //#18335
                        } //#18335
                        var _Bx = $a([$1.ac, $1.cc, $1.tc, $1.ec, $1.bc]); //#18336
                        $k[$j++] = true; //#18336
                        for (var _By = 0, _Bz = _Bx.length; _By < _Bz; _By++) { //#18336
                            var _C2 = $k[--$j]; //#18336
                            $k[$j++] = _C2 && (($1.xc + 1) < $get(_Bx, _By)); //#18336
                        } //#18336
                        if ($k[--$j]) { //#18336
                            $k[$j++] = $1.X; //#18336
                            break; //#18336
                        } //#18336
                        var _C9 = $a([$1.ac, $1.tc, $1.ec, $1.bc]); //#18337
                        $k[$j++] = true; //#18337
                        for (var _CA = 0, _CB = _C9.length; _CA < _CB; _CA++) { //#18337
                            var _CE = $k[--$j]; //#18337
                            $k[$j++] = _CE && (($1.cc + 1) < $get(_C9, _CA)); //#18337
                        } //#18337
                        if ($k[--$j]) { //#18340
                            if ($1.cc < $1.xc) { //#18338
                                $k[$j++] = $1.C; //#18338
                                break; //#18338
                            } //#18338
                            if ($1.cc == $1.xc) { //#18339
                                $k[$j++] = ($1.i + $1.k) + 1; //#18339
                                $1.XtermFirst(); //#18339
                                if ($k[--$j]) { //#18339
                                    $k[$j++] = $1.X; //#18339
                                    break; //#18339
                                } else { //#18339
                                    $k[$j++] = $1.C; //#18339
                                    break; //#18339
                                } //#18339
                            } //#18339
                        } //#18339
                    } //#18339
                    $1.k = $1.k + 1; //#18342
                } //#18342
            } //#18342
        }; //#18342
        $1.addtocws = function() {
            var _CR = $k[--$j]; //#18348
            $puti($1.cws, $1.j, _CR); //#18348
            $1.j = _CR.length + $1.j; //#18349
        }; //#18349
        $1.ECItocws = function() {
            var _CW = $f((-$k[--$j]) - 1000000); //#18354
            $k[$j++] = _CW; //#18368
            if (_CW <= 126) { //#18367
                var _CX = $k[--$j]; //#18355
                $k[$j++] = $f(_CX + 1); //#18356
                $astore($a(1)); //#18356
            } else { //#18367
                var _CZ = $k[--$j]; //#18357
                $k[$j++] = _CZ; //#18368
                if (_CZ <= 16382) { //#18367
                    var _Cb = $f($k[--$j] - 127); //#18359
                    $k[$j++] = (~~(_Cb / 254)) + 128; //#18361
                    $k[$j++] = $f((_Cb % 254) + 1); //#18361
                    $astore($a(2)); //#18361
                } else { //#18367
                    var _Ce = $f($k[--$j] - 16383); //#18364
                    $k[$j++] = (~~(_Ce / 64516)) + 192; //#18367
                    $k[$j++] = ((~~(_Ce / 254)) % 254) + 1; //#18367
                    $k[$j++] = $f((_Ce % 254) + 1); //#18367
                    $astore($a(3)); //#18367
                } //#18367
            } //#18367
        }; //#18367
        $1.encA = function() {
            for (var _Cg = 0, _Ch = 1; _Cg < _Ch; _Cg++) { //#18393
                if ($get($1.isECI, $1.i)) { //#18378
                    $k[$j++] = $get($1.Avals, $1.eci); //#18374
                    $1.addtocws(); //#18374
                    $k[$j++] = $get($1.msg, $1.i); //#18375
                    $1.ECItocws(); //#18375
                    $1.addtocws(); //#18375
                    $1.i = $1.i + 1; //#18376
                    break; //#18377
                } //#18377
                if ($get($1.numD, $1.i) >= 2) { //#18383
                    var _Cv = $s(2); //#18380
                    $put(_Cv, 0, $get($1.msg, $1.i)); //#18380
                    $put(_Cv, 1, $get($1.msg, $1.i + 1)); //#18380
                    $k[$j++] = $get($1.Avals, _Cv); //#18380
                    $1.addtocws(); //#18380
                    $1.i = $1.i + 2; //#18381
                    break; //#18382
                } //#18382
                $k[$j++] = 'newmode'; //#18384
                $1.lookup(); //#18384
                var _D5 = $k[--$j]; //#18384
                $1[$k[--$j]] = _D5; //#18384
                if ($1.newmode != $1.mode) { //#18389
                    $k[$j++] = $get($1.Avals, $get($a([-1, $1.lC, $1.lT, $1.lX, $1.lE, $1.lB]), $1.newmode)); //#18386
                    $1.addtocws(); //#18386
                    $1.mode = $1.newmode; //#18387
                    break; //#18388
                } //#18388
                $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#18390
                $1.addtocws(); //#18390
                $1.i = $1.i + 1; //#18391
                break; //#18392
            } //#18392
        }; //#18392
        $1.CTXvalstocws = function() {
            $1.in = $k[--$j]; //#18397
            $k[$j++] = Infinity; //#18398
            for (var _DT = 0, _DS = $1.in.length - 1; _DT <= _DS; _DT += 3) { //#18402
                var _DV = $geti($1.in, _DT, 3); //#18400
                $k[$j++] = 0; //#18400
                for (var _DW = 0, _DX = _DV.length; _DW < _DX; _DW++) { //#18400
                    var _DZ = $k[--$j]; //#18400
                    $k[$j++] = $f(_DZ + $get(_DV, _DW)) * 40; //#18400
                } //#18400
                var _Db = (~~($k[--$j] / 40)) + 1; //#18401
                $k[$j++] = ~~(_Db / 256); //#18401
                $k[$j++] = _Db % 256; //#18401
            } //#18401
            $astore($a($counttomark())); //#18403
            var _De = $k[--$j]; //#18403
            var _Df = $k[--$j]; //#18403
            $k[$j++] = _De; //#18403
            $k[$j++] = _Df; //#18403
            $j--; //#18403
        }; //#18403
        $1.encCTX = function() {
            $1.p = 0; //#18407
            $1.ctxvals = $a(2500); //#18408
            $1.done = false; //#18409
            for (;;) { //#18488
                if ($1.i == $1.msglen) { //#18413
                    break; //#18413
                } //#18413
                var _Dp = $get($get($1.encvals, $1.mode), $get($1.msg, $1.i)) !== undefined; //#18414
                if (!_Dp) { //#18414
                    break; //#18414
                } //#18414
                if (($1.p % 3) == 0) { //#18483
                    if ($1.p > 0) { //#18428
                        $k[$j++] = 'newmode'; //#18417
                        $1.lookup(); //#18417
                        var _Ds = $k[--$j]; //#18417
                        $1[$k[--$j]] = _Ds; //#18417
                        if ($ne($1.newmode, $1.mode)) { //#18427
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#18419
                            $1.CTXvalstocws(); //#18419
                            $1.addtocws(); //#18419
                            $k[$j++] = $a([$1.unlcw]); //#18420
                            $1.addtocws(); //#18420
                            if ($1.newmode != $1.A) { //#18423
                                $k[$j++] = $get($1.Avals, $get($a([-1, $1.lC, $1.lT, $1.lX, $1.lE, $1.lB]), $1.newmode)); //#18422
                                $1.addtocws(); //#18422
                            } //#18422
                            $1.mode = $1.newmode; //#18424
                            $1.done = true; //#18425
                            break; //#18426
                        } //#18426
                    } //#18426
                    if (($1.msglen - $1.i) <= 3) { //#18482
                        $1.remcws = $get($1.numremcws, $1.j + ((~~($1.p / 3)) * 2)); //#18430
                        $k[$j++] = Infinity; //#18436
                        var _EO = $geti($1.msg, $1.i, $1.msglen - $1.i); //#18432
                        for (var _EP = 0, _EQ = _EO.length; _EP < _EQ; _EP++) { //#18438
                            var _ER = $get(_EO, _EP); //#18438
                            var _EV = $get($get($1.encvals, $1.mode), _ER) !== undefined; //#18433
                            $k[$j++] = _ER; //#18437
                            if (_EV) { //#18436
                                $aload($get($get($1.encvals, $1.mode), $k[--$j])); //#18434
                            } else { //#18436
                                $j--; //#18436
                                $k[$j++] = -1; //#18436
                                $k[$j++] = -1; //#18436
                                $k[$j++] = -1; //#18436
                                $k[$j++] = -1; //#18436
                            } //#18436
                        } //#18436
                        $1.remvals = $a(); //#18436
                        if (($1.remcws == 2) && ($1.remvals.length == 3)) { //#18450
                            $k[$j++] = Infinity; //#18444
                            $aload($geti($1.ctxvals, 0, $1.p)); //#18443
                            $aload($1.remvals); //#18444
                            var _Ei = $a(); //#18444
                            $k[$j++] = _Ei; //#18445
                            $1.CTXvalstocws(); //#18445
                            $1.addtocws(); //#18445
                            $1.mode = $1.A; //#18446
                            $1.i = $1.msglen; //#18447
                            $1.done = true; //#18448
                            break; //#18449
                        } //#18449
                        if ((($1.remcws == 2) && ($1.remvals.length == 2)) && ($1.mode != $1.X)) { //#18462
                            $k[$j++] = Infinity; //#18456
                            $aload($geti($1.ctxvals, 0, $1.p)); //#18454
                            $aload($1.remvals); //#18455
                            $aload($get($get($1.encvals, $1.mode), $1.sft1)); //#18456
                            var _Ey = $a(); //#18456
                            $k[$j++] = _Ey; //#18457
                            $1.CTXvalstocws(); //#18457
                            $1.addtocws(); //#18457
                            $1.mode = $1.A; //#18458
                            $1.i = $1.msglen; //#18459
                            $1.done = true; //#18460
                            break; //#18461
                        } //#18461
                        if (($1.remcws == 2) && ($1.remvals.length == 1)) { //#18472
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#18465
                            $1.CTXvalstocws(); //#18465
                            $1.addtocws(); //#18465
                            $k[$j++] = $a([$1.unlcw]); //#18466
                            $1.addtocws(); //#18466
                            $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#18467
                            $1.addtocws(); //#18467
                            $1.mode = $1.A; //#18468
                            $1.i = $1.msglen; //#18469
                            $1.done = true; //#18470
                            break; //#18471
                        } //#18471
                        if (($1.remcws == 1) && ($1.remvals.length == 1)) { //#18481
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#18475
                            $1.CTXvalstocws(); //#18475
                            $1.addtocws(); //#18475
                            $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#18476
                            $1.addtocws(); //#18476
                            $1.mode = $1.A; //#18477
                            $1.i = $1.msglen; //#18478
                            $1.done = true; //#18479
                            break; //#18480
                        } //#18480
                    } //#18480
                } //#18480
                var _FX = $get($get($1.encvals, $1.mode), $get($1.msg, $1.i)); //#18484
                $puti($1.ctxvals, $1.p, _FX); //#18485
                $1.p = _FX.length + $1.p; //#18486
                $1.i = $1.i + 1; //#18487
            } //#18487
            if (!$1.done) { //#18512
                for (;;) { //#18496
                    if (($1.p % 3) == 0) { //#18493
                        break; //#18493
                    } //#18493
                    $1.i = $1.i - 1; //#18494
                    $1.p = $1.p - $get($get($1.encvals, $1.mode), $get($1.msg, $1.i)).length; //#18495
                } //#18495
                $k[$j++] = Infinity; //#18498
                $aload($geti($1.ctxvals, 0, $1.p)); //#18498
                var _Fq = $a(); //#18498
                $k[$j++] = _Fq; //#18499
                $1.CTXvalstocws(); //#18499
                $1.addtocws(); //#18499
                $k[$j++] = $a([$1.unlcw]); //#18500
                $1.addtocws(); //#18500
                $1.mode = $1.A; //#18501
                if (($1.i != $1.msglen) && $nt($get($1.isECI, $1.i))) { //#18511
                    if ($get($1.numD, $1.i) >= 2) { //#18509
                        var _G2 = $s(2); //#18505
                        $put(_G2, 0, $get($1.msg, $1.i)); //#18505
                        $put(_G2, 1, $get($1.msg, $1.i + 1)); //#18505
                        $k[$j++] = $get($1.Avals, _G2); //#18505
                        $1.addtocws(); //#18505
                        $1.i = $1.i + 2; //#18506
                    } else { //#18509
                        $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#18508
                        $1.addtocws(); //#18508
                        $1.i = $1.i + 1; //#18509
                    } //#18509
                } //#18509
            } //#18509
        }; //#18509
        $1.Evalstocws = function() {
            $1.in = $k[--$j]; //#18517
            $1.inlen = $1.in.length; //#18518
            $1.outlen = ~~(Math.ceil(($1.in.length / 4) * 3)); //#18519
            $k[$j++] = Infinity; //#18520
            $aload($1.in); //#18520
            $k[$j++] = 0; //#18520
            $k[$j++] = 0; //#18520
            $k[$j++] = 0; //#18520
            $1.in = $a(); //#18520
            $k[$j++] = Infinity; //#18521
            for (var _GP = 0, _GO = $1.inlen - 1; _GP <= _GO; _GP += 4) { //#18527
                var _GR = $geti($1.in, _GP, 4); //#18523
                $k[$j++] = 0; //#18523
                for (var _GS = 0, _GT = _GR.length; _GS < _GT; _GS++) { //#18523
                    var _GV = $k[--$j]; //#18523
                    $k[$j++] = $or(_GV, $get(_GR, _GS)) << 6; //#18523
                } //#18523
                var _GX = $k[--$j] >>> 6; //#18524
                $k[$j++] = (_GX >>> 16) & 255; //#18526
                $k[$j++] = (_GX >>> 8) & 255; //#18526
                $k[$j++] = _GX & 255; //#18526
            } //#18526
            $astore($a($counttomark())); //#18528
            var _Ga = $k[--$j]; //#18528
            var _Gb = $k[--$j]; //#18528
            $k[$j++] = _Ga; //#18528
            $k[$j++] = _Gb; //#18528
            $j--; //#18528
            var _Ge = $geti($k[--$j], 0, $1.outlen); //#18529
            $k[$j++] = _Ge; //#18529
        }; //#18529
        $1.encE = function() {
            $1.p = 0; //#18533
            $1.edifactvals = $a(2100); //#18534
            for (;;) { //#18563
                if ($1.i == $1.msglen) { //#18538
                    break; //#18538
                } //#18538
                var _Gm = $get($1.Evals, $get($1.msg, $1.i)) !== undefined; //#18539
                if (!_Gm) { //#18539
                    break; //#18539
                } //#18539
                if (($1.p % 4) == 0) { //#18558
                    if (($1.msglen - $1.i) <= 2) { //#18556
                        $1.remcws = $get($1.numremcws, $1.j + ((~~($1.p / 4)) * 3)); //#18542
                        $k[$j++] = Infinity; //#18545
                        var _Gy = $geti($1.msg, $1.i, $1.msglen - $1.i); //#18544
                        for (var _Gz = 0, _H0 = _Gy.length; _Gz < _H0; _Gz++) { //#18546
                            $aload($get($1.Avals, $get(_Gy, _Gz))); //#18545
                        } //#18545
                        $1.remvals = $a(); //#18545
                        if ((($1.remcws == 1) || ($1.remcws == 2)) && ($1.remvals.length <= $1.remcws)) { //#18555
                            $k[$j++] = $geti($1.edifactvals, 0, $1.p); //#18550
                            $1.Evalstocws(); //#18550
                            $1.addtocws(); //#18550
                            $k[$j++] = $1.remvals; //#18551
                            $1.addtocws(); //#18551
                            $1.mode = $1.A; //#18552
                            $1.i = $1.msglen; //#18553
                            break; //#18554
                        } //#18554
                    } //#18554
                    $1.lookup(); //#18557
                    if ($k[--$j] != $1.mode) { //#18557
                        break; //#18557
                    } //#18557
                } //#18557
                var _HL = $get($1.Evals, $get($1.msg, $1.i)); //#18559
                $puti($1.edifactvals, $1.p, _HL); //#18560
                $1.p = _HL.length + $1.p; //#18561
                $1.i = $1.i + 1; //#18562
            } //#18562
            if ($1.mode != $1.A) { //#18585
                $1.remcws = $f($get($1.numremcws, ($1.j + ((~~($1.p / 4)) * 3)) - 1) - 1); //#18567
                if (((($1.p % 4) != 0) || ($1.i != $1.msglen)) || ($1.remcws >= 3)) { //#18572
                    var _Hc = $get($1.Evals, $1.unl); //#18569
                    $puti($1.edifactvals, $1.p, _Hc); //#18570
                    $1.p = _Hc.length + $1.p; //#18571
                } //#18571
                $k[$j++] = $geti($1.edifactvals, 0, $1.p); //#18573
                $1.Evalstocws(); //#18573
                $1.addtocws(); //#18573
                $1.mode = $1.A; //#18574
                if (($1.i != $1.msglen) && $nt($get($1.isECI, $1.i))) { //#18584
                    if ($get($1.numD, $1.i) >= 2) { //#18582
                        var _Hs = $s(2); //#18578
                        $put(_Hs, 0, $get($1.msg, $1.i)); //#18578
                        $put(_Hs, 1, $get($1.msg, $1.i + 1)); //#18578
                        $k[$j++] = $get($1.Avals, _Hs); //#18578
                        $1.addtocws(); //#18578
                        $1.i = $1.i + 2; //#18579
                    } else { //#18582
                        $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#18581
                        $1.addtocws(); //#18581
                        $1.i = $1.i + 1; //#18582
                    } //#18582
                } //#18582
            } //#18582
        }; //#18582
        $1.encB = function() {
            $1.p = 0; //#18590
            $1.bvals = $a(1558); //#18590
            for (;;) { //#18596
                if ($1.i == $1.msglen) { //#18591
                    break; //#18591
                } //#18591
                $1.lookup(); //#18592
                if ($k[--$j] != $1.mode) { //#18592
                    break; //#18592
                } //#18592
                $put($1.bvals, $1.p, $get($1.msg, $1.i)); //#18593
                $1.p = $1.p + 1; //#18594
                $1.i = $1.i + 1; //#18595
            } //#18595
            $1.remcws = $f($get($1.numremcws, $1.j + $1.p) - 1); //#18597
            $k[$j++] = Infinity; //#18604
            if (($1.remcws == 0) && ($1.i == $1.msglen)) { //#18602
                $k[$j++] = 0; //#18600
            } else { //#18602
                if ($1.p < 250) { //#18602
                    $k[$j++] = $1.p; //#18602
                } else { //#18602
                    $k[$j++] = (~~($1.p / 250)) + 249; //#18602
                    $k[$j++] = $1.p % 250; //#18602
                } //#18602
            } //#18602
            $aload($geti($1.bvals, 0, $1.p)); //#18604
            $1.bvals = $a(); //#18604
            for (var _Ib = 0, _Ia = $1.bvals.length - 1; _Ib <= _Ia; _Ib += 1) { //#18611
                $1.p = _Ib; //#18607
                var _Ih = $f(((((($1.j + $1.p) + 1) * 149) % 255) + 1) + $get($1.bvals, $1.p)); //#18609
                $k[$j++] = _Ih; //#18609
                if (_Ih >= 256) { //#18609
                    var _Ii = $k[--$j]; //#18609
                    $k[$j++] = $f(_Ii - 256); //#18609
                } //#18609
                $put($1.bvals, $1.p, $k[--$j]); //#18610
            } //#18610
            $k[$j++] = $1.bvals; //#18612
            $1.addtocws(); //#18612
            $1.mode = $1.A; //#18613
        }; //#18613
        $1.cws = $a(1558); //#18617
        $1.mode = $1.A; //#18618
        $1.i = 0; //#18618
        $1.j = 0; //#18618
        for (;;) { //#18621
            if ($1.i >= $1.msglen) { //#18619
                break; //#18619
            } //#18619
            if ($1[$get($a(['encA', 'encCTX', 'encCTX', 'encCTX', 'encE', 'encB']), $1.mode)]() === true) {
                break;
            } //#18620
        } //#18620
        $1.cws = $geti($1.cws, 0, $1.j); //#18622
    } //#18622
    $1.datlen = $1.cws.length; //#18627
    $1.remcws = $f($get($1.numremcws, $1.j - 1) - 1); //#18628
    if ($1.remcws > 0) { //#18637
        $k[$j++] = Infinity; //#18630
        $aload($1.cws); //#18630
        for (var _J6 = 0, _J7 = $1.remcws; _J6 < _J7; _J6++) { //#18630
            $k[$j++] = 129; //#18630
        } //#18630
        $1.cws = $a(); //#18630
        for (var _JD = $1.datlen + 1, _JC = $f($f($1.datlen + $1.remcws) - 1); _JD <= _JC; _JD += 1) { //#18636
            $1.i = _JD; //#18632
            var _JF = (((($1.i + 1) * 149) % 253) + 1) + 129; //#18634
            $k[$j++] = _JF; //#18634
            if (_JF > 254) { //#18634
                var _JG = $k[--$j]; //#18634
                $k[$j++] = $f(_JG - 254); //#18634
            } //#18634
            $put($1.cws, $1.i, $k[--$j]); //#18635
        } //#18635
    } //#18635
    var _JL = $get($1.options, 'debugcws') !== undefined; //#18639
    if (_JL) { //#18639
        $k[$j++] = 'bwipp.debugcws'; //#18639
        $k[$j++] = $1.cws; //#18639
        bwipp_raiseerror(); //#18639
    } //#18639
    $1.i = 0; //#18642
    for (;;) { //#18663
        $1.m = $get($1.metrics, $1.i); //#18643
        $1.rows = $get($1.m, 0); //#18644
        $1.cols = $get($1.m, 1); //#18645
        $1.regh = $get($1.m, 2); //#18646
        $1.regv = $get($1.m, 3); //#18647
        $1.rscw = $get($1.m, 4); //#18648
        $1.rsbl = $get($1.m, 5); //#18649
        $1.mrows = $f($1.rows - (2 * $1.regh)); //#18650
        $1.mcols = $f($1.cols - (2 * $1.regv)); //#18651
        $1.rrows = ~~($1.mrows / $1.regh); //#18652
        $1.rcols = ~~($1.mcols / $1.regv); //#18653
        $1.ncws = $f((~~(($1.mrows * $1.mcols) / 8)) - $1.rscw); //#18654
        $1.okay = true; //#18655
        if ($1.cws.length != $1.ncws) { //#18656
            $1.okay = false; //#18656
        } //#18656
        if (($1.urows != 0) && ($1.urows != $1.rows)) { //#18657
            $1.okay = false; //#18657
        } //#18657
        if (($1.ucols != 0) && ($1.ucols != $1.cols)) { //#18658
            $1.okay = false; //#18658
        } //#18658
        if ($eq($1.format, "square") && $ne($1.rows, $1.cols)) { //#18659
            $1.okay = false; //#18659
        } //#18659
        if ($eq($1.format, "rectangle") && $eq($1.rows, $1.cols)) { //#18660
            $1.okay = false; //#18660
        } //#18660
        if ($1.okay) { //#18661
            break; //#18661
        } //#18661
        $1.i = $1.i + 1; //#18662
    } //#18662
    $1.cwbs = $a($1.rsbl); //#18666
    $1.ecbs = $a($1.rsbl); //#18667
    for (var _K9 = 0, _K8 = $f($1.rsbl - 1); _K9 <= _K8; _K9 += 1) { //#18682
        $1.i = _K9; //#18669
        if ($1.cws.length != 1558) { //#18673
            $1.cwbsize = ~~($1.cws.length / $1.rsbl); //#18671
        } else { //#18673
            if ($1.i <= 7) { //#18673
                $1.cwbsize = 156; //#18673
            } else { //#18673
                $1.cwbsize = 155; //#18673
            } //#18673
        } //#18673
        $1.cwb = $a($1.cwbsize); //#18675
        for (var _KI = 0, _KH = $1.cwbsize - 1; _KI <= _KH; _KI += 1) { //#18679
            $1.j = _KI; //#18677
            $put($1.cwb, $1.j, $get($1.cws, $f(($1.j * $1.rsbl) + $1.i))); //#18678
        } //#18678
        $put($1.cwbs, $1.i, $1.cwb); //#18680
        $k[$j++] = $1.ecbs; //#18681
        $k[$j++] = $1.i; //#18681
        $k[$j++] = Infinity; //#18681
        for (var _KX = 0, _KY = ~~($1.rscw / $1.rsbl); _KX < _KY; _KX++) { //#18681
            $k[$j++] = 0; //#18681
        } //#18681
        var _KZ = $a(); //#18681
        var _Ka = $k[--$j]; //#18681
        $put($k[--$j], _Ka, _KZ); //#18681
    } //#18681
    $k[$j++] = Infinity; //#18686
    $k[$j++] = 1; //#18686
    for (var _Kc = 0, _Kd = 255; _Kc < _Kd; _Kc++) { //#18686
        var _Ke = $k[--$j]; //#18686
        var _Kf = _Ke * 2; //#18686
        $k[$j++] = _Ke; //#18686
        $k[$j++] = _Kf; //#18686
        if (_Kf >= 256) { //#18686
            var _Kg = $k[--$j]; //#18686
            $k[$j++] = _Kg ^ 301; //#18686
        } //#18686
    } //#18686
    $1.rsalog = $a(); //#18686
    $1.rslog = $a(256); //#18687
    for (var _Kj = 1; _Kj <= 255; _Kj += 1) { //#18688
        $put($1.rslog, $get($1.rsalog, _Kj), _Kj); //#18688
    } //#18688
    $1.rsprod = function() {
        var _Kn = $k[--$j]; //#18693
        var _Ko = $k[--$j]; //#18693
        $k[$j++] = _Ko; //#18697
        $k[$j++] = _Kn; //#18697
        if ((_Kn != 0) && (_Ko != 0)) { //#18696
            var _Kr = $get($1.rslog, $k[--$j]); //#18694
            var _Kw = $get($1.rsalog, $f(_Kr + $get($1.rslog, $k[--$j])) % 255); //#18694
            $k[$j++] = _Kw; //#18694
        } else { //#18696
            $j -= 2; //#18696
            $k[$j++] = 0; //#18696
        } //#18696
    }; //#18696
    $k[$j++] = Infinity; //#18701
    $k[$j++] = 1; //#18701
    for (var _Kz = 0, _L0 = ~~($1.rscw / $1.rsbl); _Kz < _L0; _Kz++) { //#18701
        $k[$j++] = 0; //#18701
    } //#18701
    $1.coeffs = $a(); //#18701
    for (var _L5 = 1, _L4 = ~~($1.rscw / $1.rsbl); _L5 <= _L4; _L5 += 1) { //#18710
        $1.i = _L5; //#18703
        $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#18704
        for (var _LC = $1.i - 1; _LC >= 1; _LC -= 1) { //#18708
            $1.j = _LC; //#18706
            $k[$j++] = $1.coeffs; //#18707
            $k[$j++] = $1.j; //#18707
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#18707
            $k[$j++] = $get($1.coeffs, $1.j); //#18707
            $k[$j++] = $get($1.rsalog, $1.i); //#18707
            $1.rsprod(); //#18707
            var _LO = $k[--$j]; //#18707
            var _LP = $k[--$j]; //#18707
            var _LQ = $k[--$j]; //#18707
            $put($k[--$j], _LQ, $xo(_LP, _LO)); //#18707
        } //#18707
        $k[$j++] = $1.coeffs; //#18709
        $k[$j++] = 0; //#18709
        $k[$j++] = $get($1.coeffs, 0); //#18709
        $k[$j++] = $get($1.rsalog, $1.i); //#18709
        $1.rsprod(); //#18709
        var _LY = $k[--$j]; //#18709
        var _LZ = $k[--$j]; //#18709
        $put($k[--$j], _LZ, _LY); //#18709
    } //#18709
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#18711
    for (var _Lg = 0, _Lf = $1.cwbs.length - 1; _Lg <= _Lf; _Lg += 1) { //#18727
        $1.i = _Lg; //#18715
        $1.cwb = $get($1.cwbs, $1.i); //#18716
        $1.ecb = $get($1.ecbs, $1.i); //#18717
        for (var _Lp = 0, _Lo = $1.cwb.length - 1; _Lp <= _Lo; _Lp += 1) { //#18726
            $1.t = $xo($get($1.cwb, _Lp), $get($1.ecb, 0)); //#18719
            for (var _Lv = $1.ecb.length - 1; _Lv >= 0; _Lv -= 1) { //#18725
                $1.j = _Lv; //#18721
                $1.p = ($1.ecb.length - $1.j) - 1; //#18722
                $k[$j++] = $1.ecb; //#18723
                $k[$j++] = $1.p; //#18723
                $k[$j++] = $1.t; //#18723
                $k[$j++] = $get($1.coeffs, $1.j); //#18723
                $1.rsprod(); //#18723
                var _M4 = $k[--$j]; //#18723
                var _M5 = $k[--$j]; //#18723
                $put($k[--$j], _M5, _M4); //#18723
                if ($1.j > 0) { //#18724
                    $put($1.ecb, $1.p, $xo($get($1.ecb, $1.p + 1), $get($1.ecb, $1.p))); //#18724
                } //#18724
            } //#18724
        } //#18724
    } //#18724
    if ($1.ncws == 1558) { //#18732
        $k[$j++] = Infinity; //#18731
        var _MI = $geti($1.ecbs, 8, 2); //#18731
        for (var _MJ = 0, _MK = _MI.length; _MJ < _MK; _MJ++) { //#18731
            $k[$j++] = $get(_MI, _MJ); //#18731
        } //#18731
        var _MN = $geti($1.ecbs, 0, 8); //#18731
        for (var _MO = 0, _MP = _MN.length; _MO < _MP; _MO++) { //#18731
            $k[$j++] = $get(_MN, _MO); //#18731
        } //#18731
        $1.ecbs = $a(); //#18731
    } //#18731
    $k[$j++] = Infinity; //#18735
    var _MS = $1.cws; //#18735
    for (var _MT = 0, _MU = _MS.length; _MT < _MU; _MT++) { //#18735
        $k[$j++] = $get(_MS, _MT); //#18735
    } //#18735
    for (var _MX = 0, _MY = $1.rscw; _MX < _MY; _MX++) { //#18735
        $k[$j++] = 0; //#18735
    } //#18735
    $1.cws = $a(); //#18735
    for (var _Mc = 0, _Mb = $f($1.rscw - 1); _Mc <= _Mb; _Mc += 1) { //#18739
        $1.i = _Mc; //#18737
        $put($1.cws, $f($1.ncws + $1.i), $get($get($1.ecbs, $1.i % $1.rsbl), ~~($1.i / $1.rsbl))); //#18738
    } //#18738
    $1.module = function() {
        var _Mn = $k[--$j]; //#18744
        var _Mo = $k[--$j]; //#18744
        var _Mp = $k[--$j]; //#18744
        var _Ms = $strcpy($s(8), "00000000"); //#18745
        var _Mu = $cvrs($s(8), $k[--$j], 2); //#18745
        $puti(_Ms, 8 - _Mu.length, _Mu); //#18746
        $k[$j++] = _Mp; //#18747
        $k[$j++] = _Mo; //#18747
        $k[$j++] = _Mn; //#18747
        $k[$j++] = _Ms; //#18747
        for (var _Mv = 7; _Mv >= 0; _Mv -= 1) { //#18747
            var _Mw = $k[--$j]; //#18747
            $k[$j++] = $f($get(_Mw, _Mv) - 48); //#18747
            $k[$j++] = _Mw; //#18747
        } //#18747
        $j--; //#18747
        var _My = $k[--$j]; //#18748
        var _Mz = $k[--$j]; //#18748
        var _N0 = $k[--$j]; //#18748
        var _N1 = $k[--$j]; //#18748
        var _N2 = $k[--$j]; //#18748
        var _N3 = $k[--$j]; //#18748
        var _N4 = $k[--$j]; //#18748
        var _N5 = $k[--$j]; //#18748
        var _N6 = $k[--$j]; //#18748
        var _N7 = $k[--$j]; //#18748
        var _N8 = $k[--$j]; //#18748
        $k[$j++] = _N5; //#18765
        $k[$j++] = _N4; //#18765
        $k[$j++] = _N3; //#18765
        $k[$j++] = _N2; //#18765
        $k[$j++] = _N1; //#18765
        $k[$j++] = _N0; //#18765
        $k[$j++] = _Mz; //#18765
        $k[$j++] = _My; //#18765
        $k[$j++] = _N8; //#18765
        $k[$j++] = _N7; //#18765
        $forall(_N6, function() { //#18765
            if ($k[--$j]() === true) {
                return true;
            } //#18751
            var _NA = $k[--$j]; //#18752
            var _NB = $k[--$j]; //#18752
            $k[$j++] = _NB; //#18755
            $k[$j++] = _NA; //#18755
            if (_NB < 0) { //#18755
                var _NC = $k[--$j]; //#18753
                var _ND = $k[--$j]; //#18753
                $k[$j++] = $f(_ND + $1.mrows); //#18754
                $k[$j++] = $f(_NC + ($f(4 - ($f($1.mrows + 4) % 8)))); //#18754
            } //#18754
            var _NG = $k[--$j]; //#18756
            $k[$j++] = _NG; //#18759
            if (_NG < 0) { //#18759
                var _NI = $k[--$j]; //#18757
                var _NJ = $k[--$j]; //#18757
                $k[$j++] = $f(_NJ + ($f(4 - ($f($1.mcols + 4) % 8)))); //#18758
                $k[$j++] = $f(_NI + $1.mcols); //#18758
            } //#18758
            var _NL = $k[--$j]; //#18760
            var _NM = $k[--$j]; //#18760
            $k[$j++] = _NM; //#18762
            $k[$j++] = _NL; //#18762
            if (_NM >= $1.mrows) { //#18762
                var _NO = $k[--$j]; //#18761
                var _NP = $k[--$j]; //#18761
                $k[$j++] = $f(_NP - $1.mrows); //#18761
                $k[$j++] = _NO; //#18761
            } //#18761
            var _NR = $k[--$j]; //#18763
            var _NS = $k[--$j]; //#18763
            var _NV = $k[--$j]; //#18764
            var _NW = $k[--$j]; //#18764
            $put($1.mmat, $f(_NR + (_NS * $1.mcols)), $k[--$j]); //#18764
            $k[$j++] = _NW; //#18764
            $k[$j++] = _NV; //#18764
        }); //#18764
    }; //#18764
    var _No = $a([function() {
        var _NY = $k[--$j]; //#18770
        var _NZ = $k[--$j]; //#18770
        $k[$j++] = _NZ; //#18770
        $k[$j++] = _NY; //#18770
        $k[$j++] = $f(_NZ - 2); //#18770
        $k[$j++] = $f(_NY - 2); //#18770
    }, function() {
        var _Na = $k[--$j]; //#18770
        var _Nb = $k[--$j]; //#18770
        $k[$j++] = _Nb; //#18770
        $k[$j++] = _Na; //#18770
        $k[$j++] = $f(_Nb - 2); //#18770
        $k[$j++] = $f(_Na - 1); //#18770
    }, function() {
        var _Nc = $k[--$j]; //#18771
        var _Nd = $k[--$j]; //#18771
        $k[$j++] = _Nd; //#18771
        $k[$j++] = _Nc; //#18771
        $k[$j++] = $f(_Nd - 1); //#18771
        $k[$j++] = $f(_Nc - 2); //#18771
    }, function() {
        var _Ne = $k[--$j]; //#18771
        var _Nf = $k[--$j]; //#18771
        $k[$j++] = _Nf; //#18771
        $k[$j++] = _Ne; //#18771
        $k[$j++] = $f(_Nf - 1); //#18771
        $k[$j++] = $f(_Ne - 1); //#18771
    }, function() {
        var _Ng = $k[--$j]; //#18772
        var _Nh = $k[--$j]; //#18772
        $k[$j++] = _Nh; //#18772
        $k[$j++] = _Ng; //#18772
        $k[$j++] = $f(_Nh - 1); //#18772
        $k[$j++] = _Ng; //#18772
    }, function() {
        var _Ni = $k[--$j]; //#18772
        var _Nj = $k[--$j]; //#18772
        $k[$j++] = _Nj; //#18772
        $k[$j++] = _Ni; //#18772
        $k[$j++] = _Nj; //#18772
        $k[$j++] = $f(_Ni - 2); //#18772
    }, function() {
        var _Nk = $k[--$j]; //#18773
        var _Nl = $k[--$j]; //#18773
        $k[$j++] = _Nl; //#18773
        $k[$j++] = _Nk; //#18773
        $k[$j++] = _Nl; //#18773
        $k[$j++] = $f(_Nk - 1); //#18773
    }, function() {
        var _Nm = $k[--$j]; //#18773
        var _Nn = $k[--$j]; //#18773
        $k[$j++] = _Nn; //#18773
        $k[$j++] = _Nm; //#18773
        $k[$j++] = _Nn; //#18773
        $k[$j++] = _Nm; //#18773
    }]); //#18773
    $1.dmn = _No; //#18774
    var _Nx = $a([function() {
        $k[$j++] = $f($1.mrows - 1); //#18777
        $k[$j++] = 0; //#18777
    }, function() {
        $k[$j++] = $f($1.mrows - 1); //#18777
        $k[$j++] = 1; //#18777
    }, function() {
        $k[$j++] = $f($1.mrows - 1); //#18778
        $k[$j++] = 2; //#18778
    }, function() {
        $k[$j++] = 0; //#18778
        $k[$j++] = $f($1.mcols - 2); //#18778
    }, function() {
        $k[$j++] = 0; //#18779
        $k[$j++] = $f($1.mcols - 1); //#18779
    }, function() {
        $k[$j++] = 1; //#18779
        $k[$j++] = $f($1.mcols - 1); //#18779
    }, function() {
        $k[$j++] = 2; //#18780
        $k[$j++] = $f($1.mcols - 1); //#18780
    }, function() {
        $k[$j++] = 3; //#18780
        $k[$j++] = $f($1.mcols - 1); //#18780
    }]); //#18780
    $1.dmc1 = _Nx; //#18781
    var _O6 = $a([function() {
        $k[$j++] = $f($1.mrows - 3); //#18784
        $k[$j++] = 0; //#18784
    }, function() {
        $k[$j++] = $f($1.mrows - 2); //#18784
        $k[$j++] = 0; //#18784
    }, function() {
        $k[$j++] = $f($1.mrows - 1); //#18785
        $k[$j++] = 0; //#18785
    }, function() {
        $k[$j++] = 0; //#18785
        $k[$j++] = $f($1.mcols - 4); //#18785
    }, function() {
        $k[$j++] = 0; //#18786
        $k[$j++] = $f($1.mcols - 3); //#18786
    }, function() {
        $k[$j++] = 0; //#18786
        $k[$j++] = $f($1.mcols - 2); //#18786
    }, function() {
        $k[$j++] = 0; //#18787
        $k[$j++] = $f($1.mcols - 1); //#18787
    }, function() {
        $k[$j++] = 1; //#18787
        $k[$j++] = $f($1.mcols - 1); //#18787
    }]); //#18787
    $1.dmc2 = _O6; //#18788
    var _OF = $a([function() {
        $k[$j++] = $f($1.mrows - 3); //#18791
        $k[$j++] = 0; //#18791
    }, function() {
        $k[$j++] = $f($1.mrows - 2); //#18791
        $k[$j++] = 0; //#18791
    }, function() {
        $k[$j++] = $f($1.mrows - 1); //#18792
        $k[$j++] = 0; //#18792
    }, function() {
        $k[$j++] = 0; //#18792
        $k[$j++] = $f($1.mcols - 2); //#18792
    }, function() {
        $k[$j++] = 0; //#18793
        $k[$j++] = $f($1.mcols - 1); //#18793
    }, function() {
        $k[$j++] = 1; //#18793
        $k[$j++] = $f($1.mcols - 1); //#18793
    }, function() {
        $k[$j++] = 2; //#18794
        $k[$j++] = $f($1.mcols - 1); //#18794
    }, function() {
        $k[$j++] = 3; //#18794
        $k[$j++] = $f($1.mcols - 1); //#18794
    }]); //#18794
    $1.dmc3 = _OF; //#18795
    var _OP = $a([function() {
        $k[$j++] = $f($1.mrows - 1); //#18798
        $k[$j++] = 0; //#18798
    }, function() {
        $k[$j++] = $f($1.mrows - 1); //#18798
        $k[$j++] = $f($1.mcols - 1); //#18798
    }, function() {
        $k[$j++] = 0; //#18799
        $k[$j++] = $f($1.mcols - 3); //#18799
    }, function() {
        $k[$j++] = 0; //#18799
        $k[$j++] = $f($1.mcols - 2); //#18799
    }, function() {
        $k[$j++] = 0; //#18800
        $k[$j++] = $f($1.mcols - 1); //#18800
    }, function() {
        $k[$j++] = 1; //#18800
        $k[$j++] = $f($1.mcols - 3); //#18800
    }, function() {
        $k[$j++] = 1; //#18801
        $k[$j++] = $f($1.mcols - 2); //#18801
    }, function() {
        $k[$j++] = 1; //#18801
        $k[$j++] = $f($1.mcols - 1); //#18801
    }]); //#18801
    $1.dmc4 = _OP; //#18802
    $k[$j++] = Infinity; //#18804
    for (var _OS = 0, _OT = $1.mrows * $1.mcols; _OS < _OT; _OS++) { //#18804
        $k[$j++] = -1; //#18804
    } //#18804
    $1.mmat = $a(); //#18804
    for (var _OW = $1.cws.length - 1; _OW >= 0; _OW -= 1) { //#18805
        $k[$j++] = $get($1.cws, _OW); //#18805
    } //#18805
    $k[$j++] = 4; //#18845
    $k[$j++] = 0; //#18845
    for (;;) { //#18845
        var _OZ = $k[--$j]; //#18808
        var _Oa = $k[--$j]; //#18808
        $k[$j++] = _Oa; //#18810
        $k[$j++] = _OZ; //#18810
        if ((_OZ == 0) && (_Oa == $1.mrows)) { //#18810
            $k[$j++] = $1.dmc1; //#18809
            $1.module(); //#18809
        } //#18809
        var _Od = $k[--$j]; //#18811
        var _Oe = $k[--$j]; //#18811
        $k[$j++] = _Oe; //#18813
        $k[$j++] = _Od; //#18813
        if (((_Od == 0) && (_Oe == $f($1.mrows - 2))) && (($1.mcols % 4) != 0)) { //#18813
            $k[$j++] = $1.dmc2; //#18812
            $1.module(); //#18812
        } //#18812
        var _Oi = $k[--$j]; //#18814
        var _Oj = $k[--$j]; //#18814
        $k[$j++] = _Oj; //#18816
        $k[$j++] = _Oi; //#18816
        if (((_Oi == 0) && (_Oj == $f($1.mrows - 2))) && (($1.mcols % 8) == 4)) { //#18816
            $k[$j++] = $1.dmc3; //#18815
            $1.module(); //#18815
        } //#18815
        var _On = $k[--$j]; //#18817
        var _Oo = $k[--$j]; //#18817
        $k[$j++] = _Oo; //#18819
        $k[$j++] = _On; //#18819
        if (((_On == 2) && (_Oo == $f($1.mrows + 4))) && (($1.mcols % 8) == 0)) { //#18819
            $k[$j++] = $1.dmc4; //#18818
            $1.module(); //#18818
        } //#18818
        for (;;) { //#18829
            var _Os = $k[--$j]; //#18822
            var _Ot = $k[--$j]; //#18822
            $k[$j++] = _Ot; //#18826
            $k[$j++] = _Os; //#18826
            if ((_Os >= 0) && (_Ot < $1.mrows)) { //#18826
                var _Ov = $k[--$j]; //#18823
                var _Ow = $k[--$j]; //#18823
                $k[$j++] = _Ow; //#18825
                $k[$j++] = _Ov; //#18825
                if ($get($1.mmat, $f(_Ov + (_Ow * $1.mcols))) == -1) { //#18825
                    $k[$j++] = $1.dmn; //#18824
                    $1.module(); //#18824
                } //#18824
            } //#18824
            var _P1 = $k[--$j]; //#18827
            var _P2 = $k[--$j]; //#18827
            $k[$j++] = $f(_P2 - 2); //#18828
            $k[$j++] = $f(_P1 + 2); //#18828
            if (!(($f(_P1 + 2) < $1.mcols) && ($f(_P2 - 2) >= 0))) { //#18828
                break; //#18828
            } //#18828
        } //#18828
        var _P4 = $k[--$j]; //#18830
        var _P5 = $k[--$j]; //#18830
        $k[$j++] = $f(_P5 + 1); //#18840
        $k[$j++] = $f(_P4 + 3); //#18840
        for (;;) { //#18840
            var _P6 = $k[--$j]; //#18833
            var _P7 = $k[--$j]; //#18833
            $k[$j++] = _P7; //#18837
            $k[$j++] = _P6; //#18837
            if ((_P6 < $1.mcols) && (_P7 >= 0)) { //#18837
                var _P9 = $k[--$j]; //#18834
                var _PA = $k[--$j]; //#18834
                $k[$j++] = _PA; //#18836
                $k[$j++] = _P9; //#18836
                if ($get($1.mmat, $f(_P9 + (_PA * $1.mcols))) == -1) { //#18836
                    $k[$j++] = $1.dmn; //#18835
                    $1.module(); //#18835
                } //#18835
            } //#18835
            var _PF = $k[--$j]; //#18838
            var _PG = $k[--$j]; //#18838
            $k[$j++] = $f(_PG + 2); //#18839
            $k[$j++] = $f(_PF - 2); //#18839
            if (!(($f(_PF - 2) >= 0) && ($f(_PG + 2) < $1.mrows))) { //#18839
                break; //#18839
            } //#18839
        } //#18839
        var _PI = $k[--$j]; //#18841
        var _PJ = $k[--$j]; //#18841
        $k[$j++] = $f(_PJ + 3); //#18843
        $k[$j++] = $f(_PI + 1); //#18843
        if (!(($f(_PI + 1) < $1.mcols) || ($f(_PJ + 3) < $1.mrows))) { //#18843
            $j -= 2; //#18843
            break; //#18843
        } //#18843
    } //#18843
    if ($get($1.mmat, $f(($1.mrows * $1.mcols) - 1)) == -1) { //#18851
        $puti($1.mmat, $f(($1.mrows * $f($1.mcols - 1)) - 2), $a([1, 0])); //#18849
        $puti($1.mmat, $f(($1.mrows * $1.mcols) - 2), $a([0, 1])); //#18850
    } //#18850
    $1.pixs = $a($1.rows * $1.cols); //#18854
    $1.cwpos = 0; //#18855
    for (var _Pd = 0, _Pc = $f($1.rows - 1); _Pd <= _Pc; _Pd += 1) { //#18871
        $1.i = _Pd; //#18857
        if (($1.i % ($1.rrows + 2)) == 0) { //#18858
            $k[$j++] = $1.pixs; //#18858
            $k[$j++] = $1.i * $1.cols; //#18858
            $k[$j++] = Infinity; //#18858
            for (var _Pk = 0, _Pl = ~~($1.cols / 2); _Pk < _Pl; _Pk++) { //#18858
                $k[$j++] = 1; //#18858
                $k[$j++] = 0; //#18858
            } //#18858
            var _Pm = $a(); //#18858
            var _Pn = $k[--$j]; //#18858
            $puti($k[--$j], _Pn, _Pm); //#18858
        } //#18858
        if (($1.i % ($1.rrows + 2)) == ($1.rrows + 1)) { //#18859
            $k[$j++] = $1.pixs; //#18859
            $k[$j++] = $1.i * $1.cols; //#18859
            $k[$j++] = Infinity; //#18859
            for (var _Pw = 0, _Px = $1.cols; _Pw < _Px; _Pw++) { //#18859
                $k[$j++] = 1; //#18859
            } //#18859
            var _Py = $a(); //#18859
            var _Pz = $k[--$j]; //#18859
            $puti($k[--$j], _Pz, _Py); //#18859
        } //#18859
        if ((($1.i % ($1.rrows + 2)) != 0) && (($1.i % ($1.rrows + 2)) != ($1.rrows + 1))) { //#18870
            for (var _Q8 = 0, _Q7 = $f($1.cols - 1); _Q8 <= _Q7; _Q8 += 1) { //#18869
                $1.j = _Q8; //#18862
                if (($1.j % ($1.rcols + 2)) == 0) { //#18863
                    $put($1.pixs, $f(($1.i * $1.cols) + $1.j), 1); //#18863
                } //#18863
                if (($1.j % ($1.rcols + 2)) == ($1.rcols + 1)) { //#18864
                    $put($1.pixs, $f(($1.i * $1.cols) + $1.j), $1.i % 2); //#18864
                } //#18864
                if ((($1.j % ($1.rcols + 2)) != 0) && (($1.j % ($1.rcols + 2)) != ($1.rcols + 1))) { //#18868
                    $put($1.pixs, $f(($1.i * $1.cols) + $1.j), $get($1.mmat, $1.cwpos)); //#18866
                    $1.cwpos = $1.cwpos + 1; //#18867
                } //#18867
            } //#18867
        } //#18867
    } //#18867
    var _Qg = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.cols],
        ["pixy", $1.rows],
        ["height", ($1.rows * 2) / 72],
        ["width", ($1.cols * 2) / 72],
        ["opt", $1.options]
    ]); //#18881
    $k[$j++] = _Qg; //#18884
    if (!$1.dontdraw) { //#18884
        bwipp_renmatrix(); //#18884
    } //#18884
}

function bwipp_datamatrixrectangular() {
    var $1 = {}; //#18917
    $1.ctx = null; //#18919
    $1.dontdraw = false; //#18920
    $k[$j++] = $1; //#18922
    bwipp_processoptions(); //#18922
    $1.options = $k[--$j]; //#18922
    $1.barcode = $k[--$j]; //#18923
    $put($1.options, "dontdraw", true); //#18926
    $put($1.options, "format", "rectangle"); //#18927
    $k[$j++] = 'args'; //#18929
    $k[$j++] = $1.barcode; //#18929
    $k[$j++] = $1.options; //#18929
    bwipp_datamatrix(); //#18929
    var _6 = $k[--$j]; //#18929
    $1[$k[--$j]] = _6; //#18929
    $put($1.args, "opt", $1.options); //#18931
    $k[$j++] = $1.args; //#18934
    if (!$1.dontdraw) { //#18934
        bwipp_renmatrix(); //#18934
    } //#18934
}

function bwipp_datamatrixrectangularextension() {
    var $1 = {}; //#18965
    $1.ctx = null; //#18967
    $1.dontdraw = false; //#18968
    $1.dmre = false; //#18969
    $1.dindmre = false; //#18970
    $k[$j++] = $1; //#18972
    bwipp_processoptions(); //#18972
    $1.options = $k[--$j]; //#18972
    $1.barcode = $k[--$j]; //#18973
    $put($1.options, "dontdraw", true); //#18976
    if (!($1.dindmre || $1.dmre)) { //#18982
        $put($1.options, "dmre", true); //#18979
    } else { //#18982
        $put($1.options, "dmre", $1.dmre); //#18981
        $put($1.options, "dindmre", $1.dindmre); //#18982
    } //#18982
    $k[$j++] = 'args'; //#18985
    $k[$j++] = $1.barcode; //#18985
    $k[$j++] = $1.options; //#18985
    bwipp_datamatrix(); //#18985
    var _C = $k[--$j]; //#18985
    $1[$k[--$j]] = _C; //#18985
    $put($1.args, "opt", $1.options); //#18987
    $k[$j++] = $1.args; //#18990
    if (!$1.dontdraw) { //#18990
        bwipp_renmatrix(); //#18990
    } //#18990
}

function bwipp_mailmark() {
    var $1 = {}; //#19022
    $1.ctx = null; //#19024
    $1.type = "unset"; //#19025
    $1.parse = false; //#19026
    $1.dontdraw = false; //#19027
    $k[$j++] = $1; //#19029
    bwipp_processoptions(); //#19029
    $1.options = $k[--$j]; //#19029
    $1.barcode = $k[--$j]; //#19030
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#19036
    $1.fncvals = _3; //#19037
    $k[$j++] = 'barcode'; //#19038
    $k[$j++] = $1.barcode; //#19038
    $k[$j++] = $1.fncvals; //#19038
    bwipp_parseinput(); //#19038
    var _6 = $k[--$j]; //#19038
    $1[$k[--$j]] = _6; //#19038
    $1.barlen = $1.barcode.length; //#19039
    delete $1.options["parse"]; //#19040
    var _A = new Map([
        ["7", "24x24"],
        ["9", "32x32"],
        ["29", "16x48"]
    ]); //#19046
    $1.version = $get(_A, $1['type']); //#19047
    var _D = new Map([
        ["7", "square"],
        ["9", "square"],
        ["29", "rectangle"]
    ]); //#19052
    $1.format = $get(_D, $1['type']); //#19053
    if ($1.barcode.length < 45) { //#19058
        $k[$j++] = 'bwipp.mailmarkBadLength'; //#19057
        $k[$j++] = "Royal Mail Mailmark must contain at least 45 characters of Mailmark formatted data, including any required space padding"; //#19057
        bwipp_raiseerror(); //#19057
    } //#19057
    if ($ne($geti($1.barcode, 0, 4), "JGB ")) { //#19061
        $k[$j++] = 'bwipp.mailmarkBadIndicator'; //#19060
        $k[$j++] = "Royal Mail Mailmark must begin with JGB<space> identifier"; //#19060
        bwipp_raiseerror(); //#19060
    } //#19060
    $put($1.options, "dontdraw", true); //#19064
    $put($1.options, "version", $1.version); //#19065
    $put($1.options, "format", $1.format); //#19066
    $put($1.options, "mailmark", true); //#19067
    $k[$j++] = 'args'; //#19068
    $k[$j++] = $1.barcode; //#19068
    $k[$j++] = $1.options; //#19068
    bwipp_datamatrix(); //#19068
    var _R = $k[--$j]; //#19068
    $1[$k[--$j]] = _R; //#19068
    $put($1.args, "opt", $1.options); //#19070
    $k[$j++] = $1.args; //#19073
    if (!$1.dontdraw) { //#19073
        bwipp_renmatrix(); //#19073
    } //#19073
}

function bwipp_qrcode() {
    var $1 = {}; //#19106
    $1.ctx = null; //#19108
    $1.dontdraw = false; //#19109
    $1.format = "unset"; //#19110
    $1.version = "unset"; //#19111
    $1.eclevel = "unset"; //#19112
    $1.parse = false; //#19113
    $1.parsefnc = false; //#19114
    $1.mask = -1; //#19115
    $k[$j++] = $1; //#19117
    bwipp_processoptions(); //#19117
    $1.options = $k[--$j]; //#19117
    $1.barcode = $k[--$j]; //#19118
    if ($ne($1.version, "unset")) { //#19131
        if ($eq($1.format, "unset")) { //#19129
            $k[$j++] = "full"; //#19126
            if ($eq($geti($1.version, 0, 1), "M")) { //#19126
                $j--; //#19126
                $k[$j++] = "micro"; //#19126
            } //#19126
            if ($eq($geti($1.version, 0, 1), "R")) { //#19127
                $j--; //#19127
                $k[$j++] = "rmqr"; //#19127
            } //#19127
            $1.format = $k[--$j]; //#19128
        } //#19128
    } else { //#19131
        if ($eq($1.format, "unset")) { //#19131
            $1.format = "full"; //#19131
        } //#19131
    } //#19131
    if ($eq($1.eclevel, "unset")) { //#19135
        $k[$j++] = 'eclevel'; //#19135
        if ($ne($1.format, "micro")) { //#19135
            $k[$j++] = "M"; //#19135
        } else { //#19135
            $k[$j++] = "L"; //#19135
        } //#19135
        var _C = $k[--$j]; //#19135
        $1[$k[--$j]] = _C; //#19135
    } //#19135
    $1.fn1 = -1; //#19138
    var _H = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["eci", true],
        ["FNC1", $1.fn1]
    ]); //#19143
    $1.fncvals = _H; //#19144
    $k[$j++] = 'msg'; //#19145
    $k[$j++] = $1.barcode; //#19145
    $k[$j++] = $1.fncvals; //#19145
    bwipp_parseinput(); //#19145
    var _K = $k[--$j]; //#19145
    $1[$k[--$j]] = _K; //#19145
    $1.msglen = $1.msg.length; //#19146
    $1.fnc1first = false; //#19149
    if ($1.msglen > 0) { //#19156
        if ($get($1.msg, 0) == $1.fn1) { //#19155
            $1.fnc1first = true; //#19152
            $k[$j++] = Infinity; //#19153
            var _T = $geti($1.msg, 1, $1.msglen - 1); //#19153
            for (var _U = 0, _V = _T.length; _U < _V; _U++) { //#19153
                var _W = $get(_T, _U); //#19153
                $k[$j++] = _W; //#19153
                if (_W == 37) { //#19153
                    var _X = $k[--$j]; //#19153
                    $k[$j++] = _X; //#19153
                    $k[$j++] = _X; //#19153
                } //#19153
            } //#19153
            $1.msg = $a(); //#19153
            $1.msglen = $1.msg.length; //#19154
        } //#19154
    } //#19154
    var _a = $a(['v1to9', 'v10to26', 'v27to40', 'vM1', 'vM2', 'vM3', 'vM4', 'vR7x43', 'vR7x59', 'vR7x77', 'vR7x99', 'vR7x139', 'vR9x43', 'vR9x59', 'vR9x77', 'vR9x99', 'vR9x139', 'vR11x27', 'vR11x43', 'vR11x59', 'vR11x77', 'vR11x99', 'vR11x139', 'vR13x27', 'vR13x43', 'vR13x59', 'vR13x77', 'vR13x99', 'vR13x139', 'vR15x43', 'vR15x59', 'vR15x77', 'vR15x99', 'vR15x139', 'vR17x43', 'vR17x59', 'vR17x77', 'vR17x99', 'vR17x139']); //#19169
    $k[$j++] = 0; //#19170
    for (var _b = 0, _c = _a.length; _b < _c; _b++) { //#19170
        var _e = $k[--$j]; //#19170
        $1[$get(_a, _b)] = _e; //#19170
        $k[$j++] = $f(_e + 1); //#19170
    } //#19170
    $j--; //#19170
    $1.N = 0; //#19176
    $1.A = 1; //#19176
    $1.B = 2; //#19176
    $1.K = 3; //#19176
    $1.E = 4; //#19176
    $k[$j++] = Infinity; //#19181
    $k[$j++] = Infinity; //#19180
    for (var _f = 48; _f <= 57; _f += 1) { //#19180
        $k[$j++] = _f; //#19180
    } //#19180
    var _g = $a(); //#19180
    for (var _h = 0, _i = _g.length; _h < _i; _h++) { //#19181
        $k[$j++] = $get(_g, _h); //#19181
        $k[$j++] = -1; //#19181
    } //#19181
    $1.Nexcl = $d(); //#19182
    $k[$j++] = Infinity; //#19189
    $k[$j++] = Infinity; //#19188
    $k[$j++] = 32; //#19187
    $k[$j++] = 36; //#19187
    $k[$j++] = 37; //#19187
    $k[$j++] = 42; //#19187
    $k[$j++] = 43; //#19187
    $k[$j++] = 45; //#19187
    $k[$j++] = 46; //#19187
    $k[$j++] = 47; //#19187
    $k[$j++] = 58; //#19187
    for (var _l = 65; _l <= 90; _l += 1) { //#19187
        $k[$j++] = _l; //#19187
    } //#19187
    $k[$j++] = $1.fn1; //#19188
    var _n = $a(); //#19188
    for (var _o = 0, _p = _n.length; _o < _p; _o++) { //#19189
        $k[$j++] = $get(_n, _o); //#19189
        $k[$j++] = -1; //#19189
    } //#19189
    $1.Aexcl = $d(); //#19190
    $k[$j++] = Infinity; //#19198
    $k[$j++] = Infinity; //#19197
    for (var _s = 129; _s <= 159; _s += 1) { //#19196
        $k[$j++] = _s; //#19196
    } //#19196
    for (var _t = 224; _t <= 235; _t += 1) { //#19197
        $k[$j++] = _t; //#19197
    } //#19197
    var _u = $a(); //#19197
    for (var _v = 0, _w = _u.length; _v < _w; _v++) { //#19198
        $k[$j++] = $get(_u, _v); //#19198
        $k[$j++] = -1; //#19198
    } //#19198
    $1.Kexcl = $d(); //#19199
    $k[$j++] = Infinity; //#19211
    $k[$j++] = $a(["0001", "0010", "0100", "1000", "0111"]); //#19212
    $k[$j++] = $a(["0001", "0010", "0100", "1000", "0111"]); //#19212
    $k[$j++] = $a(["0001", "0010", "0100", "1000", "0111"]); //#19212
    $k[$j++] = $a(["", -1, -1, -1, -1]); //#19212
    $k[$j++] = $a(["0", "1", -1, -1, -1]); //#19212
    $k[$j++] = $a(["00", "01", "10", "11", -1]); //#19212
    $k[$j++] = $a(["000", "001", "010", "011", -1]); //#19212
    for (var _16 = 0, _17 = 32; _16 < _17; _16++) { //#19212
        $k[$j++] = $a(["001", "010", "011", "100", "111"]); //#19211
    } //#19211
    $1.mids = $a(); //#19211
    $1.cclens = $a([$a([10, 9, 8, 8]), $a([12, 11, 16, 10]), $a([14, 13, 16, 12]), $a([3, -1, -1, -1]), $a([4, 3, -1, -1]), $a([5, 4, 4, 3]), $a([6, 5, 5, 4]), $a([4, 3, 3, 2]), $a([5, 5, 4, 3]), $a([6, 5, 5, 4]), $a([7, 6, 5, 5]), $a([7, 6, 6, 5]), $a([5, 5, 4, 3]), $a([6, 5, 5, 4]), $a([7, 6, 5, 5]), $a([7, 6, 6, 5]), $a([8, 7, 6, 6]), $a([4, 4, 3, 2]), $a([6, 5, 5, 4]), $a([7, 6, 5, 5]), $a([7, 6, 6, 5]), $a([8, 7, 6, 6]), $a([8, 7, 7, 6]), $a([5, 5, 4, 3]), $a([6, 6, 5, 5]), $a([7, 6, 6, 5]), $a([7, 7, 6, 6]), $a([8, 7, 7, 6]), $a([8, 8, 7, 7]), $a([7, 6, 6, 5]), $a([7, 7, 6, 5]), $a([8, 7, 7, 6]), $a([8, 7, 7, 6]), $a([9, 8, 7, 7]), $a([7, 6, 6, 5]), $a([8, 7, 6, 6]), $a([8, 7, 7, 6]), $a([8, 8, 7, 6]), $a([9, 8, 8, 7])]); //#19255
    $k[$j++] = Infinity; //#19266
    for (var _1o = 0, _1p = 3; _1o < _1p; _1o++) { //#19260
        $k[$j++] = 4; //#19259
    } //#19259
    $k[$j++] = 3; //#19267
    $k[$j++] = 5; //#19267
    $k[$j++] = 7; //#19267
    $k[$j++] = 9; //#19267
    for (var _1q = 0, _1r = 32; _1q < _1r; _1q++) { //#19267
        $k[$j++] = 3; //#19266
    } //#19266
    $1.termlens = $a(); //#19266
    $1.padstrs = $a(["11101100", "00010001"]); //#19270
    $1.charmap = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:"; //#19273
    $1.charvals = new Map; //#19274
    for (var _1u = 0; _1u <= 44; _1u += 1) { //#19275
        $put($1.charvals, $get($1.charmap, _1u), _1u); //#19275
    } //#19275
    $1.tobin = function() {
        var _1z = $s($k[--$j]); //#19281
        $k[$j++] = _1z; //#19281
        for (var _21 = 0, _20 = _1z.length - 1; _21 <= _20; _21 += 1) { //#19281
            var _22 = $k[--$j]; //#19281
            $put(_22, _21, 48); //#19281
            $k[$j++] = _22; //#19281
        } //#19281
        var _23 = $k[--$j]; //#19282
        var _26 = $cvrs($s(_23.length), $k[--$j], 2); //#19282
        $puti(_23, _23.length - _26.length, _26); //#19282
        $k[$j++] = _23; //#19282
    }; //#19282
    $1.encA = function() {
        $1.in = $k[--$j]; //#19286
        if ($1.fnc1first) { //#19289
            $k[$j++] = Infinity; //#19288
            $forall($1.in, function() { //#19288
                var _2A = $k[--$j]; //#19288
                $k[$j++] = _2A; //#19288
                if (_2A == $1.fn1) { //#19288
                    $j--; //#19288
                    $k[$j++] = 37; //#19288
                } //#19288
            }); //#19288
            $1.in = $a(); //#19288
        } //#19288
        $1.out = $s((~~(($1.in.length * 11) / 2)) + 1); //#19290
        $1.k = 0; //#19291
        $1.m = 0; //#19291
        for (;;) { //#19302
            if ($1.k == $1.in.length) { //#19292
                break; //#19292
            } //#19292
            if ($1.k < ($1.in.length - 1)) { //#19298
                $k[$j++] = $f(($get($1.charvals, $get($1.in, $1.k)) * 45) + $get($1.charvals, $get($1.in, $1.k + 1))); //#19294
                $k[$j++] = 11; //#19294
                $1.tobin(); //#19294
                $1.k = $1.k + 2; //#19295
            } else { //#19298
                $k[$j++] = $get($1.charvals, $get($1.in, $1.k)); //#19297
                $k[$j++] = 6; //#19297
                $1.tobin(); //#19297
                $1.k = $1.k + 1; //#19298
            } //#19298
            var _2a = $k[--$j]; //#19300
            $puti($1.out, $1.m, _2a); //#19300
            $1.m = _2a.length + $1.m; //#19301
        } //#19301
        $k[$j++] = $geti($1.out, 0, $1.m); //#19303
    }; //#19303
    $1.encN = function() {
        $1.in = $k[--$j]; //#19307
        $1.out = $s((~~(($1.in.length * 10) / 3)) + 1); //#19308
        $1.k = 0; //#19309
        $1.m = 0; //#19309
        for (;;) { //#19325
            if ($1.k == $1.in.length) { //#19310
                break; //#19310
            } //#19310
            if ($1.k < ($1.in.length - 2)) { //#19320
                var _2q = $geti($1.in, $1.k, 3); //#19312
                $k[$j++] = 0; //#19312
                for (var _2r = 0, _2s = _2q.length; _2r < _2s; _2r++) { //#19312
                    var _2u = $k[--$j]; //#19312
                    $k[$j++] = $f($get(_2q, _2r) + ($f((_2u * 10) - 48))); //#19312
                } //#19312
                $k[$j++] = 10; //#19312
                $1.tobin(); //#19312
                $1.k = $1.k + 3; //#19313
            } else { //#19320
                if ($1.k == ($1.in.length - 2)) { //#19320
                    var _30 = $geti($1.in, $1.k, 2); //#19316
                    $k[$j++] = 0; //#19316
                    for (var _31 = 0, _32 = _30.length; _31 < _32; _31++) { //#19316
                        var _34 = $k[--$j]; //#19316
                        $k[$j++] = $f($get(_30, _31) + ($f((_34 * 10) - 48))); //#19316
                    } //#19316
                    $k[$j++] = 7; //#19316
                    $1.tobin(); //#19316
                    $1.k = $1.k + 2; //#19317
                } else { //#19320
                    var _38 = $geti($1.in, $1.k, 1); //#19319
                    $k[$j++] = 0; //#19319
                    for (var _39 = 0, _3A = _38.length; _39 < _3A; _39++) { //#19319
                        var _3C = $k[--$j]; //#19319
                        $k[$j++] = $f($get(_38, _39) + ($f((_3C * 10) - 48))); //#19319
                    } //#19319
                    $k[$j++] = 4; //#19319
                    $1.tobin(); //#19319
                    $1.k = $1.k + 1; //#19320
                } //#19320
            } //#19320
            var _3E = $k[--$j]; //#19323
            $puti($1.out, $1.m, _3E); //#19323
            $1.m = _3E.length + $1.m; //#19324
        } //#19324
        $k[$j++] = $geti($1.out, 0, $1.m); //#19326
    }; //#19326
    $1.encB = function() {
        $1.in = $k[--$j]; //#19330
        if ($1.fnc1first) { //#19333
            $k[$j++] = Infinity; //#19332
            $forall($1.in, function() { //#19332
                var _3O = $k[--$j]; //#19332
                $k[$j++] = _3O; //#19332
                if (_3O == $1.fn1) { //#19332
                    $j--; //#19332
                    $k[$j++] = 29; //#19332
                } //#19332
            }); //#19332
            $1.in = $a(); //#19332
        } //#19332
        $1.out = $s($1.in.length * 8); //#19334
        for (var _3V = 0, _3U = $1.in.length - 1; _3V <= _3U; _3V += 1) { //#19339
            $1.k = _3V; //#19336
            $k[$j++] = $cvi($get($1.in, $1.k)); //#19337
            $k[$j++] = 8; //#19337
            $1.tobin(); //#19337
            $puti($1.out, $1.k * 8, $k[--$j]); //#19338
        } //#19338
        $k[$j++] = $1.out; //#19340
    }; //#19340
    $1.encK = function() {
        $1.in = $k[--$j]; //#19344
        $1.out = $s((~~($1.in.length / 2)) * 13); //#19345
        $1.k = 0; //#19346
        $1.m = 0; //#19346
        for (;;) { //#19354
            if ($1.k == $1.in.length) { //#19347
                break; //#19347
            } //#19347
            var _3o = $f(($get($1.in, $1.k) * 256) + $get($1.in, $1.k + 1)); //#19349
            $k[$j++] = _3o; //#19349
            if (_3o < 57408) { //#19349
                $k[$j++] = 33088; //#19349
            } else { //#19349
                $k[$j++] = 49472; //#19349
            } //#19349
            var _3p = $k[--$j]; //#19349
            var _3r = $f($k[--$j] - _3p); //#19350
            $k[$j++] = $f(((_3r >>> 8) * 192) + (_3r & 255)); //#19351
            $k[$j++] = 13; //#19351
            $1.tobin(); //#19351
            var _3s = $k[--$j]; //#19351
            $puti($1.out, $1.m, _3s); //#19351
            $1.m = _3s.length + $1.m; //#19352
            $1.k = $1.k + 2; //#19353
        } //#19353
        $k[$j++] = $1.out; //#19355
    }; //#19355
    $1.encE = function() {
        var _40 = $f((-$get($k[--$j], 0)) - 1000000); //#19360
        $k[$j++] = _40; //#19366
        if (_40 <= 127) { //#19365
            $k[$j++] = 8; //#19361
            $1.tobin(); //#19361
        } else { //#19365
            var _41 = $k[--$j]; //#19362
            $k[$j++] = _41; //#19366
            if (_41 <= 16383) { //#19365
                var _42 = $k[--$j]; //#19363
                $k[$j++] = $f(_42 + 32768); //#19363
                $k[$j++] = 16; //#19363
                $1.tobin(); //#19363
            } else { //#19365
                var _43 = $k[--$j]; //#19365
                $k[$j++] = $f(_43 + 12582912); //#19365
                $k[$j++] = 24; //#19365
                $1.tobin(); //#19365
            } //#19365
        } //#19365
    }; //#19365
    $1.encfuncs = $a(['encN', 'encA', 'encB', 'encK', 'encE']); //#19369
    $1.addtobits = function() {
        var _45 = $k[--$j]; //#19372
        $puti($1.bits, $1.j, _45); //#19372
        $1.j = _45.length + $1.j; //#19373
    }; //#19373
    $k[$j++] = Infinity; //#19376
    for (var _4A = 0, _4B = $1.msglen; _4A < _4B; _4A++) { //#19376
        $k[$j++] = 0; //#19376
    } //#19376
    $k[$j++] = 0; //#19376
    $1.numNs = $a(); //#19376
    $k[$j++] = Infinity; //#19377
    for (var _4E = 0, _4F = $1.msglen; _4E < _4F; _4E++) { //#19377
        $k[$j++] = 0; //#19377
    } //#19377
    $k[$j++] = 0; //#19377
    $1.numAs = $a(); //#19377
    $k[$j++] = Infinity; //#19378
    for (var _4I = 0, _4J = $1.msglen; _4I < _4J; _4I++) { //#19378
        $k[$j++] = 0; //#19378
    } //#19378
    $k[$j++] = 0; //#19378
    $1.numAorNs = $a(); //#19378
    $k[$j++] = Infinity; //#19379
    for (var _4M = 0, _4N = $1.msglen; _4M < _4N; _4M++) { //#19379
        $k[$j++] = 0; //#19379
    } //#19379
    $k[$j++] = 0; //#19379
    $1.numBs = $a(); //#19379
    $k[$j++] = Infinity; //#19380
    for (var _4Q = 0, _4R = $1.msglen; _4Q < _4R; _4Q++) { //#19380
        $k[$j++] = 0; //#19380
    } //#19380
    $k[$j++] = 0; //#19380
    $1.numKs = $a(); //#19380
    $k[$j++] = Infinity; //#19381
    for (var _4U = 0, _4V = $1.msglen; _4U < _4V; _4U++) { //#19381
        $k[$j++] = 0; //#19381
    } //#19381
    $k[$j++] = 9999; //#19381
    $1.nextNs = $a(); //#19381
    $k[$j++] = Infinity; //#19382
    for (var _4Y = 0, _4Z = $1.msglen; _4Y < _4Z; _4Y++) { //#19382
        $k[$j++] = 0; //#19382
    } //#19382
    $k[$j++] = 9999; //#19382
    $1.nextBs = $a(); //#19382
    $k[$j++] = Infinity; //#19383
    for (var _4c = 0, _4d = $1.msglen; _4c < _4d; _4c++) { //#19383
        $k[$j++] = 0; //#19383
    } //#19383
    $k[$j++] = 9999; //#19383
    $1.nextAs = $a(); //#19383
    $k[$j++] = Infinity; //#19384
    for (var _4g = 0, _4h = $1.msglen; _4g < _4h; _4g++) { //#19384
        $k[$j++] = 0; //#19384
    } //#19384
    $k[$j++] = 9999; //#19384
    $1.nextKs = $a(); //#19384
    $1.isECI = $a($1.msglen); //#19385
    for (var _4m = $1.msglen - 1; _4m >= 0; _4m -= 1) { //#19415
        $1.i = _4m; //#19387
        $1.barchar = $get($1.msg, $1.i); //#19388
        var _4s = $get($1.Kexcl, $1.barchar) !== undefined; //#19389
        if (_4s) { //#19398
            $k[$j++] = 'sjis'; //#19390
            if (($1.i + 1) < $1.msglen) { //#19390
                $k[$j++] = $f(($1.barchar * 256) + $get($1.msg, $1.i + 1)); //#19390
            } else { //#19390
                $k[$j++] = 0; //#19390
            } //#19390
            var _4z = $k[--$j]; //#19390
            $1[$k[--$j]] = _4z; //#19390
            if ((($1.sjis >= 33088) && ($1.sjis <= 40956)) || (($1.sjis >= 57408) && ($1.sjis <= 60351))) { //#19395
                $put($1.nextKs, $1.i, 0); //#19392
                $put($1.numKs, $1.i, $f($get($1.numKs, $1.i + 2) + 1)); //#19393
            } else { //#19395
                $put($1.nextKs, $1.i, $f($get($1.nextKs, $1.i + 1) + 1)); //#19395
            } //#19395
        } else { //#19398
            $put($1.nextKs, $1.i, $f($get($1.nextKs, $1.i + 1) + 1)); //#19398
        } //#19398
        var _5O = $get($1.Nexcl, $1.barchar) !== undefined; //#19400
        if (_5O) { //#19405
            $put($1.nextNs, $1.i, 0); //#19401
            $put($1.numNs, $1.i, $f($get($1.numNs, $1.i + 1) + 1)); //#19402
            $put($1.numAorNs, $1.i, $f($get($1.numAorNs, $1.i + 1) + 1)); //#19403
        } else { //#19405
            $put($1.nextNs, $1.i, $f($get($1.nextNs, $1.i + 1) + 1)); //#19405
        } //#19405
        var _5i = $get($1.Aexcl, $1.barchar) !== undefined; //#19407
        if (_5i) { //#19412
            $put($1.nextAs, $1.i, 0); //#19408
            $put($1.numAs, $1.i, $f($get($1.numAs, $1.i + 1) + 1)); //#19409
            $put($1.numAorNs, $1.i, $f($get($1.numAorNs, $1.i + 1) + 1)); //#19410
        } else { //#19412
            $put($1.nextAs, $1.i, $f($get($1.nextAs, $1.i + 1) + 1)); //#19412
        } //#19412
        $put($1.isECI, $1.i, $1.barchar <= -1000000); //#19414
    } //#19414
    for (var _65 = 0, _64 = $1.msglen - 1; _65 <= _64; _65 += 1) { //#19422
        $1.i = _65; //#19417
        if ($get($1.numKs, $1.i) > 0) { //#19421
            $put($1.numKs, $1.i + 1, 0); //#19419
            $put($1.nextKs, $1.i + 1, $f($get($1.nextKs, $1.i + 1) + 1)); //#19420
        } //#19420
    } //#19420
    for (var _6H = $1.msglen - 1; _6H >= 0; _6H -= 1) { //#19431
        $1.i = _6H; //#19424
        if ((($f($get($1.numNs, $1.i) + $f($get($1.numAs, $1.i) + $get($1.numKs, $1.i)))) == 0) && $nt($get($1.isECI, $1.i))) { //#19429
            $put($1.nextBs, $1.i, 0); //#19426
            $put($1.numBs, $1.i, $f($get($1.numBs, $1.i + 1) + 1)); //#19427
        } else { //#19429
            $put($1.nextBs, $1.i, $f($get($1.nextBs, $1.i + 1) + 1)); //#19429
        } //#19429
    } //#19429
    $1.KbeforeB = function() {
        var _6j = $get($k[--$j], $1.ver); //#19433
        $k[$j++] = $ge($1.numK, _6j) && ($get($1.nextBs, $f(($1.numK * 2) + $1.i)) == 0); //#19433
    }; //#19433
    $1.KbeforeA = function() {
        var _6r = $get($k[--$j], $1.ver); //#19434
        $k[$j++] = $ge($1.numK, _6r) && ($get($1.nextAs, $f(($1.numK * 2) + $1.i)) == 0); //#19434
    }; //#19434
    $1.KbeforeN = function() {
        var _6z = $get($k[--$j], $1.ver); //#19435
        $k[$j++] = $ge($1.numK, _6z) && ($get($1.nextNs, $f(($1.numK * 2) + $1.i)) == 0); //#19435
    }; //#19435
    $1.KbeforeE = function() {
        var _77 = $get($k[--$j], $1.ver); //#19436
        $k[$j++] = $ge($1.numK, _77) && (($f(($1.numK * 2) + $1.i)) == $1.msglen); //#19436
    }; //#19436
    $1.AbeforeK = function() {
        var _7E = $get($k[--$j], $1.ver); //#19437
        $k[$j++] = $ge($1.numA, _7E) && ($get($1.nextKs, $f($1.numA + $1.i)) == 0); //#19437
    }; //#19437
    $1.AbeforeB = function() {
        var _7M = $get($k[--$j], $1.ver); //#19438
        $k[$j++] = $ge($1.numA, _7M) && ($get($1.nextBs, $f($1.numA + $1.i)) == 0); //#19438
    }; //#19438
    $1.AbeforeN = function() {
        var _7U = $get($k[--$j], $1.ver); //#19439
        $k[$j++] = $ge($1.numA, _7U) && ($get($1.nextNs, $f($1.numA + $1.i)) == 0); //#19439
    }; //#19439
    $1.AbeforeE = function() {
        var _7c = $get($k[--$j], $1.ver); //#19440
        $k[$j++] = $ge($1.numA, _7c) && ($f($1.numA + $1.i) == $1.msglen); //#19440
    }; //#19440
    $1.NbeforeK = function() {
        var _7j = $get($k[--$j], $1.ver); //#19441
        $k[$j++] = $ge($1.numN, _7j) && ($get($1.nextKs, $f($1.numN + $1.i)) == 0); //#19441
    }; //#19441
    $1.NbeforeB = function() {
        var _7r = $get($k[--$j], $1.ver); //#19442
        $k[$j++] = $ge($1.numN, _7r) && ($get($1.nextBs, $f($1.numN + $1.i)) == 0); //#19442
    }; //#19442
    $1.NbeforeA = function() {
        var _7z = $get($k[--$j], $1.ver); //#19443
        $k[$j++] = $ge($1.numN, _7z) && ($get($1.nextAs, $f($1.numN + $1.i)) == 0); //#19443
    }; //#19443
    $1.NbeforeE = function() {
        var _87 = $get($k[--$j], $1.ver); //#19444
        $k[$j++] = $ge($1.numN, _87) && ($f($1.numN + $1.i) == $1.msglen); //#19444
    }; //#19444
    $1.AorNbeforeB = function() {
        var _8E = $get($k[--$j], $1.ver); //#19445
        $k[$j++] = $ge($1.numAorN, _8E) && ($get($1.nextBs, $f($1.numAorN + $1.i)) == 0); //#19445
    }; //#19445
    $1.AorNbeforeE = function() {
        var _8M = $get($k[--$j], $1.ver); //#19446
        $k[$j++] = $ge($1.numAorN, _8M) && ($f($1.numAorN + $1.i) == $1.msglen); //#19446
    }; //#19446
    $1.nextNslt = function() {
        if ($get($1.nextNs, $1.i) >= $1.msglen) { //#19448
            $j--; //#19448
            $k[$j++] = true; //#19448
        } else { //#19448
            var _8c = $get($k[--$j], $1.ver); //#19448
            $k[$j++] = $lt($get($1.numNs, $f($get($1.nextNs, $1.i) + $1.i)), _8c); //#19448
        } //#19448
    }; //#19448
    $k[$j++] = Infinity; //#19473
    for (var _8d = 0; _8d <= 9; _8d += 1) { //#19460
        $k[$j++] = $cvrs($s(2), _8d, 10); //#19460
        $k[$j++] = $1.v1to9; //#19460
    } //#19460
    for (var _8h = 10; _8h <= 26; _8h += 1) { //#19461
        $k[$j++] = $cvrs($s(2), _8h, 10); //#19461
        $k[$j++] = $1.v10to26; //#19461
    } //#19461
    for (var _8l = 27; _8l <= 40; _8l += 1) { //#19462
        $k[$j++] = $cvrs($s(2), _8l, 10); //#19462
        $k[$j++] = $1.v27to40; //#19462
    } //#19462
    $k[$j++] = "M1"; //#19473
    $k[$j++] = $1.vM1; //#19473
    $k[$j++] = "M2"; //#19473
    $k[$j++] = $1.vM2; //#19473
    $k[$j++] = "M3"; //#19473
    $k[$j++] = $1.vM3; //#19473
    $k[$j++] = "M4"; //#19473
    $k[$j++] = $1.vM4; //#19473
    $k[$j++] = "R7x43"; //#19473
    $k[$j++] = $1.vR7x43; //#19473
    $k[$j++] = "R7x59"; //#19473
    $k[$j++] = $1.vR7x59; //#19473
    $k[$j++] = "R7x77"; //#19473
    $k[$j++] = $1.vR7x77; //#19473
    $k[$j++] = "R7x99"; //#19473
    $k[$j++] = $1.vR7x99; //#19473
    $k[$j++] = "R7x139"; //#19473
    $k[$j++] = $1.vR7x139; //#19473
    $k[$j++] = "R9x43"; //#19473
    $k[$j++] = $1.vR9x43; //#19473
    $k[$j++] = "R9x59"; //#19473
    $k[$j++] = $1.vR9x59; //#19473
    $k[$j++] = "R9x77"; //#19473
    $k[$j++] = $1.vR9x77; //#19473
    $k[$j++] = "R9x99"; //#19473
    $k[$j++] = $1.vR9x99; //#19473
    $k[$j++] = "R9x139"; //#19473
    $k[$j++] = $1.vR9x139; //#19473
    $k[$j++] = "R11x27"; //#19473
    $k[$j++] = $1.vR11x27; //#19473
    $k[$j++] = "R11x43"; //#19473
    $k[$j++] = $1.vR11x43; //#19473
    $k[$j++] = "R11x59"; //#19473
    $k[$j++] = $1.vR11x59; //#19473
    $k[$j++] = "R11x77"; //#19473
    $k[$j++] = $1.vR11x77; //#19473
    $k[$j++] = "R11x99"; //#19473
    $k[$j++] = $1.vR11x99; //#19473
    $k[$j++] = "R11x139"; //#19473
    $k[$j++] = $1.vR11x139; //#19473
    $k[$j++] = "R13x27"; //#19473
    $k[$j++] = $1.vR13x27; //#19473
    $k[$j++] = "R13x43"; //#19473
    $k[$j++] = $1.vR13x43; //#19473
    $k[$j++] = "R13x59"; //#19473
    $k[$j++] = $1.vR13x59; //#19473
    $k[$j++] = "R13x77"; //#19473
    $k[$j++] = $1.vR13x77; //#19473
    $k[$j++] = "R13x99"; //#19473
    $k[$j++] = $1.vR13x99; //#19473
    $k[$j++] = "R13x139"; //#19473
    $k[$j++] = $1.vR13x139; //#19473
    $k[$j++] = "R15x43"; //#19473
    $k[$j++] = $1.vR15x43; //#19473
    $k[$j++] = "R15x59"; //#19473
    $k[$j++] = $1.vR15x59; //#19473
    $k[$j++] = "R15x77"; //#19473
    $k[$j++] = $1.vR15x77; //#19473
    $k[$j++] = "R15x99"; //#19473
    $k[$j++] = $1.vR15x99; //#19473
    $k[$j++] = "R15x139"; //#19473
    $k[$j++] = $1.vR15x139; //#19473
    $k[$j++] = "R17x43"; //#19473
    $k[$j++] = $1.vR17x43; //#19473
    $k[$j++] = "R17x59"; //#19473
    $k[$j++] = $1.vR17x59; //#19473
    $k[$j++] = "R17x77"; //#19473
    $k[$j++] = $1.vR17x77; //#19473
    $k[$j++] = "R17x99"; //#19473
    $k[$j++] = $1.vR17x99; //#19473
    $k[$j++] = "R17x139"; //#19473
    $k[$j++] = $1.vR17x139; //#19473
    $1.versetmap = $d(); //#19474
    $1.versetfull = $a([$1.v1to9, $1.v10to26, $1.v27to40]); //#19475
    $1.versetmicro = $a([$1.vM1, $1.vM2, $1.vM3, $1.vM4]); //#19476
    if ($ne($1.version, "unset")) { //#19484
        $k[$j++] = 'verset'; //#19480
        $k[$j++] = $get($1.versetmap, $1.version); //#19480
        $k[$j++] = Infinity; //#19480
        var _9d = $k[--$j]; //#19480
        var _9e = $k[--$j]; //#19480
        $k[$j++] = _9d; //#19480
        $k[$j++] = _9e; //#19480
        var _9f = $a(); //#19480
        $1[$k[--$j]] = _9f; //#19480
    } else { //#19484
        if ($eq($1.format, "full")) { //#19483
            $1.verset = $1.versetfull; //#19483
        } //#19483
        if ($eq($1.format, "micro")) { //#19484
            $1.verset = $1.versetmicro; //#19484
        } //#19484
    } //#19484
    $k[$j++] = Infinity; //#19489
    for (var _9l = 0, _9m = 39; _9l < _9m; _9l++) { //#19489
        $k[$j++] = -1; //#19489
    } //#19489
    $1.msgbits = $a(); //#19489
    $1.e = 10000; //#19490
    $1.mode0forceKB = $a([1, 1, 1, $1.e, $1.e, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]); //#19496
    $1.mode0forceA = $a([1, 1, 1, $1.e, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]); //#19497
    $1.mode0forceN = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]); //#19498
    $1.mode0NbeforeB = $a([4, 4, 5, $1.e, $1.e, 2, 3, 2, 2, 3, 3, 3, 2, 3, 3, 3, 3, 2, 3, 3, 3, 3, 3, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3]); //#19500
    $1.modeBKbeforeB = $a([9, 12, 13, $1.e, $1.e, 4, 6, 4, 5, 6, 6, 6, 5, 6, 6, 6, 7, 4, 6, 6, 6, 7, 7, 5, 6, 6, 7, 7, 7, 6, 6, 7, 7, 7, 6, 7, 7, 7, 8]); //#19502
    $1.modeBKbeforeA = $a([8, 10, 11, $1.e, $1.e, 4, 5, 4, 5, 5, 6, 6, 5, 5, 6, 6, 6, 4, 5, 6, 6, 6, 6, 5, 6, 6, 6, 6, 7, 6, 6, 6, 6, 7, 6, 6, 6, 7, 7]); //#19503
    $1.modeBKbeforeN = $a([8, 9, 11, $1.e, $1.e, 3, 5, 3, 4, 5, 5, 5, 4, 5, 5, 5, 6, 3, 5, 5, 5, 6, 6, 4, 5, 5, 6, 6, 6, 5, 5, 6, 6, 7, 5, 6, 6, 6, 7]); //#19504
    $1.modeBKbeforeE = $a([5, 5, 6, $1.e, $1.e, 2, 3, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 2, 3, 3, 3, 4, 4, 3, 3, 3, 4, 4, 4, 3, 3, 4, 4, 4, 3, 4, 4, 4, 4]); //#19505
    $1.modeBAbeforeK = $a([11, 12, 14, $1.e, $1.e, 5, 7, 5, 6, 7, 8, 8, 6, 7, 8, 8, 8, 6, 7, 8, 8, 8, 8, 6, 8, 8, 8, 8, 9, 8, 8, 8, 8, 9, 8, 8, 8, 9, 9]); //#19507
    $1.modeBAbeforeB = $a([11, 15, 16, $1.e, $1.e, 6, 7, 6, 7, 7, 8, 8, 7, 7, 8, 8, 8, 6, 7, 8, 8, 8, 9, 7, 8, 8, 8, 9, 9, 8, 8, 9, 9, 9, 8, 8, 9, 9, 10]); //#19508
    $1.modeBAbeforeN = $a([12, 13, 15, $1.e, $1.e, 6, 8, 6, 7, 8, 8, 8, 7, 8, 8, 8, 9, 6, 8, 8, 8, 9, 9, 7, 8, 8, 9, 9, 10, 8, 9, 9, 9, 10, 8, 9, 9, 10, 10]); //#19509
    $1.modeBAbeforeE = $a([6, 7, 8, $1.e, $1.e, 3, 4, 3, 4, 4, 4, 4, 4, 4, 4, 4, 5, 4, 4, 4, 4, 5, 5, 4, 4, 4, 5, 5, 5, 4, 5, 5, 5, 5, 4, 5, 5, 5, 5]); //#19510
    $1.modeBNbeforeK = $a([6, 7, 8, $1.e, $1.e, 3, 4, 3, 4, 4, 5, 5, 4, 4, 5, 5, 5, 3, 4, 5, 5, 5, 5, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5]); //#19512
    $1.modeBNbeforeB = $a([6, 8, 9, $1.e, $1.e, 3, 4, 3, 4, 4, 5, 5, 4, 4, 5, 5, 5, 3, 4, 5, 5, 5, 5, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6]); //#19513
    $1.modeBNbeforeA = $a([6, 7, 8, $1.e, $1.e, 3, 4, 3, 4, 4, 5, 5, 4, 4, 5, 5, 5, 4, 4, 5, 5, 5, 5, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 5, 5, 5, 5, 6]); //#19514
    $1.modeBNbeforeE = $a([3, 4, 4, $1.e, $1.e, 2, 3, 2, 2, 3, 3, 3, 2, 3, 3, 3, 3, 2, 3, 3, 3, 3, 3, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3]); //#19515
    $1.modeANbeforeA = $a([13, 15, 17, $1.e, 5, 7, 9, 7, 8, 9, 9, 9, 8, 9, 9, 9, 11, 7, 9, 9, 9, 11, 11, 8, 9, 9, 10, 11, 11, 9, 10, 11, 11, 11, 9, 11, 11, 11, 11]); //#19517
    $1.modeANbeforeB = $a([13, 17, 18, $1.e, $1.e, 7, 9, 7, 8, 9, 9, 9, 8, 9, 9, 9, 10, 7, 9, 9, 9, 10, 11, 8, 9, 9, 9, 11, 11, 9, 9, 11, 11, 11, 9, 10, 11, 11, 11]); //#19518
    $1.modeANbeforeE = $a([7, 8, 9, $1.e, 3, 4, 5, 4, 5, 5, 5, 5, 5, 5, 5, 5, 6, 4, 5, 5, 5, 6, 6, 5, 5, 5, 5, 6, 6, 5, 5, 6, 6, 6, 5, 6, 6, 6, 6]); //#19519
    var _Ae = $1.verset; //#19522
    for (var _Af = 0, _Ag = _Ae.length; _Af < _Ag; _Af++) { //#19654
        $1.ver = $get(_Ae, _Af); //#19523
        $1.mode = -1; //#19526
        $1.seq = $a([]); //#19526
        $1.i = 0; //#19526
        for (;;) { //#19623
            if ($1.i >= $1.msglen) { //#19527
                break; //#19527
            } //#19527
            $1.numK = $get($1.numKs, $1.i); //#19528
            $1.numB = $get($1.numBs, $1.i); //#19529
            $1.numA = $get($1.numAs, $1.i); //#19530
            $1.numN = $get($1.numNs, $1.i); //#19531
            $1.numAorN = $get($1.numAorNs, $1.i); //#19532
            $1.eci = $get($1.isECI, $1.i); //#19533
            if ($eq($1.ver, $1.vM1) && ($1.numA >= 1)) { //#19534
                $1.seq = -1; //#19534
                break; //#19534
            } //#19534
            if ($eq($1.ver, $1.vM1) && ($1.numB >= 1)) { //#19535
                $1.seq = -1; //#19535
                break; //#19535
            } //#19535
            if ($eq($1.ver, $1.vM1) && ($1.numK >= 1)) { //#19536
                $1.seq = -1; //#19536
                break; //#19536
            } //#19536
            if ($eq($1.ver, $1.vM1) && $1.eci) { //#19537
                $1.seq = -1; //#19537
                break; //#19537
            } //#19537
            if ($eq($1.ver, $1.vM2) && ($1.numB >= 1)) { //#19538
                $1.seq = -1; //#19538
                break; //#19538
            } //#19538
            if ($eq($1.ver, $1.vM2) && ($1.numK >= 1)) { //#19539
                $1.seq = -1; //#19539
                break; //#19539
            } //#19539
            if ($eq($1.ver, $1.vM2) && $1.eci) { //#19540
                $1.seq = -1; //#19540
                break; //#19540
            } //#19540
            if ($eq($1.ver, $1.vM3) && $1.eci) { //#19541
                $1.seq = -1; //#19541
                break; //#19541
            } //#19541
            if ($eq($1.ver, $1.vM4) && $1.eci) { //#19542
                $1.seq = -1; //#19542
                break; //#19542
            } //#19542
            for (;;) { //#19603
                if ($1.eci) { //#19546
                    $k[$j++] = $1.E; //#19545
                    break; //#19545
                } //#19545
                if ($1.mode == -1) { //#19561
                    $k[$j++] = $1.mode0forceKB; //#19548
                    $1.KbeforeA(); //#19548
                    if ($k[--$j]) { //#19548
                        $k[$j++] = $1.K; //#19548
                        break; //#19548
                    } //#19548
                    $k[$j++] = $1.mode0forceKB; //#19549
                    $1.KbeforeN(); //#19549
                    if ($k[--$j]) { //#19549
                        $k[$j++] = $1.K; //#19549
                        break; //#19549
                    } //#19549
                    $k[$j++] = $1.modeBKbeforeE; //#19550
                    $1.KbeforeB(); //#19550
                    if ($k[--$j]) { //#19550
                        $k[$j++] = $1.K; //#19550
                        break; //#19550
                    } //#19550
                    $k[$j++] = $1.mode0forceKB; //#19551
                    $1.KbeforeE(); //#19551
                    if ($k[--$j]) { //#19551
                        $k[$j++] = $1.K; //#19551
                        break; //#19551
                    } //#19551
                    if ($1.numK >= 1) { //#19552
                        $k[$j++] = $1.B; //#19552
                        break; //#19552
                    } //#19552
                    $k[$j++] = $1.mode0NbeforeB; //#19553
                    $1.NbeforeB(); //#19553
                    if ($k[--$j]) { //#19553
                        $k[$j++] = $1.N; //#19553
                        break; //#19553
                    } //#19553
                    $k[$j++] = $1.mode0forceKB; //#19554
                    $1.NbeforeB(); //#19554
                    if ($k[--$j]) { //#19554
                        $k[$j++] = $1.B; //#19554
                        break; //#19554
                    } //#19554
                    $k[$j++] = $1.modeANbeforeE; //#19555
                    $1.NbeforeA(); //#19555
                    if ($k[--$j]) { //#19555
                        $k[$j++] = $1.N; //#19555
                        break; //#19555
                    } //#19555
                    $k[$j++] = $1.mode0forceN; //#19556
                    $1.NbeforeE(); //#19556
                    if ($k[--$j]) { //#19556
                        $k[$j++] = $1.N; //#19556
                        break; //#19556
                    } //#19556
                    $k[$j++] = $1.modeBAbeforeE; //#19557
                    $1.AbeforeK(); //#19557
                    if ($k[--$j]) { //#19557
                        $k[$j++] = $1.A; //#19557
                        break; //#19557
                    } //#19557
                    $k[$j++] = $1.modeBAbeforeE; //#19558
                    $1.AorNbeforeB(); //#19558
                    if ($k[--$j]) { //#19558
                        $k[$j++] = $1.A; //#19558
                        break; //#19558
                    } //#19558
                    $k[$j++] = $1.mode0forceA; //#19559
                    $1.AorNbeforeE(); //#19559
                    if ($k[--$j]) { //#19559
                        $k[$j++] = $1.A; //#19559
                        break; //#19559
                    } //#19559
                    $k[$j++] = $1.B; //#19560
                    break; //#19560
                } //#19560
                if ($1.mode == $1.B) { //#19579
                    $k[$j++] = $1.modeBKbeforeB; //#19563
                    $1.KbeforeB(); //#19563
                    if ($k[--$j]) { //#19563
                        $k[$j++] = $1.K; //#19563
                        break; //#19563
                    } //#19563
                    $k[$j++] = $1.modeBKbeforeA; //#19564
                    $1.KbeforeA(); //#19564
                    if ($k[--$j]) { //#19564
                        $k[$j++] = $1.K; //#19564
                        break; //#19564
                    } //#19564
                    $k[$j++] = $1.modeBKbeforeN; //#19565
                    $1.KbeforeN(); //#19565
                    if ($k[--$j]) { //#19565
                        $k[$j++] = $1.K; //#19565
                        break; //#19565
                    } //#19565
                    $k[$j++] = $1.modeBKbeforeE; //#19566
                    $1.KbeforeE(); //#19566
                    if ($k[--$j]) { //#19566
                        $k[$j++] = $1.K; //#19566
                        break; //#19566
                    } //#19566
                    $k[$j++] = $1.modeBAbeforeK; //#19567
                    $1.AbeforeK(); //#19567
                    if ($k[--$j]) { //#19567
                        $k[$j++] = $1.A; //#19567
                        break; //#19567
                    } //#19567
                    $k[$j++] = $1.modeBAbeforeB; //#19568
                    $1.AbeforeB(); //#19568
                    if ($k[--$j]) { //#19568
                        $k[$j++] = $1.A; //#19568
                        break; //#19568
                    } //#19568
                    $k[$j++] = $1.modeBAbeforeN; //#19569
                    $1.AbeforeN(); //#19569
                    if ($k[--$j]) { //#19569
                        $k[$j++] = $1.A; //#19569
                        break; //#19569
                    } //#19569
                    $k[$j++] = $1.modeBAbeforeE; //#19570
                    $1.AbeforeE(); //#19570
                    if ($k[--$j]) { //#19570
                        $k[$j++] = $1.A; //#19570
                        break; //#19570
                    } //#19570
                    $k[$j++] = $1.modeBNbeforeK; //#19571
                    $1.NbeforeK(); //#19571
                    if ($k[--$j]) { //#19571
                        $k[$j++] = $1.N; //#19571
                        break; //#19571
                    } //#19571
                    $k[$j++] = $1.modeBNbeforeB; //#19572
                    $1.NbeforeB(); //#19572
                    if ($k[--$j]) { //#19572
                        $k[$j++] = $1.N; //#19572
                        break; //#19572
                    } //#19572
                    $k[$j++] = $1.modeBNbeforeA; //#19573
                    $1.NbeforeA(); //#19573
                    if ($k[--$j]) { //#19573
                        $k[$j++] = $1.N; //#19573
                        break; //#19573
                    } //#19573
                    $k[$j++] = $1.modeBNbeforeE; //#19574
                    $1.NbeforeE(); //#19574
                    if ($k[--$j]) { //#19574
                        $k[$j++] = $1.N; //#19574
                        break; //#19574
                    } //#19574
                    $k[$j++] = $1.modeBAbeforeE; //#19575
                    $1.AorNbeforeE(); //#19575
                    var _Co = $k[--$j]; //#19575
                    if (_Co && $le($1.numAorN, $get($1.modeBAbeforeN, $1.ver))) { //#19577
                        $k[$j++] = $1.modeBNbeforeA; //#19576
                        $1.nextNslt(); //#19576
                        if ($k[--$j]) { //#19576
                            $k[$j++] = $1.A; //#19576
                            break; //#19576
                        } //#19576
                    } //#19576
                    $k[$j++] = $1.B; //#19578
                    break; //#19578
                } //#19578
                if ($1.mode == $1.A) { //#19588
                    if ($1.numK >= 1) { //#19581
                        $k[$j++] = $1.K; //#19581
                        break; //#19581
                    } //#19581
                    if ($1.numB >= 1) { //#19582
                        $k[$j++] = $1.B; //#19582
                        break; //#19582
                    } //#19582
                    $k[$j++] = $1.modeANbeforeA; //#19583
                    $1.NbeforeA(); //#19583
                    if ($k[--$j]) { //#19583
                        $k[$j++] = $1.N; //#19583
                        break; //#19583
                    } //#19583
                    $k[$j++] = $1.modeANbeforeB; //#19584
                    $1.NbeforeB(); //#19584
                    if ($k[--$j]) { //#19584
                        $k[$j++] = $1.N; //#19584
                        break; //#19584
                    } //#19584
                    $k[$j++] = $1.modeANbeforeE; //#19585
                    $1.NbeforeE(); //#19585
                    if ($k[--$j]) { //#19585
                        $k[$j++] = $1.N; //#19585
                        break; //#19585
                    } //#19585
                    if (($1.numA >= 1) || ($1.numN >= 1)) { //#19586
                        $k[$j++] = $1.A; //#19586
                        break; //#19586
                    } //#19586
                    $k[$j++] = $1.B; //#19587
                    break; //#19587
                } //#19587
                if ($1.mode == $1.N) { //#19595
                    if ($1.numK >= 1) { //#19590
                        $k[$j++] = $1.K; //#19590
                        break; //#19590
                    } //#19590
                    if ($1.numB >= 1) { //#19591
                        $k[$j++] = $1.B; //#19591
                        break; //#19591
                    } //#19591
                    if ($1.numA >= 1) { //#19592
                        $k[$j++] = $1.A; //#19592
                        break; //#19592
                    } //#19592
                    if ($1.numN >= 1) { //#19593
                        $k[$j++] = $1.N; //#19593
                        break; //#19593
                    } //#19593
                    $k[$j++] = $1.B; //#19594
                    break; //#19594
                } //#19594
                if ($1.mode == $1.K) { //#19602
                    if ($1.numB >= 1) { //#19597
                        $k[$j++] = $1.B; //#19597
                        break; //#19597
                    } //#19597
                    if ($1.numA >= 1) { //#19598
                        $k[$j++] = $1.A; //#19598
                        break; //#19598
                    } //#19598
                    if ($1.numN >= 1) { //#19599
                        $k[$j++] = $1.N; //#19599
                        break; //#19599
                    } //#19599
                    if ($1.numK >= 1) { //#19600
                        $k[$j++] = $1.K; //#19600
                        break; //#19600
                    } //#19600
                    $k[$j++] = $1.B; //#19601
                    break; //#19601
                } //#19601
            } //#19601
            var _DY = $k[--$j]; //#19604
            $k[$j++] = _DY; //#19604
            if ((_DY == $1.K) && $1.fnc1first) { //#19604
                $j--; //#19604
                $k[$j++] = $1.B; //#19604
            } //#19604
            var _Dc = $k[--$j]; //#19605
            $k[$j++] = _Dc; //#19621
            if (_Dc == $1.mode) { //#19620
                $j--; //#19606
                var _Di = ($1.mode == $1.K) ? 2 : 1; //#19607
                $1.dat = $geti($1.msg, $1.i, _Di); //#19607
                $k[$j++] = Infinity; //#19610
                $aload($1.seq); //#19609
                $k[$j++] = Infinity; //#19610
                var _Dl = $k[--$j]; //#19610
                var _Dm = $k[--$j]; //#19610
                $k[$j++] = _Dl; //#19610
                $aload(_Dm); //#19610
                $aload($1.dat); //#19610
                var _Do = $a(); //#19610
                $k[$j++] = _Do; //#19610
                $1.seq = $a(); //#19610
            } else { //#19620
                $1.mode = $k[--$j]; //#19613
                if ($1.mode == $1.K) { //#19614
                    $k[$j++] = $1.K; //#19614
                    $k[$j++] = $geti($1.msg, $1.i, $1.numK * 2); //#19614
                } //#19614
                if ($1.mode == $1.B) { //#19615
                    $k[$j++] = $1.B; //#19615
                    $k[$j++] = $geti($1.msg, $1.i, $1.numB); //#19615
                } //#19615
                if ($1.mode == $1.A) { //#19616
                    $k[$j++] = $1.A; //#19616
                    $k[$j++] = $geti($1.msg, $1.i, $1.numA); //#19616
                } //#19616
                if ($1.mode == $1.N) { //#19617
                    $k[$j++] = $1.N; //#19617
                    $k[$j++] = $geti($1.msg, $1.i, $1.numN); //#19617
                } //#19617
                if ($1.mode == $1.E) { //#19618
                    $1.mode = -1; //#19618
                    $k[$j++] = $1.E; //#19618
                    $k[$j++] = $geti($1.msg, $1.i, 1); //#19618
                } //#19618
                $1.dat = $k[--$j]; //#19619
                $1.sw = $k[--$j]; //#19619
                $k[$j++] = Infinity; //#19620
                $aload($1.seq); //#19620
                $k[$j++] = $1.sw; //#19620
                $k[$j++] = $1.dat; //#19620
                $1.seq = $a(); //#19620
            } //#19620
            $1.i = $1.i + $1.dat.length; //#19622
        } //#19622
        for (;;) { //#19653
            if ($1.seq == -1) { //#19627
                break; //#19627
            } //#19627
            $1.bits = $s(23648); //#19628
            $1.j = 0; //#19629
            if ($1.fnc1first) { //#19632
                if ($lt($1.ver, $1.vR7x43)) { //#19631
                    $k[$j++] = "0101"; //#19631
                } else { //#19631
                    $k[$j++] = "101"; //#19631
                } //#19631
                $1.addtobits(); //#19631
            } //#19631
            $1.abort = false; //#19633
            for (var _Ee = 0, _Ed = $1.seq.length - 1; _Ee <= _Ed; _Ee += 2) { //#19648
                $1.i = _Ee; //#19635
                $1.mode = $get($1.seq, $1.i); //#19636
                $k[$j++] = $get($get($1.mids, $1.ver), $1.mode); //#19637
                $1.addtobits(); //#19637
                $1.chars = $get($1.seq, $1.i + 1); //#19638
                $k[$j++] = 'charslen'; //#19639
                $k[$j++] = $1.chars.length; //#19639
                if ($1.mode == $1.K) { //#19639
                    var _Et = $k[--$j]; //#19639
                    $k[$j++] = ~~(_Et / 2); //#19639
                } //#19639
                var _Eu = $k[--$j]; //#19639
                $1[$k[--$j]] = _Eu; //#19639
                if ($1.mode != $1.E) { //#19646
                    $1.cclen = $get($get($1.cclens, $1.ver), $1.mode); //#19641
                    if ($1.charslen >= (~~Math.pow(2, $1.cclen))) { //#19644
                        $1.abort = true; //#19643
                        break; //#19643
                    } //#19643
                    $k[$j++] = $1.charslen; //#19645
                    $k[$j++] = $1.cclen; //#19645
                    $1.tobin(); //#19645
                    $1.addtobits(); //#19645
                } //#19645
                $k[$j++] = $1.chars; //#19647
                if ($1[$get($1.encfuncs, $1.mode)]() === true) {
                    break;
                } //#19647
                $1.addtobits(); //#19647
            } //#19647
            if ($1.abort) { //#19649
                break; //#19649
            } //#19649
            $1.bits = $geti($1.bits, 0, $1.j); //#19650
            $put($1.msgbits, $1.ver, $1.bits); //#19651
            break; //#19652
        } //#19652
    } //#19652
    $1.metrics = $a([$a(["micro", "M1", $1.vM1, 11, 11, 98, 99, 36, $a([2, 99, 99, 99]), $a([1, 0, -1, -1, -1, -1, -1, -1])]), $a(["micro", "M2", $1.vM2, 13, 13, 98, 99, 80, $a([5, 6, 99, 99]), $a([1, 0, 1, 0, -1, -1, -1, -1])]), $a(["micro", "M3", $1.vM3, 15, 15, 98, 99, 132, $a([6, 8, 99, 99]), $a([1, 0, 1, 0, -1, -1, -1, -1])]), $a(["micro", "M4", $1.vM4, 17, 17, 98, 99, 192, $a([8, 10, 14, 99]), $a([1, 0, 1, 0, 1, 0, -1, -1])]), $a(["full", "1", $1.v1to9, 21, 21, 98, 99, 208, $a([7, 10, 13, 17]), $a([1, 0, 1, 0, 1, 0, 1, 0])]), $a(["full", "2", $1.v1to9, 25, 25, 18, 99, 359, $a([10, 16, 22, 28]), $a([1, 0, 1, 0, 1, 0, 1, 0])]), $a(["full", "3", $1.v1to9, 29, 29, 22, 99, 567, $a([15, 26, 36, 44]), $a([1, 0, 1, 0, 2, 0, 2, 0])]), $a(["full", "4", $1.v1to9, 33, 33, 26, 99, 807, $a([20, 36, 52, 64]), $a([1, 0, 2, 0, 2, 0, 4, 0])]), $a(["full", "5", $1.v1to9, 37, 37, 30, 99, 1079, $a([26, 48, 72, 88]), $a([1, 0, 2, 0, 2, 2, 2, 2])]), $a(["full", "6", $1.v1to9, 41, 41, 34, 99, 1383, $a([36, 64, 96, 112]), $a([2, 0, 4, 0, 4, 0, 4, 0])]), $a(["full", "7", $1.v1to9, 45, 45, 22, 38, 1568, $a([40, 72, 108, 130]), $a([2, 0, 4, 0, 2, 4, 4, 1])]), $a(["full", "8", $1.v1to9, 49, 49, 24, 42, 1936, $a([48, 88, 132, 156]), $a([2, 0, 2, 2, 4, 2, 4, 2])]), $a(["full", "9", $1.v1to9, 53, 53, 26, 46, 2336, $a([60, 110, 160, 192]), $a([2, 0, 3, 2, 4, 4, 4, 4])]), $a(["full", "10", $1.v10to26, 57, 57, 28, 50, 2768, $a([72, 130, 192, 224]), $a([2, 2, 4, 1, 6, 2, 6, 2])]), $a(["full", "11", $1.v10to26, 61, 61, 30, 54, 3232, $a([80, 150, 224, 264]), $a([4, 0, 1, 4, 4, 4, 3, 8])]), $a(["full", "12", $1.v10to26, 65, 65, 32, 58, 3728, $a([96, 176, 260, 308]), $a([2, 2, 6, 2, 4, 6, 7, 4])]), $a(["full", "13", $1.v10to26, 69, 69, 34, 62, 4256, $a([104, 198, 288, 352]), $a([4, 0, 8, 1, 8, 4, 12, 4])]), $a(["full", "14", $1.v10to26, 73, 73, 26, 46, 4651, $a([120, 216, 320, 384]), $a([3, 1, 4, 5, 11, 5, 11, 5])]), $a(["full", "15", $1.v10to26, 77, 77, 26, 48, 5243, $a([132, 240, 360, 432]), $a([5, 1, 5, 5, 5, 7, 11, 7])]), $a(["full", "16", $1.v10to26, 81, 81, 26, 50, 5867, $a([144, 280, 408, 480]), $a([5, 1, 7, 3, 15, 2, 3, 13])]), $a(["full", "17", $1.v10to26, 85, 85, 30, 54, 6523, $a([168, 308, 448, 532]), $a([1, 5, 10, 1, 1, 15, 2, 17])]), $a(["full", "18", $1.v10to26, 89, 89, 30, 56, 7211, $a([180, 338, 504, 588]), $a([5, 1, 9, 4, 17, 1, 2, 19])]), $a(["full", "19", $1.v10to26, 93, 93, 30, 58, 7931, $a([196, 364, 546, 650]), $a([3, 4, 3, 11, 17, 4, 9, 16])]), $a(["full", "20", $1.v10to26, 97, 97, 34, 62, 8683, $a([224, 416, 600, 700]), $a([3, 5, 3, 13, 15, 5, 15, 10])]), $a(["full", "21", $1.v10to26, 101, 101, 28, 50, 9252, $a([224, 442, 644, 750]), $a([4, 4, 17, 0, 17, 6, 19, 6])]), $a(["full", "22", $1.v10to26, 105, 105, 26, 50, 10068, $a([252, 476, 690, 816]), $a([2, 7, 17, 0, 7, 16, 34, 0])]), $a(["full", "23", $1.v10to26, 109, 109, 30, 54, 10916, $a([270, 504, 750, 900]), $a([4, 5, 4, 14, 11, 14, 16, 14])]), $a(["full", "24", $1.v10to26, 113, 113, 28, 54, 11796, $a([300, 560, 810, 960]), $a([6, 4, 6, 14, 11, 16, 30, 2])]), $a(["full", "25", $1.v10to26, 117, 117, 32, 58, 12708, $a([312, 588, 870, 1050]), $a([8, 4, 8, 13, 7, 22, 22, 13])]), $a(["full", "26", $1.v10to26, 121, 121, 30, 58, 13652, $a([336, 644, 952, 1110]), $a([10, 2, 19, 4, 28, 6, 33, 4])]), $a(["full", "27", $1.v27to40, 125, 125, 34, 62, 14628, $a([360, 700, 1020, 1200]), $a([8, 4, 22, 3, 8, 26, 12, 28])]), $a(["full", "28", $1.v27to40, 129, 129, 26, 50, 15371, $a([390, 728, 1050, 1260]), $a([3, 10, 3, 23, 4, 31, 11, 31])]), $a(["full", "29", $1.v27to40, 133, 133, 30, 54, 16411, $a([420, 784, 1140, 1350]), $a([7, 7, 21, 7, 1, 37, 19, 26])]), $a(["full", "30", $1.v27to40, 137, 137, 26, 52, 17483, $a([450, 812, 1200, 1440]), $a([5, 10, 19, 10, 15, 25, 23, 25])]), $a(["full", "31", $1.v27to40, 141, 141, 30, 56, 18587, $a([480, 868, 1290, 1530]), $a([13, 3, 2, 29, 42, 1, 23, 28])]), $a(["full", "32", $1.v27to40, 145, 145, 34, 60, 19723, $a([510, 924, 1350, 1620]), $a([17, 0, 10, 23, 10, 35, 19, 35])]), $a(["full", "33", $1.v27to40, 149, 149, 30, 58, 20891, $a([540, 980, 1440, 1710]), $a([17, 1, 14, 21, 29, 19, 11, 46])]), $a(["full", "34", $1.v27to40, 153, 153, 34, 62, 22091, $a([570, 1036, 1530, 1800]), $a([13, 6, 14, 23, 44, 7, 59, 1])]), $a(["full", "35", $1.v27to40, 157, 157, 30, 54, 23008, $a([570, 1064, 1590, 1890]), $a([12, 7, 12, 26, 39, 14, 22, 41])]), $a(["full", "36", $1.v27to40, 161, 161, 24, 50, 24272, $a([600, 1120, 1680, 1980]), $a([6, 14, 6, 34, 46, 10, 2, 64])]), $a(["full", "37", $1.v27to40, 165, 165, 28, 54, 25568, $a([630, 1204, 1770, 2100]), $a([17, 4, 29, 14, 49, 10, 24, 46])]), $a(["full", "38", $1.v27to40, 169, 169, 32, 58, 26896, $a([660, 1260, 1860, 2220]), $a([4, 18, 13, 32, 48, 14, 42, 32])]), $a(["full", "39", $1.v27to40, 173, 173, 26, 54, 28256, $a([720, 1316, 1950, 2310]), $a([20, 4, 40, 7, 43, 22, 10, 67])]), $a(["full", "40", $1.v27to40, 177, 177, 30, 58, 29648, $a([750, 1372, 2040, 2430]), $a([19, 6, 18, 31, 34, 34, 20, 61])]), $a(["rmqr", "R7x43", $1.vR7x43, 7, 43, 22, 99, 104, $a([99, 7, 99, 10]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R7x59", $1.vR7x59, 7, 59, 20, 40, 171, $a([99, 9, 99, 14]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R7x77", $1.vR7x77, 7, 77, 26, 52, 261, $a([99, 12, 99, 22]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R7x99", $1.vR7x99, 7, 99, 24, 50, 358, $a([99, 16, 99, 30]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R7x139", $1.vR7x139, 7, 139, 28, 56, 545, $a([99, 24, 99, 44]), $a([-1, -1, 1, 0, -1, -1, 2, 0])]), $a(["rmqr", "R9x43", $1.vR9x43, 9, 43, 22, 99, 170, $a([99, 9, 99, 14]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R9x59", $1.vR9x59, 9, 59, 20, 40, 267, $a([99, 12, 99, 22]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R9x77", $1.vR9x77, 9, 77, 26, 52, 393, $a([99, 18, 99, 32]), $a([-1, -1, 1, 0, -1, -1, 1, 1])]), $a(["rmqr", "R9x99", $1.vR9x99, 9, 99, 24, 50, 532, $a([99, 24, 99, 44]), $a([-1, -1, 1, 0, -1, -1, 2, 0])]), $a(["rmqr", "R9x139", $1.vR9x139, 9, 139, 28, 56, 797, $a([99, 36, 99, 66]), $a([-1, -1, 1, 1, -1, -1, 3, 0])]), $a(["rmqr", "R11x27", $1.vR11x27, 11, 27, 98, 99, 122, $a([99, 8, 99, 10]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R11x43", $1.vR11x43, 11, 43, 22, 99, 249, $a([99, 12, 99, 20]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R11x59", $1.vR11x59, 11, 59, 20, 40, 376, $a([99, 16, 99, 32]), $a([-1, -1, 1, 0, -1, -1, 1, 1])]), $a(["rmqr", "R11x77", $1.vR11x77, 11, 77, 26, 52, 538, $a([99, 24, 99, 44]), $a([-1, -1, 1, 0, -1, -1, 1, 1])]), $a(["rmqr", "R11x99", $1.vR11x99, 11, 99, 24, 50, 719, $a([99, 32, 99, 60]), $a([-1, -1, 1, 1, -1, -1, 1, 1])]), $a(["rmqr", "R11x139", $1.vR11x139, 11, 139, 28, 56, 1062, $a([99, 48, 99, 90]), $a([-1, -1, 2, 0, -1, -1, 3, 0])]), $a(["rmqr", "R13x27", $1.vR13x27, 13, 27, 98, 99, 172, $a([99, 9, 99, 14]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R13x43", $1.vR13x43, 13, 43, 22, 99, 329, $a([99, 14, 99, 28]), $a([-1, -1, 1, 0, -1, -1, 1, 0])]), $a(["rmqr", "R13x59", $1.vR13x59, 13, 59, 20, 40, 486, $a([99, 22, 99, 40]), $a([-1, -1, 1, 0, -1, -1, 2, 0])]), $a(["rmqr", "R13x77", $1.vR13x77, 13, 77, 26, 52, 684, $a([99, 32, 99, 56]), $a([-1, -1, 1, 1, -1, -1, 1, 1])]), $a(["rmqr", "R13x99", $1.vR13x99, 13, 99, 24, 50, 907, $a([99, 40, 99, 78]), $a([-1, -1, 1, 1, -1, -1, 1, 2])]), $a(["rmqr", "R13x139", $1.vR13x139, 13, 139, 28, 56, 1328, $a([99, 60, 99, 112]), $a([-1, -1, 2, 1, -1, -1, 2, 2])]), $a(["rmqr", "R15x43", $1.vR15x43, 15, 43, 22, 99, 409, $a([99, 18, 99, 36]), $a([-1, -1, 1, 0, -1, -1, 1, 1])]), $a(["rmqr", "R15x59", $1.vR15x59, 15, 59, 20, 40, 596, $a([99, 26, 99, 48]), $a([-1, -1, 1, 0, -1, -1, 2, 0])]), $a(["rmqr", "R15x77", $1.vR15x77, 15, 77, 26, 52, 830, $a([99, 36, 99, 72]), $a([-1, -1, 1, 1, -1, -1, 2, 1])]), $a(["rmqr", "R15x99", $1.vR15x99, 15, 99, 24, 50, 1095, $a([99, 48, 99, 88]), $a([-1, -1, 2, 0, -1, -1, 4, 0])]), $a(["rmqr", "R15x139", $1.vR15x139, 15, 139, 28, 56, 1594, $a([99, 72, 99, 130]), $a([-1, -1, 2, 1, -1, -1, 1, 4])]), $a(["rmqr", "R17x43", $1.vR17x43, 17, 43, 22, 99, 489, $a([99, 22, 99, 40]), $a([-1, -1, 1, 0, -1, -1, 1, 1])]), $a(["rmqr", "R17x59", $1.vR17x59, 17, 59, 20, 40, 706, $a([99, 32, 99, 60]), $a([-1, -1, 2, 0, -1, -1, 2, 0])]), $a(["rmqr", "R17x77", $1.vR17x77, 17, 77, 26, 52, 976, $a([99, 44, 99, 84]), $a([-1, -1, 2, 0, -1, -1, 1, 2])]), $a(["rmqr", "R17x99", $1.vR17x99, 17, 99, 24, 50, 1283, $a([99, 60, 99, 104]), $a([-1, -1, 2, 1, -1, -1, 4, 0])]), $a(["rmqr", "R17x139", $1.vR17x139, 17, 139, 28, 56, 1860, $a([99, 80, 99, 156]), $a([-1, -1, 4, 0, -1, -1, 2, 4])])]); //#19737
    $k[$j++] = 'eclval'; //#19740
    $search("LMQH", $1.eclevel); //#19740
    $j--; //#19740
    var _KF = $k[--$j]; //#19740
    var _KG = $k[--$j]; //#19740
    $k[$j++] = _KF.length; //#19740
    $k[$j++] = _KG; //#19740
    $j--; //#19740
    var _KH = $k[--$j]; //#19740
    var _KI = $k[--$j]; //#19740
    $k[$j++] = _KH; //#19740
    $k[$j++] = _KI; //#19740
    $j--; //#19740
    var _KJ = $k[--$j]; //#19740
    $1[$k[--$j]] = _KJ; //#19740
    for (var _KN = 0, _KM = $1.metrics.length - 1; _KN <= _KM; _KN += 1) { //#19779
        $1.i = _KN; //#19742
        $1.m = $get($1.metrics, $1.i); //#19743
        $1.frmt = $get($1.m, 0); //#19744
        $1.vers = $get($1.m, 1); //#19745
        $1.vergrp = $get($1.m, 2); //#19746
        $1.verind = $1.i - 44; //#19747
        $1.rows = $get($1.m, 3); //#19748
        $1.cols = $get($1.m, 4); //#19749
        $1.asp2 = $get($1.m, 5); //#19750
        $1.asp3 = $get($1.m, 6); //#19751
        $1.nmod = $get($1.m, 7); //#19752
        $1.ncws = ~~($1.nmod / 8); //#19753
        $1.rbit = $1.nmod % 8; //#19754
        $1.lc4b = false; //#19755
        if ($eq($1.vers, "M1") || $eq($1.vers, "M3")) { //#19760
            $1.ncws = $1.ncws + 1; //#19757
            $1.rbit = 0; //#19758
            $1.lc4b = true; //#19759
        } //#19759
        $1.ecws = $get($get($1.m, 8), $1.eclval); //#19761
        $1.dcws = $f($1.ncws - $1.ecws); //#19762
        var _Kv = $1.lc4b ? 4 : 0; //#19763
        $1.dmod = $f(($1.dcws * 8) - _Kv); //#19763
        $1.ecb1 = $get($get($1.m, 9), $1.eclval * 2); //#19764
        $1.ecb2 = $get($get($1.m, 9), $f(($1.eclval * 2) + 1)); //#19765
        $1.okay = true; //#19766
        if ($ne($1.format, $1.frmt)) { //#19767
            $1.okay = false; //#19767
        } //#19767
        if ($eq($1.frmt, "micro") && $1.fnc1first) { //#19768
            $1.okay = false; //#19768
        } //#19768
        if ($ne($1.version, "unset") && $ne($1.version, $1.vers)) { //#19769
            $1.okay = false; //#19769
        } //#19769
        if (($1.ecb1 == -1) || ($1.ecb2 == -1)) { //#19770
            $1.okay = false; //#19770
        } //#19770
        $1.verbits = $get($1.msgbits, $1.vergrp); //#19771
        if ($1.verbits == -1) { //#19775
            $1.okay = false; //#19773
        } else { //#19775
            if ($1.verbits.length > $1.dmod) { //#19775
                $1.okay = false; //#19775
            } //#19775
        } //#19775
        $1.term = $geti("000000000", 0, $get($1.termlens, $1.vergrp)); //#19777
        if ($1.okay) { //#19778
            break; //#19778
        } //#19778
    } //#19778
    if (!$1.okay) { //#19783
        $k[$j++] = 'bwipp.qrcodeNoValidSymbol'; //#19782
        $k[$j++] = "Maximum length exceeded or invalid content"; //#19782
        bwipp_raiseerror(); //#19782
    } //#19782
    $1.format = $1.frmt; //#19785
    $1.version = $1.vers; //#19786
    $1.msgbits = $1.verbits; //#19787
    $1.dcpb = ~~($1.dcws / $f($1.ecb1 + $1.ecb2)); //#19788
    $1.ecpb = (~~($1.ncws / $f($1.ecb1 + $1.ecb2))) - $1.dcpb; //#19789
    var _LZ = $1.term; //#19792
    var _La = $1.dmod; //#19792
    var _Lb = $1.msgbits; //#19792
    var _Lc = $1.term; //#19792
    var _Ld = _Lc.length; //#19792
    var _Le = $f(_La - _Lb.length); //#19792
    if ($f(_La - _Lb.length) > _Lc.length) { //#19792
        var _ = _Ld; //#19792
        _Ld = _Le; //#19792
        _Le = _; //#19792
    } //#19792
    $1.term = $geti(_LZ, 0, _Le); //#19792
    var _Li = $s($1.msgbits.length + $1.term.length); //#19793
    $puti(_Li, 0, $1.msgbits); //#19794
    $puti(_Li, $1.msgbits.length, $1.term); //#19795
    $1.msgbits = _Li; //#19796
    $1.pad = $s($1.dmod); //#19799
    for (var _Lq = 0, _Lp = $1.pad.length - 1; _Lq <= _Lp; _Lq += 1) { //#19800
        $put($1.pad, _Lq, 48); //#19800
    } //#19800
    $puti($1.pad, 0, $1.msgbits); //#19801
    $1.padnum = 0; //#19802
    var _Lx = $1.lc4b ? 5 : 1; //#19803
    for (var _Lz = ~~(Math.ceil($1.msgbits.length / 8) * 8), _Ly = $f($1.dmod - _Lx); _Lz <= _Ly; _Lz += 8) { //#19806
        $puti($1.pad, _Lz, $get($1.padstrs, $1.padnum)); //#19804
        $1.padnum = ($1.padnum + 1) % 2; //#19805
    } //#19805
    $1.cws = $a($1.dcws); //#19809
    for (var _M9 = 0, _M8 = $1.cws.length - 1; _M9 <= _M8; _M9 += 1) { //#19821
        $1.c = _M9; //#19811
        $1.bpcw = 8; //#19812
        if ($1.lc4b && ($1.c == ($1.cws.length - 1))) { //#19813
            $1.bpcw = 4; //#19813
        } //#19813
        $1.cwb = $geti($1.pad, $1.c * 8, $1.bpcw); //#19814
        $1.cw = 0; //#19815
        for (var _MJ = 0, _MI = $1.bpcw - 1; _MJ <= _MI; _MJ += 1) { //#19819
            $1.i = _MJ; //#19817
            $1.cw = $f($1.cw + ((~~(Math.pow(2, ($1.bpcw - $1.i) - 1))) * $f($get($1.cwb, $1.i) - 48))); //#19818
        } //#19818
        $put($1.cws, $1.c, $1.cw); //#19820
    } //#19820
    if ($1.lc4b) { //#19824
        var _MU = $1.cws; //#19824
        var _MV = $1.cws; //#19824
        $put(_MU, _MV.length - 1, $get(_MU, _MV.length - 1) << 4); //#19824
    } //#19824
    var _MY = $get($1.options, 'debugcws') !== undefined; //#19826
    if (_MY) { //#19826
        $k[$j++] = 'bwipp.debugcws'; //#19826
        $k[$j++] = $1.cws; //#19826
        bwipp_raiseerror(); //#19826
    } //#19826
    $k[$j++] = Infinity; //#19830
    $k[$j++] = 1; //#19830
    for (var _Ma = 0, _Mb = 255; _Ma < _Mb; _Ma++) { //#19830
        var _Mc = $k[--$j]; //#19830
        var _Md = _Mc * 2; //#19830
        $k[$j++] = _Mc; //#19830
        $k[$j++] = _Md; //#19830
        if (_Md >= 256) { //#19830
            var _Me = $k[--$j]; //#19830
            $k[$j++] = _Me ^ 285; //#19830
        } //#19830
    } //#19830
    $1.rsalog = $a(); //#19830
    $1.rslog = $a(256); //#19831
    for (var _Mh = 1; _Mh <= 255; _Mh += 1) { //#19832
        $put($1.rslog, $get($1.rsalog, _Mh), _Mh); //#19832
    } //#19832
    $1.rsprod = function() {
        var _Ml = $k[--$j]; //#19837
        var _Mm = $k[--$j]; //#19837
        $k[$j++] = _Mm; //#19841
        $k[$j++] = _Ml; //#19841
        if ((_Ml != 0) && (_Mm != 0)) { //#19840
            var _Mp = $get($1.rslog, $k[--$j]); //#19838
            var _Mu = $get($1.rsalog, $f(_Mp + $get($1.rslog, $k[--$j])) % 255); //#19838
            $k[$j++] = _Mu; //#19838
        } else { //#19840
            $j -= 2; //#19840
            $k[$j++] = 0; //#19840
        } //#19840
    }; //#19840
    $k[$j++] = Infinity; //#19845
    $k[$j++] = 1; //#19845
    for (var _Mw = 0, _Mx = $1.ecpb; _Mw < _Mx; _Mw++) { //#19845
        $k[$j++] = 0; //#19845
    } //#19845
    $1.coeffs = $a(); //#19845
    for (var _N1 = 0, _N0 = $1.ecpb - 1; _N1 <= _N0; _N1 += 1) { //#19854
        $1.i = _N1; //#19847
        $put($1.coeffs, $1.i + 1, $get($1.coeffs, $1.i)); //#19848
        for (var _N8 = $1.i; _N8 >= 1; _N8 -= 1) { //#19852
            $1.j = _N8; //#19850
            $k[$j++] = $1.coeffs; //#19851
            $k[$j++] = $1.j; //#19851
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#19851
            $k[$j++] = $get($1.coeffs, $1.j); //#19851
            $k[$j++] = $get($1.rsalog, $1.i); //#19851
            $1.rsprod(); //#19851
            var _NK = $k[--$j]; //#19851
            var _NL = $k[--$j]; //#19851
            var _NM = $k[--$j]; //#19851
            $put($k[--$j], _NM, $xo(_NL, _NK)); //#19851
        } //#19851
        $k[$j++] = $1.coeffs; //#19853
        $k[$j++] = 0; //#19853
        $k[$j++] = $get($1.coeffs, 0); //#19853
        $k[$j++] = $get($1.rsalog, $1.i); //#19853
        $1.rsprod(); //#19853
        var _NU = $k[--$j]; //#19853
        var _NV = $k[--$j]; //#19853
        $put($k[--$j], _NV, _NU); //#19853
    } //#19853
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#19855
    $1.rscodes = function() {
        $1.rscws = $k[--$j]; //#19859
        $1.rsnd = $1.rscws.length; //#19860
        $k[$j++] = Infinity; //#19861
        $forall($1.rscws); //#19861
        for (var _Ne = 0, _Nf = $1.ecpb; _Ne < _Nf; _Ne++) { //#19861
            $k[$j++] = 0; //#19861
        } //#19861
        $1.rscws = $a(); //#19861
        for (var _Nj = 0, _Ni = $1.rsnd - 1; _Nj <= _Ni; _Nj += 1) { //#19869
            $1.m = _Nj; //#19863
            $1.k = $get($1.rscws, $1.m); //#19864
            for (var _Np = 0, _No = $1.ecpb - 1; _Np <= _No; _Np += 1) { //#19868
                $1.j = _Np; //#19866
                $k[$j++] = $1.rscws; //#19867
                $k[$j++] = ($1.m + $1.j) + 1; //#19867
                $k[$j++] = $get($1.coeffs, ($1.ecpb - $1.j) - 1); //#19867
                $k[$j++] = $1.k; //#19867
                $1.rsprod(); //#19867
                var _O2 = $k[--$j]; //#19867
                var _O3 = $k[--$j]; //#19867
                $put($k[--$j], _O3, $xo(_O2, $get($1.rscws, ($1.m + $1.j) + 1))); //#19867
            } //#19867
        } //#19867
        $k[$j++] = $geti($1.rscws, $1.rsnd, $1.ecpb); //#19870
    }; //#19870
    $1.dcwsb = $a($f($1.ecb1 + $1.ecb2)); //#19874
    $1.ecwsb = $a($f($1.ecb1 + $1.ecb2)); //#19875
    for (var _OH = 0, _OG = $f($1.ecb1 - 1); _OH <= _OG; _OH += 1) { //#19880
        $1.i = _OH; //#19877
        $put($1.dcwsb, $1.i, $geti($1.cws, $1.i * $1.dcpb, $1.dcpb)); //#19878
        $k[$j++] = $1.ecwsb; //#19879
        $k[$j++] = $1.i; //#19879
        $k[$j++] = $get($1.dcwsb, $1.i); //#19879
        $1.rscodes(); //#19879
        var _OU = $k[--$j]; //#19879
        var _OV = $k[--$j]; //#19879
        $put($k[--$j], _OV, _OU); //#19879
    } //#19879
    for (var _OZ = 0, _OY = $f($1.ecb2 - 1); _OZ <= _OY; _OZ += 1) { //#19885
        $1.i = _OZ; //#19882
        $put($1.dcwsb, $f($1.ecb1 + $1.i), $geti($1.cws, $f(($1.ecb1 * $1.dcpb) + ($1.i * ($1.dcpb + 1))), $1.dcpb + 1)); //#19883
        $k[$j++] = $1.ecwsb; //#19884
        $k[$j++] = $f($1.ecb1 + $1.i); //#19884
        $k[$j++] = $get($1.dcwsb, $f($1.ecb1 + $1.i)); //#19884
        $1.rscodes(); //#19884
        var _Or = $k[--$j]; //#19884
        var _Os = $k[--$j]; //#19884
        $put($k[--$j], _Os, _Or); //#19884
    } //#19884
    $1.cws = $a($1.ncws); //#19888
    $1.cw = 0; //#19889
    for (var _Oy = 0, _Ox = $1.dcpb; _Oy <= _Ox; _Oy += 1) { //#19899
        $1.i = _Oy; //#19891
        for (var _P2 = 0, _P1 = $f($f($1.ecb1 + $1.ecb2) - 1); _P2 <= _P1; _P2 += 1) { //#19898
            $1.j = _P2; //#19893
            if ($1.i < $get($1.dcwsb, $1.j).length) { //#19897
                $put($1.cws, $1.cw, $get($get($1.dcwsb, $1.j), $1.i)); //#19895
                $1.cw = $1.cw + 1; //#19896
            } //#19896
        } //#19896
    } //#19896
    for (var _PH = 0, _PG = $1.ecpb - 1; _PH <= _PG; _PH += 1) { //#19907
        $1.i = _PH; //#19901
        for (var _PL = 0, _PK = $f($f($1.ecb1 + $1.ecb2) - 1); _PL <= _PK; _PL += 1) { //#19906
            $1.j = _PL; //#19903
            $put($1.cws, $1.cw, $get($get($1.ecwsb, $1.j), $1.i)); //#19904
            $1.cw = $1.cw + 1; //#19905
        } //#19905
    } //#19905
    if ($1.rbit > 0) { //#19915
        $1.pad = $a($1.cws.length + 1); //#19911
        $puti($1.pad, 0, $1.cws); //#19912
        $put($1.pad, $1.pad.length - 1, 0); //#19913
        $1.cws = $1.pad; //#19914
    } //#19914
    if ($1.lc4b) { //#19926
        var _Pd = $1.cws; //#19919
        var _Pe = $1.dcws; //#19919
        $put(_Pd, $f(_Pe - 1), $get(_Pd, $f(_Pe - 1)) >>> 4); //#19919
        for (var _Pj = $f($1.dcws - 1), _Pi = $1.ncws - 2; _Pj <= _Pi; _Pj += 1) { //#19924
            $1.i = _Pj; //#19921
            $put($1.cws, $1.i, ($get($1.cws, $1.i) & 15) << 4); //#19922
            $put($1.cws, $1.i, (($get($1.cws, $1.i + 1) >>> 4) & 15) | $get($1.cws, $1.i)); //#19923
        } //#19923
        $put($1.cws, $1.ncws - 1, ($get($1.cws, $1.ncws - 1) & 15) << 4); //#19925
    } //#19925
    var _Q3 = $get($1.options, 'debugecc') !== undefined; //#19928
    if (_Q3) { //#19928
        $k[$j++] = 'bwipp.debugecc'; //#19928
        $k[$j++] = $1.cws; //#19928
        bwipp_raiseerror(); //#19928
    } //#19928
    $k[$j++] = Infinity; //#19931
    for (var _Q7 = 0, _Q8 = $1.rows * $1.cols; _Q7 < _Q8; _Q7++) { //#19931
        $k[$j++] = -1; //#19931
    } //#19931
    $1.pixs = $a(); //#19931
    $1.qmv = function() {
        var _QB = $k[--$j]; //#19932
        var _QC = $k[--$j]; //#19932
        $k[$j++] = $f(_QC + (_QB * $1.cols)); //#19932
    }; //#19932
    if ($eq($1.format, "full")) { //#19941
        for (var _QG = 8, _QF = $f($1.cols - 9); _QG <= _QF; _QG += 1) { //#19940
            $1.i = _QG; //#19937
            $k[$j++] = $1.pixs; //#19938
            $k[$j++] = $1.i; //#19938
            $k[$j++] = 6; //#19938
            $1.qmv(); //#19938
            var _QK = $k[--$j]; //#19938
            $put($k[--$j], _QK, ($1.i + 1) % 2); //#19938
            $k[$j++] = $1.pixs; //#19939
            $k[$j++] = 6; //#19939
            $k[$j++] = $1.i; //#19939
            $1.qmv(); //#19939
            var _QP = $k[--$j]; //#19939
            $put($k[--$j], _QP, ($1.i + 1) % 2); //#19939
        } //#19939
    } //#19939
    if ($eq($1.format, "micro")) { //#19948
        for (var _QU = 8, _QT = $f($1.cols - 1); _QU <= _QT; _QU += 1) { //#19947
            $1.i = _QU; //#19944
            $k[$j++] = $1.pixs; //#19945
            $k[$j++] = $1.i; //#19945
            $k[$j++] = 0; //#19945
            $1.qmv(); //#19945
            var _QY = $k[--$j]; //#19945
            $put($k[--$j], _QY, ($1.i + 1) % 2); //#19945
            $k[$j++] = $1.pixs; //#19946
            $k[$j++] = 0; //#19946
            $k[$j++] = $1.i; //#19946
            $1.qmv(); //#19946
            var _Qd = $k[--$j]; //#19946
            $put($k[--$j], _Qd, ($1.i + 1) % 2); //#19946
        } //#19946
    } //#19946
    if ($eq($1.format, "rmqr")) { //#19967
        for (var _Qi = 3, _Qh = $f($1.cols - 4); _Qi <= _Qh; _Qi += 1) { //#19954
            $1.i = _Qi; //#19951
            $k[$j++] = $1.pixs; //#19952
            $k[$j++] = $1.i; //#19952
            $k[$j++] = 0; //#19952
            $1.qmv(); //#19952
            var _Qm = $k[--$j]; //#19952
            $put($k[--$j], _Qm, ($1.i + 1) % 2); //#19952
            $k[$j++] = $1.pixs; //#19953
            $k[$j++] = $1.i; //#19953
            $k[$j++] = $f($1.rows - 1); //#19953
            $1.qmv(); //#19953
            var _Qs = $k[--$j]; //#19953
            $put($k[--$j], _Qs, ($1.i + 1) % 2); //#19953
        } //#19953
        for (var _Qw = 3, _Qv = $f($1.rows - 4); _Qw <= _Qv; _Qw += 1) { //#19959
            $1.i = _Qw; //#19956
            $k[$j++] = $1.pixs; //#19957
            $k[$j++] = 0; //#19957
            $k[$j++] = $1.i; //#19957
            $1.qmv(); //#19957
            var _R0 = $k[--$j]; //#19957
            $put($k[--$j], _R0, ($1.i + 1) % 2); //#19957
            $k[$j++] = $1.pixs; //#19958
            $k[$j++] = $f($1.cols - 1); //#19958
            $k[$j++] = $1.i; //#19958
            $1.qmv(); //#19958
            var _R6 = $k[--$j]; //#19958
            $put($k[--$j], _R6, ($1.i + 1) % 2); //#19958
        } //#19958
        for (var _RD = $f($1.asp2 - 1), _RE = $f($1.asp3 - $1.asp2), _RC = $f($1.cols - 13); _RE < 0 ? _RD >= _RC : _RD <= _RC; _RD += _RE) { //#19966
            $1.i = _RD; //#19961
            for (var _RH = 3, _RG = $f($1.rows - 4); _RH <= _RG; _RH += 1) { //#19965
                $1.j = _RH; //#19963
                $k[$j++] = $1.pixs; //#19964
                $k[$j++] = $1.i; //#19964
                $k[$j++] = $1.j; //#19964
                $1.qmv(); //#19964
                var _RM = $k[--$j]; //#19964
                $put($k[--$j], _RM, ($1.j + 1) % 2); //#19964
            } //#19964
        } //#19964
    } //#19964
    $1.fpat = $a([$a([1, 1, 1, 1, 1, 1, 1, 0]), $a([1, 0, 0, 0, 0, 0, 1, 0]), $a([1, 0, 1, 1, 1, 0, 1, 0]), $a([1, 0, 1, 1, 1, 0, 1, 0]), $a([1, 0, 1, 1, 1, 0, 1, 0]), $a([1, 0, 0, 0, 0, 0, 1, 0]), $a([1, 1, 1, 1, 1, 1, 1, 0]), $a([0, 0, 0, 0, 0, 0, 0, 0])]); //#19980
    $1.fsubpat = $a([$a([1, 1, 1, 1, 1, 9, 9, 9]), $a([1, 0, 0, 0, 1, 9, 9, 9]), $a([1, 0, 1, 0, 1, 9, 9, 9]), $a([1, 0, 0, 0, 1, 9, 9, 9]), $a([1, 1, 1, 1, 1, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9])]); //#19990
    $1.fcorpat = $a([$a([1, 1, 1, 9, 9, 9, 9, 9]), $a([1, 0, 9, 9, 9, 9, 9, 9]), $a([1, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9])]); //#20000
    $1.fnullpat = $a([$a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9, 9, 9, 9])]); //#20010
    var _SD = new Map([
        ["full", $a([$1.fpat, $1.fpat, $1.fpat, $1.fnullpat])],
        ["micro", $a([$1.fpat, $1.fnullpat, $1.fnullpat, $1.fnullpat])],
        ["rmqr", $a([$1.fpat, $1.fcorpat, $1.fcorpat, $1.fsubpat])]
    ]); //#20015
    $1.fpatmap = _SD; //#20016
    $1.fpats = $get($1.fpatmap, $1.format); //#20018
    for (var _SH = 0; _SH <= 7; _SH += 1) { //#20032
        $1.y = _SH; //#20020
        for (var _SI = 0; _SI <= 7; _SI += 1) { //#20031
            $1.x = _SI; //#20022
            $1.fpb0 = $get($get($get($1.fpats, 0), $1.y), $1.x); //#20023
            $1.fpb1 = $get($get($get($1.fpats, 1), $1.y), $1.x); //#20024
            $1.fpb2 = $get($get($get($1.fpats, 2), $1.y), $1.x); //#20025
            $1.fpb3 = $get($get($get($1.fpats, 3), $1.y), $1.x); //#20026
            if (($1.fpb0 != 9) && ($1.y < $1.rows)) { //#20027
                $k[$j++] = $1.pixs; //#20027
                $k[$j++] = $1.x; //#20027
                $k[$j++] = $1.y; //#20027
                $1.qmv(); //#20027
                var _So = $k[--$j]; //#20027
                $put($k[--$j], _So, $1.fpb0); //#20027
            } //#20027
            if ($1.fpb1 != 9) { //#20028
                $k[$j++] = $1.pixs; //#20028
                $k[$j++] = $f($f($1.cols - $1.x) - 1); //#20028
                $k[$j++] = $1.y; //#20028
                $1.qmv(); //#20028
                var _Sw = $k[--$j]; //#20028
                $put($k[--$j], _Sw, $1.fpb1); //#20028
            } //#20028
            if ($1.fpb2 != 9) { //#20029
                $k[$j++] = $1.pixs; //#20029
                $k[$j++] = $1.x; //#20029
                $k[$j++] = $f($f($1.rows - $1.y) - 1); //#20029
                $1.qmv(); //#20029
                var _T4 = $k[--$j]; //#20029
                $put($k[--$j], _T4, $1.fpb2); //#20029
            } //#20029
            if ($1.fpb3 != 9) { //#20030
                $k[$j++] = $1.pixs; //#20030
                $k[$j++] = $f($f($1.cols - $1.x) - 1); //#20030
                $k[$j++] = $f($f($1.rows - $1.y) - 1); //#20030
                $1.qmv(); //#20030
                var _TD = $k[--$j]; //#20030
                $put($k[--$j], _TD, $1.fpb3); //#20030
            } //#20030
        } //#20030
    } //#20030
    $1.algnpatfull = $a([$a([1, 1, 1, 1, 1]), $a([1, 0, 0, 0, 1]), $a([1, 0, 1, 0, 1]), $a([1, 0, 0, 0, 1]), $a([1, 1, 1, 1, 1])]); //#20042
    $1.algnpatrmqr = $a([$a([1, 1, 1, 9, 9]), $a([1, 0, 1, 9, 9]), $a([1, 1, 1, 9, 9]), $a([9, 9, 9, 9, 9]), $a([9, 9, 9, 9, 9])]); //#20049
    $1.putalgnpat = function() {
        $1.py = $k[--$j]; //#20053
        $1.px = $k[--$j]; //#20054
        for (var _TT = 0; _TT <= 4; _TT += 1) { //#20064
            $1.pb = _TT; //#20056
            for (var _TU = 0; _TU <= 4; _TU += 1) { //#20063
                $1.pa = _TU; //#20058
                $1.algnb = $get($get($1.algnpat, $1.pb), $1.pa); //#20059
                if ($1.algnb != 9) { //#20062
                    $k[$j++] = $1.pixs; //#20061
                    $k[$j++] = $f($1.px + $1.pa); //#20061
                    $k[$j++] = $f($1.py + $1.pb); //#20061
                    $1.qmv(); //#20061
                    var _Th = $k[--$j]; //#20061
                    $put($k[--$j], _Th, $1.algnb); //#20061
                } //#20061
            } //#20061
        } //#20061
    }; //#20061
    if ($eq($1.format, "full")) { //#20080
        $1.algnpat = $1.algnpatfull; //#20067
        for (var _Tq = $f($1.asp2 - 2), _Tr = $f($1.asp3 - $1.asp2), _Tp = $f($1.cols - 13); _Tr < 0 ? _Tq >= _Tp : _Tq <= _Tp; _Tq += _Tr) { //#20072
            $1.i = _Tq; //#20069
            $k[$j++] = $1.i; //#20070
            $k[$j++] = 4; //#20070
            $1.putalgnpat(); //#20070
            $k[$j++] = 4; //#20071
            $k[$j++] = $1.i; //#20071
            $1.putalgnpat(); //#20071
        } //#20071
        for (var _Tz = $f($1.asp2 - 2), _U0 = $f($1.asp3 - $1.asp2), _Ty = $f($1.cols - 9); _U0 < 0 ? _Tz >= _Ty : _Tz <= _Ty; _Tz += _U0) { //#20079
            $1.x = _Tz; //#20074
            for (var _U6 = $f($1.asp2 - 2), _U7 = $f($1.asp3 - $1.asp2), _U5 = $f($1.rows - 9); _U7 < 0 ? _U6 >= _U5 : _U6 <= _U5; _U6 += _U7) { //#20078
                $1.y = _U6; //#20076
                $k[$j++] = $1.x; //#20077
                $k[$j++] = $1.y; //#20077
                $1.putalgnpat(); //#20077
            } //#20077
        } //#20077
    } //#20077
    if ($eq($1.format, "rmqr")) { //#20088
        $1.algnpat = $1.algnpatrmqr; //#20082
        for (var _UH = $f($1.asp2 - 2), _UI = $f($1.asp3 - $1.asp2), _UG = $f($1.cols - 13); _UI < 0 ? _UH >= _UG : _UH <= _UG; _UH += _UI) { //#20087
            $1.i = _UH; //#20084
            $k[$j++] = $1.i; //#20085
            $k[$j++] = 0; //#20085
            $1.putalgnpat(); //#20085
            $k[$j++] = $1.i; //#20086
            $k[$j++] = $f($1.rows - 3); //#20086
            $1.putalgnpat(); //#20086
        } //#20086
    } //#20086
    $1.formatmapmicro = $a([$a([$a([1, 8])]), $a([$a([2, 8])]), $a([$a([3, 8])]), $a([$a([4, 8])]), $a([$a([5, 8])]), $a([$a([6, 8])]), $a([$a([7, 8])]), $a([$a([8, 8])]), $a([$a([8, 7])]), $a([$a([8, 6])]), $a([$a([8, 5])]), $a([$a([8, 4])]), $a([$a([8, 3])]), $a([$a([8, 2])]), $a([$a([8, 1])])]); //#20096
    var _XK = new Map([
        ["full", $a([$a([$a([0, 8]), $a([8, $f($1.cols - 1)])]), $a([$a([1, 8]), $a([8, $f($1.cols - 2)])]), $a([$a([2, 8]), $a([8, $f($1.cols - 3)])]), $a([$a([3, 8]), $a([8, $f($1.cols - 4)])]), $a([$a([4, 8]), $a([8, $f($1.cols - 5)])]), $a([$a([5, 8]), $a([8, $f($1.cols - 6)])]), $a([$a([7, 8]), $a([8, $f($1.cols - 7)])]), $a([$a([8, 8]), $a([$f($1.cols - 8), 8])]), $a([$a([8, 7]), $a([$f($1.cols - 7), 8])]), $a([$a([8, 5]), $a([$f($1.cols - 6), 8])]), $a([$a([8, 4]), $a([$f($1.cols - 5), 8])]), $a([$a([8, 3]), $a([$f($1.cols - 4), 8])]), $a([$a([8, 2]), $a([$f($1.cols - 3), 8])]), $a([$a([8, 1]), $a([$f($1.cols - 2), 8])]), $a([$a([8, 0]), $a([$f($1.cols - 1), 8])])])],
        ["micro", $1.formatmapmicro],
        ["rmqr", $a([$a([$a([11, 3]), $a([$f($1.cols - 3), $f($1.rows - 6)])]), $a([$a([11, 2]), $a([$f($1.cols - 4), $f($1.rows - 6)])]), $a([$a([11, 1]), $a([$f($1.cols - 5), $f($1.rows - 6)])]), $a([$a([10, 5]), $a([$f($1.cols - 6), $f($1.rows - 2)])]), $a([$a([10, 4]), $a([$f($1.cols - 6), $f($1.rows - 3)])]), $a([$a([10, 3]), $a([$f($1.cols - 6), $f($1.rows - 4)])]), $a([$a([10, 2]), $a([$f($1.cols - 6), $f($1.rows - 5)])]), $a([$a([10, 1]), $a([$f($1.cols - 6), $f($1.rows - 6)])]), $a([$a([9, 5]), $a([$f($1.cols - 7), $f($1.rows - 2)])]), $a([$a([9, 4]), $a([$f($1.cols - 7), $f($1.rows - 3)])]), $a([$a([9, 3]), $a([$f($1.cols - 7), $f($1.rows - 4)])]), $a([$a([9, 2]), $a([$f($1.cols - 7), $f($1.rows - 5)])]), $a([$a([9, 1]), $a([$f($1.cols - 7), $f($1.rows - 6)])]), $a([$a([8, 5]), $a([$f($1.cols - 8), $f($1.rows - 2)])]), $a([$a([8, 4]), $a([$f($1.cols - 8), $f($1.rows - 3)])]), $a([$a([8, 3]), $a([$f($1.cols - 8), $f($1.rows - 4)])]), $a([$a([8, 2]), $a([$f($1.cols - 8), $f($1.rows - 5)])]), $a([$a([8, 1]), $a([$f($1.cols - 8), $f($1.rows - 6)])])])]
    ]); //#20113
    $1.formatmap = $get(_XK, $1.format); //#20115
    $forall($1.formatmap, function() { //#20118
        $forall($k[--$j], function() { //#20117
            $forall($k[--$j]); //#20117
            $1.qmv(); //#20117
            $put($1.pixs, $k[--$j], 1); //#20117
        }); //#20117
    }); //#20117
    if ($eq($1.format, "full") && ($1.cols >= 45)) { //#20134
        $1.versionmap = $a([$a([$a([$f($1.cols - 9), 5]), $a([5, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 5]), $a([5, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 5]), $a([5, $f($1.cols - 11)])]), $a([$a([$f($1.cols - 9), 4]), $a([4, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 4]), $a([4, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 4]), $a([4, $f($1.cols - 11)])]), $a([$a([$f($1.cols - 9), 3]), $a([3, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 3]), $a([3, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 3]), $a([3, $f($1.cols - 11)])]), $a([$a([$f($1.cols - 9), 2]), $a([2, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 2]), $a([2, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 2]), $a([2, $f($1.cols - 11)])]), $a([$a([$f($1.cols - 9), 1]), $a([1, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 1]), $a([1, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 1]), $a([1, $f($1.cols - 11)])]), $a([$a([$f($1.cols - 9), 0]), $a([0, $f($1.cols - 9)])]), $a([$a([$f($1.cols - 10), 0]), $a([0, $f($1.cols - 10)])]), $a([$a([$f($1.cols - 11), 0]), $a([0, $f($1.cols - 11)])])]); //#20132
    } else { //#20134
        $1.versionmap = $a([]); //#20134
    } //#20134
    var _Yy = $1.versionmap; //#20136
    for (var _Yz = 0, _Z0 = _Yy.length; _Yz < _Z0; _Yz++) { //#20138
        $forall($get(_Yy, _Yz), function() { //#20137
            $forall($k[--$j]); //#20137
            $1.qmv(); //#20137
            $put($1.pixs, $k[--$j], 0); //#20137
        }); //#20137
    } //#20137
    if ($eq($1.format, "full")) { //#20143
        $k[$j++] = $1.pixs; //#20142
        $k[$j++] = 8; //#20142
        $k[$j++] = $f($1.rows - 8); //#20142
        $1.qmv(); //#20142
        var _Z8 = $k[--$j]; //#20142
        $put($k[--$j], _Z8, 0); //#20142
    } //#20142
    var _ZS = $a([function() {
        var _ZA = $k[--$j]; //#20148
        var _ZB = $k[--$j]; //#20148
        $k[$j++] = $f(_ZB + _ZA) % 2; //#20148
    }, function() {
        var _ZC = $k[--$j]; //#20149
        var _ZD = $k[--$j]; //#20149
        $k[$j++] = _ZC; //#20149
        $k[$j++] = _ZD; //#20149
        $j--; //#20149
        var _ZE = $k[--$j]; //#20149
        $k[$j++] = _ZE % 2; //#20149
    }, function() {
        $j--; //#20150
        var _ZF = $k[--$j]; //#20150
        $k[$j++] = _ZF % 3; //#20150
    }, function() {
        var _ZG = $k[--$j]; //#20151
        var _ZH = $k[--$j]; //#20151
        $k[$j++] = $f(_ZH + _ZG) % 3; //#20151
    }, function() {
        var _ZI = $k[--$j]; //#20152
        var _ZJ = $k[--$j]; //#20152
        $k[$j++] = ((~~(_ZI / 2)) + (~~(_ZJ / 3))) % 2; //#20152
    }, function() {
        var _ZK = $k[--$j]; //#20153
        var _ZM = $k[--$j] * _ZK; //#20153
        $k[$j++] = $f((_ZM % 2) + (_ZM % 3)); //#20153
    }, function() {
        var _ZN = $k[--$j]; //#20154
        var _ZP = $k[--$j] * _ZN; //#20154
        $k[$j++] = ($f((_ZP % 2) + (_ZP % 3))) % 2; //#20154
    }, function() {
        var _ZQ = $k[--$j]; //#20155
        var _ZR = $k[--$j]; //#20155
        $k[$j++] = ($f(((_ZR * _ZQ) % 3) + ($f(_ZR + _ZQ) % 2))) % 2; //#20155
    }]); //#20155
    var _Zd = $a([function() {
        var _ZT = $k[--$j]; //#20158
        var _ZU = $k[--$j]; //#20158
        $k[$j++] = _ZT; //#20158
        $k[$j++] = _ZU; //#20158
        $j--; //#20158
        var _ZV = $k[--$j]; //#20158
        $k[$j++] = _ZV % 2; //#20158
    }, function() {
        var _ZW = $k[--$j]; //#20159
        var _ZX = $k[--$j]; //#20159
        $k[$j++] = ((~~(_ZW / 2)) + (~~(_ZX / 3))) % 2; //#20159
    }, function() {
        var _ZY = $k[--$j]; //#20160
        var _Za = $k[--$j] * _ZY; //#20160
        $k[$j++] = ($f((_Za % 2) + (_Za % 3))) % 2; //#20160
    }, function() {
        var _Zb = $k[--$j]; //#20161
        var _Zc = $k[--$j]; //#20161
        $k[$j++] = ($f(((_Zc * _Zb) % 3) + ($f(_Zc + _Zb) % 2))) % 2; //#20161
    }]); //#20161
    var _Zg = $a([function() {
        var _Ze = $k[--$j]; //#20164
        var _Zf = $k[--$j]; //#20164
        $k[$j++] = ((~~(_Ze / 2)) + (~~(_Zf / 3))) % 2; //#20164
    }]); //#20164
    var _Zh = new Map([
        ["full", _ZS],
        ["micro", _Zd],
        ["rmqr", _Zg]
    ]); //#20164
    $1.maskfuncs = $get(_Zh, $1.format); //#20166
    if ($1.mask != -1) { //#20170
        $1.maskfuncs = $a([$get($1.maskfuncs, $1.mask - 1)]); //#20168
        $1.bestmaskval = $1.mask - 1; //#20169
    } //#20169
    $1.masks = $a($1.maskfuncs.length); //#20171
    for (var _Zu = 0, _Zt = $1.masks.length - 1; _Zu <= _Zt; _Zu += 1) { //#20185
        $1.m = _Zu; //#20173
        $1.mask = $a($1.rows * $1.cols); //#20174
        for (var _a0 = 0, _Zz = $f($1.rows - 1); _a0 <= _Zz; _a0 += 1) { //#20183
            $1.j = _a0; //#20176
            for (var _a3 = 0, _a2 = $f($1.cols - 1); _a3 <= _a2; _a3 += 1) { //#20182
                $1.i = _a3; //#20178
                $k[$j++] = $1.i; //#20179
                $k[$j++] = $1.j; //#20179
                if ($get($1.maskfuncs, $1.m)() === true) {
                    break;
                } //#20179
                var _a9 = $k[--$j]; //#20179
                $k[$j++] = _a9 == 0; //#20180
                $k[$j++] = $1.pixs; //#20180
                $k[$j++] = $1.i; //#20180
                $k[$j++] = $1.j; //#20180
                $1.qmv(); //#20180
                var _aD = $k[--$j]; //#20180
                var _aF = $get($k[--$j], _aD); //#20180
                var _aG = $k[--$j]; //#20180
                var _aH = (_aG && (_aF == -1)) ? 1 : 0; //#20180
                $k[$j++] = _aH; //#20181
                $k[$j++] = $1.mask; //#20181
                $k[$j++] = $1.i; //#20181
                $k[$j++] = $1.j; //#20181
                $1.qmv(); //#20181
                var _aL = $k[--$j]; //#20181
                var _aM = $k[--$j]; //#20181
                $put(_aM, _aL, $k[--$j]); //#20181
            } //#20181
        } //#20181
        $put($1.masks, $1.m, $1.mask); //#20184
    } //#20184
    var _aT = $ne($1.format, "rmqr") ? 1 : 2; //#20188
    $1.posx = $f($1.cols - _aT); //#20188
    $1.posy = $f($1.rows - 1); //#20189
    $1.dir = -1; //#20190
    $1.col = 1; //#20191
    $1.num = 0; //#20192
    for (;;) { //#20215
        if ($1.posx < 0) { //#20194
            break; //#20194
        } //#20194
        $k[$j++] = $1.pixs; //#20195
        $k[$j++] = $1.posx; //#20195
        $k[$j++] = $1.posy; //#20195
        $1.qmv(); //#20195
        var _aZ = $k[--$j]; //#20195
        if ($get($k[--$j], _aZ) == -1) { //#20199
            var _ae = $get($1.cws, ~~($1.num / 8)); //#20196
            var _ag = -(7 - ($1.num % 8)); //#20196
            $k[$j++] = ((_ag < 0 ? _ae >>> -_ag : _ae << _ag)) & 1; //#20197
            $k[$j++] = $1.pixs; //#20197
            $k[$j++] = $1.posx; //#20197
            $k[$j++] = $1.posy; //#20197
            $1.qmv(); //#20197
            var _ak = $k[--$j]; //#20197
            var _al = $k[--$j]; //#20197
            $put(_al, _ak, $k[--$j]); //#20197
            $1.num = $1.num + 1; //#20198
        } //#20198
        if ($1.col == 1) { //#20212
            $1.col = 0; //#20201
            $1.posx = $f($1.posx - 1); //#20202
        } else { //#20212
            $1.col = 1; //#20204
            $1.posx = $f($1.posx + 1); //#20205
            $1.posy = $f($1.posy + $1.dir); //#20206
            if (($1.posy < 0) || ($1.posy >= $1.rows)) { //#20213
                $1.dir = $1.dir * -1; //#20208
                $1.posy = $f($1.posy + $1.dir); //#20209
                $1.posx = $f($1.posx - 2); //#20210
                if ($eq($1.format, "full") && ($1.posx == 6)) { //#20212
                    $1.posx = $f($1.posx - 1); //#20212
                } //#20212
            } //#20212
        } //#20212
    } //#20212
    $1.evalfulln1n3 = function() {
        $1.scrle = $k[--$j]; //#20219
        $k[$j++] = 'scr1'; //#20221
        $k[$j++] = 0; //#20221
        $forall($1.scrle, function() { //#20221
            var _b5 = $k[--$j]; //#20221
            $k[$j++] = _b5; //#20221
            if (_b5 >= 5) { //#20221
                var _b6 = $k[--$j]; //#20221
                var _b8 = $f($f($k[--$j] + _b6) - 2); //#20221
                $k[$j++] = _b8; //#20221
                $k[$j++] = _b8; //#20221
            } //#20221
            $j--; //#20221
        }); //#20221
        var _b9 = $k[--$j]; //#20221
        $1[$k[--$j]] = _b9; //#20221
        $1.scr3 = 0; //#20223
        for (var _bD = 3, _bC = $1.scrle.length - 3; _bD <= _bC; _bD += 2) { //#20238
            $1.j = _bD; //#20225
            if (($get($1.scrle, $1.j) % 3) == 0) { //#20237
                $1.fact = ~~($get($1.scrle, $1.j) / 3); //#20227
                var _bM = $geti($1.scrle, $1.j - 2, 5); //#20228
                for (var _bN = 0, _bO = _bM.length; _bN < _bO; _bN++) { //#20228
                    $k[$j++] = $get(_bM, _bN) == $1.fact; //#20228
                } //#20228
                var _bR = $k[--$j]; //#20228
                var _bS = $k[--$j]; //#20228
                var _bT = $k[--$j]; //#20228
                $k[$j++] = $an(_bS, _bR); //#20228
                $k[$j++] = _bT; //#20228
                $j--; //#20228
                var _bU = $k[--$j]; //#20228
                var _bV = $k[--$j]; //#20228
                var _bW = $k[--$j]; //#20228
                if (_bW && (_bV && _bU)) { //#20236
                    if (($1.j == 3) || (($1.j + 4) >= $1.scrle.length)) { //#20233
                        $1.scr3 = $1.scr3 + 40; //#20230
                    } else { //#20233
                        if (($get($1.scrle, $1.j - 3) >= 4) || ($get($1.scrle, $1.j + 3) >= 4)) { //#20234
                            $1.scr3 = $1.scr3 + 40; //#20233
                        } //#20233
                    } //#20233
                } //#20233
            } //#20233
        } //#20233
        $k[$j++] = $1.scr1; //#20239
        $k[$j++] = $1.scr3; //#20239
    }; //#20239
    $1.evalfull = function() {
        $1.sym = $k[--$j]; //#20244
        $1.n1 = 0; //#20246
        $1.n2 = 0; //#20246
        $1.n3 = 0; //#20246
        $1.rle = $a($f($1.cols + 1)); //#20247
        $1.lastpairs = $a($1.cols); //#20248
        $1.thispairs = $a($1.cols); //#20249
        $1.colsadd1 = $f($1.cols + 1); //#20250
        for (var _bu = 0, _bt = $f($1.cols - 1); _bu <= _bt; _bu += 1) { //#20289
            $1.i = _bu; //#20252
            $k[$j++] = Infinity; //#20255
            var _bw = $1.cols; //#20256
            $k[$j++] = 0; //#20258
            $k[$j++] = 0; //#20258
            for (var _by = $1.i, _bz = _bw, _bx = $f((_bw * _bw) - 1); _bz < 0 ? _by >= _bx : _by <= _bx; _by += _bz) { //#20258
                var _c1 = $get($1.sym, _by); //#20257
                var _c2 = $k[--$j]; //#20257
                $k[$j++] = _c1; //#20257
                if ($eq(_c2, _c1)) { //#20257
                    var _c3 = $k[--$j]; //#20257
                    var _c4 = $k[--$j]; //#20257
                    $k[$j++] = $f(_c4 + 1); //#20257
                    $k[$j++] = _c3; //#20257
                } else { //#20257
                    var _c5 = $k[--$j]; //#20257
                    $k[$j++] = 1; //#20257
                    $k[$j++] = _c5; //#20257
                } //#20257
            } //#20257
            $j--; //#20259
            var _c7 = $counttomark() + 2; //#20260
            $astore($geti($1.rle, 0, _c7 - 2)); //#20260
            $1.evalfulln1n3(); //#20261
            $1.n3 = $f($k[--$j] + $1.n3); //#20261
            $1.n1 = $f($k[--$j] + $1.n1); //#20261
            $j--; //#20262
            $1.symrow = $geti($1.sym, $1.i * $1.cols, $1.cols); //#20265
            $k[$j++] = Infinity; //#20266
            var _cI = $1.symrow; //#20267
            $k[$j++] = 0; //#20269
            $k[$j++] = 0; //#20269
            for (var _cJ = 0, _cK = _cI.length; _cJ < _cK; _cJ++) { //#20269
                var _cL = $get(_cI, _cJ); //#20269
                var _cM = $k[--$j]; //#20268
                $k[$j++] = _cL; //#20268
                if ($eq(_cM, _cL)) { //#20268
                    var _cN = $k[--$j]; //#20268
                    var _cO = $k[--$j]; //#20268
                    $k[$j++] = $f(_cO + 1); //#20268
                    $k[$j++] = _cN; //#20268
                } else { //#20268
                    var _cP = $k[--$j]; //#20268
                    $k[$j++] = 1; //#20268
                    $k[$j++] = _cP; //#20268
                } //#20268
            } //#20268
            $j--; //#20270
            var _cR = $counttomark() + 2; //#20271
            $astore($geti($1.rle, 0, _cR - 2)); //#20271
            $1.evalfulln1n3(); //#20272
            $1.n3 = $f($k[--$j] + $1.n3); //#20272
            $1.n1 = $f($k[--$j] + $1.n1); //#20272
            $j--; //#20273
            var _cX = $1.thispairs; //#20276
            $1.thispairs = $1.lastpairs; //#20276
            $1.lastpairs = _cX; //#20276
            var _cb = ($get($1.symrow, 0) == 1) ? 0 : 1; //#20277
            var _cc = $1.symrow; //#20278
            $k[$j++] = _cb; //#20278
            for (var _cd = 0, _ce = _cc.length; _cd < _ce; _cd++) { //#20278
                var _cf = $get(_cc, _cd); //#20278
                var _cg = $k[--$j]; //#20278
                $k[$j++] = $f(_cg + _cf); //#20278
                $k[$j++] = _cf; //#20278
            } //#20278
            $j--; //#20279
            $astore($1.thispairs); //#20280
            $j--; //#20280
            if ($1.i > 0) { //#20287
                $k[$j++] = Infinity; //#20282
                $aload($1.lastpairs); //#20283
                $aload($1.thispairs); //#20283
                $k[$j++] = $1.n2; //#20284
                for (var _cn = 0, _co = $1.cols; _cn < _co; _cn++) { //#20284
                    var _cp = $k[--$j]; //#20284
                    var _cq = $k[--$j]; //#20284
                    $k[$j++] = _cp; //#20284
                    $k[$j++] = _cq; //#20284
                    var _cs = $k[$j - 1 - $1.colsadd1]; //#20284
                    if (($f($k[--$j] + _cs) & 3) == 0) { //#20284
                        var _cu = $k[--$j]; //#20284
                        $k[$j++] = $f(_cu + 3); //#20284
                    } //#20284
                } //#20284
                $1.n2 = $k[--$j]; //#20285
                $cleartomark(); //#20286
            } //#20286
        } //#20286
        $k[$j++] = 'dark'; //#20292
        $k[$j++] = 0; //#20292
        $forall($1.sym, function() { //#20292
            var _cx = $k[--$j]; //#20292
            var _cy = $k[--$j]; //#20292
            $k[$j++] = $f(_cy + _cx); //#20292
        }); //#20292
        var _cz = $k[--$j]; //#20292
        $1[$k[--$j]] = _cz; //#20292
        var _d2 = $1.cols; //#20293
        $1.n4 = (~~((Math.abs($f((($1.dark * 100) / (_d2 * _d2)) - 50))) / 5)) * 10; //#20293
        $k[$j++] = $f(($f($f($1.n1 + $1.n2) + $1.n3)) + $1.n4); //#20295
    }; //#20295
    $1.evalmicro = function() {
        $1.sym = $k[--$j]; //#20300
        $1.dkrhs = 0; //#20301
        $1.dkbot = 0; //#20301
        for (var _dA = 1, _d9 = $f($1.cols - 1); _dA <= _d9; _dA += 1) { //#20306
            $1.i = _dA; //#20303
            $k[$j++] = 'dkrhs'; //#20304
            $k[$j++] = $1.dkrhs; //#20304
            $k[$j++] = $1.sym; //#20304
            $k[$j++] = $f($1.cols - 1); //#20304
            $k[$j++] = $1.i; //#20304
            $1.qmv(); //#20304
            var _dF = $k[--$j]; //#20304
            var _dH = $get($k[--$j], _dF); //#20304
            var _dI = $k[--$j]; //#20304
            $1[$k[--$j]] = $f(_dI + _dH); //#20304
            $k[$j++] = 'dkbot'; //#20305
            $k[$j++] = $1.dkbot; //#20305
            $k[$j++] = $1.sym; //#20305
            $k[$j++] = $1.i; //#20305
            $k[$j++] = $f($1.cols - 1); //#20305
            $1.qmv(); //#20305
            var _dO = $k[--$j]; //#20305
            var _dQ = $get($k[--$j], _dO); //#20305
            var _dR = $k[--$j]; //#20305
            $1[$k[--$j]] = $f(_dR + _dQ); //#20305
        } //#20305
        if ($1.dkrhs <= $1.dkbot) { //#20310
            $k[$j++] = -(($1.dkrhs * 16) + $1.dkbot); //#20308
        } else { //#20310
            $k[$j++] = -(($1.dkbot * 16) + $1.dkrhs); //#20310
        } //#20310
    }; //#20310
    $1.bestscore = 999999999; //#20315
    for (var _db = 0, _da = $1.masks.length - 1; _db <= _da; _db += 1) { //#20337
        $1.m = _db; //#20317
        $1.masksym = $a($1.rows * $1.cols); //#20318
        for (var _di = 0, _dh = $f(($1.rows * $1.cols) - 1); _di <= _dh; _di += 1) { //#20322
            $1.i = _di; //#20320
            $put($1.masksym, $1.i, $xo($get($1.pixs, $1.i), $get($get($1.masks, $1.m), $1.i))); //#20321
        } //#20321
        if ($1.masks.length != 1) { //#20335
            if ($eq($1.format, "full")) { //#20327
                $k[$j++] = $1.masksym; //#20325
                $1.evalfull(); //#20325
                $1.score = $k[--$j]; //#20325
            } else { //#20327
                $k[$j++] = $1.masksym; //#20327
                $1.evalmicro(); //#20327
                $1.score = $k[--$j]; //#20327
            } //#20327
            if ($1.score < $1.bestscore) { //#20333
                $1.bestsym = $1.masksym; //#20330
                $1.bestmaskval = $1.m; //#20331
                $1.bestscore = $1.score; //#20332
            } //#20332
        } else { //#20335
            $1.bestsym = $1.masksym; //#20335
        } //#20335
    } //#20335
    $1.pixs = $1.bestsym; //#20338
    if ($eq($1.format, "full")) { //#20343
        $k[$j++] = $1.pixs; //#20342
        $k[$j++] = 8; //#20342
        $k[$j++] = $f($1.cols - 8); //#20342
        $1.qmv(); //#20342
        var _e9 = $k[--$j]; //#20342
        $put($k[--$j], _e9, 1); //#20342
    } //#20342
    $1.fmtvalsfull = $a([21522, 20773, 24188, 23371, 17913, 16590, 20375, 19104, 30660, 29427, 32170, 30877, 26159, 25368, 27713, 26998, 5769, 5054, 7399, 6608, 1890, 597, 3340, 2107, 13663, 12392, 16177, 14854, 9396, 8579, 11994, 11245]); //#20352
    $1.fmtvalsmicro = $a([17477, 16754, 20011, 19228, 21934, 20633, 24512, 23287, 26515, 25252, 28157, 26826, 30328, 29519, 31766, 31009, 1758, 1001, 3248, 2439, 5941, 4610, 7515, 6252, 9480, 8255, 12134, 10833, 13539, 12756, 16013, 15290]); //#20358
    $1.fmtvalsrmqr1 = $a([129714, 124311, 121821, 115960, 112748, 108361, 104707, 99878, 98062, 90155, 89697, 82244, 81360, 74485, 72895, 66458, 61898, 61167, 53413, 53120, 45844, 44081, 37499, 36190, 29814, 27475, 21785, 19004, 13992, 10637, 6087, 2274, 258919, 257090, 250376, 249133, 242105, 241308, 233686, 233459, 227035, 223742, 219060, 215185, 209925, 207648, 202090, 199247, 194591, 190266, 186736, 181845, 178881, 173540, 170926, 165003, 163235, 156294, 154828, 148457, 147325, 139352, 138770, 131383]); //#20368
    $1.fmtvalsrmqr2 = $a([133755, 136542, 142100, 144433, 149669, 153472, 158154, 161519, 167879, 168162, 175784, 176525, 183577, 184892, 191606, 193363, 196867, 204326, 204908, 212809, 213981, 220408, 221874, 228759, 230591, 236442, 239056, 244469, 247393, 252228, 255758, 260139, 942, 7307, 8897, 15844, 16752, 24149, 24607, 32570, 34322, 39223, 42877, 47192, 50380, 56297, 58787, 64134, 67798, 71667, 76217, 79516, 84488, 87341, 93031, 95298, 101738, 102991, 109573, 111392, 118708, 118929, 126683, 127486]); //#20378
    if ($eq($1.format, "full")) { //#20389
        $k[$j++] = 'ecid'; //#20381
        $search("MLHQ", $1.eclevel); //#20381
        $j--; //#20381
        var _eH = $k[--$j]; //#20381
        var _eI = $k[--$j]; //#20381
        $k[$j++] = _eH.length; //#20381
        $k[$j++] = _eI; //#20381
        $j--; //#20381
        var _eJ = $k[--$j]; //#20381
        var _eK = $k[--$j]; //#20381
        $k[$j++] = _eJ; //#20381
        $k[$j++] = _eK; //#20381
        $j--; //#20381
        var _eL = $k[--$j]; //#20381
        $1[$k[--$j]] = _eL; //#20381
        $1.fmtval = $get($1.fmtvalsfull, ($1.ecid << 3) + $1.bestmaskval); //#20382
        for (var _eT = 0, _eS = $1.formatmap.length - 1; _eT <= _eS; _eT += 1) { //#20388
            $1.i = _eT; //#20384
            $forall($get($1.formatmap, $1.i), function() { //#20387
                var _eY = $k[--$j]; //#20386
                $k[$j++] = $1.pixs; //#20386
                $aload(_eY); //#20386
                $1.qmv(); //#20386
                var _eZ = $1.fmtval; //#20386
                var _eb = -(14 - $1.i); //#20386
                var _ec = $k[--$j]; //#20386
                $put($k[--$j], _ec, ((_eb < 0 ? _eZ >>> -_eb : _eZ << _eb)) & 1); //#20386
            }); //#20386
        } //#20386
    } //#20386
    if ($eq($1.format, "micro")) { //#20397
        $1.symid = $get($get($a([$a([0]), $a([1, 2]), $a([3, 4]), $a([5, 6, 7])]), ~~($f($1.cols - 11) / 2)), $1.eclval); //#20391
        $1.fmtval = $get($1.fmtvalsmicro, ($1.symid << 2) + $1.bestmaskval); //#20392
        for (var _eu = 0, _et = $1.formatmap.length - 1; _eu <= _et; _eu += 1) { //#20396
            $1.i = _eu; //#20394
            $k[$j++] = $1.pixs; //#20395
            $aload($get($get($1.formatmap, $1.i), 0)); //#20395
            $1.qmv(); //#20395
            var _f0 = $1.fmtval; //#20395
            var _f2 = -(14 - $1.i); //#20395
            var _f3 = $k[--$j]; //#20395
            $put($k[--$j], _f3, ((_f2 < 0 ? _f0 >>> -_f2 : _f0 << _f2)) & 1); //#20395
        } //#20395
    } //#20395
    if ($eq($1.format, "rmqr")) { //#20407
        $k[$j++] = 'fmtvalu'; //#20399
        $search("MH", $1.eclevel); //#20399
        $j--; //#20399
        var _f7 = $k[--$j]; //#20399
        var _f8 = $k[--$j]; //#20399
        $k[$j++] = _f7.length; //#20399
        $k[$j++] = _f8; //#20399
        $j--; //#20399
        var _f9 = $k[--$j]; //#20399
        var _fA = $k[--$j]; //#20399
        $k[$j++] = _f9; //#20399
        $k[$j++] = _fA; //#20399
        $j--; //#20399
        var _fB = $k[--$j]; //#20399
        $1[$k[--$j]] = (_fB << 5) + $1.verind; //#20399
        $1.fmtval1 = $get($1.fmtvalsrmqr1, $1.fmtvalu); //#20400
        $1.fmtval2 = $get($1.fmtvalsrmqr2, $1.fmtvalu); //#20401
        for (var _fM = 0, _fL = $1.formatmap.length - 1; _fM <= _fL; _fM += 1) { //#20406
            $1.i = _fM; //#20403
            $k[$j++] = $1.pixs; //#20404
            $aload($get($get($1.formatmap, $1.i), 0)); //#20404
            $1.qmv(); //#20404
            var _fS = $1.fmtval1; //#20404
            var _fU = -(17 - $1.i); //#20404
            var _fV = $k[--$j]; //#20404
            $put($k[--$j], _fV, ((_fU < 0 ? _fS >>> -_fU : _fS << _fU)) & 1); //#20404
            $k[$j++] = $1.pixs; //#20405
            $aload($get($get($1.formatmap, $1.i), 1)); //#20405
            $1.qmv(); //#20405
            var _fc = $1.fmtval2; //#20405
            var _fe = -(17 - $1.i); //#20405
            var _ff = $k[--$j]; //#20405
            $put($k[--$j], _ff, ((_fe < 0 ? _fc >>> -_fe : _fc << _fe)) & 1); //#20405
        } //#20405
    } //#20405
    $1.vervals = $a([31892, 34236, 39577, 42195, 48118, 51042, 55367, 58893, 63784, 68472, 70749, 76311, 79154, 84390, 87683, 92361, 96236, 102084, 102881, 110507, 110734, 117786, 119615, 126325, 127568, 133589, 136957, 141498, 145311, 150283, 152622, 158308, 161089, 167017]); //#20417
    if ($eq($1.format, "full") && ($1.cols >= 45)) { //#20427
        $1.verval = $get($1.vervals, (~~($f($1.cols - 17) / 4)) - 7); //#20420
        for (var _fp = 0, _fo = $1.versionmap.length - 1; _fp <= _fo; _fp += 1) { //#20426
            $1.i = _fp; //#20422
            $forall($get($1.versionmap, $1.i), function() { //#20425
                var _fu = $k[--$j]; //#20424
                $k[$j++] = $1.pixs; //#20424
                $forall(_fu); //#20424
                $1.qmv(); //#20424
                var _fv = $1.verval; //#20424
                var _fx = -(17 - $1.i); //#20424
                var _fy = $k[--$j]; //#20424
                $put($k[--$j], _fy, ((_fx < 0 ? _fv >>> -_fx : _fv << _fx)) & 1); //#20424
            }); //#20424
        } //#20424
    } //#20424
    var _g6 = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.cols],
        ["pixy", $1.rows],
        ["height", ($1.rows * 2) / 72],
        ["width", ($1.cols * 2) / 72],
        ["opt", $1.options]
    ]); //#20437
    $k[$j++] = _g6; //#20440
    if (!$1.dontdraw) { //#20440
        bwipp_renmatrix(); //#20440
    } //#20440
}

function bwipp_swissqrcode() {
    var $1 = {}; //#20474
    $1.ctx = null; //#20476
    $1.dontdraw = false; //#20477
    $1.parse = false; //#20478
    $k[$j++] = $1; //#20480
    bwipp_processoptions(); //#20480
    $1.options = $k[--$j]; //#20480
    $1.barcode = $k[--$j]; //#20481
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#20487
    $1.fncvals = _3; //#20488
    $k[$j++] = 'barcode'; //#20489
    $k[$j++] = $1.barcode; //#20489
    $k[$j++] = $1.fncvals; //#20489
    bwipp_parseinput(); //#20489
    var _6 = $k[--$j]; //#20489
    $1[$k[--$j]] = _6; //#20489
    $1.barlen = $1.barcode.length; //#20490
    delete $1.options["parse"]; //#20491
    if ($1.barcode.length > 997) { //#20496
        $k[$j++] = 'bwipp.swissqrcodeBadLength'; //#20495
        $k[$j++] = "Swiss QR Code input must not exceed 997 digits"; //#20495
        bwipp_raiseerror(); //#20495
    } //#20495
    $put($1.options, "dontdraw", true); //#20499
    $k[$j++] = 'args'; //#20500
    $k[$j++] = $1.barcode; //#20500
    $k[$j++] = $1.options; //#20500
    bwipp_qrcode(); //#20500
    var _E = $k[--$j]; //#20500
    $1[$k[--$j]] = _E; //#20500
    $put($1.args, "opt", $1.options); //#20502
    $k[$j++] = $1.args; //#20571
    if (!$1.dontdraw) { //#20571
        $$.save(); //#20516
        var _K = $$.currpos(); //#20517
        $$.translate(_K.x, _K.y); //#20517
        var _L = 72 / 25.4; //#20518
        $$.scale(_L, _L); //#20518
        $$.save(); //#20521
        $$.newpath(); //#20522
        $$.moveto(0, 0); //#20523
        $$.lineto(46, 0); //#20524
        $$.lineto(46, 46); //#20525
        $$.lineto(0, 46); //#20526
        $$.closepath(); //#20527
        $$.moveto(19.5, 19.5); //#20528
        $$.lineto(19.5, 26.5); //#20529
        $$.lineto(26.5, 26.5); //#20530
        $$.lineto(26.5, 19.5); //#20531
        $$.closepath(); //#20532
        $$.clip(); //#20533
        $$.save(); //#20536
        $$.moveto(0, 0); //#20537
        var _O = (46 / $get($1.args, "pixx")) / 2; //#20538
        $$.scale(_O, _O); //#20538
        bwipp_renmatrix(); //#20539
        $$.restore(); //#20540
        $$.restore(); //#20542
        $$.translate(19.5, 19.5); //#20545
        var _P = 7 / 83; //#20546
        $$.scale(_P, _P); //#20546
        $$.newpath(); //#20548
        $$.moveto(6, 6); //#20549
        $$.lineto(6, 77); //#20550
        $$.lineto(77, 77); //#20551
        $$.lineto(77, 6); //#20552
        $$.closepath(); //#20553
        $$.moveto(49, 18); //#20554
        $$.lineto(49, 34); //#20555
        $$.lineto(65, 34); //#20556
        $$.lineto(65, 49); //#20557
        $$.lineto(49, 49); //#20558
        $$.lineto(49, 65); //#20559
        $$.lineto(34, 65); //#20560
        $$.lineto(34, 49); //#20561
        $$.lineto(18, 49); //#20562
        $$.lineto(18, 34); //#20563
        $$.lineto(34, 34); //#20564
        $$.lineto(34, 18); //#20565
        $$.closepath(); //#20566
        $$.setrgbcolor(0, 0, 0); //#20567
        $$.fill(); //#20567
        $$.restore(); //#20569
    } //#20569
}

function bwipp_microqrcode() {
    var $1 = {}; //#20602
    $1.ctx = null; //#20604
    $1.dontdraw = false; //#20605
    $k[$j++] = $1; //#20607
    bwipp_processoptions(); //#20607
    $1.options = $k[--$j]; //#20607
    $1.barcode = $k[--$j]; //#20608
    $put($1.options, "dontdraw", true); //#20611
    $put($1.options, "format", "micro"); //#20612
    $k[$j++] = 'args'; //#20614
    $k[$j++] = $1.barcode; //#20614
    $k[$j++] = $1.options; //#20614
    bwipp_qrcode(); //#20614
    var _6 = $k[--$j]; //#20614
    $1[$k[--$j]] = _6; //#20614
    $put($1.args, "opt", $1.options); //#20616
    $k[$j++] = $1.args; //#20619
    if (!$1.dontdraw) { //#20619
        bwipp_renmatrix(); //#20619
    } //#20619
}

function bwipp_rectangularmicroqrcode() {
    var $1 = {}; //#20650
    $1.ctx = null; //#20652
    $1.dontdraw = false; //#20653
    $k[$j++] = $1; //#20655
    bwipp_processoptions(); //#20655
    $1.options = $k[--$j]; //#20655
    $1.barcode = $k[--$j]; //#20656
    $put($1.options, "dontdraw", true); //#20659
    $put($1.options, "format", "rmqr"); //#20660
    $k[$j++] = 'args'; //#20662
    $k[$j++] = $1.barcode; //#20662
    $k[$j++] = $1.options; //#20662
    bwipp_qrcode(); //#20662
    var _6 = $k[--$j]; //#20662
    $1[$k[--$j]] = _6; //#20662
    $put($1.args, "opt", $1.options); //#20664
    $k[$j++] = $1.args; //#20667
    if (!$1.dontdraw) { //#20667
        bwipp_renmatrix(); //#20667
    } //#20667
}

function bwipp_maxicode() {
    var $1 = {}; //#20700
    $1.ctx = null; //#20702
    $1.dontdraw = false; //#20703
    $1.mode = -1; //#20704
    $1.sam = -1; //#20705
    $1.parse = false; //#20706
    $1.parsefnc = false; //#20707
    $k[$j++] = $1; //#20709
    bwipp_processoptions(); //#20709
    $1.options = $k[--$j]; //#20709
    $1.barcode = $k[--$j]; //#20710
    var _4 = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["eci", true]
    ]); //#20718
    $1.fncvals = _4; //#20720
    $k[$j++] = 'msg'; //#20721
    $k[$j++] = $1.barcode; //#20721
    $k[$j++] = $1.fncvals; //#20721
    bwipp_parseinput(); //#20721
    var _7 = $k[--$j]; //#20721
    $1[$k[--$j]] = _7; //#20721
    $1.msglen = $1.msg.length; //#20722
    if (($1.mode == 2) || ($1.mode == 3)) { //#20761
        $1.barcode = $s($1.msglen); //#20728
        for (var _G = 0, _F = $1.msglen - 1; _G <= _F; _G += 1) { //#20734
            $1.i = _G; //#20730
            if ($get($1.msg, $1.i) > 0) { //#20733
                $put($1.barcode, $1.i, $get($1.msg, $1.i)); //#20732
            } //#20732
        } //#20732
        $1.barlen = $1.barcode.length; //#20735
        if ($eq($geti($1.barcode, 0, 7), "\x5b\x29\x3e\x1e\x30\x31\x1d")) { //#20742
            $1.fid = $geti($1.barcode, 0, 9); //#20739
            $1.barcode = $geti($1.barcode, 9, $1.barlen - 9); //#20740
        } else { //#20742
            $1.fid = ""; //#20742
        } //#20742
        $search($1.barcode, "\x1d"); //#20746
        $j--; //#20746
        $1.pcode = $k[--$j]; //#20746
        $j--; //#20747
        $search($k[--$j], "\x1d"); //#20747
        $j--; //#20747
        $1.ccode = $k[--$j]; //#20747
        $j--; //#20748
        $search($k[--$j], "\x1d"); //#20748
        $j--; //#20748
        $1.scode = $k[--$j]; //#20748
        $j--; //#20749
        $1.barcode = $k[--$j]; //#20749
        var _g = $s($1.barcode.length + $1.fid.length); //#20752
        $puti(_g, 0, $1.fid); //#20753
        $puti(_g, $1.fid.length, $1.barcode); //#20754
        $1.barcode = _g; //#20755
        $1.barlen = $1.barcode.length; //#20756
        $k[$j++] = Infinity; //#20758
        var _l = $1.barcode; //#20758
        for (var _m = 0, _n = _l.length; _m < _n; _m++) { //#20758
            $k[$j++] = $get(_l, _m); //#20758
        } //#20758
        $1.msg = $a(); //#20758
        $1.msglen = $1.msg.length; //#20759
    } //#20759
    $1.eci = -1; //#20765
    $1.pad = -2; //#20765
    $1.ns = -3; //#20765
    $1.la = -4; //#20766
    $1.lb = -5; //#20766
    $1.sa = -6; //#20767
    $1.sb = -7; //#20767
    $1.sc = -8; //#20767
    $1.sd = -9; //#20767
    $1.se = -10; //#20767
    $1.sa2 = -11; //#20768
    $1.sa3 = -12; //#20768
    $1.lkc = -13; //#20769
    $1.lkd = -14; //#20769
    $1.lke = -15; //#20769
    $1.pd2 = -16; //#20770
    $1.pd3 = -17; //#20770
    $1.charmaps = $a([$a([13, "`", 192, 224, 0]), $a(["A", "a", 193, 225, 1]), $a(["B", "b", 194, 226, 2]), $a(["C", "c", 195, 227, 3]), $a(["D", "d", 196, 228, 4]), $a(["E", "e", 197, 229, 5]), $a(["F", "f", 198, 230, 6]), $a(["G", "g", 199, 231, 7]), $a(["H", "h", 200, 232, 8]), $a(["I", "i", 201, 233, 9]), $a(["J", "j", 202, 234, 10]), $a(["K", "k", 203, 235, 11]), $a(["L", "l", 204, 236, 12]), $a(["M", "m", 205, 237, 13]), $a(["N", "n", 206, 238, 14]), $a(["O", "o", 207, 239, 15]), $a(["P", "p", 208, 240, 16]), $a(["Q", "q", 209, 241, 17]), $a(["R", "r", 210, 242, 18]), $a(["S", "s", 211, 243, 19]), $a(["T", "t", 212, 244, 20]), $a(["U", "u", 213, 245, 21]), $a(["V", "v", 214, 246, 22]), $a(["W", "w", 215, 247, 23]), $a(["X", "x", 216, 248, 24]), $a(["Y", "y", 217, 249, 25]), $a(["Z", "z", 218, 250, 26]), $a([$1.eci, $1.eci, $1.eci, $1.eci, $1.eci]), $a([28, 28, 28, 28, $1.pad]), $a([29, 29, 29, 29, $1.pad]), $a([30, 30, 30, 30, 27]), $a([$1.ns, $1.ns, $1.ns, $1.ns, $1.ns]), $a([" ", "{", 219, 251, 28]), $a([$1.pad, $1.pad, 220, 252, 29]), $a(["\"", "}", 221, 253, 30]), $a(["#", "~", 222, 254, 31]), $a(["$", 127, 223, 255, 159]), $a(["%", ";", 170, 161, 160]), $a(["&", "<", 172, 168, 162]), $a(["'", "=", 177, 171, 163]), $a([40, ">", 178, 175, 164]), $a([41, "?", 179, 176, 165]), $a(["*", "[", 181, 180, 166]), $a(["+", 92, 185, 183, 167]), $a([",", "]", 186, 184, 169]), $a(["-", "^", 188, 187, 173]), $a([".", "_", 189, 191, 174]), $a(["/", " ", 190, 138, 182]), $a(["0", ",", 128, 139, 149]), $a(["1", ".", 129, 140, 150]), $a(["2", "/", 130, 141, 151]), $a(["3", ":", 131, 142, 152]), $a(["4", "@", 132, 143, 153]), $a(["5", "!", 133, 144, 154]), $a(["6", "|", 134, 145, 155]), $a(["7", $1.pd2, 135, 146, 156]), $a(["8", $1.sa2, 136, 147, 157]), $a(["9", $1.sa3, 137, 148, 158]), $a([":", $1.pd3, $1.la, $1.la, $1.la]), $a([$1.sb, $1.sa, " ", " ", " "]), $a([$1.sc, $1.sc, $1.lkc, $1.sc, $1.sc]), $a([$1.sd, $1.sd, $1.sd, $1.lkd, $1.sd]), $a([$1.se, $1.se, $1.se, $1.se, $1.lke]), $a([$1.lb, $1.la, $1.lb, $1.lb, $1.lb])]); //#20839
    $1.charvals = $a([new Map, new Map, new Map, new Map, new Map]); //#20842
    for (var _2e = 0, _2d = $1.charmaps.length - 1; _2e <= _2d; _2e += 1) { //#20851
        $1.i = _2e; //#20844
        $1.encs = $get($1.charmaps, $1.i); //#20845
        for (var _2i = 0; _2i <= 4; _2i += 1) { //#20850
            $1.j = _2i; //#20847
            var _2l = $get($1.encs, $1.j); //#20848
            $k[$j++] = _2l; //#20848
            if ($eq($type(_2l), 'stringtype')) { //#20848
                var _2o = $get($k[--$j], 0); //#20848
                $k[$j++] = _2o; //#20848
            } //#20848
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#20849
        } //#20849
    } //#20849
    $1.seta = $get($1.charvals, 0); //#20852
    $1.setb = $get($1.charvals, 1); //#20853
    $1.setc = $get($1.charvals, 2); //#20854
    $1.setd = $get($1.charvals, 3); //#20855
    $1.sete = $get($1.charvals, 4); //#20856
    $k[$j++] = Infinity; //#20860
    for (var _35 = 0, _36 = $1.msglen + 1; _35 < _36; _35++) { //#20860
        $k[$j++] = 0; //#20860
    } //#20860
    $1.nseq = $a(); //#20860
    for (var _39 = $1.msglen - 1; _39 >= 0; _39 -= 1) { //#20868
        $1.i = _39; //#20862
        var _3C = $get($1.msg, $1.i); //#20863
        if ((_3C >= 48) && (_3C <= 57)) { //#20866
            $put($1.nseq, $1.i, $f($get($1.nseq, $1.i + 1) + 1)); //#20864
        } else { //#20866
            $put($1.nseq, $1.i, 0); //#20866
        } //#20866
    } //#20866
    $1.nseq = $geti($1.nseq, 0, $1.msglen); //#20869
    $1.prefixinset = function() {
        $k[$j++] = 0; //#20876
        for (;;) { //#20876
            var _3N = $k[--$j]; //#20874
            var _3O = $k[--$j]; //#20874
            $k[$j++] = _3O; //#20874
            $k[$j++] = _3N; //#20874
            if (_3N >= _3O.length) { //#20874
                break; //#20874
            } //#20874
            var _3P = $k[--$j]; //#20875
            var _3Q = $k[--$j]; //#20875
            var _3S = $k[--$j]; //#20875
            var _3T = $get(_3S, $get(_3Q, _3P)) !== undefined; //#20875
            $k[$j++] = _3S; //#20875
            $k[$j++] = _3Q; //#20875
            $k[$j++] = _3P; //#20875
            if (_3T) { //#20875
                var _3U = $k[--$j]; //#20875
                $k[$j++] = $f(_3U + 1); //#20875
            } else { //#20875
                break; //#20875
            } //#20875
        } //#20875
        var _3V = $k[--$j]; //#20877
        var _3W = $k[--$j]; //#20877
        $k[$j++] = _3V; //#20877
        $k[$j++] = _3W; //#20877
        $j--; //#20877
        var _3X = $k[--$j]; //#20877
        var _3Y = $k[--$j]; //#20877
        $k[$j++] = _3X; //#20877
        $k[$j++] = _3Y; //#20877
        $j--; //#20877
    }; //#20877
    $1.enc = function() {
        var _3Z = $k[--$j]; //#20881
        $put($1.out, $1.j, $get(_3Z, $k[--$j])); //#20881
        $1.j = $1.j + 1; //#20882
    }; //#20882
    $1.out = $a(144); //#20885
    $1.i = 0; //#20886
    $1.j = 0; //#20886
    $1.cset = "seta"; //#20886
    for (;;) { //#21038
        if ($1.i == $1.msglen) { //#20895
            if ($ne($1.cset, "seta") && $ne($1.cset, "setb")) { //#20893
                $k[$j++] = $1.la; //#20891
                $k[$j++] = $1[$1.cset]; //#20891
                $1.enc(); //#20891
                $1.cset = "seta"; //#20892
            } //#20892
            break; //#20894
        } //#20894
        for (;;) { //#21037
            if ($get($1.msg, $1.i) <= -1000000) { //#20924
                $k[$j++] = $1.eci; //#20899
                $k[$j++] = $1[$1.cset]; //#20899
                $1.enc(); //#20899
                var _3w = $f((-$get($1.msg, $1.i)) - 1000000); //#20901
                $k[$j++] = _3w; //#20919
                if (_3w <= 31) { //#20918
                    var _3x = $k[--$j]; //#20902
                    $k[$j++] = _3x & 63; //#20903
                    $astore($a(1)); //#20903
                } else { //#20918
                    var _3z = $k[--$j]; //#20904
                    $k[$j++] = _3z; //#20919
                    if (_3z <= 1023) { //#20918
                        var _40 = $k[--$j]; //#20905
                        $k[$j++] = ((_40 >>> 6) & 31) | 32; //#20907
                        $k[$j++] = _40 & 63; //#20907
                        $astore($a(2)); //#20907
                    } else { //#20918
                        var _42 = $k[--$j]; //#20908
                        $k[$j++] = _42; //#20919
                        if (_42 <= 32767) { //#20918
                            var _43 = $k[--$j]; //#20909
                            $k[$j++] = ((_43 >>> 12) & 47) | 48; //#20912
                            $k[$j++] = (_43 >>> 6) & 63; //#20912
                            $k[$j++] = _43 & 63; //#20912
                            $astore($a(3)); //#20912
                        } else { //#20918
                            var _45 = $k[--$j]; //#20914
                            $k[$j++] = ((_45 >>> 18) & 55) | 56; //#20918
                            $k[$j++] = (_45 >>> 12) & 63; //#20918
                            $k[$j++] = (_45 >>> 6) & 63; //#20918
                            $k[$j++] = _45 & 63; //#20918
                            $astore($a(4)); //#20918
                        } //#20918
                    } //#20918
                } //#20918
                var _47 = $k[--$j]; //#20920
                $puti($1.out, $1.j, _47); //#20920
                $1.j = _47.length + $1.j; //#20921
                $1.i = $1.i + 1; //#20922
                break; //#20923
            } //#20923
            if ($get($1.nseq, $1.i) >= 9) { //#20935
                var _4H = $geti($1.msg, $1.i, 9); //#20928
                $k[$j++] = 0; //#20928
                for (var _4I = 0, _4J = _4H.length; _4I < _4J; _4I++) { //#20928
                    var _4L = $k[--$j]; //#20928
                    $k[$j++] = ($f(_4L + $f($get(_4H, _4I) - 48))) * 10; //#20928
                } //#20928
                var _4M = $k[--$j]; //#20928
                $k[$j++] = ~~(_4M / 10); //#20929
                for (var _4N = 0, _4O = 4; _4N < _4O; _4N++) { //#20929
                    var _4P = $k[--$j]; //#20929
                    $k[$j++] = _4P & 63; //#20929
                    $k[$j++] = _4P >>> 6; //#20929
                } //#20929
                $k[$j++] = $get($1[$1.cset], $1.ns); //#20930
                for (var _4U = 0; _4U <= 10; _4U += 2) { //#20930
                    var _4V = $k[$j - 1 - _4U]; //#20930
                    $k[$j++] = _4V; //#20930
                } //#20930
                $astore($a(6)); //#20930
                var _4X = $k[--$j]; //#20930
                var _4Y = $k[--$j]; //#20930
                var _4Z = $k[--$j]; //#20930
                var _4a = $k[--$j]; //#20930
                var _4b = $k[--$j]; //#20930
                var _4c = $k[--$j]; //#20930
                var _4d = $k[--$j]; //#20930
                $k[$j++] = _4X; //#20930
                $k[$j++] = _4d; //#20930
                $k[$j++] = _4c; //#20930
                $k[$j++] = _4b; //#20930
                $k[$j++] = _4a; //#20930
                $k[$j++] = _4Z; //#20930
                $k[$j++] = _4Y; //#20930
                for (var _4e = 0, _4f = 6; _4e < _4f; _4e++) { //#20930
                    $j--; //#20930
                } //#20930
                $puti($1.out, $1.j, $k[--$j]); //#20931
                $1.i = $1.i + 9; //#20932
                $1.j = $1.j + 6; //#20933
                break; //#20934
            } //#20934
            $1.char1 = $get($1.msg, $1.i); //#20938
            $k[$j++] = 'char2'; //#20939
            if (($1.i + 1) < $1.msglen) { //#20939
                $k[$j++] = $get($1.msg, $1.i + 1); //#20939
            } else { //#20939
                $k[$j++] = -99; //#20939
            } //#20939
            var _4t = $k[--$j]; //#20939
            $1[$k[--$j]] = _4t; //#20939
            $k[$j++] = 'char3'; //#20940
            if (($1.i + 2) < $1.msglen) { //#20940
                $k[$j++] = $get($1.msg, $1.i + 2); //#20940
            } else { //#20940
                $k[$j++] = -99; //#20940
            } //#20940
            var _50 = $k[--$j]; //#20940
            $1[$k[--$j]] = _50; //#20940
            var _55 = $get($1[$1.cset], $1.char1) !== undefined; //#20943
            if (_55) { //#20947
                $k[$j++] = $1.char1; //#20944
                $k[$j++] = $1[$1.cset]; //#20944
                $1.enc(); //#20944
                $1.i = $1.i + 1; //#20945
                break; //#20946
            } //#20946
            var _5D = $get($1.setb, $1.char1) !== undefined; //#20950
            if ($eq($1.cset, "seta") && _5D) { //#20960
                var _5G = $get($1.setb, $1.char2) !== undefined; //#20951
                if (_5G) { //#20957
                    $k[$j++] = $1.lb; //#20952
                    $k[$j++] = $1.seta; //#20952
                    $1.enc(); //#20952
                    $1.cset = "setb"; //#20953
                } else { //#20957
                    $k[$j++] = $1.sb; //#20955
                    $k[$j++] = $1.seta; //#20955
                    $1.enc(); //#20955
                    $k[$j++] = $1.char1; //#20956
                    $k[$j++] = $1.setb; //#20956
                    $1.enc(); //#20956
                    $1.i = $1.i + 1; //#20957
                } //#20957
                break; //#20959
            } //#20959
            var _5R = $get($1.seta, $1.char1) !== undefined; //#20963
            if ($eq($1.cset, "setb") && _5R) { //#20988
                var _5S = $1.seta; //#20964
                var _5T = $1.msg; //#20964
                var _5U = $1.i; //#20964
                var _5V = $1.msglen; //#20964
                var _5W = $1.i; //#20964
                var _5X = _5V - _5W; //#20964
                var _5Y = 4; //#20964
                if (4 > (_5V - _5W)) { //#20964
                    var _ = _5X; //#20964
                    _5X = _5Y; //#20964
                    _5Y = _; //#20964
                } //#20964
                $k[$j++] = 'p'; //#20964
                $k[$j++] = _5S; //#20964
                $k[$j++] = $geti(_5T, _5U, _5Y); //#20964
                $1.prefixinset(); //#20964
                var _5a = $k[--$j]; //#20964
                $1[$k[--$j]] = _5a; //#20964
                if ($1.p == 1) { //#20969
                    $k[$j++] = $1.sa; //#20966
                    $k[$j++] = $1.setb; //#20966
                    $1.enc(); //#20966
                    $k[$j++] = $1.char1; //#20967
                    $k[$j++] = $1.seta; //#20967
                    $1.enc(); //#20967
                    $1.i = $1.i + 1; //#20968
                } //#20968
                if ($1.p == 2) { //#20975
                    $k[$j++] = $1.sa2; //#20971
                    $k[$j++] = $1.setb; //#20971
                    $1.enc(); //#20971
                    $k[$j++] = $1.char1; //#20972
                    $k[$j++] = $1.seta; //#20972
                    $1.enc(); //#20972
                    $k[$j++] = $1.char2; //#20973
                    $k[$j++] = $1.seta; //#20973
                    $1.enc(); //#20973
                    $1.i = $1.i + 2; //#20974
                } //#20974
                if ($1.p == 3) { //#20982
                    $k[$j++] = $1.sa3; //#20977
                    $k[$j++] = $1.setb; //#20977
                    $1.enc(); //#20977
                    $k[$j++] = $1.char1; //#20978
                    $k[$j++] = $1.seta; //#20978
                    $1.enc(); //#20978
                    $k[$j++] = $1.char2; //#20979
                    $k[$j++] = $1.seta; //#20979
                    $1.enc(); //#20979
                    $k[$j++] = $1.char3; //#20980
                    $k[$j++] = $1.seta; //#20980
                    $1.enc(); //#20980
                    $1.i = $1.i + 3; //#20981
                } //#20981
                if ($1.p >= 4) { //#20986
                    $k[$j++] = $1.la; //#20984
                    $k[$j++] = $1.setb; //#20984
                    $1.enc(); //#20984
                    $1.cset = "seta"; //#20985
                } //#20985
                break; //#20987
            } //#20987
            var _65 = $get($1.seta, $1.char1) !== undefined; //#20991
            if (_65) { //#20995
                $k[$j++] = $1.la; //#20992
                $k[$j++] = $1[$1.cset]; //#20992
                $1.enc(); //#20992
                $1.cset = "seta"; //#20993
                break; //#20994
            } //#20994
            var _6B = $get($1.setb, $1.char1) !== undefined; //#20996
            if (_6B) { //#21000
                $k[$j++] = $1.lb; //#20997
                $k[$j++] = $1[$1.cset]; //#20997
                $1.enc(); //#20997
                $1.cset = "setb"; //#20998
                break; //#20999
            } //#20999
            var _6H = $get($1.setc, $1.char1) !== undefined; //#21003
            if (_6H) { //#21003
                $1.setx = "setc"; //#21003
                $1.sx = $1.sc; //#21003
                $1.lkx = $1.lkc; //#21003
            } //#21003
            var _6M = $get($1.setd, $1.char1) !== undefined; //#21004
            if (_6M) { //#21004
                $1.setx = "setd"; //#21004
                $1.sx = $1.sd; //#21004
                $1.lkx = $1.lkd; //#21004
            } //#21004
            var _6R = $get($1.sete, $1.char1) !== undefined; //#21005
            if (_6R) { //#21005
                $1.setx = "sete"; //#21005
                $1.sx = $1.se; //#21005
                $1.lkx = $1.lke; //#21005
            } //#21005
            var _6V = $1[$1.setx]; //#21008
            var _6W = $1.msg; //#21008
            var _6X = $1.i; //#21008
            var _6Y = $1.msglen; //#21008
            var _6Z = $1.i; //#21008
            var _6a = _6Y - _6Z; //#21008
            var _6b = 4; //#21008
            if (4 > (_6Y - _6Z)) { //#21008
                var _ = _6a; //#21008
                _6a = _6b; //#21008
                _6b = _; //#21008
            } //#21008
            $k[$j++] = 'p'; //#21008
            $k[$j++] = _6V; //#21008
            $k[$j++] = $geti(_6W, _6X, _6b); //#21008
            $1.prefixinset(); //#21008
            var _6d = $k[--$j]; //#21008
            $1[$k[--$j]] = _6d; //#21008
            if ($1.p == 1) { //#21013
                $k[$j++] = $1.sx; //#21010
                $k[$j++] = $1[$1.cset]; //#21010
                $1.enc(); //#21010
                $k[$j++] = $1.char1; //#21011
                $k[$j++] = $1[$1.setx]; //#21011
                $1.enc(); //#21011
                $1.i = $1.i + 1; //#21012
            } //#21012
            if ($1.p == 2) { //#21020
                $k[$j++] = $1.sx; //#21015
                $k[$j++] = $1[$1.cset]; //#21015
                $1.enc(); //#21015
                $k[$j++] = $1.char1; //#21016
                $k[$j++] = $1[$1.setx]; //#21016
                $1.enc(); //#21016
                $k[$j++] = $1.sx; //#21017
                $k[$j++] = $1[$1.cset]; //#21017
                $1.enc(); //#21017
                $k[$j++] = $1.char2; //#21018
                $k[$j++] = $1[$1.setx]; //#21018
                $1.enc(); //#21018
                $1.i = $1.i + 2; //#21019
            } //#21019
            if ($1.p == 3) { //#21029
                $k[$j++] = $1.sx; //#21022
                $k[$j++] = $1[$1.cset]; //#21022
                $1.enc(); //#21022
                $k[$j++] = $1.char1; //#21023
                $k[$j++] = $1[$1.setx]; //#21023
                $1.enc(); //#21023
                $k[$j++] = $1.sx; //#21024
                $k[$j++] = $1[$1.cset]; //#21024
                $1.enc(); //#21024
                $k[$j++] = $1.char2; //#21025
                $k[$j++] = $1[$1.setx]; //#21025
                $1.enc(); //#21025
                $k[$j++] = $1.sx; //#21026
                $k[$j++] = $1[$1.cset]; //#21026
                $1.enc(); //#21026
                $k[$j++] = $1.char3; //#21027
                $k[$j++] = $1[$1.setx]; //#21027
                $1.enc(); //#21027
                $1.i = $1.i + 3; //#21028
            } //#21028
            if ($1.p >= 4) { //#21034
                $k[$j++] = $1.sx; //#21031
                $k[$j++] = $1[$1.cset]; //#21031
                $1.enc(); //#21031
                $k[$j++] = $1.lkx; //#21032
                $k[$j++] = $1[$1.setx]; //#21032
                $1.enc(); //#21032
                $1.cset = $1.setx; //#21033
            } //#21033
            break; //#21036
        } //#21036
    } //#21036
    $1.encmsg = $geti($1.out, 0, $1.j); //#21039
    $1.padval = $get($1[$1.cset], $1.pad); //#21040
    $1.sami = $a([]); //#21043
    if ($1.sam != -1) { //#21048
        $1.sami = $a(2); //#21045
        $put($1.sami, 0, $get($1.seta, $1.pad)); //#21046
        $put($1.sami, 1, (((~~($1.sam / 10)) - 1) * 8) + (($1.sam % 10) - 1)); //#21047
    } //#21047
    $k[$j++] = Infinity; //#21049
    $aload($1.sami); //#21049
    $aload($1.encmsg); //#21049
    $1.encmsg = $a(); //#21049
    if (($1.mode == 2) || ($1.mode == 3)) { //#21104
        var _7q = $strcpy($s(4), "0000"); //#21055
        var _7t = $cvrs($s(4), ~~$1.mode, 2); //#21055
        $puti(_7q, 4 - _7t.length, _7t); //#21055
        $1.mdb = _7q; //#21055
        var _7v = $strcpy($s(10), "0000000000"); //#21056
        var _7y = $cvrs($s(10), $cvi($1.ccode), 2); //#21056
        $puti(_7v, 10 - _7y.length, _7y); //#21056
        $1.ccb = _7v; //#21056
        var _80 = $strcpy($s(10), "0000000000"); //#21057
        var _83 = $cvrs($s(10), $cvi($1.scode), 2); //#21057
        $puti(_80, 10 - _83.length, _83); //#21057
        $1.scb = _80; //#21057
        $1.pcb = $strcpy($s(36), "000000000000000000000000000000000000"); //#21058
        if ($1.mode == 2) { //#21071
            var _8A = $cvrs($s(6), $1.pcode.length, 2); //#21061
            $puti($1.pcb, 6 - _8A.length, _8A); //#21061
            var _8E = $cvrs($s(30), $cvi($1.pcode), 2); //#21062
            $puti($1.pcb, 36 - _8E.length, _8E); //#21062
        } else { //#21071
            $k[$j++] = Infinity; //#21067
            var _8G = $strcpy($s(6), "      "); //#21066
            $k[$j++] = _8G; //#21066
            $k[$j++] = _8G; //#21066
            $k[$j++] = 0; //#21066
            if ($1.pcode.length > 6) { //#21066
                $k[$j++] = $geti($1.pcode, 0, 6); //#21066
            } else { //#21066
                $k[$j++] = $1.pcode; //#21066
            } //#21066
            var _8L = $k[--$j]; //#21066
            var _8M = $k[--$j]; //#21066
            $puti($k[--$j], _8M, _8L); //#21066
            $forall($k[--$j], function() { //#21067
                var _8R = $get($1.seta, $k[--$j]); //#21067
                $k[$j++] = _8R; //#21067
            }); //#21067
            $1.pccw = $a(); //#21067
            for (var _8T = 0; _8T <= 5; _8T += 1) { //#21072
                $1.i = _8T; //#21070
                var _8Z = $cvrs($s(6), $get($1.pccw, $1.i), 2); //#21071
                $puti($1.pcb, ((6 * $1.i) + 6) - _8Z.length, _8Z); //#21071
            } //#21071
        } //#21071
        $1.scm = $s(60); //#21076
        $puti($1.scm, 2, $1.mdb); //#21077
        $puti($1.scm, 38, $geti($1.pcb, 0, 4)); //#21078
        $puti($1.scm, 30, $geti($1.pcb, 4, 6)); //#21079
        $puti($1.scm, 24, $geti($1.pcb, 10, 6)); //#21080
        $puti($1.scm, 18, $geti($1.pcb, 16, 6)); //#21081
        $puti($1.scm, 12, $geti($1.pcb, 22, 6)); //#21082
        $puti($1.scm, 6, $geti($1.pcb, 28, 6)); //#21083
        $puti($1.scm, 0, $geti($1.pcb, 34, 2)); //#21084
        $puti($1.scm, 52, $geti($1.ccb, 0, 2)); //#21085
        $puti($1.scm, 42, $geti($1.ccb, 2, 6)); //#21086
        $puti($1.scm, 36, $geti($1.ccb, 8, 2)); //#21087
        $puti($1.scm, 54, $geti($1.scb, 0, 6)); //#21088
        $puti($1.scm, 48, $geti($1.scb, 6, 4)); //#21089
        $1.pri = $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0]); //#21092
        for (var _9F = 0; _9F <= 59; _9F += 1) { //#21098
            $1.i = _9F; //#21094
            $1.ps = ~~($1.i / 6); //#21095
            $1.ep = (~~(Math.pow(2, 5 - ($1.i % 6)))) * ($get($1.scm, $1.i) - 48); //#21096
            $put($1.pri, $1.ps, $f($get($1.pri, $1.ps) + $1.ep)); //#21097
        } //#21097
        $k[$j++] = Infinity; //#21101
        for (var _9R = 0, _9S = 84; _9R < _9S; _9R++) { //#21101
            $k[$j++] = $1.padval; //#21101
        } //#21101
        $1.sec = $a(); //#21101
        $puti($1.sec, 0, $1.encmsg); //#21102
    } //#21102
    if (((($1.mode == 4) || ($1.mode == 5)) || ($1.mode == 6)) || ($1.mode == -1)) { //#21123
        if ($1.mode == -1) { //#21112
            var _9d = ($1.encmsg.length <= 77) ? 5 : 4; //#21111
            $1.mode = _9d; //#21111
        } //#21111
        $k[$j++] = Infinity; //#21115
        var _9f = ($1.mode == 5) ? 78 : 94; //#21115
        for (var _9g = 0, _9h = _9f; _9g < _9h; _9g++) { //#21115
            $k[$j++] = $1.padval; //#21115
        } //#21115
        $1.cws = $a(); //#21115
        $put($1.cws, 0, $1.mode); //#21116
        $puti($1.cws, 1, $1.encmsg); //#21117
        $1.pri = $geti($1.cws, 0, 10); //#21120
        $1.sec = $geti($1.cws, 10, $1.cws.length - 10); //#21121
    } //#21121
    $k[$j++] = Infinity; //#21126
    $k[$j++] = 1; //#21126
    for (var _9t = 0, _9u = 63; _9t < _9u; _9t++) { //#21126
        var _9v = $k[--$j]; //#21126
        var _9w = _9v * 2; //#21126
        $k[$j++] = _9v; //#21126
        $k[$j++] = _9w; //#21126
        if (_9w >= 64) { //#21126
            var _9x = $k[--$j]; //#21126
            $k[$j++] = _9x ^ 67; //#21126
        } //#21126
    } //#21126
    $1.rsalog = $a(); //#21126
    $1.rslog = $a(64); //#21127
    for (var _A0 = 1; _A0 <= 63; _A0 += 1) { //#21128
        $put($1.rslog, $get($1.rsalog, _A0), _A0); //#21128
    } //#21128
    $1.rsprod = function() {
        var _A4 = $k[--$j]; //#21132
        var _A5 = $k[--$j]; //#21132
        $k[$j++] = _A5; //#21136
        $k[$j++] = _A4; //#21136
        if ((_A4 != 0) && (_A5 != 0)) { //#21135
            var _A8 = $get($1.rslog, $k[--$j]); //#21133
            var _AD = $get($1.rsalog, $f(_A8 + $get($1.rslog, $k[--$j])) % 63); //#21133
            $k[$j++] = _AD; //#21133
        } else { //#21135
            $j -= 2; //#21135
            $k[$j++] = 0; //#21135
        } //#21135
    }; //#21135
    $1.rscodes = function() {
        $1.rsnum = $k[--$j]; //#21142
        $1.cwb = $k[--$j]; //#21143
        $k[$j++] = Infinity; //#21146
        $k[$j++] = 1; //#21146
        for (var _AH = 0, _AI = $1.rsnum; _AH < _AI; _AH++) { //#21146
            $k[$j++] = 0; //#21146
        } //#21146
        $1.coeffs = $a(); //#21146
        for (var _AM = 1, _AL = $1.rsnum; _AM <= _AL; _AM += 1) { //#21155
            $1.i = _AM; //#21148
            $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#21149
            for (var _AT = $1.i - 1; _AT >= 1; _AT -= 1) { //#21153
                $1.j = _AT; //#21151
                $k[$j++] = $1.coeffs; //#21152
                $k[$j++] = $1.j; //#21152
                $k[$j++] = $get($1.coeffs, $1.j - 1); //#21152
                $k[$j++] = $get($1.coeffs, $1.j); //#21152
                $k[$j++] = $get($1.rsalog, $1.i); //#21152
                $1.rsprod(); //#21152
                var _Af = $k[--$j]; //#21152
                var _Ag = $k[--$j]; //#21152
                var _Ah = $k[--$j]; //#21152
                $put($k[--$j], _Ah, $xo(_Ag, _Af)); //#21152
            } //#21152
            $k[$j++] = $1.coeffs; //#21154
            $k[$j++] = 0; //#21154
            $k[$j++] = $get($1.coeffs, 0); //#21154
            $k[$j++] = $get($1.rsalog, $1.i); //#21154
            $1.rsprod(); //#21154
            var _Ap = $k[--$j]; //#21154
            var _Aq = $k[--$j]; //#21154
            $put($k[--$j], _Aq, _Ap); //#21154
        } //#21154
        $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#21156
        $k[$j++] = Infinity; //#21159
        for (var _Aw = 0, _Ax = $1.rsnum; _Aw < _Ax; _Aw++) { //#21159
            $k[$j++] = 0; //#21159
        } //#21159
        $1.ecb = $a(); //#21159
        for (var _B1 = 0, _B0 = $1.cwb.length - 1; _B1 <= _B0; _B1 += 1) { //#21168
            $1.t = $xo($get($1.cwb, _B1), $get($1.ecb, 0)); //#21161
            for (var _B7 = $1.ecb.length - 1; _B7 >= 0; _B7 -= 1) { //#21167
                $1.i = _B7; //#21163
                $1.p = ($1.ecb.length - $1.i) - 1; //#21164
                $k[$j++] = $1.ecb; //#21165
                $k[$j++] = $1.p; //#21165
                $k[$j++] = $1.t; //#21165
                $k[$j++] = $get($1.coeffs, $1.i); //#21165
                $1.rsprod(); //#21165
                var _BG = $k[--$j]; //#21165
                var _BH = $k[--$j]; //#21165
                $put($k[--$j], _BH, _BG); //#21165
                if ($1.i > 0) { //#21166
                    $put($1.ecb, $1.p, $xo($get($1.ecb, $1.p + 1), $get($1.ecb, $1.p))); //#21166
                } //#21166
            } //#21166
        } //#21166
        $k[$j++] = $1.ecb; //#21170
    }; //#21170
    $k[$j++] = Infinity; //#21175
    for (var _BV = 0, _BU = $1.sec.length - 1; _BV <= _BU; _BV += 2) { //#21175
        $k[$j++] = $get($1.sec, _BV); //#21175
    } //#21175
    $1.seco = $a(); //#21175
    $k[$j++] = Infinity; //#21176
    for (var _Bb = 1, _Ba = $1.sec.length - 1; _Bb <= _Ba; _Bb += 2) { //#21176
        $k[$j++] = $get($1.sec, _Bb); //#21176
    } //#21176
    $1.sece = $a(); //#21176
    var _Bg = ($1.sec.length == 84) ? 20 : 28; //#21179
    $1.scodes = _Bg; //#21179
    $k[$j++] = 'secochk'; //#21180
    $k[$j++] = $1.seco; //#21180
    $k[$j++] = $1.scodes; //#21180
    $1.rscodes(); //#21180
    var _Bj = $k[--$j]; //#21180
    $1[$k[--$j]] = _Bj; //#21180
    $k[$j++] = 'secechk'; //#21181
    $k[$j++] = $1.sece; //#21181
    $k[$j++] = $1.scodes; //#21181
    $1.rscodes(); //#21181
    var _Bn = $k[--$j]; //#21181
    $1[$k[--$j]] = _Bn; //#21181
    $k[$j++] = Infinity; //#21184
    for (var _Br = 0, _Bq = $1.scodes - 1; _Br <= _Bq; _Br += 1) { //#21184
        $k[$j++] = $get($1.secochk, _Br); //#21184
        $k[$j++] = $get($1.secechk, _Br); //#21184
    } //#21184
    $1.secchk = $a(); //#21184
    $k[$j++] = Infinity; //#21191
    $aload($1.pri); //#21188
    $k[$j++] = $1.pri; //#21189
    $k[$j++] = 10; //#21189
    $1.rscodes(); //#21189
    $aload($k[--$j]); //#21189
    $aload($1.sec); //#21190
    $aload($1.secchk); //#21191
    $1.codewords = $a(); //#21191
    $k[$j++] = Infinity; //#21195
    for (var _C3 = 0, _C4 = 864; _C3 < _C4; _C3++) { //#21195
        $k[$j++] = 0; //#21195
    } //#21195
    $1.mods = $a(); //#21195
    for (var _C6 = 0; _C6 <= 143; _C6 += 1) { //#21200
        $1.i = _C6; //#21197
        $k[$j++] = Infinity; //#21198
        var _CB = $cvrs($s(6), $get($1.codewords, $1.i), 2); //#21198
        for (var _CC = 0, _CD = _CB.length; _CC < _CD; _CC++) { //#21198
            $k[$j++] = $get(_CB, _CC) - 48; //#21198
        } //#21198
        $1.cw = $a(); //#21198
        $puti($1.mods, (6 * $1.i) + (6 - $1.cw.length), $1.cw); //#21199
    } //#21199
    $1.modmap = $a([469, 529, 286, 316, 347, 346, 673, 672, 703, 702, 647, 676, 283, 282, 313, 312, 370, 610, 618, 379, 378, 409, 408, 439, 705, 704, 559, 589, 588, 619, 458, 518, 640, 701, 675, 674, 285, 284, 315, 314, 310, 340, 531, 289, 288, 319, 349, 348, 456, 486, 517, 516, 471, 470, 369, 368, 399, 398, 429, 428, 549, 548, 579, 578, 609, 608, 649, 648, 679, 678, 709, 708, 639, 638, 669, 668, 699, 698, 279, 278, 309, 308, 339, 338, 381, 380, 411, 410, 441, 440, 561, 560, 591, 590, 621, 620, 547, 546, 577, 576, 607, 606, 367, 366, 397, 396, 427, 426, 291, 290, 321, 320, 351, 350, 651, 650, 681, 680, 711, 710, 1, 0, 31, 30, 61, 60, 3, 2, 33, 32, 63, 62, 5, 4, 35, 34, 65, 64, 7, 6, 37, 36, 67, 66, 9, 8, 39, 38, 69, 68, 11, 10, 41, 40, 71, 70, 13, 12, 43, 42, 73, 72, 15, 14, 45, 44, 75, 74, 17, 16, 47, 46, 77, 76, 19, 18, 49, 48, 79, 78, 21, 20, 51, 50, 81, 80, 23, 22, 53, 52, 83, 82, 25, 24, 55, 54, 85, 84, 27, 26, 57, 56, 87, 86, 117, 116, 147, 146, 177, 176, 115, 114, 145, 144, 175, 174, 113, 112, 143, 142, 173, 172, 111, 110, 141, 140, 171, 170, 109, 108, 139, 138, 169, 168, 107, 106, 137, 136, 167, 166, 105, 104, 135, 134, 165, 164, 103, 102, 133, 132, 163, 162, 101, 100, 131, 130, 161, 160, 99, 98, 129, 128, 159, 158, 97, 96, 127, 126, 157, 156, 95, 94, 125, 124, 155, 154, 93, 92, 123, 122, 153, 152, 91, 90, 121, 120, 151, 150, 181, 180, 211, 210, 241, 240, 183, 182, 213, 212, 243, 242, 185, 184, 215, 214, 245, 244, 187, 186, 217, 216, 247, 246, 189, 188, 219, 218, 249, 248, 191, 190, 221, 220, 251, 250, 193, 192, 223, 222, 253, 252, 195, 194, 225, 224, 255, 254, 197, 196, 227, 226, 257, 256, 199, 198, 229, 228, 259, 258, 201, 200, 231, 230, 261, 260, 203, 202, 233, 232, 263, 262, 205, 204, 235, 234, 265, 264, 207, 206, 237, 236, 267, 266, 297, 296, 327, 326, 357, 356, 295, 294, 325, 324, 355, 354, 293, 292, 323, 322, 353, 352, 277, 276, 307, 306, 337, 336, 275, 274, 305, 304, 335, 334, 273, 272, 303, 302, 333, 332, 271, 270, 301, 300, 331, 330, 361, 360, 391, 390, 421, 420, 363, 362, 393, 392, 423, 422, 365, 364, 395, 394, 425, 424, 383, 382, 413, 412, 443, 442, 385, 384, 415, 414, 445, 444, 387, 386, 417, 416, 447, 446, 477, 476, 507, 506, 537, 536, 475, 474, 505, 504, 535, 534, 473, 472, 503, 502, 533, 532, 455, 454, 485, 484, 515, 514, 453, 452, 483, 482, 513, 512, 451, 450, 481, 480, 511, 510, 541, 540, 571, 570, 601, 600, 543, 542, 573, 572, 603, 602, 545, 544, 575, 574, 605, 604, 563, 562, 593, 592, 623, 622, 565, 564, 595, 594, 625, 624, 567, 566, 597, 596, 627, 626, 657, 656, 687, 686, 717, 716, 655, 654, 685, 684, 715, 714, 653, 652, 683, 682, 713, 712, 637, 636, 667, 666, 697, 696, 635, 634, 665, 664, 695, 694, 633, 632, 663, 662, 693, 692, 631, 630, 661, 660, 691, 690, 721, 720, 751, 750, 781, 780, 723, 722, 753, 752, 783, 782, 725, 724, 755, 754, 785, 784, 727, 726, 757, 756, 787, 786, 729, 728, 759, 758, 789, 788, 731, 730, 761, 760, 791, 790, 733, 732, 763, 762, 793, 792, 735, 734, 765, 764, 795, 794, 737, 736, 767, 766, 797, 796, 739, 738, 769, 768, 799, 798, 741, 740, 771, 770, 801, 800, 743, 742, 773, 772, 803, 802, 745, 744, 775, 774, 805, 804, 747, 746, 777, 776, 807, 806, 837, 836, 867, 866, 897, 896, 835, 834, 865, 864, 895, 894, 833, 832, 863, 862, 893, 892, 831, 830, 861, 860, 891, 890, 829, 828, 859, 858, 889, 888, 827, 826, 857, 856, 887, 886, 825, 824, 855, 854, 885, 884, 823, 822, 853, 852, 883, 882, 821, 820, 851, 850, 881, 880, 819, 818, 849, 848, 879, 878, 817, 816, 847, 846, 877, 876, 815, 814, 845, 844, 875, 874, 813, 812, 843, 842, 873, 872, 811, 810, 841, 840, 871, 870, 901, 900, 931, 930, 961, 960, 903, 902, 933, 932, 963, 962, 905, 904, 935, 934, 965, 964, 907, 906, 937, 936, 967, 966, 909, 908, 939, 938, 969, 968, 911, 910, 941, 940, 971, 970, 913, 912, 943, 942, 973, 972, 915, 914, 945, 944, 975, 974, 917, 916, 947, 946, 977, 976, 919, 918, 949, 948, 979, 978, 921, 920, 951, 950, 981, 980, 923, 922, 953, 952, 983, 982, 925, 924, 955, 954, 985, 984, 927, 926, 957, 956, 987, 986, 58, 89, 88, 118, 149, 148, 178, 209, 208, 238, 269, 268, 298, 329, 328, 358, 389, 388, 418, 449, 448, 478, 509, 508, 538, 569, 568, 598, 629, 628, 658, 689, 688, 718, 749, 748, 778, 809, 808, 838, 869, 868, 898, 929, 928, 958, 989, 988]); //#21249
    $1.pixs = $a(864); //#21253
    $1.j = 0; //#21254
    for (var _CO = 0, _CN = $1.mods.length - 1; _CO <= _CN; _CO += 1) { //#21261
        $1.i = _CO; //#21256
        if ($get($1.mods, $1.i) == 1) { //#21260
            $put($1.pixs, $1.j, $get($1.modmap, $1.i)); //#21258
            $1.j = $1.j + 1; //#21259
        } //#21259
    } //#21259
    $k[$j++] = Infinity; //#21262
    var _Ca = $geti($1.pixs, 0, $1.j); //#21262
    for (var _Cb = 0, _Cc = _Ca.length; _Cb < _Cc; _Cb++) { //#21262
        $k[$j++] = $get(_Ca, _Cb); //#21262
    } //#21262
    $k[$j++] = 28; //#21262
    $k[$j++] = 29; //#21262
    $k[$j++] = 280; //#21262
    $k[$j++] = 281; //#21262
    $k[$j++] = 311; //#21262
    $k[$j++] = 457; //#21262
    $k[$j++] = 488; //#21262
    $k[$j++] = 500; //#21262
    $k[$j++] = 530; //#21262
    $k[$j++] = 670; //#21262
    $k[$j++] = 700; //#21262
    $k[$j++] = 677; //#21262
    $k[$j++] = 707; //#21262
    $1.pixs = $a(); //#21262
    var _Ch = new Map([
        ["ren", bwipp_renmaximatrix],
        ["pixs", $1.pixs],
        ["opt", $1.options]
    ]); //#21268
    $k[$j++] = _Ch; //#21271
    if (!$1.dontdraw) { //#21271
        bwipp_renmaximatrix(); //#21271
    } //#21271
}

function bwipp_azteccode() {
    var $1 = {}; //#21306
    $1.ctx = null; //#21308
    $1.dontdraw = false; //#21309
    $1.format = "unset"; //#21310
    $1.readerinit = false; //#21311
    $1.layers = -1; //#21312
    $1.eclevel = 23; //#21313
    $1.ecaddchars = 3; //#21314
    $1.raw = false; //#21315
    $1.parse = false; //#21316
    $1.parsefnc = false; //#21317
    $k[$j++] = $1; //#21319
    bwipp_processoptions(); //#21319
    $1.options = $k[--$j]; //#21319
    $1.barcode = $k[--$j]; //#21320
    if ($eq($1.format, "rune")) { //#21336
        if ($1.barcode.length == 0) { //#21327
            $k[$j++] = 'bwipp.aztecRuneNotNumeric'; //#21326
            $k[$j++] = "Aztec runes must be numeric"; //#21326
            bwipp_raiseerror(); //#21326
        } //#21326
        $forall($1.barcode, function() { //#21332
            var _5 = $k[--$j]; //#21329
            if ((_5 < 48) || (_5 > 57)) { //#21331
                $k[$j++] = 'bwipp.aztecRuneNotNumeric'; //#21330
                $k[$j++] = "Aztec runes must be numeric"; //#21330
                bwipp_raiseerror(); //#21330
            } //#21330
        }); //#21330
        var _7 = $cvi($1.barcode); //#21333
        if ((_7 < 0) || (_7 > 255)) { //#21335
            $k[$j++] = 'bwipp.aztecRuneInvalid'; //#21334
            $k[$j++] = "Aztec runes must be 0 to 255"; //#21334
            bwipp_raiseerror(); //#21334
        } //#21334
    } //#21334
    $1.fn1 = -1; //#21339
    var _B = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["eci", true],
        ["FNC1", $1.fn1]
    ]); //#21344
    $1.fncvals = _B; //#21345
    $k[$j++] = 'msg'; //#21346
    $k[$j++] = $1.barcode; //#21346
    $k[$j++] = $1.fncvals; //#21346
    bwipp_parseinput(); //#21346
    var _E = $k[--$j]; //#21346
    $1[$k[--$j]] = _E; //#21346
    $1.msglen = $1.msg.length; //#21347
    $1.U = 0; //#21351
    $1.L = 1; //#21351
    $1.M = 2; //#21351
    $1.P = 3; //#21351
    $1.D = 4; //#21351
    $1.B = 5; //#21351
    $1.lu = -2; //#21354
    $1.ll = -3; //#21354
    $1.lm = -4; //#21354
    $1.lp = -5; //#21355
    $1.ld = -6; //#21355
    $1.su = -7; //#21355
    $1.sp = -8; //#21356
    $1.sb = -9; //#21356
    $1.fl = -10; //#21356
    $1.p2 = -11; //#21357
    $1.p3 = -12; //#21357
    $1.p4 = -13; //#21357
    $1.p5 = -14; //#21357
    $1.charmaps = $a([$a([$1.sp, $1.sp, $1.sp, $1.fl, $1.sp]), $a([32, 32, 32, 13, 32]), $a(["A", "a", 1, $1.p2, "0"]), $a(["B", "b", 2, $1.p3, "1"]), $a(["C", "c", 3, $1.p4, "2"]), $a(["D", "d", 4, $1.p5, "3"]), $a(["E", "e", 5, "!", "4"]), $a(["F", "f", 6, "\"", "5"]), $a(["G", "g", 7, "#", "6"]), $a(["H", "h", 8, "$", "7"]), $a(["I", "i", 9, "%", "8"]), $a(["J", "j", 10, "&", "9"]), $a(["K", "k", 11, "'", ","]), $a(["L", "l", 12, 40, "."]), $a(["M", "m", 13, 41, $1.lu]), $a(["N", "n", 27, "*", $1.su]), $a(["O", "o", 28, "+", -99]), $a(["P", "p", 29, ",", -99]), $a(["Q", "q", 30, "-", -99]), $a(["R", "r", 31, ".", -99]), $a(["S", "s", "@", "/", -99]), $a(["T", "t", 92, ":", -99]), $a(["U", "u", "^", ";", -99]), $a(["V", "v", "_", "<", -99]), $a(["W", "w", "`", "=", -99]), $a(["X", "x", "|", ">", -99]), $a(["Y", "y", "~", "?", -99]), $a(["Z", "z", 127, "[", -99]), $a([$1.ll, $1.su, $1.ll, "]", -99]), $a([$1.lm, $1.lm, $1.lu, "{", -99]), $a([$1.ld, $1.ld, $1.lp, "}", -99]), $a([$1.sb, $1.sb, $1.sb, $1.lu, -99])]); //#21394
    $1.charvals = $a([new Map, new Map, new Map, new Map, new Map]); //#21397
    for (var _1F = 0, _1E = $1.charmaps.length - 1; _1F <= _1E; _1F += 1) { //#21406
        $1.i = _1F; //#21399
        $1.encs = $get($1.charmaps, $1.i); //#21400
        for (var _1J = 0; _1J <= 4; _1J += 1) { //#21405
            $1.j = _1J; //#21402
            var _1M = $get($1.encs, $1.j); //#21403
            $k[$j++] = _1M; //#21403
            if ($eq($type(_1M), 'stringtype')) { //#21403
                var _1P = $get($k[--$j], 0); //#21403
                $k[$j++] = _1P; //#21403
            } //#21403
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#21404
        } //#21404
    } //#21404
    var _1Z = new Map([
        ["\x0d\x0a", $1.p2],
        [". ", $1.p3],
        [", ", $1.p4],
        [": ", $1.p5]
    ]); //#21413
    $1.pcomp = _1Z; //#21414
    $1.e = 10000; //#21416
    $1.latlen = $a([$a([0, 5, 5, 10, 5, 10]), $a([9, 0, 5, 10, 5, 10]), $a([5, 5, 0, 5, 10, 10]), $a([5, 10, 10, 0, 10, 15]), $a([4, 9, 9, 14, 0, 14]), $a([0, 0, 0, 0, 0, 0])]); //#21426
    $1.latseq = $a([$a([$a([]), $a([$1.ll]), $a([$1.lm]), $a([$1.lm, $1.lp]), $a([$1.ld]), $a([$1.sb])]), $a([$a([$1.ld, $1.lu]), $a([]), $a([$1.lm]), $a([$1.lm, $1.lp]), $a([$1.ld]), $a([$1.sb])]), $a([$a([$1.lu]), $a([$1.ll]), $a([]), $a([$1.lp]), $a([$1.lu, $1.ld]), $a([$1.sb])]), $a([$a([$1.lu]), $a([$1.lu, $1.ll]), $a([$1.lu, $1.lm]), $a([]), $a([$1.lu, $1.ld]), $a([$1.lu, $1.sb])]), $a([$a([$1.lu]), $a([$1.lu, $1.ll]), $a([$1.lu, $1.lm]), $a([$1.lu, $1.lm, $1.lp]), $a([]), $a([$1.lu, $1.sb])]), $a([$a([$1.lu]), $a([$1.ll]), $a([$1.lm]), $a([]), $a([]), $a([])])]); //#21436
    $1.shftlen = $a([$a([$1.e, $1.e, $1.e, 5, $1.e]), $a([5, $1.e, $1.e, 5, $1.e]), $a([$1.e, $1.e, $1.e, 5, $1.e]), $a([$1.e, $1.e, $1.e, $1.e, $1.e]), $a([4, $1.e, $1.e, 4, $1.e])]); //#21445
    $1.msgbits = ""; //#21450
    if ($ne($1.format, "rune") && $1.raw) { //#21451
        $1.msgbits = $1.barcode; //#21451
    } //#21451
    if ($ne($1.format, "rune") && (!$1.raw)) { //#21742
        $1.charsize = function() {
            var _3X = $k[--$j]; //#21455
            $k[$j++] = _3X; //#21466
            if (_3X >= 0) { //#21464
                $j--; //#21457
                var _3a = $get($a([5, 5, 5, 5, 4, 8]), $k[--$j]); //#21457
                $k[$j++] = _3a; //#21457
            } else { //#21464
                var _3b = $k[--$j]; //#21459
                var _3c = $k[--$j]; //#21459
                $k[$j++] = _3b; //#21459
                $k[$j++] = _3c; //#21459
                $j--; //#21459
                var _3d = $k[--$j]; //#21460
                $k[$j++] = _3d; //#21465
                if (_3d == $1.fn1) { //#21464
                    $j--; //#21461
                    $k[$j++] = 8; //#21461
                } else { //#21464
                    var _3g = $f((-$k[--$j]) - 1000000); //#21463
                    $k[$j++] = _3g; //#21463
                    if (_3g == 0) { //#21463
                        $j--; //#21463
                        $k[$j++] = 1; //#21463
                    } //#21463
                    var _3h = $k[--$j]; //#21464
                    $k[$j++] = (((~~(Math.log(_3h) / Math.log(10))) + 1) * 4) + 8; //#21464
                } //#21464
            } //#21464
        }; //#21464
        $1.curlen = $a([0, $1.e, $1.e, $1.e, $1.e, $1.e]); //#21470
        $1.curseq = $a([$a([]), $a([]), $a([]), $a([]), $a([]), $a([])]); //#21471
        $1.backto = $1.U; //#21473
        $1.lastchar = ""; //#21474
        $forall($1.msg, function() { //#21626
            $1.char = $k[--$j]; //#21479
            for (;;) { //#21505
                $1.imp = false; //#21483
                var _44 = $a([$1.U, $1.L, $1.M, $1.P, $1.D, $1.B]); //#21484
                for (var _45 = 0, _46 = _44.length; _45 < _46; _45++) { //#21503
                    $1.x = $get(_44, _45); //#21485
                    var _4E = $a([$1.U, $1.L, $1.M, $1.P, $1.D, $1.B]); //#21486
                    for (var _4F = 0, _4G = _4E.length; _4F < _4G; _4F++) { //#21502
                        $1.y = $get(_4E, _4F); //#21487
                        if (($1.x != $1.B) || ($1.y == $1.backto)) { //#21501
                            $1.cost = $f($get($1.curlen, $1.x) + $get($get($1.latlen, $1.x), $1.y)); //#21489
                            if ($1.cost < $get($1.curlen, $1.y)) { //#21500
                                $put($1.curlen, $1.y, $1.cost); //#21491
                                $k[$j++] = $1.curseq; //#21494
                                $k[$j++] = $1.y; //#21494
                                $k[$j++] = Infinity; //#21494
                                $aload($get($1.curseq, $1.x)); //#21493
                                $aload($get($get($1.latseq, $1.x), $1.y)); //#21494
                                var _4l = $a(); //#21494
                                var _4m = $k[--$j]; //#21495
                                $put($k[--$j], _4m, _4l); //#21495
                                if ($1.y == $1.B) { //#21498
                                    $k[$j++] = 'backto'; //#21497
                                    if (($1.x == $1.P) || ($1.x == $1.D)) { //#21497
                                        $k[$j++] = $1.U; //#21497
                                    } else { //#21497
                                        $k[$j++] = $1.x; //#21497
                                    } //#21497
                                    var _4w = $k[--$j]; //#21497
                                    $1[$k[--$j]] = _4w; //#21497
                                } //#21497
                                $1.imp = true; //#21499
                            } //#21499
                        } //#21499
                    } //#21499
                } //#21499
                if (!$1.imp) { //#21504
                    break; //#21504
                } //#21504
            } //#21504
            $1.nxtlen = $a([$1.e, $1.e, $1.e, $1.e, $1.e, $1.e]); //#21508
            $1.nxtseq = $a(6); //#21509
            var _5D = $a([$1.U, $1.L, $1.M, $1.P, $1.D, $1.B]); //#21511
            for (var _5E = 0, _5F = _5D.length; _5E < _5F; _5E++) { //#21550
                $1.x = $get(_5D, _5E); //#21512
                for (;;) { //#21548
                    if ($1.char >= 0) { //#21520
                        if ($1.x != $1.B) { //#21518
                            var _5O = $get($get($1.charvals, $1.x), $1.char) !== undefined; //#21518
                            if (!_5O) { //#21518
                                break; //#21518
                            } //#21518
                        } //#21518
                    } else { //#21520
                        if ($1.x != $1.P) { //#21520
                            break; //#21520
                        } //#21520
                    } //#21520
                    $k[$j++] = 'cost'; //#21524
                    $k[$j++] = $get($1.curlen, $1.x); //#21524
                    $k[$j++] = $1.x; //#21524
                    $k[$j++] = $1.char; //#21524
                    $1.charsize(); //#21524
                    var _5W = $k[--$j]; //#21524
                    var _5X = $k[--$j]; //#21524
                    $1[$k[--$j]] = $f(_5X + _5W); //#21524
                    if ($1.cost < $get($1.nxtlen, $1.x)) { //#21528
                        $put($1.nxtlen, $1.x, $1.cost); //#21526
                        $k[$j++] = $1.nxtseq; //#21527
                        $k[$j++] = $1.x; //#21527
                        $k[$j++] = Infinity; //#21527
                        $aload($get($1.curseq, $1.x)); //#21527
                        $k[$j++] = $1.char; //#21527
                        var _5m = $a(); //#21527
                        var _5n = $k[--$j]; //#21527
                        $put($k[--$j], _5n, _5m); //#21527
                    } //#21527
                    if ($1.x == $1.B) { //#21531
                        break; //#21531
                    } //#21531
                    var _5w = $a([$1.U, $1.L, $1.M, $1.P, $1.D]); //#21532
                    for (var _5x = 0, _5y = _5w.length; _5x < _5y; _5x++) { //#21545
                        $1.y = $get(_5w, _5x); //#21533
                        if ($ne($1.x, $1.y)) { //#21544
                            $k[$j++] = 'cost'; //#21535
                            $k[$j++] = $f($get($1.curlen, $1.y) + $get($get($1.shftlen, $1.y), $1.x)); //#21535
                            $k[$j++] = $1.x; //#21535
                            $k[$j++] = $1.char; //#21535
                            $1.charsize(); //#21535
                            var _6C = $k[--$j]; //#21535
                            var _6D = $k[--$j]; //#21535
                            $1[$k[--$j]] = $f(_6D + _6C); //#21535
                            if ($1.cost < $get($1.nxtlen, $1.y)) { //#21543
                                $put($1.nxtlen, $1.y, $1.cost); //#21537
                                $k[$j++] = $1.nxtseq; //#21541
                                $k[$j++] = $1.y; //#21541
                                $k[$j++] = Infinity; //#21541
                                $aload($get($1.curseq, $1.y)); //#21539
                                var _6T = ($1.x == $1.U) ? $1.su : $1.sp; //#21540
                                $k[$j++] = _6T; //#21541
                                $k[$j++] = $1.char; //#21541
                                var _6V = $a(); //#21541
                                var _6W = $k[--$j]; //#21542
                                $put($k[--$j], _6W, _6V); //#21542
                            } //#21542
                        } //#21542
                    } //#21542
                    break; //#21547
                } //#21547
            } //#21547
            if ($ne($1.lastchar, "") && ($1.char >= 0)) { //#21611
                var _6a = $s(2); //#21554
                $put(_6a, 0, $1.lastchar); //#21554
                $put(_6a, 1, $1.char); //#21554
                $1.pchars = _6a; //#21554
                var _6f = $get($1.pcomp, $1.pchars) !== undefined; //#21555
                if (_6f) { //#21610
                    var _6l = $a([$1.U, $1.L, $1.M, $1.P, $1.D]); //#21556
                    for (var _6m = 0, _6n = _6l.length; _6m < _6n; _6m++) { //#21609
                        $1.i = $get(_6l, _6m); //#21557
                        $1.inP = true; //#21558
                        if ($1.i == $1.M) { //#21563
                            if ($1.lastchar == 13) { //#21560
                                $1.inP = false; //#21560
                            } //#21560
                        } else { //#21563
                            if ($1.i == $1.D) { //#21564
                                if (($1.lastchar == 44) || ($1.lastchar == 46)) { //#21563
                                    $1.inP = false; //#21563
                                } //#21563
                            } //#21563
                        } //#21563
                        if ($1.inP && $lt($get($1.curlen, $1.i), $get($1.nxtlen, $1.i))) { //#21608
                            $1.curseqi = $get($1.curseq, $1.i); //#21567
                            $1.lastld = false; //#21568
                            $1.lastsp = false; //#21569
                            $1.lastidx = -1; //#21570
                            for (var _77 = $1.curseqi.length - 1; _77 >= 0; _77 -= 1) { //#21591
                                $1.idx = _77; //#21572
                                $1.ch = $get($1.curseqi, $1.idx); //#21573
                                if ($1.lastidx == -1) { //#21588
                                    if ($eq($1.ch, $1.lastchar)) { //#21580
                                        $1.lastidx = $1.idx; //#21576
                                        if ($1.idx > 0) { //#21579
                                            if ($get($1.curseqi, $1.idx - 1) == $1.sp) { //#21578
                                                $1.lastsp = true; //#21578
                                            } //#21578
                                        } //#21578
                                    } //#21578
                                } else { //#21588
                                    if (($1.ch < 0) && ($1.ch >= $1.ld)) { //#21589
                                        if ($1.i == $1.P) { //#21586
                                            if ($1.ch == $1.ld) { //#21584
                                                $1.lastld = true; //#21584
                                            } //#21584
                                        } else { //#21586
                                            if ($1.ch != $1.lp) { //#21586
                                                $1.inP = $1.lastsp; //#21586
                                            } //#21586
                                        } //#21586
                                        break; //#21588
                                    } //#21588
                                } //#21588
                            } //#21588
                            if ($1.inP && ($1.lastidx >= 0)) { //#21607
                                $put($1.nxtlen, $1.i, $get($1.curlen, $1.i)); //#21593
                                if ($1.lastidx < ($1.curseqi.length - 1)) { //#21605
                                    if ($1.i == $1.P) { //#21602
                                        if ($1.lastld) { //#21596
                                            $put($1.nxtlen, $1.i, $f($get($1.nxtlen, $1.i) + 1)); //#21596
                                        } //#21596
                                        $k[$j++] = $1.nxtseq; //#21598
                                        $k[$j++] = $1.i; //#21598
                                        $k[$j++] = Infinity; //#21598
                                        $aload($1.curseqi); //#21598
                                        $r($1.curseqi.length - $1.lastidx, -1); //#21598
                                        $j--; //#21598
                                        $k[$j++] = $get($1.pcomp, $1.pchars); //#21598
                                        var _7t = $a(); //#21598
                                        var _7u = $k[--$j]; //#21598
                                        $put($k[--$j], _7u, _7t); //#21598
                                    } else { //#21602
                                        $k[$j++] = $1.nxtseq; //#21601
                                        $k[$j++] = $1.i; //#21601
                                        $k[$j++] = Infinity; //#21601
                                        $aload($1.curseqi); //#21601
                                        var _7z = $a(); //#21601
                                        var _80 = $k[--$j]; //#21601
                                        $put($k[--$j], _80, _7z); //#21601
                                        $put($get($1.nxtseq, $1.i), $1.lastidx, $get($1.pcomp, $1.pchars)); //#21602
                                    } //#21602
                                } else { //#21605
                                    $k[$j++] = $1.nxtseq; //#21605
                                    $k[$j++] = $1.i; //#21605
                                    $k[$j++] = Infinity; //#21605
                                    $aload($1.curseqi); //#21605
                                    $j--; //#21605
                                    $k[$j++] = $get($1.pcomp, $1.pchars); //#21605
                                    var _8F = $a(); //#21605
                                    var _8G = $k[--$j]; //#21605
                                    $put($k[--$j], _8G, _8F); //#21605
                                } //#21605
                            } //#21605
                        } //#21605
                    } //#21605
                } //#21605
            } //#21605
            if ($ne($get($1.nxtseq, $1.B), null)) { //#21620
                $1.numbytes = 0; //#21615
                $forall($get($1.nxtseq, $1.B), function() { //#21618
                    if ($k[--$j] == $1.sb) { //#21617
                        $k[$j++] = 0; //#21617
                    } else { //#21617
                        $k[$j++] = $1.numbytes + 1; //#21617
                    } //#21617
                    $1.numbytes = $k[--$j]; //#21617
                }); //#21617
                if ($1.numbytes == 32) { //#21619
                    $put($1.nxtlen, $1.B, $f($get($1.nxtlen, $1.B) + 11)); //#21619
                } //#21619
            } //#21619
            $1.curlen = $1.nxtlen; //#21622
            $1.curseq = $1.nxtseq; //#21623
            $k[$j++] = 'lastchar'; //#21624
            if ($1.char >= 0) { //#21624
                $k[$j++] = $1.char; //#21624
            } else { //#21624
                $k[$j++] = ""; //#21624
            } //#21624
            var _8c = $k[--$j]; //#21624
            $1[$k[--$j]] = _8c; //#21624
        }); //#21624
        $1.minseq = $1.e; //#21629
        var _8l = $a([$1.U, $1.L, $1.M, $1.P, $1.D, $1.B]); //#21630
        for (var _8m = 0, _8n = _8l.length; _8m < _8n; _8m++) { //#21636
            $1.i = $get(_8l, _8m); //#21631
            if ($get($1.curlen, $1.i) < $1.minseq) { //#21635
                $1.minseq = $get($1.curlen, $1.i); //#21633
                $1.seq = $get($1.curseq, $1.i); //#21634
            } //#21634
        } //#21634
        $1.tobin = function() {
            var _90 = $s($k[--$j]); //#21640
            $k[$j++] = _90; //#21640
            for (var _92 = 0, _91 = _90.length - 1; _92 <= _91; _92 += 1) { //#21640
                var _93 = $k[--$j]; //#21640
                $put(_93, _92, 48); //#21640
                $k[$j++] = _93; //#21640
            } //#21640
            var _94 = $k[--$j]; //#21641
            var _97 = $cvrs($s(_94.length), $k[--$j], 2); //#21641
            $puti(_94, _94.length - _97.length, _97); //#21641
            $k[$j++] = _94; //#21641
        }; //#21641
        $1.encu = function() {
            var _9C = $get($get($1.charvals, $1.U), $k[--$j]); //#21644
            $k[$j++] = _9C; //#21644
            $k[$j++] = 5; //#21644
            $1.tobin(); //#21644
        }; //#21644
        $1.encl = function() {
            var _9H = $get($get($1.charvals, $1.L), $k[--$j]); //#21645
            $k[$j++] = _9H; //#21645
            $k[$j++] = 5; //#21645
            $1.tobin(); //#21645
        }; //#21645
        $1.encm = function() {
            var _9M = $get($get($1.charvals, $1.M), $k[--$j]); //#21646
            $k[$j++] = _9M; //#21646
            $k[$j++] = 5; //#21646
            $1.tobin(); //#21646
        }; //#21646
        $1.encd = function() {
            var _9R = $get($get($1.charvals, $1.D), $k[--$j]); //#21647
            $k[$j++] = _9R; //#21647
            $k[$j++] = 4; //#21647
            $1.tobin(); //#21647
        }; //#21647
        $1.encp = function() {
            var _9S = $k[--$j]; //#21650
            $k[$j++] = _9S; //#21667
            if (_9S == $1.fn1) { //#21666
                $j--; //#21651
                $k[$j++] = "00000000"; //#21651
            } else { //#21666
                var _9U = $k[--$j]; //#21653
                $k[$j++] = _9U; //#21667
                if (_9U <= -1000000) { //#21666
                    var _9W = $f((-$k[--$j]) - 1000000); //#21654
                    $k[$j++] = _9W; //#21654
                    $k[$j++] = _9W; //#21654
                    if (_9W == 0) { //#21654
                        $j--; //#21654
                        $k[$j++] = 1; //#21654
                    } //#21654
                    var _9Y = ~~(Math.log($k[--$j]) / Math.log(10)); //#21656
                    var _9Z = $s(((_9Y + 1) * 4) + 8); //#21656
                    $puti(_9Z, 0, "00000"); //#21657
                    $k[$j++] = _9Y; //#21658
                    $k[$j++] = _9Z; //#21658
                    $k[$j++] = _9Z; //#21658
                    $k[$j++] = _9Y + 1; //#21658
                    $k[$j++] = 3; //#21658
                    $1.tobin(); //#21658
                    var _9a = $k[--$j]; //#21658
                    $puti($k[--$j], 5, _9a); //#21658
                    var _9c = $k[--$j]; //#21659
                    var _9d = $k[--$j]; //#21659
                    var _9e = $k[--$j]; //#21659
                    $k[$j++] = _9c; //#21663
                    $k[$j++] = _9e; //#21663
                    for (var _9f = _9d; _9f >= 0; _9f -= 1) { //#21663
                        var _9g = $k[--$j]; //#21660
                        var _9h = $k[--$j]; //#21661
                        $k[$j++] = _9h; //#21662
                        $k[$j++] = ~~(_9g / 10); //#21662
                        $k[$j++] = _9h; //#21662
                        $k[$j++] = (_9f * 4) + 8; //#21662
                        $k[$j++] = $f((_9g % 10) + 2); //#21662
                        $k[$j++] = 4; //#21662
                        $1.tobin(); //#21662
                        var _9i = $k[--$j]; //#21662
                        var _9j = $k[--$j]; //#21662
                        $puti($k[--$j], _9j, _9i); //#21662
                    } //#21662
                    $j--; //#21664
                } else { //#21666
                    var _9p = $get($get($1.charvals, $1.P), $k[--$j]); //#21666
                    $k[$j++] = _9p; //#21666
                    $k[$j++] = 5; //#21666
                    $1.tobin(); //#21666
                } //#21666
            } //#21666
        }; //#21666
        $1.encfuncs = $a(['encu', 'encl', 'encm', 'encp', 'encd']); //#21670
        $1.addtomsgbits = function() {
            $1.v = $k[--$j]; //#21673
            $puti($1.msgbits, $1.j, $1.v); //#21674
            $1.j = $1.j + $1.v.length; //#21675
        }; //#21675
        $1.state = $1.U; //#21679
        $1.msgbits = $s($1.minseq); //#21680
        $1.i = 0; //#21681
        $1.j = 0; //#21681
        for (;;) { //#21740
            if ($1.i >= $1.seq.length) { //#21682
                break; //#21682
            } //#21682
            if ($1.state != $1.B) { //#21735
                $1.char = $get($1.seq, $1.i); //#21686
                $k[$j++] = $1.char; //#21689
                if ($1[$get($1.encfuncs, $1.state)]() === true) {
                    break;
                } //#21689
                $1.addtomsgbits(); //#21689
                $1.i = $1.i + 1; //#21690
                if (($1.char == $1.su) || ($1.char == $1.sp)) { //#21696
                    $k[$j++] = $get($1.seq, $1.i); //#21694
                    if ($1.char == $1.su) { //#21694
                        $1.encu(); //#21694
                    } else { //#21694
                        $1.encp(); //#21694
                    } //#21694
                    $1.addtomsgbits(); //#21694
                    $1.i = $1.i + 1; //#21695
                } //#21695
                if ($1.char == $1.lu) { //#21699
                    $1.state = $1.U; //#21699
                } //#21699
                if ($1.char == $1.ll) { //#21700
                    $1.state = $1.L; //#21700
                } //#21700
                if ($1.char == $1.lm) { //#21701
                    $1.state = $1.M; //#21701
                } //#21701
                if ($1.char == $1.lp) { //#21702
                    $1.state = $1.P; //#21702
                } //#21702
                if ($1.char == $1.ld) { //#21703
                    $1.state = $1.D; //#21703
                } //#21703
                if ($1.char == $1.sb) { //#21704
                    $1.state = $1.B; //#21704
                } //#21704
            } else { //#21735
                $1.numbytes = 0; //#21709
                for (;;) { //#21713
                    if (($1.i + $1.numbytes) >= $1.seq.length) { //#21710
                        break; //#21710
                    } //#21710
                    if ($get($1.seq, $1.i + $1.numbytes) < 0) { //#21711
                        break; //#21711
                    } //#21711
                    $1.numbytes = $1.numbytes + 1; //#21712
                } //#21712
                if ($1.numbytes <= 31) { //#21720
                    $k[$j++] = $1.numbytes; //#21717
                    $k[$j++] = 5; //#21717
                    $1.tobin(); //#21717
                    $1.addtomsgbits(); //#21717
                } else { //#21720
                    $k[$j++] = 0; //#21719
                    $k[$j++] = 5; //#21719
                    $1.tobin(); //#21719
                    $1.addtomsgbits(); //#21719
                    $k[$j++] = $1.numbytes - 31; //#21720
                    $k[$j++] = 11; //#21720
                    $1.tobin(); //#21720
                    $1.addtomsgbits(); //#21720
                } //#21720
                for (var _Ar = 0, _As = $1.numbytes; _Ar < _As; _Ar++) { //#21727
                    $k[$j++] = $get($1.seq, $1.i); //#21725
                    $k[$j++] = 8; //#21725
                    $1.tobin(); //#21725
                    $1.addtomsgbits(); //#21725
                    $1.i = $1.i + 1; //#21726
                } //#21726
                if ($1.i < $1.seq.length) { //#21736
                    $1.char = $get($1.seq, $1.i); //#21731
                    $1.i = $1.i + 1; //#21732
                    if ($1.char == $1.lu) { //#21733
                        $1.state = $1.U; //#21733
                    } //#21733
                    if ($1.char == $1.ll) { //#21734
                        $1.state = $1.L; //#21734
                    } //#21734
                    if ($1.char == $1.lm) { //#21735
                        $1.state = $1.M; //#21735
                    } //#21735
                } //#21735
            } //#21735
        } //#21735
    } //#21735
    $1.metrics = $a([$a(["rune", 0, 0, 0, 6]), $a(["compact", 1, 1, 17, 6]), $a(["full", 1, 1, 21, 6]), $a(["compact", 2, 0, 40, 6]), $a(["full", 2, 1, 48, 6]), $a(["compact", 3, 0, 51, 8]), $a(["full", 3, 1, 60, 8]), $a(["compact", 4, 0, 76, 8]), $a(["full", 4, 1, 88, 8]), $a(["full", 5, 1, 120, 8]), $a(["full", 6, 1, 156, 8]), $a(["full", 7, 1, 196, 8]), $a(["full", 8, 1, 240, 8]), $a(["full", 9, 1, 230, 10]), $a(["full", 10, 1, 272, 10]), $a(["full", 11, 1, 316, 10]), $a(["full", 12, 1, 364, 10]), $a(["full", 13, 1, 416, 10]), $a(["full", 14, 1, 470, 10]), $a(["full", 15, 1, 528, 10]), $a(["full", 16, 1, 588, 10]), $a(["full", 17, 1, 652, 10]), $a(["full", 18, 1, 720, 10]), $a(["full", 19, 1, 790, 10]), $a(["full", 20, 1, 864, 10]), $a(["full", 21, 1, 940, 10]), $a(["full", 22, 1, 1020, 10]), $a(["full", 23, 0, 920, 12]), $a(["full", 24, 0, 992, 12]), $a(["full", 25, 0, 1066, 12]), $a(["full", 26, 0, 1144, 12]), $a(["full", 27, 0, 1224, 12]), $a(["full", 28, 0, 1306, 12]), $a(["full", 29, 0, 1392, 12]), $a(["full", 30, 0, 1480, 12]), $a(["full", 31, 0, 1570, 12]), $a(["full", 32, 0, 1664, 12])]); //#21760
    $1.i = 0; //#21763
    for (;;) { //#21781
        $1.m = $get($1.metrics, $1.i); //#21765
        $1.frmt = $get($1.m, 0); //#21766
        $1.mlyr = $get($1.m, 1); //#21767
        $1.icap = $get($1.m, 2); //#21768
        $1.ncws = $get($1.m, 3); //#21769
        $1.bpcw = $get($1.m, 4); //#21770
        $1.numecw = ~~(Math.ceil($f((($1.ncws * $1.eclevel) / 100) + $1.ecaddchars))); //#21771
        if ($1.msgbits.length == 0) { //#21772
            $1.numecw = 0; //#21772
        } //#21772
        $1.numdcw = $f($1.ncws - $1.numecw); //#21773
        $1.okay = true; //#21774
        if ($ne($1.format, "unset") && $ne($1.format, $1.frmt)) { //#21775
            $1.okay = false; //#21775
        } //#21775
        if ($1.readerinit && ($1.icap != 1)) { //#21776
            $1.okay = false; //#21776
        } //#21776
        if (($1.layers != -1) && ($1.layers != $1.mlyr)) { //#21777
            $1.okay = false; //#21777
        } //#21777
        if ((~~Math.ceil($1.msgbits.length / $1.bpcw)) > $1.numdcw) { //#21778
            $1.okay = false; //#21778
        } //#21778
        if ($1.okay) { //#21779
            break; //#21779
        } //#21779
        $1.i = $1.i + 1; //#21780
    } //#21780
    $1.layers = $1.mlyr; //#21782
    $1.format = $1.frmt; //#21783
    $1.allzero = function() {
        var _CM = $k[--$j]; //#21786
        $k[$j++] = $eq(_CM, $geti("000000000000", 0, _CM.length)); //#21786
    }; //#21786
    $1.allones = function() {
        var _CO = $k[--$j]; //#21787
        $k[$j++] = $eq(_CO, $geti("111111111111", 0, _CO.length)); //#21787
    }; //#21787
    $1.cws = $a($1.ncws); //#21788
    $1.m = 0; //#21789
    $1.c = 0; //#21789
    for (;;) { //#21816
        if ($1.msgbits.length <= $1.m) { //#21791
            break; //#21791
        } //#21791
        if (($1.msgbits.length - $1.m) >= $1.bpcw) { //#21805
            $1.cwb = $geti($1.msgbits, $1.m, $f($1.bpcw - 1)); //#21793
            $1.cwf = $geti($1.msgbits, $f($f($1.m + $1.bpcw) - 1), 1); //#21794
            $k[$j++] = $1.cwb; //#21795
            $1.allzero(); //#21795
            if ($k[--$j]) { //#21795
                $1.cwf = "1"; //#21795
                $1.m = $1.m - 1; //#21795
            } //#21795
            $k[$j++] = $1.cwb; //#21796
            $1.allones(); //#21796
            if ($k[--$j]) { //#21796
                $1.cwf = "0"; //#21796
                $1.m = $1.m - 1; //#21796
            } //#21796
            var _Cl = $s(12); //#21798
            $puti(_Cl, 0, $1.cwb); //#21798
            $puti(_Cl, $f($1.bpcw - 1), $1.cwf); //#21799
            $1.cwb = $geti(_Cl, 0, $1.bpcw); //#21801
        } else { //#21805
            $1.cwb = $geti($1.msgbits, $1.m, $1.msgbits.length - $1.m); //#21803
            var _Cx = $strcpy($s(12), "111111111111"); //#21804
            $puti(_Cx, 0, $1.cwb); //#21804
            $1.cwb = $geti(_Cx, 0, $1.bpcw); //#21804
            $k[$j++] = $1.cwb; //#21805
            $1.allones(); //#21805
            if ($k[--$j]) { //#21805
                $puti($1.cwb, $1.cwb.length - 1, "0"); //#21805
            } //#21805
        } //#21805
        $1.cw = 0; //#21808
        for (var _D7 = 0, _D6 = $f($1.bpcw - 1); _D7 <= _D6; _D7 += 1) { //#21812
            $1.i = _D7; //#21810
            $1.cw = $f($1.cw + ((~~(Math.pow(2, $f($f($1.bpcw - $1.i) - 1)))) * $f($get($1.cwb, $1.i) - 48))); //#21811
        } //#21811
        $put($1.cws, $1.c, $1.cw); //#21813
        $1.m = $f($1.m + $1.bpcw); //#21814
        $1.c = $1.c + 1; //#21815
    } //#21815
    $1.cws = $geti($1.cws, 0, $1.c); //#21817
    var _DO = $get($1.options, 'debugcws') !== undefined; //#21819
    if (_DO) { //#21819
        $k[$j++] = 'bwipp.debugcws'; //#21819
        $k[$j++] = $1.cws; //#21819
        bwipp_raiseerror(); //#21819
    } //#21819
    $1.rscodes = function() {
        $1.rspm = $k[--$j]; //#21824
        $1.rsgf = $k[--$j]; //#21825
        $1.rsnc = $k[--$j]; //#21826
        $1.rscws = $k[--$j]; //#21827
        $k[$j++] = Infinity; //#21830
        $k[$j++] = 1; //#21830
        for (var _DV = 0, _DW = $f($1.rsgf - 1); _DV < _DW; _DV++) { //#21830
            var _DX = $k[--$j]; //#21830
            var _DY = _DX * 2; //#21830
            $k[$j++] = _DX; //#21830
            $k[$j++] = _DY; //#21830
            if (_DY >= $1.rsgf) { //#21830
                var _Db = $k[--$j]; //#21830
                $k[$j++] = $xo(_Db, $1.rspm); //#21830
            } //#21830
        } //#21830
        $1.rsalog = $a(); //#21830
        $1.rslog = $a($1.rsgf); //#21831
        for (var _Dh = 1, _Dg = $f($1.rsgf - 1); _Dh <= _Dg; _Dh += 1) { //#21832
            $put($1.rslog, $get($1.rsalog, _Dh), _Dh); //#21832
        } //#21832
        $1.rsprod = function() {
            var _Dl = $k[--$j]; //#21836
            var _Dm = $k[--$j]; //#21836
            $k[$j++] = _Dm; //#21840
            $k[$j++] = _Dl; //#21840
            if ((_Dl != 0) && (_Dm != 0)) { //#21839
                var _Dp = $get($1.rslog, $k[--$j]); //#21837
                var _Dv = $get($1.rsalog, $f(_Dp + $get($1.rslog, $k[--$j])) % $f($1.rsgf - 1)); //#21837
                $k[$j++] = _Dv; //#21837
            } else { //#21839
                $j -= 2; //#21839
                $k[$j++] = 0; //#21839
            } //#21839
        }; //#21839
        $k[$j++] = Infinity; //#21844
        $k[$j++] = 1; //#21844
        for (var _Dx = 0, _Dy = $1.rsnc; _Dx < _Dy; _Dx++) { //#21844
            $k[$j++] = 0; //#21844
        } //#21844
        $1.coeffs = $a(); //#21844
        for (var _E2 = 1, _E1 = $1.rsnc; _E2 <= _E1; _E2 += 1) { //#21853
            $1.i = _E2; //#21846
            $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#21847
            for (var _E9 = $1.i - 1; _E9 >= 1; _E9 -= 1) { //#21851
                $1.j = _E9; //#21849
                $k[$j++] = $1.coeffs; //#21850
                $k[$j++] = $1.j; //#21850
                $k[$j++] = $get($1.coeffs, $1.j - 1); //#21850
                $k[$j++] = $get($1.coeffs, $1.j); //#21850
                $k[$j++] = $get($1.rsalog, $1.i); //#21850
                $1.rsprod(); //#21850
                var _EL = $k[--$j]; //#21850
                var _EM = $k[--$j]; //#21850
                var _EN = $k[--$j]; //#21850
                $put($k[--$j], _EN, $xo(_EM, _EL)); //#21850
            } //#21850
            $k[$j++] = $1.coeffs; //#21852
            $k[$j++] = 0; //#21852
            $k[$j++] = $get($1.coeffs, 0); //#21852
            $k[$j++] = $get($1.rsalog, $1.i); //#21852
            $1.rsprod(); //#21852
            var _EV = $k[--$j]; //#21852
            var _EW = $k[--$j]; //#21852
            $put($k[--$j], _EW, _EV); //#21852
        } //#21852
        $1.nd = $1.rscws.length; //#21856
        $k[$j++] = Infinity; //#21857
        $forall($1.rscws); //#21857
        for (var _Eb = 0, _Ec = $1.rsnc; _Eb < _Ec; _Eb++) { //#21857
            $k[$j++] = 0; //#21857
        } //#21857
        $k[$j++] = 0; //#21857
        $1.rscws = $a(); //#21857
        for (var _Eg = 0, _Ef = $1.nd - 1; _Eg <= _Ef; _Eg += 1) { //#21864
            $1.k = $xo($get($1.rscws, _Eg), $get($1.rscws, $1.nd)); //#21859
            for (var _Eo = 0, _En = $f($1.rsnc - 1); _Eo <= _En; _Eo += 1) { //#21863
                $1.j = _Eo; //#21861
                $k[$j++] = $1.rscws; //#21862
                $k[$j++] = $1.nd + $1.j; //#21862
                $k[$j++] = $get($1.rscws, ($1.nd + $1.j) + 1); //#21862
                $k[$j++] = $1.k; //#21862
                $k[$j++] = $get($1.coeffs, $f($f($1.rsnc - $1.j) - 1)); //#21862
                $1.rsprod(); //#21862
                var _F1 = $k[--$j]; //#21862
                var _F2 = $k[--$j]; //#21862
                var _F3 = $k[--$j]; //#21862
                $put($k[--$j], _F3, $xo(_F2, _F1)); //#21862
            } //#21862
        } //#21862
        $k[$j++] = $geti($1.rscws, 0, $1.rscws.length - 1); //#21867
    }; //#21867
    if ($eq($1.format, "full")) { //#21882
        $1.mode = ($f($1.layers - 1) << 11) + ($1.cws.length - 1); //#21873
        if ($1.readerinit) { //#21874
            $1.mode = $1.mode | 1024; //#21874
        } //#21874
        $1.mode = $a([($1.mode & 61440) >>> 12, ($1.mode & 3840) >>> 8, ($1.mode & 240) >>> 4, $1.mode & 15]); //#21880
        $k[$j++] = 'mode'; //#21881
        $k[$j++] = $1.mode; //#21881
        $k[$j++] = 6; //#21881
        $k[$j++] = 16; //#21881
        $k[$j++] = 19; //#21881
        $1.rscodes(); //#21881
        var _FJ = $k[--$j]; //#21881
        $1[$k[--$j]] = _FJ; //#21881
    } //#21881
    if ($eq($1.format, "compact")) { //#21891
        $1.mode = ($f($1.layers - 1) << 6) + ($1.cws.length - 1); //#21884
        if ($1.readerinit) { //#21885
            $1.mode = $1.mode | 32; //#21885
        } //#21885
        $1.mode = $a([($1.mode & 240) >>> 4, $1.mode & 15]); //#21889
        $k[$j++] = 'mode'; //#21890
        $k[$j++] = $1.mode; //#21890
        $k[$j++] = 5; //#21890
        $k[$j++] = 16; //#21890
        $k[$j++] = 19; //#21890
        $1.rscodes(); //#21890
        var _FU = $k[--$j]; //#21890
        $1[$k[--$j]] = _FU; //#21890
    } //#21890
    if ($eq($1.format, "rune")) { //#21900
        $1.mode = $cvi($1.barcode); //#21893
        $1.mode = $a([($1.mode & 240) >>> 4, $1.mode & 15]); //#21897
        $k[$j++] = 'mode'; //#21898
        $k[$j++] = $1.mode; //#21898
        $k[$j++] = 5; //#21898
        $k[$j++] = 16; //#21898
        $k[$j++] = 19; //#21898
        $1.rscodes(); //#21898
        var _Fc = $k[--$j]; //#21898
        $1[$k[--$j]] = _Fc; //#21898
        $k[$j++] = Infinity; //#21899
        var _Fe = $1.mode; //#21899
        for (var _Ff = 0, _Fg = _Fe.length; _Ff < _Fg; _Ff++) { //#21899
            $k[$j++] = $get(_Fe, _Ff) ^ 10; //#21899
        } //#21899
        $1.mode = $a(); //#21899
    } //#21899
    $1.modebits = $s($1.mode.length * 4); //#21901
    for (var _Fn = 0, _Fm = $1.modebits.length - 1; _Fn <= _Fm; _Fn += 1) { //#21902
        $puti($1.modebits, _Fn, "0"); //#21902
    } //#21902
    for (var _Fr = 0, _Fq = $1.mode.length - 1; _Fr <= _Fq; _Fr += 1) { //#21906
        $1.i = _Fr; //#21904
        var _Fx = $cvrs($s(4), $get($1.mode, $1.i), 2); //#21905
        $puti($1.modebits, (4 - _Fx.length) + (4 * $1.i), _Fx); //#21905
    } //#21905
    $1.rsparams = $a([$a([]), $a([]), $a([]), $a([]), $a([]), $a([]), $a([64, 67]), $a([]), $a([256, 301]), $a([]), $a([1024, 1033]), $a([]), $a([4096, 4201])]); //#21919
    $k[$j++] = 'cws'; //#21921
    $k[$j++] = $1.cws; //#21921
    $k[$j++] = $f($1.ncws - $1.cws.length); //#21921
    $forall($get($1.rsparams, $1.bpcw)); //#21921
    $1.rscodes(); //#21921
    var _GJ = $k[--$j]; //#21921
    $1[$k[--$j]] = _GJ; //#21921
    if ($eq($1.format, "full")) { //#21925
        $1.databits = $s($f((($1.layers * $1.layers) * 16) + ($1.layers * 112))); //#21923
    } else { //#21925
        $1.databits = $s($f((($1.layers * $1.layers) * 16) + ($1.layers * 88))); //#21925
    } //#21925
    for (var _GW = 0, _GV = $1.databits.length - 1; _GW <= _GV; _GW += 1) { //#21927
        $puti($1.databits, _GW, "0"); //#21927
    } //#21927
    for (var _Ga = 0, _GZ = $f($1.ncws - 1); _Ga <= _GZ; _Ga += 1) { //#21933
        $1.i = _Ga; //#21929
        var _Gh = $cvrs($s($1.bpcw), $get($1.cws, $1.i), 2); //#21930
        $puti($1.databits, $f(($f($f($1.bpcw - _Gh.length) + ($1.bpcw * $1.i))) + ($f($1.databits.length - ($1.ncws * $1.bpcw)))), _Gh); //#21932
    } //#21932
    $1.cmv = function() {
        var _Gp = $k[--$j]; //#21936
        var _Gq = $k[--$j]; //#21936
        $k[$j++] = $f(($f(_Gq - (_Gp * $1.size))) + $1.mid); //#21936
    }; //#21936
    $1.lmv = function() {
        $1.lbit = $k[--$j]; //#21940
        $1.llyr = $k[--$j]; //#21941
        $1.lwid = $f($1.fw + ($1.llyr * 4)); //#21942
        $1.ldir = ~~((~~($1.lbit / 2)) / $1.lwid); //#21943
        if ($1.ldir == 0) { //#21948
            $k[$j++] = $f(((-(~~($f($1.lwid - 1) / 2))) + 1) + ((~~($1.lbit / 2)) % $1.lwid)); //#21947
            $k[$j++] = $f(($f((~~(($1.fw - 1) / 2)) + ($1.llyr * 2))) + ($1.lbit % 2)); //#21947
            $1.cmv(); //#21947
        } //#21947
        if ($1.ldir == 1) { //#21953
            $k[$j++] = $f(($f((~~($1.fw / 2)) + ($1.llyr * 2))) + ($1.lbit % 2)); //#21952
            $k[$j++] = $f(((~~($f($1.lwid - 1) / 2)) - 1) - ((~~($1.lbit / 2)) % $1.lwid)); //#21952
            $1.cmv(); //#21952
        } //#21952
        if ($1.ldir == 2) { //#21958
            $k[$j++] = -($f(((-(~~($1.lwid / 2))) + 1) + ((~~($1.lbit / 2)) % $1.lwid))); //#21957
            $k[$j++] = -($f(($f((~~($1.fw / 2)) + ($1.llyr * 2))) + ($1.lbit % 2))); //#21957
            $1.cmv(); //#21957
        } //#21957
        if ($1.ldir == 3) { //#21963
            $k[$j++] = -($f(($f((~~(($1.fw - 1) / 2)) + ($1.llyr * 2))) + ($1.lbit % 2))); //#21962
            $k[$j++] = -($f(((~~($1.lwid / 2)) - 1) - ((~~($1.lbit / 2)) % $1.lwid))); //#21962
            $1.cmv(); //#21962
        } //#21962
    }; //#21962
    if ($eq($1.format, "full")) { //#21968
        $1.fw = 12; //#21968
    } else { //#21968
        $1.fw = 9; //#21968
    } //#21968
    $1.size = $f(($f($1.fw + ($1.layers * 4))) + 2); //#21969
    $k[$j++] = Infinity; //#21970
    for (var _HV = 0, _HW = $1.size * $1.size; _HV < _HW; _HV++) { //#21970
        $k[$j++] = -1; //#21970
    } //#21970
    $1.pixs = $a(); //#21970
    $1.mid = $f(((~~($f($1.size - 1) / 2)) * $1.size) + (~~($f($1.size - 1) / 2))); //#21971
    $1.i = 0; //#21974
    for (var _Hd = 1, _Hc = $1.layers; _Hd <= _Hc; _Hd += 1) { //#21982
        $1.layer = _Hd; //#21976
        for (var _Hh = 0, _Hg = (($1.fw + ($1.layer * 4)) * 8) - 1; _Hh <= _Hg; _Hh += 1) { //#21981
            $1.pos = _Hh; //#21978
            $k[$j++] = $1.pixs; //#21979
            $k[$j++] = $1.layer; //#21979
            $k[$j++] = $1.pos; //#21979
            $1.lmv(); //#21979
            var _Hp = $k[--$j]; //#21979
            $put($k[--$j], _Hp, $get($1.databits, ($1.databits.length - $1.i) - 1) - 48); //#21979
            $1.i = $1.i + 1; //#21980
        } //#21980
    } //#21980
    if ($eq($1.format, "full")) { //#22009
        $1.fw = 13; //#21986
        $1.size = $f(($f(($f($1.fw + ($1.layers * 4))) + 2)) + ((~~($f(($f($1.layers + 10.5) / 7.5) - 1))) * 2)); //#21987
        $1.mid = ~~(($1.size * $1.size) / 2); //#21988
        $k[$j++] = Infinity; //#21989
        for (var _I0 = 0, _I1 = $1.size * $1.size; _I0 < _I1; _I0++) { //#21989
            $k[$j++] = -2; //#21989
        } //#21989
        $1.npixs = $a(); //#21989
        for (var _I5 = 0, _I4 = ~~($1.size / 2); _I5 <= _I4; _I5 += 16) { //#21999
            $1.i = _I5; //#21991
            for (var _I8 = 0, _I7 = $f($1.size - 1); _I8 <= _I7; _I8 += 1) { //#21998
                $1.j = _I8; //#21993
                $k[$j++] = $1.npixs; //#21994
                $k[$j++] = (-(~~($1.size / 2))) + $1.j; //#21994
                $k[$j++] = $1.i; //#21994
                $1.cmv(); //#21994
                var _IH = $k[--$j]; //#21994
                $puti($k[--$j], _IH, $a([((((~~($1.size / 2)) + $1.j) + $1.i) + 1) % 2])); //#21994
                $k[$j++] = $1.npixs; //#21995
                $k[$j++] = (-(~~($1.size / 2))) + $1.j; //#21995
                $k[$j++] = -$1.i; //#21995
                $1.cmv(); //#21995
                var _IR = $k[--$j]; //#21995
                $puti($k[--$j], _IR, $a([((((~~($1.size / 2)) + $1.j) + $1.i) + 1) % 2])); //#21995
                $k[$j++] = $1.npixs; //#21996
                $k[$j++] = $1.i; //#21996
                $k[$j++] = (-(~~($1.size / 2))) + $1.j; //#21996
                $1.cmv(); //#21996
                var _Ib = $k[--$j]; //#21996
                $puti($k[--$j], _Ib, $a([((((~~($1.size / 2)) + $1.j) + $1.i) + 1) % 2])); //#21996
                $k[$j++] = $1.npixs; //#21997
                $k[$j++] = -$1.i; //#21997
                $k[$j++] = (-(~~($1.size / 2))) + $1.j; //#21997
                $1.cmv(); //#21997
                var _Il = $k[--$j]; //#21997
                $puti($k[--$j], _Il, $a([((((~~($1.size / 2)) + $1.j) + $1.i) + 1) % 2])); //#21997
            } //#21997
        } //#21997
        $1.j = 0; //#22000
        for (var _Ip = 0, _Io = $1.npixs.length - 1; _Ip <= _Io; _Ip += 1) { //#22007
            $1.i = _Ip; //#22002
            if ($get($1.npixs, $1.i) == -2) { //#22006
                $put($1.npixs, $1.i, $get($1.pixs, $1.j)); //#22004
                $1.j = $1.j + 1; //#22005
            } //#22005
        } //#22005
        $1.pixs = $1.npixs; //#22008
    } //#22008
    $1.fw = ~~($1.fw / 2); //#22012
    for (var _J4 = -$1.fw, _J3 = $1.fw; _J4 <= _J3; _J4 += 1) { //#22021
        $1.i = _J4; //#22014
        for (var _J8 = -$1.fw, _J7 = $1.fw; _J8 <= _J7; _J8 += 1) { //#22020
            $1.j = _J8; //#22016
            $k[$j++] = $1.pixs; //#22017
            $k[$j++] = $1.i; //#22017
            $k[$j++] = $1.j; //#22017
            $1.cmv(); //#22017
            if (Math.abs($1.i) > Math.abs($1.j)) { //#22018
                $k[$j++] = Math.abs($1.i); //#22018
            } else { //#22018
                $k[$j++] = Math.abs($1.j); //#22018
            } //#22018
            var _JG = $k[--$j]; //#22018
            var _JH = $k[--$j]; //#22019
            $put($k[--$j], _JH, $f(_JG + 1) % 2); //#22019
        } //#22019
    } //#22019
    var _Jt = $a([$a([-($1.fw + 1), $1.fw, 1]), $a([-($1.fw + 1), $1.fw + 1, 1]), $a([-$1.fw, $1.fw + 1, 1]), $a([$1.fw + 1, $1.fw + 1, 1]), $a([$1.fw + 1, $1.fw, 1]), $a([$1.fw + 1, -$1.fw, 1]), $a([$1.fw, $1.fw + 1, 0]), $a([$1.fw + 1, -($1.fw + 1), 0]), $a([$1.fw, -($1.fw + 1), 0]), $a([-$1.fw, -($1.fw + 1), 0]), $a([-($1.fw + 1), -($1.fw + 1), 0]), $a([-($1.fw + 1), -$1.fw, 0])]); //#22029
    for (var _Ju = 0, _Jv = _Jt.length; _Ju < _Jv; _Ju++) { //#22030
        $k[$j++] = $1.pixs; //#22030
        $forall($get(_Jt, _Ju)); //#22030
        var _Jy = $k[--$j]; //#22030
        var _Jz = $k[--$j]; //#22030
        var _K0 = $k[--$j]; //#22030
        $k[$j++] = _Jy; //#22030
        $k[$j++] = _K0; //#22030
        $k[$j++] = _Jz; //#22030
        $1.cmv(); //#22030
        var _K1 = $k[--$j]; //#22030
        var _K2 = $k[--$j]; //#22030
        $put($k[--$j], _K1, _K2); //#22030
    } //#22030
    $1.modemapfull = $a([$a([-5, 7]), $a([-4, 7]), $a([-3, 7]), $a([-2, 7]), $a([-1, 7]), $a([1, 7]), $a([2, 7]), $a([3, 7]), $a([4, 7]), $a([5, 7]), $a([7, 5]), $a([7, 4]), $a([7, 3]), $a([7, 2]), $a([7, 1]), $a([7, -1]), $a([7, -2]), $a([7, -3]), $a([7, -4]), $a([7, -5]), $a([5, -7]), $a([4, -7]), $a([3, -7]), $a([2, -7]), $a([1, -7]), $a([-1, -7]), $a([-2, -7]), $a([-3, -7]), $a([-4, -7]), $a([-5, -7]), $a([-7, -5]), $a([-7, -4]), $a([-7, -3]), $a([-7, -2]), $a([-7, -1]), $a([-7, 1]), $a([-7, 2]), $a([-7, 3]), $a([-7, 4]), $a([-7, 5])]); //#22039
    $1.modemapcompact = $a([$a([-3, 5]), $a([-2, 5]), $a([-1, 5]), $a([0, 5]), $a([1, 5]), $a([2, 5]), $a([3, 5]), $a([5, 3]), $a([5, 2]), $a([5, 1]), $a([5, 0]), $a([5, -1]), $a([5, -2]), $a([5, -3]), $a([3, -5]), $a([2, -5]), $a([1, -5]), $a([0, -5]), $a([-1, -5]), $a([-2, -5]), $a([-3, -5]), $a([-5, -3]), $a([-5, -2]), $a([-5, -1]), $a([-5, 0]), $a([-5, 1]), $a([-5, 2]), $a([-5, 3])]); //#22045
    $k[$j++] = 'modemap'; //#22047
    if ($eq($1.format, "full")) { //#22047
        $k[$j++] = $1.modemapfull; //#22047
    } else { //#22047
        $k[$j++] = $1.modemapcompact; //#22047
    } //#22047
    var _LF = $k[--$j]; //#22047
    $1[$k[--$j]] = _LF; //#22047
    for (var _LJ = 0, _LI = $1.modemap.length - 1; _LJ <= _LI; _LJ += 1) { //#22051
        $1.i = _LJ; //#22049
        $k[$j++] = $1.pixs; //#22050
        $forall($get($1.modemap, $1.i)); //#22050
        $1.cmv(); //#22050
        var _LR = $k[--$j]; //#22050
        $put($k[--$j], _LR, $get($1.modebits, $1.i) - 48); //#22050
    } //#22050
    var _LZ = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.size],
        ["pixy", $1.size],
        ["height", ($1.size * 2) / 72],
        ["width", ($1.size * 2) / 72],
        ["opt", $1.options]
    ]); //#22060
    $k[$j++] = _LZ; //#22063
    if (!$1.dontdraw) { //#22063
        bwipp_renmatrix(); //#22063
    } //#22063
}

function bwipp_azteccodecompact() {
    var $1 = {}; //#22096
    $1.ctx = null; //#22098
    $1.dontdraw = false; //#22099
    $k[$j++] = $1; //#22101
    bwipp_processoptions(); //#22101
    $1.options = $k[--$j]; //#22101
    $1.barcode = $k[--$j]; //#22102
    $put($1.options, "dontdraw", true); //#22105
    $put($1.options, "format", "compact"); //#22106
    $k[$j++] = 'args'; //#22108
    $k[$j++] = $1.barcode; //#22108
    $k[$j++] = $1.options; //#22108
    bwipp_azteccode(); //#22108
    var _6 = $k[--$j]; //#22108
    $1[$k[--$j]] = _6; //#22108
    $put($1.args, "opt", $1.options); //#22110
    $k[$j++] = $1.args; //#22113
    if (!$1.dontdraw) { //#22113
        bwipp_renmatrix(); //#22113
    } //#22113
}

function bwipp_aztecrune() {
    var $1 = {}; //#22144
    $1.ctx = null; //#22146
    $1.dontdraw = false; //#22147
    $k[$j++] = $1; //#22149
    bwipp_processoptions(); //#22149
    $1.options = $k[--$j]; //#22149
    $1.barcode = $k[--$j]; //#22150
    $put($1.options, "dontdraw", true); //#22153
    $put($1.options, "format", "rune"); //#22154
    $k[$j++] = 'args'; //#22156
    $k[$j++] = $1.barcode; //#22156
    $k[$j++] = $1.options; //#22156
    bwipp_azteccode(); //#22156
    var _6 = $k[--$j]; //#22156
    $1[$k[--$j]] = _6; //#22156
    $put($1.args, "opt", $1.options); //#22158
    $k[$j++] = $1.args; //#22161
    if (!$1.dontdraw) { //#22161
        bwipp_renmatrix(); //#22161
    } //#22161
}

function bwipp_codeone() {
    var $1 = {}; //#22194
    $1.ctx = null; //#22196
    $1.dontdraw = false; //#22197
    $1.version = "unset"; //#22198
    $1.parse = false; //#22199
    $1.parsefnc = false; //#22200
    $k[$j++] = $1; //#22202
    bwipp_processoptions(); //#22202
    $1.options = $k[--$j]; //#22202
    $1.barcode = $k[--$j]; //#22203
    $1.stype = $eq($geti($1.version, 0, 1), "S"); //#22207
    $1.stypevals = $a(["1", "1010", "1100100", "1111101000", "10011100010000", "11000011010100000", "11110100001001000000", "100110001001011010000000", "101111101011110000100000000", "111011100110101100101000000000", "1001010100000010111110010000000000", "1011101001000011101101110100000000000", "1110100011010100101001010001000000000000", "10010001100001001110011100101010000000000000", "10110101111001100010000011110100100000000000000", "11100011010111111010100100110001101000000000000000", "100011100001101111001001101111110000010000000000000000", "101100011010001010111100001011101100010100000000000000000"]); //#22229
    $1.stypemetrics = $a([$a(["S-10", 8, 11, 10, 4, 4, 1, 99, 99, 99]), $a(["S-20", 8, 21, 20, 8, 8, 1, 99, 99, 99]), $a(["S-30", 8, 31, 30, 12, 12, 1, 99, 99, 99])]); //#22237
    $1.nonstypemetrics = $a([$a(["A", 16, 18, 16, 10, 10, 1, 4, 99, 6]), $a(["B", 22, 22, 20, 19, 16, 1, 4, 99, 8]), $a(["C", 28, 32, 28, 44, 26, 1, 4, 22, 11]), $a(["D", 40, 42, 36, 91, 44, 1, 4, 16, 16]), $a(["E", 52, 54, 48, 182, 70, 1, 4, 22, 22]), $a(["F", 70, 76, 68, 370, 140, 2, 4, 22, 31]), $a(["G", 104, 98, 88, 732, 280, 4, 6, 21, 47]), $a(["H", 148, 134, 120, 1480, 560, 8, 6, 20, 69]), $a(["T-16", 16, 17, 16, 10, 10, 1, 99, 99, 99]), $a(["T-32", 16, 33, 32, 24, 16, 1, 99, 99, 99]), $a(["T-48", 16, 49, 48, 38, 22, 1, 99, 99, 99])]); //#22253
    $1.fnc1 = -1; //#22256
    $1.fnc3 = -2; //#22256
    $1.lC = -5; //#22257
    $1.lB = -6; //#22257
    $1.lX = -7; //#22257
    $1.lT = -8; //#22257
    $1.lD = -9; //#22257
    $1.unl = -10; //#22257
    $1.fnc2 = -11; //#22258
    $1.fnc4 = -12; //#22258
    $1.sft1 = -13; //#22258
    $1.sft2 = -14; //#22258
    $1.sft3 = -15; //#22258
    $1.eci = -16; //#22258
    $1.pad = -17; //#22258
    $1.fnc1lD = -18; //#22258
    $1.unlcw = 255; //#22259
    $k[$j++] = Infinity; //#22270
    for (var _L = 0; _L <= 128; _L += 1) { //#22262
        $k[$j++] = _L; //#22262
        $k[$j++] = _L + 1; //#22262
    } //#22262
    $k[$j++] = $1.pad; //#22267
    $k[$j++] = 129; //#22267
    for (var _N = 0; _N <= 99; _N += 1) { //#22267
        var _P = $cvrs($s(2), _N, 10); //#22265
        var _R = $strcpy($s(2), "00"); //#22265
        $puti(_R, 2 - _P.length, _P); //#22265
        $k[$j++] = _R; //#22266
        $k[$j++] = _N + 130; //#22266
    } //#22266
    var _Z = $a([$1.lC, $1.lB, $1.fnc1, $1.fnc2, $1.fnc3, $1.fnc4, $1.fnc1lD]); //#22268
    $k[$j++] = 229; //#22268
    for (var _a = 0, _b = _Z.length; _a < _b; _a++) { //#22268
        var _e = $f($k[--$j] + 1); //#22268
        $k[$j++] = $get(_Z, _a); //#22268
        $k[$j++] = _e; //#22268
        $k[$j++] = _e; //#22268
    } //#22268
    $j--; //#22268
    $k[$j++] = $1.lX; //#22270
    $k[$j++] = 238; //#22270
    $k[$j++] = $1.lT; //#22270
    $k[$j++] = 239; //#22270
    $1.Avals = $d(); //#22272
    $k[$j++] = Infinity; //#22274
    var _i = $1.Avals; //#22274
    for (var _n = _i.size, _m = _i.keys(), _l = 0; _l < _n; _l++) { //#22274
        var _j = _m.next().value; //#22274
        $k[$j++] = _j; //#22274
        $k[$j++] = _i.get(_j); //#22274
        $k[$j++] = Infinity; //#22274
        var _o = $k[--$j]; //#22274
        var _p = $k[--$j]; //#22274
        $k[$j++] = _o; //#22274
        $k[$j++] = _p; //#22274
        var _q = $a(); //#22274
        $k[$j++] = _q; //#22274
    } //#22274
    $1.Avals = $d(); //#22275
    $k[$j++] = Infinity; //#22283
    $k[$j++] = $1.sft1; //#22282
    $k[$j++] = 0; //#22282
    $k[$j++] = $1.sft2; //#22282
    $k[$j++] = 1; //#22282
    $k[$j++] = $1.sft3; //#22282
    $k[$j++] = 2; //#22282
    $k[$j++] = 32; //#22282
    $k[$j++] = 3; //#22282
    for (var _v = 48; _v <= 57; _v += 1) { //#22282
        $k[$j++] = _v; //#22282
        $k[$j++] = _v - 44; //#22282
    } //#22282
    for (var _w = 65; _w <= 90; _w += 1) { //#22283
        $k[$j++] = _w; //#22283
        $k[$j++] = _w - 51; //#22283
    } //#22283
    $1.CNvals = $d(); //#22284
    $k[$j++] = Infinity; //#22285
    for (var _y = 0; _y <= 31; _y += 1) { //#22285
        $k[$j++] = _y; //#22285
        $k[$j++] = _y; //#22285
    } //#22285
    $1.C1vals = $d(); //#22285
    $k[$j++] = Infinity; //#22294
    for (var _10 = 33; _10 <= 47; _10 += 1) { //#22287
        $k[$j++] = _10; //#22287
        $k[$j++] = _10 - 33; //#22287
    } //#22287
    for (var _11 = 58; _11 <= 64; _11 += 1) { //#22288
        $k[$j++] = _11; //#22288
        $k[$j++] = _11 - 43; //#22288
    } //#22288
    for (var _12 = 91; _12 <= 95; _12 += 1) { //#22289
        $k[$j++] = _12; //#22289
        $k[$j++] = _12 - 69; //#22289
    } //#22289
    $k[$j++] = $1.fnc1; //#22294
    $k[$j++] = 27; //#22294
    $k[$j++] = $1.fnc2; //#22294
    $k[$j++] = 28; //#22294
    $k[$j++] = $1.fnc3; //#22294
    $k[$j++] = 29; //#22294
    $k[$j++] = $1.fnc4; //#22294
    $k[$j++] = 30; //#22294
    $k[$j++] = $1.pad; //#22294
    $k[$j++] = 31; //#22294
    $1.C2vals = $d(); //#22295
    $k[$j++] = Infinity; //#22296
    for (var _19 = 96; _19 <= 127; _19 += 1) { //#22296
        $k[$j++] = _19; //#22296
        $k[$j++] = _19 - 96; //#22296
    } //#22296
    $1.C3vals = $d(); //#22296
    $k[$j++] = Infinity; //#22301
    var _1B = $1.CNvals; //#22298
    for (var _1G = _1B.size, _1F = _1B.keys(), _1E = 0; _1E < _1G; _1E++) { //#22298
        var _1C = _1F.next().value; //#22298
        $k[$j++] = _1C; //#22298
        $k[$j++] = _1B.get(_1C); //#22298
        $k[$j++] = Infinity; //#22298
        var _1H = $k[--$j]; //#22298
        var _1I = $k[--$j]; //#22298
        $k[$j++] = _1H; //#22298
        $k[$j++] = _1I; //#22298
        var _1J = $a(); //#22298
        $k[$j++] = _1J; //#22298
    } //#22298
    var _1K = $1.C1vals; //#22299
    for (var _1P = _1K.size, _1O = _1K.keys(), _1N = 0; _1N < _1P; _1N++) { //#22299
        var _1L = _1O.next().value; //#22299
        $k[$j++] = _1L; //#22299
        $k[$j++] = _1K.get(_1L); //#22299
        $k[$j++] = Infinity; //#22299
        var _1Q = $k[--$j]; //#22299
        var _1R = $k[--$j]; //#22299
        $k[$j++] = _1Q; //#22299
        $k[$j++] = $get($1.CNvals, $1.sft1); //#22299
        $k[$j++] = _1R; //#22299
        var _1V = $a(); //#22299
        $k[$j++] = _1V; //#22299
    } //#22299
    var _1W = $1.C2vals; //#22300
    for (var _1b = _1W.size, _1a = _1W.keys(), _1Z = 0; _1Z < _1b; _1Z++) { //#22300
        var _1X = _1a.next().value; //#22300
        $k[$j++] = _1X; //#22300
        $k[$j++] = _1W.get(_1X); //#22300
        $k[$j++] = Infinity; //#22300
        var _1c = $k[--$j]; //#22300
        var _1d = $k[--$j]; //#22300
        $k[$j++] = _1c; //#22300
        $k[$j++] = $get($1.CNvals, $1.sft2); //#22300
        $k[$j++] = _1d; //#22300
        var _1h = $a(); //#22300
        $k[$j++] = _1h; //#22300
    } //#22300
    var _1i = $1.C3vals; //#22301
    for (var _1n = _1i.size, _1m = _1i.keys(), _1l = 0; _1l < _1n; _1l++) { //#22301
        var _1j = _1m.next().value; //#22301
        $k[$j++] = _1j; //#22301
        $k[$j++] = _1i.get(_1j); //#22301
        $k[$j++] = Infinity; //#22301
        var _1o = $k[--$j]; //#22301
        var _1p = $k[--$j]; //#22301
        $k[$j++] = _1o; //#22301
        $k[$j++] = $get($1.CNvals, $1.sft3); //#22301
        $k[$j++] = _1p; //#22301
        var _1t = $a(); //#22301
        $k[$j++] = _1t; //#22301
    } //#22301
    $1.Cvals = $d(); //#22302
    $k[$j++] = Infinity; //#22310
    $k[$j++] = $1.sft1; //#22309
    $k[$j++] = 0; //#22309
    $k[$j++] = $1.sft2; //#22309
    $k[$j++] = 1; //#22309
    $k[$j++] = $1.sft3; //#22309
    $k[$j++] = 2; //#22309
    $k[$j++] = 32; //#22309
    $k[$j++] = 3; //#22309
    for (var _1y = 48; _1y <= 57; _1y += 1) { //#22309
        $k[$j++] = _1y; //#22309
        $k[$j++] = _1y - 44; //#22309
    } //#22309
    for (var _1z = 97; _1z <= 122; _1z += 1) { //#22310
        $k[$j++] = _1z; //#22310
        $k[$j++] = _1z - 83; //#22310
    } //#22310
    $1.TNvals = $d(); //#22311
    $k[$j++] = Infinity; //#22312
    for (var _21 = 0; _21 <= 31; _21 += 1) { //#22312
        $k[$j++] = _21; //#22312
        $k[$j++] = _21; //#22312
    } //#22312
    $1.T1vals = $d(); //#22312
    $k[$j++] = Infinity; //#22321
    for (var _23 = 33; _23 <= 47; _23 += 1) { //#22314
        $k[$j++] = _23; //#22314
        $k[$j++] = _23 - 33; //#22314
    } //#22314
    for (var _24 = 58; _24 <= 64; _24 += 1) { //#22315
        $k[$j++] = _24; //#22315
        $k[$j++] = _24 - 43; //#22315
    } //#22315
    for (var _25 = 91; _25 <= 95; _25 += 1) { //#22316
        $k[$j++] = _25; //#22316
        $k[$j++] = _25 - 69; //#22316
    } //#22316
    $k[$j++] = $1.fnc1; //#22321
    $k[$j++] = 27; //#22321
    $k[$j++] = $1.fnc2; //#22321
    $k[$j++] = 28; //#22321
    $k[$j++] = $1.fnc3; //#22321
    $k[$j++] = 29; //#22321
    $k[$j++] = $1.fnc4; //#22321
    $k[$j++] = 30; //#22321
    $k[$j++] = $1.pad; //#22321
    $k[$j++] = 31; //#22321
    $1.T2vals = $d(); //#22322
    $k[$j++] = Infinity; //#22326
    $k[$j++] = 96; //#22325
    $k[$j++] = 0; //#22325
    for (var _2C = 65; _2C <= 90; _2C += 1) { //#22325
        $k[$j++] = _2C; //#22325
        $k[$j++] = _2C - 64; //#22325
    } //#22325
    for (var _2D = 123; _2D <= 127; _2D += 1) { //#22326
        $k[$j++] = _2D; //#22326
        $k[$j++] = _2D - 96; //#22326
    } //#22326
    $1.T3vals = $d(); //#22327
    $k[$j++] = Infinity; //#22332
    var _2F = $1.TNvals; //#22329
    for (var _2K = _2F.size, _2J = _2F.keys(), _2I = 0; _2I < _2K; _2I++) { //#22329
        var _2G = _2J.next().value; //#22329
        $k[$j++] = _2G; //#22329
        $k[$j++] = _2F.get(_2G); //#22329
        $k[$j++] = Infinity; //#22329
        var _2L = $k[--$j]; //#22329
        var _2M = $k[--$j]; //#22329
        $k[$j++] = _2L; //#22329
        $k[$j++] = _2M; //#22329
        var _2N = $a(); //#22329
        $k[$j++] = _2N; //#22329
    } //#22329
    var _2O = $1.T1vals; //#22330
    for (var _2T = _2O.size, _2S = _2O.keys(), _2R = 0; _2R < _2T; _2R++) { //#22330
        var _2P = _2S.next().value; //#22330
        $k[$j++] = _2P; //#22330
        $k[$j++] = _2O.get(_2P); //#22330
        $k[$j++] = Infinity; //#22330
        var _2U = $k[--$j]; //#22330
        var _2V = $k[--$j]; //#22330
        $k[$j++] = _2U; //#22330
        $k[$j++] = $get($1.TNvals, $1.sft1); //#22330
        $k[$j++] = _2V; //#22330
        var _2Z = $a(); //#22330
        $k[$j++] = _2Z; //#22330
    } //#22330
    var _2a = $1.T2vals; //#22331
    for (var _2f = _2a.size, _2e = _2a.keys(), _2d = 0; _2d < _2f; _2d++) { //#22331
        var _2b = _2e.next().value; //#22331
        $k[$j++] = _2b; //#22331
        $k[$j++] = _2a.get(_2b); //#22331
        $k[$j++] = Infinity; //#22331
        var _2g = $k[--$j]; //#22331
        var _2h = $k[--$j]; //#22331
        $k[$j++] = _2g; //#22331
        $k[$j++] = $get($1.TNvals, $1.sft2); //#22331
        $k[$j++] = _2h; //#22331
        var _2l = $a(); //#22331
        $k[$j++] = _2l; //#22331
    } //#22331
    var _2m = $1.T3vals; //#22332
    for (var _2r = _2m.size, _2q = _2m.keys(), _2p = 0; _2p < _2r; _2p++) { //#22332
        var _2n = _2q.next().value; //#22332
        $k[$j++] = _2n; //#22332
        $k[$j++] = _2m.get(_2n); //#22332
        $k[$j++] = Infinity; //#22332
        var _2s = $k[--$j]; //#22332
        var _2t = $k[--$j]; //#22332
        $k[$j++] = _2s; //#22332
        $k[$j++] = $get($1.TNvals, $1.sft3); //#22332
        $k[$j++] = _2t; //#22332
        var _2x = $a(); //#22332
        $k[$j++] = _2x; //#22332
    } //#22332
    $1.Tvals = $d(); //#22333
    for (var _2z = 128; _2z <= 255; _2z += 1) { //#22341
        $1.i = _2z; //#22337
        $k[$j++] = $1.Avals; //#22338
        $k[$j++] = $1.i; //#22338
        $k[$j++] = Infinity; //#22338
        $aload($get($1.Avals, $1.fnc4)); //#22338
        $aload($get($1.Avals, $1.i - 128)); //#22338
        var _38 = $a(); //#22338
        var _39 = $k[--$j]; //#22338
        $put($k[--$j], _39, _38); //#22338
        $k[$j++] = $1.Cvals; //#22339
        $k[$j++] = $1.i; //#22339
        $k[$j++] = Infinity; //#22339
        $aload($get($1.Cvals, $1.fnc4)); //#22339
        $aload($get($1.Cvals, $1.i - 128)); //#22339
        var _3J = $a(); //#22339
        var _3K = $k[--$j]; //#22339
        $put($k[--$j], _3K, _3J); //#22339
        $k[$j++] = $1.Tvals; //#22340
        $k[$j++] = $1.i; //#22340
        $k[$j++] = Infinity; //#22340
        $aload($get($1.Tvals, $1.fnc4)); //#22340
        $aload($get($1.Tvals, $1.i - 128)); //#22340
        var _3U = $a(); //#22340
        var _3V = $k[--$j]; //#22340
        $put($k[--$j], _3V, _3U); //#22340
    } //#22340
    $k[$j++] = Infinity; //#22349
    $k[$j++] = 13; //#22348
    $k[$j++] = 0; //#22348
    $k[$j++] = 42; //#22348
    $k[$j++] = 1; //#22348
    $k[$j++] = 62; //#22348
    $k[$j++] = 2; //#22348
    $k[$j++] = 32; //#22348
    $k[$j++] = 3; //#22348
    for (var _3X = 48; _3X <= 57; _3X += 1) { //#22348
        $k[$j++] = _3X; //#22348
        $k[$j++] = _3X - 44; //#22348
    } //#22348
    for (var _3Y = 65; _3Y <= 90; _3Y += 1) { //#22349
        $k[$j++] = _3Y; //#22349
        $k[$j++] = _3Y - 51; //#22349
    } //#22349
    $1.Xvals = $d(); //#22350
    $k[$j++] = Infinity; //#22352
    var _3a = $1.Xvals; //#22352
    for (var _3f = _3a.size, _3e = _3a.keys(), _3d = 0; _3d < _3f; _3d++) { //#22352
        var _3b = _3e.next().value; //#22352
        $k[$j++] = _3b; //#22352
        $k[$j++] = _3a.get(_3b); //#22352
        $k[$j++] = Infinity; //#22352
        var _3g = $k[--$j]; //#22352
        var _3h = $k[--$j]; //#22352
        $k[$j++] = _3g; //#22352
        $k[$j++] = _3h; //#22352
        var _3i = $a(); //#22352
        $k[$j++] = _3i; //#22352
    } //#22352
    $1.Xvals = $d(); //#22353
    $k[$j++] = Infinity; //#22356
    for (var _3k = 0; _3k <= 255; _3k += 1) { //#22356
        $k[$j++] = _3k; //#22356
        $k[$j++] = _3k; //#22356
    } //#22356
    $1.Bvals = $d(); //#22357
    $k[$j++] = Infinity; //#22359
    var _3m = $1.Bvals; //#22359
    for (var _3r = _3m.size, _3q = _3m.keys(), _3p = 0; _3p < _3r; _3p++) { //#22359
        var _3n = _3q.next().value; //#22359
        $k[$j++] = _3n; //#22359
        $k[$j++] = _3m.get(_3n); //#22359
        $k[$j++] = Infinity; //#22359
        var _3s = $k[--$j]; //#22359
        var _3t = $k[--$j]; //#22359
        $k[$j++] = _3s; //#22359
        $k[$j++] = _3t; //#22359
        var _3u = $a(); //#22359
        $k[$j++] = _3u; //#22359
    } //#22359
    $1.Bvals = $d(); //#22360
    $1.encvals = $a([$1.Avals, $1.Cvals, $1.Tvals, $1.Xvals, -1, $1.Bvals]); //#22362
    $1.A = 0; //#22364
    $1.C = 1; //#22364
    $1.T = 2; //#22364
    $1.X = 3; //#22364
    $1.D = 4; //#22364
    $1.B = 5; //#22364
    if ($1.stype) { //#22849
        $1.normalize = function() {
            $1.base = $k[--$j]; //#22370
            $1.num = $k[--$j]; //#22371
            for (var _46 = $1.num.length - 1; _46 >= 1; _46 -= 1) { //#22376
                $1.i = _46; //#22373
                var _47 = $1.num; //#22374
                var _48 = $1.i; //#22374
                $put(_47, _48 - 1, $f($get(_47, _48 - 1) + (~~($get($1.num, $1.i) / $1.base)))); //#22374
                $put($1.num, $1.i, $get($1.num, $1.i) % $1.base); //#22375
            } //#22375
            for (;;) { //#22382
                if ($lt($get($1.num, 0), $1.base)) { //#22378
                    break; //#22378
                } //#22378
                $k[$j++] = Infinity; //#22379
                $k[$j++] = 0; //#22379
                $forall($1.num); //#22379
                $1.num = $a(); //#22379
                $put($1.num, 0, $f($get($1.num, 0) + (~~($get($1.num, 1) / $1.base)))); //#22380
                $put($1.num, 1, $get($1.num, 1) % $1.base); //#22381
            } //#22381
            $k[$j++] = Infinity; //#22384
            $1.i = true; //#22384
            var _4Z = $1.num; //#22384
            for (var _4a = 0, _4b = _4Z.length; _4a < _4b; _4a++) { //#22384
                var _4c = $get(_4Z, _4a); //#22384
                $k[$j++] = _4c; //#22384
                if ((_4c == 0) && $1.i) { //#22384
                    $j--; //#22384
                } else { //#22384
                    $1.i = false; //#22384
                } //#22384
            } //#22384
            $1.num = $a(); //#22384
            if ($1.num.length == 0) { //#22385
                $1.num = $a([0]); //#22385
            } //#22385
            $k[$j++] = $1.num; //#22386
        }; //#22386
        $1.bigadd = function() {
            var _4i = $k[--$j]; //#22390
            var _4j = $k[--$j]; //#22390
            $1.offset = Math.abs(_4i.length - _4j.length); //#22391
            if (_4i.length < _4j.length) { //#22392
                var _ = _4i; //#22392
                _4i = _4j; //#22392
                _4j = _; //#22392
            } //#22392
            $1.a = _4i; //#22393
            $1.b = _4j; //#22393
            for (var _4m = 0, _4l = $1.b.length - 1; _4m <= _4l; _4m += 1) { //#22396
                var _4n = $1.a; //#22395
                var _4o = $1.offset; //#22395
                $put(_4n, _4m + _4o, $f($get(_4n, _4m + _4o) + $get($1.b, _4m))); //#22395
            } //#22395
            $k[$j++] = $1.a; //#22397
        }; //#22397
        $1.barlen = $1.barcode.length; //#22400
        $1.v = $a([1]); //#22403
        for (var _4x = 0, _4w = $1.barlen - 1; _4x <= _4w; _4x += 1) { //#22408
            $1.i = _4x; //#22405
            $k[$j++] = Infinity; //#22406
            $forall($get($1.stypevals, $1.i), function() { //#22406
                var _51 = $k[--$j]; //#22406
                $k[$j++] = $f(_51 - 48) * $f($get($1.barcode, ($1.barlen - $1.i) - 1) - 48); //#22406
            }); //#22406
            var _56 = $a(); //#22406
            $k[$j++] = _56; //#22407
            $k[$j++] = $1.v; //#22407
            $1.bigadd(); //#22407
            $1.v = $k[--$j]; //#22407
        } //#22407
        $k[$j++] = 'v'; //#22409
        $k[$j++] = $1.v; //#22409
        $k[$j++] = 2; //#22409
        $1.normalize(); //#22409
        var _5A = $k[--$j]; //#22409
        $1[$k[--$j]] = _5A; //#22409
        $k[$j++] = Infinity; //#22412
        for (var _5D = 0, _5E = (5 - ($1.v.length % 5)) % 5; _5D < _5E; _5D++) { //#22412
            $k[$j++] = 0; //#22412
        } //#22412
        $aload($1.v); //#22412
        $1.v = $a(); //#22412
        $1.cws = $a(~~($1.v.length / 5)); //#22413
        for (var _5L = 0, _5K = $1.cws.length - 1; _5L <= _5K; _5L += 1) { //#22419
            $1.i = _5L; //#22415
            var _5O = $geti($1.v, $1.i * 5, 5); //#22416
            $k[$j++] = 0; //#22417
            for (var _5P = 0, _5Q = _5O.length; _5P < _5Q; _5P++) { //#22417
                var _5S = $k[--$j]; //#22417
                $k[$j++] = $f(_5S + $get(_5O, _5P)) * 2; //#22417
            } //#22417
            $put($1.cws, $1.i, ~~($k[--$j] / 2)); //#22418
        } //#22418
        $1.metrics = $1.stypemetrics; //#22421
    } else { //#22849
        var _5b = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["eci", true],
            ["FNC1", $1.fnc1],
            ["FNC3", $1.fnc3]
        ]); //#22431
        $1.fncvals = _5b; //#22432
        $k[$j++] = 'msg'; //#22433
        $k[$j++] = $1.barcode; //#22433
        $k[$j++] = $1.fncvals; //#22433
        bwipp_parseinput(); //#22433
        var _5e = $k[--$j]; //#22433
        $1[$k[--$j]] = _5e; //#22433
        $1.msglen = $1.msg.length; //#22434
        $1.eciesc = 92; //#22437
        var _5h = $1.msg; //#22438
        $k[$j++] = 'numecis'; //#22438
        $k[$j++] = 0; //#22438
        for (var _5i = 0, _5j = _5h.length; _5i < _5j; _5i++) { //#22438
            if ($get(_5h, _5i) <= -1000000) { //#22438
                var _5l = $k[--$j]; //#22438
                $k[$j++] = $f(_5l + 1); //#22438
            } //#22438
        } //#22438
        var _5m = $k[--$j]; //#22438
        $1[$k[--$j]] = _5m; //#22438
        if ($1.numecis > 0) { //#22465
            $1.msgtmp = $a($f(($f(($1.msg.length * 2) + ($1.numecis * 6))) + 2)); //#22440
            $put($1.msgtmp, 0, $1.pad); //#22441
            $put($1.msgtmp, 1, $1.eciesc); //#22442
            $1.j = 2; //#22443
            for (var _5y = 0, _5x = $1.msg.length - 1; _5y <= _5x; _5y += 1) { //#22462
                var _60 = $get($1.msg, _5y); //#22445
                $k[$j++] = _60; //#22461
                if (_60 <= -1000000) { //#22459
                    var _64 = $geti($cvrs($s(7), -$k[--$j], 10), 1, 6); //#22447
                    for (var _65 = 0, _66 = _64.length; _65 < _66; _65++) { //#22447
                        $k[$j++] = $get(_64, _65); //#22447
                    } //#22447
                    $astore($a(6)); //#22447
                    $puti($1.msgtmp, $1.j + 1, $k[--$j]); //#22448
                    $put($1.msgtmp, $1.j, $1.eciesc); //#22449
                    $1.j = $1.j + 7; //#22450
                } else { //#22459
                    var _6G = $k[--$j]; //#22452
                    $k[$j++] = _6G; //#22460
                    if (_6G != $1.eciesc) { //#22459
                        $put($1.msgtmp, $1.j, $k[--$j]); //#22453
                        $1.j = $1.j + 1; //#22454
                    } else { //#22459
                        $j--; //#22456
                        $put($1.msgtmp, $1.j, $1.eciesc); //#22457
                        $put($1.msgtmp, $1.j + 1, $1.eciesc); //#22458
                        $1.j = $1.j + 2; //#22459
                    } //#22459
                } //#22459
            } //#22459
            $1.msg = $geti($1.msgtmp, 0, $1.j); //#22463
            $1.msglen = $1.msg.length; //#22464
        } //#22464
        $1.metrics = $1.nonstypemetrics; //#22467
        $1.fullcws = $a([]); //#22470
        var _6Z = $1.metrics; //#22471
        for (var _6a = 0, _6b = _6Z.length; _6a < _6b; _6a++) { //#22482
            $1.m = $get(_6Z, _6a); //#22472
            $1.vers = $get($1.m, 0); //#22473
            $1.dcws = $get($1.m, 4); //#22474
            $1.okay = true; //#22475
            if ($eq($1.version, "unset")) { //#22479
                if ($1.vers.length != 1) { //#22477
                    $1.okay = false; //#22477
                } //#22477
            } else { //#22479
                if ($ne($1.version, $1.vers)) { //#22479
                    $1.okay = false; //#22479
                } //#22479
            } //#22479
            if ($1.okay) { //#22481
                $k[$j++] = Infinity; //#22481
                $aload($1.fullcws); //#22481
                $k[$j++] = $1.dcws; //#22481
                $1.fullcws = $a(); //#22481
            } //#22481
        } //#22481
        $k[$j++] = Infinity; //#22483
        for (var _6p = 0, _6q = 1480; _6p < _6q; _6p++) { //#22483
            $k[$j++] = 10000; //#22483
        } //#22483
        $1.numremcws = $a(); //#22483
        var _6s = $1.fullcws; //#22484
        for (var _6t = 0, _6u = _6s.length; _6t < _6u; _6t++) { //#22484
            $put($1.numremcws, $f($get(_6s, _6t) - 1), 1); //#22484
        } //#22484
        for (var _6x = 1478; _6x >= 0; _6x -= 1) { //#22490
            $1.i = _6x; //#22486
            if ($get($1.numremcws, $1.i) != 1) { //#22489
                $put($1.numremcws, $1.i, $f($get($1.numremcws, $1.i + 1) + 1)); //#22488
            } //#22488
        } //#22488
        $k[$j++] = Infinity; //#22492
        for (var _77 = 0, _78 = $1.msglen; _77 < _78; _77++) { //#22492
            $k[$j++] = 0; //#22492
        } //#22492
        $k[$j++] = 0; //#22492
        $1.numD = $a(); //#22492
        $k[$j++] = Infinity; //#22493
        for (var _7B = 0, _7C = $1.msglen; _7B < _7C; _7B++) { //#22493
            $k[$j++] = 0; //#22493
        } //#22493
        $k[$j++] = 9999; //#22493
        $1.nextXterm = $a(); //#22493
        $k[$j++] = Infinity; //#22494
        for (var _7F = 0, _7G = $1.msglen; _7F < _7G; _7F++) { //#22494
            $k[$j++] = 0; //#22494
        } //#22494
        $k[$j++] = 9999; //#22494
        $1.nextNonX = $a(); //#22494
        for (var _7J = $1.msglen - 1; _7J >= 0; _7J -= 1) { //#22511
            $1.i = _7J; //#22496
            $1.barchar = $get($1.msg, $1.i); //#22497
            if (($1.barchar >= 48) && ($1.barchar <= 57)) { //#22500
                $put($1.numD, $1.i, $f($get($1.numD, $1.i + 1) + 1)); //#22499
            } //#22499
            if ((($1.barchar == 13) || ($1.barchar == 42)) || ($1.barchar == 62)) { //#22504
                $put($1.nextXterm, $1.i, 0); //#22502
            } else { //#22504
                $put($1.nextXterm, $1.i, $f($get($1.nextXterm, $1.i + 1) + 1)); //#22504
            } //#22504
            var _7g = $get($1.Xvals, $1.barchar) !== undefined; //#22506
            if (!_7g) { //#22509
                $put($1.nextNonX, $1.i, 0); //#22507
            } else { //#22509
                $put($1.nextNonX, $1.i, $f($get($1.nextNonX, $1.i + 1) + 1)); //#22509
            } //#22509
        } //#22509
        $k[$j++] = Infinity; //#22512
        var _7o = $1.nextXterm; //#22512
        for (var _7p = 0, _7q = _7o.length; _7p < _7q; _7p++) { //#22512
            var _7r = $get(_7o, _7p); //#22512
            $k[$j++] = _7r; //#22512
            if (_7r > 10000) { //#22512
                $j--; //#22512
                $k[$j++] = 10000; //#22512
            } //#22512
        } //#22512
        $1.nextXterm = $a(); //#22512
        $k[$j++] = Infinity; //#22513
        var _7t = $1.nextNonX; //#22513
        for (var _7u = 0, _7v = _7t.length; _7u < _7v; _7u++) { //#22513
            var _7w = $get(_7t, _7u); //#22513
            $k[$j++] = _7w; //#22513
            if (_7w > 10000) { //#22513
                $j--; //#22513
                $k[$j++] = 10000; //#22513
            } //#22513
        } //#22513
        $1.nextNonX = $a(); //#22513
        $1.isD = function() {
            $k[$j++] = ($1.char >= 48) && ($1.char <= 57); //#22515
        }; //#22515
        $1.isC = function() {
            var _82 = $get($1.CNvals, $1.char) !== undefined; //#22516
            $k[$j++] = _82; //#22516
        }; //#22516
        $1.isT = function() {
            var _85 = $get($1.TNvals, $1.char) !== undefined; //#22517
            $k[$j++] = _85; //#22517
        }; //#22517
        $1.isX = function() {
            var _88 = $get($1.Xvals, $1.char) !== undefined; //#22518
            $k[$j++] = _88; //#22518
        }; //#22518
        $1.isEA = function() {
            $k[$j++] = $1.char > 127; //#22519
        }; //#22519
        $1.isFN = function() {
            $k[$j++] = $1.char < 0; //#22520
        }; //#22520
        $1.XtermFirst = function() {
            var _8B = $k[--$j]; //#22521
            $k[$j++] = $lt($get($1.nextXterm, _8B), $get($1.nextNonX, _8B)); //#22521
        }; //#22521
        $1.lookup = function() {
            $1.ac = 1; //#22524
            $1.cc = 2; //#22524
            $1.tc = 2; //#22524
            $1.xc = 2; //#22524
            $1.bc = 3; //#22524
            if ($1.mode == $1.A) { //#22525
                $1.ac = 0; //#22525
                $1.cc = 1; //#22525
                $1.tc = 1; //#22525
                $1.xc = 1; //#22525
                $1.bc = 2; //#22525
            } //#22525
            if ($1.mode == $1.C) { //#22526
                $1.cc = 0; //#22526
            } //#22526
            if ($1.mode == $1.T) { //#22527
                $1.tc = 0; //#22527
            } //#22527
            if ($1.mode == $1.X) { //#22528
                $1.xc = 0; //#22528
            } //#22528
            if ($1.mode == $1.B) { //#22529
                $1.bc = 0; //#22529
            } //#22529
            for (var _8Q = 0, _8R = 1; _8Q < _8R; _8Q++) { //#22557
                $1.k = 0; //#22531
                for (;;) { //#22556
                    if (($1.i + $1.k) == $1.msglen) { //#22538
                        var _8Z = $a([$1.ac, $1.cc, $1.tc, $1.xc]); //#22533
                        $k[$j++] = true; //#22533
                        for (var _8a = 0, _8b = _8Z.length; _8a < _8b; _8a++) { //#22533
                            var _8e = $k[--$j]; //#22533
                            $k[$j++] = _8e && ($1.bc <= Math.ceil($get(_8Z, _8a))); //#22533
                        } //#22533
                        if ($k[--$j]) { //#22533
                            $k[$j++] = $1.B; //#22533
                            break; //#22533
                        } //#22533
                        var _8l = $a([$1.cc, $1.tc, $1.xc, $1.bc]); //#22534
                        $k[$j++] = true; //#22534
                        for (var _8m = 0, _8n = _8l.length; _8m < _8n; _8m++) { //#22534
                            var _8q = $k[--$j]; //#22534
                            $k[$j++] = _8q && ($1.ac <= Math.ceil($get(_8l, _8m))); //#22534
                        } //#22534
                        if ($k[--$j]) { //#22534
                            $k[$j++] = $1.A; //#22534
                            break; //#22534
                        } //#22534
                        var _8v = $a([$1.tc, $1.xc]); //#22535
                        $k[$j++] = true; //#22535
                        for (var _8w = 0, _8x = _8v.length; _8w < _8x; _8w++) { //#22535
                            var _90 = $k[--$j]; //#22535
                            $k[$j++] = _90 && (Math.ceil($1.cc) <= Math.ceil($get(_8v, _8w))); //#22535
                        } //#22535
                        if ($k[--$j]) { //#22535
                            $k[$j++] = $1.C; //#22535
                            break; //#22535
                        } //#22535
                        var _94 = $a([$1.xc]); //#22536
                        $k[$j++] = true; //#22536
                        for (var _95 = 0, _96 = _94.length; _95 < _96; _95++) { //#22536
                            var _99 = $k[--$j]; //#22536
                            $k[$j++] = _99 && (Math.ceil($1.tc) <= Math.ceil($get(_94, _95))); //#22536
                        } //#22536
                        if ($k[--$j]) { //#22536
                            $k[$j++] = $1.T; //#22536
                            break; //#22536
                        } //#22536
                        $k[$j++] = $1.X; //#22537
                        break; //#22537
                    } //#22537
                    $1.char = $get($1.msg, $1.i + $1.k); //#22539
                    $k[$j++] = 'ac'; //#22540
                    $k[$j++] = $1.ac; //#22540
                    $1.isD(); //#22540
                    if ($k[--$j]) { //#22540
                        var _9J = $k[--$j]; //#22540
                        $k[$j++] = $f(_9J + (1 / 2)); //#22540
                    } else { //#22540
                        $1.isEA(); //#22540
                        if ($k[--$j]) { //#22540
                            var _9L = $k[--$j]; //#22540
                            $k[$j++] = Math.ceil(_9L) + 2; //#22540
                        } else { //#22540
                            var _9M = $k[--$j]; //#22540
                            $k[$j++] = Math.ceil(_9M) + 1; //#22540
                        } //#22540
                    } //#22540
                    var _9N = $k[--$j]; //#22540
                    $1[$k[--$j]] = _9N; //#22540
                    $k[$j++] = 'cc'; //#22541
                    $k[$j++] = $1.cc; //#22541
                    $1.isC(); //#22541
                    if ($k[--$j]) { //#22541
                        var _9R = $k[--$j]; //#22541
                        $k[$j++] = $f(_9R + 0.6666667); //#22541
                    } else { //#22541
                        $1.isEA(); //#22541
                        if ($k[--$j]) { //#22541
                            var _9T = $k[--$j]; //#22541
                            $k[$j++] = $f(_9T + 2.6666667); //#22541
                        } else { //#22541
                            var _9U = $k[--$j]; //#22541
                            $k[$j++] = $f(_9U + 1.3333334); //#22541
                        } //#22541
                    } //#22541
                    var _9V = $k[--$j]; //#22541
                    $1[$k[--$j]] = _9V; //#22541
                    $k[$j++] = 'tc'; //#22542
                    $k[$j++] = $1.tc; //#22542
                    $1.isT(); //#22542
                    if ($k[--$j]) { //#22542
                        var _9Z = $k[--$j]; //#22542
                        $k[$j++] = $f(_9Z + 0.6666667); //#22542
                    } else { //#22542
                        $1.isEA(); //#22542
                        if ($k[--$j]) { //#22542
                            var _9b = $k[--$j]; //#22542
                            $k[$j++] = $f(_9b + 2.6666667); //#22542
                        } else { //#22542
                            var _9c = $k[--$j]; //#22542
                            $k[$j++] = $f(_9c + 1.3333334); //#22542
                        } //#22542
                    } //#22542
                    var _9d = $k[--$j]; //#22542
                    $1[$k[--$j]] = _9d; //#22542
                    $k[$j++] = 'xc'; //#22543
                    $k[$j++] = $1.xc; //#22543
                    $1.isX(); //#22543
                    if ($k[--$j]) { //#22543
                        var _9h = $k[--$j]; //#22543
                        $k[$j++] = $f(_9h + 0.6666667); //#22543
                    } else { //#22543
                        $1.isEA(); //#22543
                        if ($k[--$j]) { //#22543
                            var _9j = $k[--$j]; //#22543
                            $k[$j++] = $f(_9j + 4.3333334); //#22543
                        } else { //#22543
                            var _9k = $k[--$j]; //#22543
                            $k[$j++] = $f(_9k + 3.3333334); //#22543
                        } //#22543
                    } //#22543
                    var _9l = $k[--$j]; //#22543
                    $1[$k[--$j]] = _9l; //#22543
                    $k[$j++] = 'bc'; //#22544
                    $k[$j++] = $1.bc; //#22544
                    $1.isFN(); //#22544
                    if ($k[--$j]) { //#22544
                        var _9p = $k[--$j]; //#22544
                        $k[$j++] = $f(_9p + 3); //#22544
                    } else { //#22544
                        var _9q = $k[--$j]; //#22544
                        $k[$j++] = $f(_9q + 1); //#22544
                    } //#22544
                    var _9r = $k[--$j]; //#22544
                    $1[$k[--$j]] = _9r; //#22544
                    if ($1.k >= 3) { //#22554
                        var _9y = $a([$1.ac, $1.cc, $1.tc, $1.xc]); //#22546
                        $k[$j++] = true; //#22546
                        for (var _9z = 0, _A0 = _9y.length; _9z < _A0; _9z++) { //#22546
                            var _A3 = $k[--$j]; //#22546
                            $k[$j++] = _A3 && (($1.bc + 1) <= Math.ceil($get(_9y, _9z))); //#22546
                        } //#22546
                        if ($k[--$j]) { //#22546
                            $k[$j++] = $1.B; //#22546
                            break; //#22546
                        } //#22546
                        var _AA = $a([$1.cc, $1.tc, $1.xc, $1.bc]); //#22547
                        $k[$j++] = true; //#22547
                        for (var _AB = 0, _AC = _AA.length; _AB < _AC; _AB++) { //#22547
                            var _AF = $k[--$j]; //#22547
                            $k[$j++] = _AF && (($1.ac + 1) <= Math.ceil($get(_AA, _AB))); //#22547
                        } //#22547
                        if ($k[--$j]) { //#22547
                            $k[$j++] = $1.A; //#22547
                            break; //#22547
                        } //#22547
                        var _AM = $a([$1.ac, $1.cc, $1.xc, $1.bc]); //#22548
                        $k[$j++] = true; //#22548
                        for (var _AN = 0, _AO = _AM.length; _AN < _AO; _AN++) { //#22548
                            var _AR = $k[--$j]; //#22548
                            $k[$j++] = _AR && ((Math.ceil($1.tc) + 1) <= Math.ceil($get(_AM, _AN))); //#22548
                        } //#22548
                        if ($k[--$j]) { //#22548
                            $k[$j++] = $1.T; //#22548
                            break; //#22548
                        } //#22548
                        var _AW = $a([$1.ac, $1.tc]); //#22549
                        $k[$j++] = true; //#22549
                        for (var _AX = 0, _AY = _AW.length; _AX < _AY; _AX++) { //#22549
                            var _Ab = $k[--$j]; //#22549
                            $k[$j++] = _Ab && ((Math.ceil($1.cc) + 1) <= Math.ceil($get(_AW, _AX))); //#22549
                        } //#22549
                        if ($k[--$j]) { //#22552
                            if (Math.ceil($1.cc) < Math.ceil($1.xc)) { //#22550
                                $k[$j++] = $1.C; //#22550
                                break; //#22550
                            } //#22550
                            if ($1.cc == $1.xc) { //#22551
                                $k[$j++] = ($1.i + $1.k) + 1; //#22551
                                $1.XtermFirst(); //#22551
                                if ($k[--$j]) { //#22551
                                    $k[$j++] = $1.X; //#22551
                                    break; //#22551
                                } else { //#22551
                                    $k[$j++] = $1.C; //#22551
                                    break; //#22551
                                } //#22551
                            } //#22551
                        } //#22551
                        var _Ar = $a([$1.ac, $1.cc, $1.tc, $1.bc]); //#22553
                        $k[$j++] = true; //#22553
                        for (var _As = 0, _At = _Ar.length; _As < _At; _As++) { //#22553
                            var _Aw = $k[--$j]; //#22553
                            $k[$j++] = _Aw && ((Math.ceil($1.xc) + 1) <= Math.ceil($get(_Ar, _As))); //#22553
                        } //#22553
                        if ($k[--$j]) { //#22553
                            $k[$j++] = $1.X; //#22553
                            break; //#22553
                        } //#22553
                    } //#22553
                    $1.k = $1.k + 1; //#22555
                } //#22555
            } //#22555
        }; //#22555
        $1.addtocws = function() {
            var _B0 = $k[--$j]; //#22561
            $puti($1.cws, $1.j, _B0); //#22561
            $1.j = _B0.length + $1.j; //#22562
        }; //#22562
        $1.tobin = function() {
            var _B5 = $s($k[--$j]); //#22566
            $k[$j++] = _B5; //#22566
            for (var _B7 = 0, _B6 = _B5.length - 1; _B7 <= _B6; _B7 += 1) { //#22566
                var _B8 = $k[--$j]; //#22566
                $put(_B8, _B7, 48); //#22566
                $k[$j++] = _B8; //#22566
            } //#22566
            var _B9 = $k[--$j]; //#22567
            var _BC = $cvrs($s(_B9.length), $k[--$j], 2); //#22567
            $puti(_B9, _B9.length - _BC.length, _BC); //#22567
            $k[$j++] = _B9; //#22568
            $k[$j++] = Infinity; //#22568
            var _BD = $k[--$j]; //#22568
            var _BE = $k[--$j]; //#22568
            $k[$j++] = _BD; //#22568
            $forall(_BE, function() { //#22568
                var _BF = $k[--$j]; //#22568
                $k[$j++] = $f(_BF - 48); //#22568
            }); //#22568
            var _BG = $a(); //#22568
            $k[$j++] = _BG; //#22568
        }; //#22568
        $1.encA = function() {
            for (var _BH = 0, _BI = 1; _BH < _BI; _BH++) { //#22613
                if ($get($1.numD, $1.i) >= 21) { //#22577
                    $1.Dbits = $a([1, 1, 1, 1]); //#22574
                    $1.mode = $1.D; //#22575
                    break; //#22576
                } //#22576
                var _BQ = $get($1.numD, $1.i); //#22578
                if ((_BQ >= 13) && ($f(_BQ + $1.i) == $1.msglen)) { //#22582
                    $1.Dbits = $a([1, 1, 1, 1]); //#22579
                    $1.mode = $1.D; //#22580
                    break; //#22581
                } //#22581
                if ($get($1.numD, $1.i) >= 2) { //#22587
                    var _BY = $s(2); //#22584
                    $put(_BY, 0, $get($1.msg, $1.i)); //#22584
                    $put(_BY, 1, $get($1.msg, $1.i + 1)); //#22584
                    $k[$j++] = $get($1.Avals, _BY); //#22584
                    $1.addtocws(); //#22584
                    $1.i = $1.i + 2; //#22585
                    break; //#22586
                } //#22586
                if ($get($1.msg, $1.i) == $1.fnc1) { //#22603
                    if ($get($1.numD, $1.i + 1) >= 15) { //#22595
                        $k[$j++] = $get($1.Avals, $1.fnc1lD); //#22590
                        $1.addtocws(); //#22590
                        $1.i = $1.i + 1; //#22591
                        $1.Dbits = $a([]); //#22592
                        $1.mode = $1.D; //#22593
                        break; //#22594
                    } //#22594
                    var _Bx = $get($1.numD, $1.i + 1); //#22596
                    if ((_Bx >= 7) && (($f($f(_Bx + $1.i) + 1)) == $1.msglen)) { //#22602
                        $k[$j++] = $get($1.Avals, $1.fnc1lD); //#22597
                        $1.addtocws(); //#22597
                        $1.i = $1.i + 1; //#22598
                        $1.Dbits = $a([]); //#22599
                        $1.mode = $1.D; //#22600
                        break; //#22601
                    } //#22601
                } //#22601
                $k[$j++] = 'newmode'; //#22604
                $1.lookup(); //#22604
                var _C6 = $k[--$j]; //#22604
                $1[$k[--$j]] = _C6; //#22604
                if ($1.newmode != $1.mode) { //#22609
                    $k[$j++] = $get($1.Avals, $get($a([-1, $1.lC, $1.lT, $1.lX, $1.lD, $1.lB]), $1.newmode)); //#22606
                    $1.addtocws(); //#22606
                    $1.mode = $1.newmode; //#22607
                    break; //#22608
                } //#22608
                $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#22610
                $1.addtocws(); //#22610
                $1.i = $1.i + 1; //#22611
                break; //#22612
            } //#22612
        }; //#22612
        $1.CTXvalstocws = function() {
            $1.in = $k[--$j]; //#22617
            $k[$j++] = Infinity; //#22618
            for (var _CU = 0, _CT = $1.in.length - 1; _CU <= _CT; _CU += 3) { //#22622
                var _CW = $geti($1.in, _CU, 3); //#22620
                $k[$j++] = 0; //#22620
                for (var _CX = 0, _CY = _CW.length; _CX < _CY; _CX++) { //#22620
                    var _Ca = $k[--$j]; //#22620
                    $k[$j++] = $f(_Ca + $get(_CW, _CX)) * 40; //#22620
                } //#22620
                var _Cc = (~~($k[--$j] / 40)) + 1; //#22621
                $k[$j++] = ~~(_Cc / 256); //#22621
                $k[$j++] = _Cc % 256; //#22621
            } //#22621
            $astore($a($counttomark())); //#22623
            var _Cf = $k[--$j]; //#22623
            var _Cg = $k[--$j]; //#22623
            $k[$j++] = _Cf; //#22623
            $k[$j++] = _Cg; //#22623
            $j--; //#22623
        }; //#22623
        $1.encCTX = function() {
            $1.p = 0; //#22627
            $1.ctxvals = $a(2220); //#22628
            for (;;) { //#22725
                if ($1.i == $1.msglen) { //#22632
                    break; //#22632
                } //#22632
                if (($1.p % 3) == 0) { //#22720
                    if ($get($1.numD, $1.i) >= 12) { //#22639
                        $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22635
                        $1.CTXvalstocws(); //#22635
                        $1.addtocws(); //#22635
                        $k[$j++] = $a([$1.unlcw]); //#22636
                        $1.addtocws(); //#22636
                        $1.mode = $1.A; //#22637
                        break; //#22638
                    } //#22638
                    var _Cw = $get($1.numD, $1.i); //#22640
                    if ((_Cw >= 8) && ($f(_Cw + $1.i) == $1.msglen)) { //#22645
                        $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22641
                        $1.CTXvalstocws(); //#22641
                        $1.addtocws(); //#22641
                        $k[$j++] = $a([$1.unlcw]); //#22642
                        $1.addtocws(); //#22642
                        $1.mode = $1.A; //#22643
                        break; //#22644
                    } //#22644
                    if ($1.mode == $1.X) { //#22667
                        var _DB = $get($1.Xvals, $get($1.msg, $1.i)) !== undefined; //#22647
                        if (!_DB) { //#22655
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22648
                            $1.CTXvalstocws(); //#22648
                            $1.addtocws(); //#22648
                            if (($get($1.numremcws, $1.j) != 1) || ($get($1.msg, $1.i) > 127)) { //#22652
                                $k[$j++] = $a([$1.unlcw]); //#22651
                                $1.addtocws(); //#22651
                            } //#22651
                            $1.mode = $1.A; //#22653
                            break; //#22654
                        } //#22654
                        if (($1.i + 1) < $1.msglen) { //#22661
                            var _DU = $get($1.Xvals, $get($1.msg, $1.i + 1)) !== undefined; //#22657
                            if (!_DU) { //#22657
                                break; //#22657
                            } //#22657
                            if (($1.i + 2) < $1.msglen) { //#22660
                                var _Db = $get($1.Xvals, $get($1.msg, $1.i + 2)) !== undefined; //#22659
                                if (!_Db) { //#22659
                                    break; //#22659
                                } //#22659
                            } //#22659
                        } //#22659
                    } else { //#22667
                        $1.lookup(); //#22663
                        if ($k[--$j] != $1.mode) { //#22668
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22664
                            $1.CTXvalstocws(); //#22664
                            $1.addtocws(); //#22664
                            $k[$j++] = $a([$1.unlcw]); //#22665
                            $1.addtocws(); //#22665
                            $1.mode = $1.A; //#22666
                            break; //#22667
                        } //#22667
                    } //#22667
                    if (($1.msglen - $1.i) <= 3) { //#22719
                        $1.remcws = $get($1.numremcws, $1.j + ((~~($1.p / 3)) * 2)); //#22671
                        $k[$j++] = Infinity; //#22677
                        var _Du = $geti($1.msg, $1.i, $1.msglen - $1.i); //#22673
                        for (var _Dv = 0, _Dw = _Du.length; _Dv < _Dw; _Dv++) { //#22679
                            var _Dx = $get(_Du, _Dv); //#22679
                            var _E1 = $get($get($1.encvals, $1.mode), _Dx) !== undefined; //#22674
                            $k[$j++] = _Dx; //#22678
                            if (_E1) { //#22677
                                $aload($get($get($1.encvals, $1.mode), $k[--$j])); //#22675
                            } else { //#22677
                                $j--; //#22677
                                $k[$j++] = -1; //#22677
                                $k[$j++] = -1; //#22677
                                $k[$j++] = -1; //#22677
                                $k[$j++] = -1; //#22677
                            } //#22677
                        } //#22677
                        $1.remvals = $a(); //#22677
                        if (($1.remcws == 2) && ($1.remvals.length == 3)) { //#22690
                            $k[$j++] = Infinity; //#22685
                            $aload($geti($1.ctxvals, 0, $1.p)); //#22684
                            $aload($1.remvals); //#22685
                            var _EE = $a(); //#22685
                            $k[$j++] = _EE; //#22686
                            $1.CTXvalstocws(); //#22686
                            $1.addtocws(); //#22686
                            $1.mode = $1.A; //#22687
                            $1.i = $1.msglen; //#22688
                            break; //#22689
                        } //#22689
                        if ((($1.remcws == 2) && ($1.remvals.length == 2)) && ($1.mode != $1.X)) { //#22701
                            $k[$j++] = Infinity; //#22696
                            $aload($geti($1.ctxvals, 0, $1.p)); //#22694
                            $aload($1.remvals); //#22695
                            $aload($get($get($1.encvals, $1.mode), $1.sft1)); //#22696
                            var _EU = $a(); //#22696
                            $k[$j++] = _EU; //#22697
                            $1.CTXvalstocws(); //#22697
                            $1.addtocws(); //#22697
                            $1.mode = $1.A; //#22698
                            $1.i = $1.msglen; //#22699
                            break; //#22700
                        } //#22700
                        if (($1.remcws == 2) && ($1.remvals.length == 1)) { //#22710
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22704
                            $1.CTXvalstocws(); //#22704
                            $1.addtocws(); //#22704
                            $k[$j++] = $a([$1.unlcw]); //#22705
                            $1.addtocws(); //#22705
                            $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#22706
                            $1.addtocws(); //#22706
                            $1.mode = $1.A; //#22707
                            $1.i = $1.msglen; //#22708
                            break; //#22709
                        } //#22709
                        if (($1.remcws == 1) && ($1.remvals.length == 1)) { //#22718
                            $k[$j++] = $geti($1.ctxvals, 0, $1.p); //#22713
                            $1.CTXvalstocws(); //#22713
                            $1.addtocws(); //#22713
                            $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#22714
                            $1.addtocws(); //#22714
                            $1.mode = $1.A; //#22715
                            $1.i = $1.msglen; //#22716
                            break; //#22717
                        } //#22717
                    } //#22717
                } //#22717
                var _F3 = $get($get($1.encvals, $1.mode), $get($1.msg, $1.i)); //#22721
                $puti($1.ctxvals, $1.p, _F3); //#22722
                $1.p = _F3.length + $1.p; //#22723
                $1.i = $1.i + 1; //#22724
            } //#22724
            if ($1.mode != $1.A) { //#22749
                for (;;) { //#22733
                    if (($1.p % 3) == 0) { //#22730
                        break; //#22730
                    } //#22730
                    $1.i = $1.i - 1; //#22731
                    $1.p = $1.p - $get($get($1.encvals, $1.mode), $get($1.msg, $1.i)).length; //#22732
                } //#22732
                $k[$j++] = Infinity; //#22735
                $aload($geti($1.ctxvals, 0, $1.p)); //#22735
                var _FN = $a(); //#22735
                $k[$j++] = _FN; //#22736
                $1.CTXvalstocws(); //#22736
                $1.addtocws(); //#22736
                $k[$j++] = $a([$1.unlcw]); //#22737
                $1.addtocws(); //#22737
                $1.mode = $1.A; //#22738
                if ($1.i != $1.msglen) { //#22748
                    if ($get($1.numD, $1.i) >= 2) { //#22746
                        var _FW = $s(2); //#22742
                        $put(_FW, 0, $get($1.msg, $1.i)); //#22742
                        $put(_FW, 1, $get($1.msg, $1.i + 1)); //#22742
                        $k[$j++] = $get($1.Avals, _FW); //#22742
                        $1.addtocws(); //#22742
                        $1.i = $1.i + 2; //#22743
                    } else { //#22746
                        $k[$j++] = $get($1.Avals, $get($1.msg, $1.i)); //#22745
                        $1.addtocws(); //#22745
                        $1.i = $1.i + 1; //#22746
                    } //#22746
                } //#22746
            } //#22746
        }; //#22746
        $1.encD = function() {
            for (;;) { //#22810
                if ($get($1.numD, $1.i) < 3) { //#22800
                    $1.Drem = (8 - ($1.Dbits.length % 8)) % 8; //#22759
                    $1.remcws = $get($1.numremcws, $1.j + (~~($1.Dbits.length / 8))); //#22760
                    if (((($f($get($1.numremcws, ($1.j + (~~($1.Dbits.length / 8))) - 1) - 1) == 0) && ($1.Drem == 0)) || (($1.remcws == 1) && ($1.Drem != 0))) && ($1.i == $1.msglen)) { //#22769
                        if (($1.Drem == 4) || ($1.Drem == 6)) { //#22766
                            $k[$j++] = Infinity; //#22766
                            $aload($1.Dbits); //#22766
                            $k[$j++] = 1; //#22766
                            $k[$j++] = 1; //#22766
                            $k[$j++] = 1; //#22766
                            $k[$j++] = 1; //#22766
                            $1.Dbits = $a(); //#22766
                        } //#22766
                        if (($1.Drem == 2) || ($1.Drem == 6)) { //#22767
                            $k[$j++] = Infinity; //#22767
                            $aload($1.Dbits); //#22767
                            $k[$j++] = 0; //#22767
                            $k[$j++] = 1; //#22767
                            $1.Dbits = $a(); //#22767
                        } //#22767
                        break; //#22768
                    } //#22768
                    if ((((($1.i == ($1.msglen - 1)) && ($get($1.numD, $1.i) == 1)) || (($1.i == ($1.msglen - 2)) && ($get($1.numD, $1.i) == 2))) && ($1.remcws == 1)) && ($1.Drem == 0)) { //#22774
                        break; //#22774
                    } //#22774
                    if (!(((($1.i == ($1.msglen - 1)) && ($get($1.numD, $1.i) == 1)) && ($1.remcws == 1)) && (($1.Drem == 4) || ($1.Drem == 6)))) { //#22781
                        $k[$j++] = Infinity; //#22779
                        $aload($1.Dbits); //#22779
                        $k[$j++] = 1; //#22779
                        $k[$j++] = 1; //#22779
                        $k[$j++] = 1; //#22779
                        $k[$j++] = 1; //#22779
                        $k[$j++] = 1; //#22779
                        $k[$j++] = 1; //#22779
                        $1.Dbits = $a(); //#22779
                        $1.Drem = (8 - ($1.Dbits.length % 8)) % 8; //#22780
                    } //#22780
                    if (($1.Drem == 4) || ($1.Drem == 6)) { //#22792
                        if ($get($1.numD, $1.i) >= 1) { //#22789
                            $k[$j++] = Infinity; //#22786
                            $aload($1.Dbits); //#22786
                            $k[$j++] = $f($f($get($1.msg, $1.i) - 48) + 1); //#22786
                            $k[$j++] = 4; //#22786
                            $1.tobin(); //#22786
                            $aload($k[--$j]); //#22786
                            $1.Dbits = $a(); //#22786
                            $1.i = $1.i + 1; //#22787
                        } else { //#22789
                            $k[$j++] = Infinity; //#22789
                            $aload($1.Dbits); //#22789
                            $k[$j++] = 1; //#22789
                            $k[$j++] = 1; //#22789
                            $k[$j++] = 1; //#22789
                            $k[$j++] = 1; //#22789
                            $1.Dbits = $a(); //#22789
                        } //#22789
                        $1.Drem = $1.Drem - 4; //#22791
                    } //#22791
                    if ($1.Drem == 2) { //#22796
                        $k[$j++] = Infinity; //#22794
                        $aload($1.Dbits); //#22794
                        $k[$j++] = 0; //#22794
                        $k[$j++] = 1; //#22794
                        $1.Dbits = $a(); //#22794
                        $1.Drem = 0; //#22795
                    } //#22795
                    break; //#22798
                } //#22798
                $k[$j++] = Infinity; //#22806
                $aload($1.Dbits); //#22804
                var _Gt = $geti($1.msg, $1.i, 3); //#22805
                $k[$j++] = 0; //#22805
                for (var _Gu = 0, _Gv = _Gt.length; _Gu < _Gv; _Gu++) { //#22805
                    var _Gx = $k[--$j]; //#22805
                    $k[$j++] = ($f(_Gx + $f($get(_Gt, _Gu) - 48))) * 10; //#22805
                } //#22805
                var _Gy = $k[--$j]; //#22805
                $k[$j++] = (~~(_Gy / 10)) + 1; //#22806
                $k[$j++] = 10; //#22806
                $1.tobin(); //#22806
                $aload($k[--$j]); //#22806
                $1.Dbits = $a(); //#22806
                $1.i = $1.i + 3; //#22808
            } //#22808
            $k[$j++] = Infinity; //#22812
            for (var _H4 = 0, _H3 = $1.Dbits.length - 1; _H4 <= _H3; _H4 += 8) { //#22815
                var _H6 = $geti($1.Dbits, _H4, 8); //#22814
                $k[$j++] = 0; //#22814
                for (var _H7 = 0, _H8 = _H6.length; _H7 < _H8; _H7++) { //#22814
                    var _HA = $k[--$j]; //#22814
                    $k[$j++] = $f(_HA + $get(_H6, _H7)) * 2; //#22814
                } //#22814
                var _HB = $k[--$j]; //#22814
                $k[$j++] = ~~(_HB / 2); //#22814
            } //#22814
            $astore($a($counttomark())); //#22816
            var _HE = $k[--$j]; //#22816
            var _HF = $k[--$j]; //#22816
            $k[$j++] = _HE; //#22816
            $k[$j++] = _HF; //#22816
            $j--; //#22816
            $1.addtocws(); //#22816
            $1.mode = $1.A; //#22817
        }; //#22817
        $1.encB = function() {
            $1.p = 0; //#22822
            $1.bvals = $a(1480); //#22822
            for (;;) { //#22829
                if ($1.i == $1.msglen) { //#22823
                    break; //#22823
                } //#22823
                if ($get($1.msg, $1.i) < 0) { //#22824
                    break; //#22824
                } //#22824
                $1.lookup(); //#22825
                if ($k[--$j] != $1.mode) { //#22825
                    break; //#22825
                } //#22825
                $put($1.bvals, $1.p, $get($1.msg, $1.i)); //#22826
                $1.p = $1.p + 1; //#22827
                $1.i = $1.i + 1; //#22828
            } //#22828
            $1.remcws = $f($get($1.numremcws, $1.j + $1.p) - 1); //#22830
            $k[$j++] = Infinity; //#22837
            if (($1.remcws == 0) && ($1.i == $1.msglen)) { //#22835
                $k[$j++] = 0; //#22833
            } else { //#22835
                if ($1.p < 250) { //#22835
                    $k[$j++] = $1.p; //#22835
                } else { //#22835
                    $k[$j++] = (~~($1.p / 250)) + 249; //#22835
                    $k[$j++] = $1.p % 250; //#22835
                } //#22835
            } //#22835
            $aload($geti($1.bvals, 0, $1.p)); //#22837
            $1.bvals = $a(); //#22837
            $k[$j++] = $1.bvals; //#22839
            $1.addtocws(); //#22839
            $1.mode = $1.A; //#22840
        }; //#22840
        $1.cws = $a(1480); //#22844
        $1.mode = $1.A; //#22845
        $1.i = 0; //#22845
        $1.j = 0; //#22845
        for (;;) { //#22848
            if ($1.i >= $1.msglen) { //#22846
                break; //#22846
            } //#22846
            if ($1[$get($a(['encA', 'encCTX', 'encCTX', 'encCTX', 'encD', 'encB']), $1.mode)]() === true) {
                break;
            } //#22847
        } //#22847
        $1.cws = $geti($1.cws, 0, $1.j); //#22849
    } //#22849
    $1.i = 0; //#22854
    for (;;) { //#22874
        $1.m = $get($1.metrics, $1.i); //#22856
        $1.vers = $get($1.m, 0); //#22857
        $1.rows = $get($1.m, 1); //#22858
        $1.cols = $get($1.m, 2); //#22859
        $1.dcol = $get($1.m, 3); //#22860
        $1.dcws = $get($1.m, 4); //#22861
        $1.rscw = $get($1.m, 5); //#22862
        $1.rsbl = $get($1.m, 6); //#22863
        $1.riso = $get($1.m, 7); //#22864
        $1.risi = $get($1.m, 8); //#22865
        $1.risl = $get($1.m, 9); //#22866
        $1.dcpb = ~~($1.dcws / $1.rsbl); //#22867
        $1.ecpb = ~~($1.rscw / $1.rsbl); //#22868
        $1.okay = true; //#22869
        if ($ne($1.version, "unset") && $ne($1.version, $1.vers)) { //#22870
            $1.okay = false; //#22870
        } //#22870
        if ($1.cws.length > $1.dcws) { //#22871
            $1.okay = false; //#22871
        } //#22871
        if ($1.okay) { //#22872
            break; //#22872
        } //#22872
        $1.i = $1.i + 1; //#22873
    } //#22873
    if (!$1.stype) { //#22880
        $k[$j++] = Infinity; //#22878
        $aload($1.cws); //#22878
        for (var _Ia = 0, _Ib = $f($1.dcws - $1.cws.length); _Ia < _Ib; _Ia++) { //#22878
            $k[$j++] = 129; //#22878
        } //#22878
        $1.cws = $a(); //#22878
    } else { //#22880
        $k[$j++] = Infinity; //#22880
        for (var _If = 0, _Ig = $f($1.dcws - $1.cws.length); _If < _Ig; _If++) { //#22880
            $k[$j++] = 0; //#22880
        } //#22880
        $aload($1.cws); //#22880
        $1.cws = $a(); //#22880
    } //#22880
    var _Ik = $get($1.options, 'debugcws') !== undefined; //#22883
    if (_Ik) { //#22883
        $k[$j++] = 'bwipp.debugcws'; //#22883
        $k[$j++] = $1.cws; //#22883
        bwipp_raiseerror(); //#22883
    } //#22883
    $1.cwbs = $a($1.rsbl); //#22886
    $1.ecbs = $a($1.rsbl); //#22887
    for (var _Is = 0, _Ir = $f($1.rsbl - 1); _Is <= _Ir; _Is += 1) { //#22896
        $1.i = _Is; //#22889
        $1.cwb = $a($1.dcpb); //#22890
        for (var _Ix = 0, _Iw = $1.dcpb - 1; _Ix <= _Iw; _Ix += 1) { //#22894
            $1.j = _Ix; //#22892
            $put($1.cwb, $1.j, $get($1.cws, $f(($1.j * $1.rsbl) + $1.i))); //#22893
        } //#22893
        $put($1.cwbs, $1.i, $1.cwb); //#22895
    } //#22895
    var _J9 = $1.stype ? 32 : 256; //#22899
    $1.gf = _J9; //#22899
    $1['gf-1'] = $1.gf - 1; //#22900
    var _JC = $1.stype ? 37 : 301; //#22901
    $1.pm = _JC; //#22901
    $k[$j++] = Infinity; //#22902
    $k[$j++] = 1; //#22902
    for (var _JE = 0, _JF = $1["gf-1"]; _JE < _JF; _JE++) { //#22902
        var _JG = $k[--$j]; //#22902
        var _JH = _JG * 2; //#22902
        $k[$j++] = _JG; //#22902
        $k[$j++] = _JH; //#22902
        if (_JH >= $1.gf) { //#22902
            var _JK = $k[--$j]; //#22902
            $k[$j++] = _JK ^ $1.pm; //#22902
        } //#22902
    } //#22902
    $1.rsalog = $a(); //#22902
    $1.rslog = $a($1.gf); //#22903
    for (var _JQ = 1, _JP = $1["gf-1"]; _JQ <= _JP; _JQ += 1) { //#22904
        $put($1.rslog, $get($1.rsalog, _JQ), _JQ); //#22904
    } //#22904
    $1.rsprod = function() {
        var _JU = $k[--$j]; //#22906
        var _JV = $k[--$j]; //#22906
        $k[$j++] = _JV; //#22910
        $k[$j++] = _JU; //#22910
        if ((_JU != 0) && (_JV != 0)) { //#22909
            var _JY = $get($1.rslog, $k[--$j]); //#22907
            var _Je = $get($1.rsalog, $f(_JY + $get($1.rslog, $k[--$j])) % $1["gf-1"]); //#22907
            $k[$j++] = _Je; //#22907
        } else { //#22909
            $j -= 2; //#22909
            $k[$j++] = 0; //#22909
        } //#22909
    }; //#22909
    $k[$j++] = Infinity; //#22914
    $k[$j++] = 1; //#22914
    for (var _Jg = 0, _Jh = $1.ecpb; _Jg < _Jh; _Jg++) { //#22914
        $k[$j++] = 0; //#22914
    } //#22914
    $1.coeffs = $a(); //#22914
    for (var _Jl = 0, _Jk = $1.ecpb - 1; _Jl <= _Jk; _Jl += 1) { //#22923
        $1.i = _Jl; //#22916
        $put($1.coeffs, $1.i + 1, $get($1.coeffs, $1.i)); //#22917
        for (var _Js = $1.i; _Js >= 1; _Js -= 1) { //#22921
            $1.j = _Js; //#22919
            $k[$j++] = $1.coeffs; //#22920
            $k[$j++] = $1.j; //#22920
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#22920
            $k[$j++] = $get($1.coeffs, $1.j); //#22920
            $k[$j++] = $get($1.rsalog, $1.i); //#22920
            $1.rsprod(); //#22920
            var _K4 = $k[--$j]; //#22920
            var _K5 = $k[--$j]; //#22920
            var _K6 = $k[--$j]; //#22920
            $put($k[--$j], _K6, $xo(_K5, _K4)); //#22920
        } //#22920
        $k[$j++] = $1.coeffs; //#22922
        $k[$j++] = 0; //#22922
        $k[$j++] = $get($1.coeffs, 0); //#22922
        $k[$j++] = $get($1.rsalog, $1.i); //#22922
        $1.rsprod(); //#22922
        var _KE = $k[--$j]; //#22922
        var _KF = $k[--$j]; //#22922
        $put($k[--$j], _KF, _KE); //#22922
    } //#22922
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#22924
    for (var _KM = 0, _KL = $1.cwbs.length - 1; _KM <= _KL; _KM += 1) { //#22939
        $1.i = _KM; //#22928
        $k[$j++] = Infinity; //#22929
        $aload($get($1.cwbs, $1.i)); //#22929
        for (var _KR = 0, _KS = $1.ecpb; _KR < _KS; _KR++) { //#22929
            $k[$j++] = 0; //#22929
        } //#22929
        $1.rscws = $a(); //#22929
        for (var _KW = 0, _KV = $1.dcpb - 1; _KW <= _KV; _KW += 1) { //#22937
            $1.m = _KW; //#22931
            $1.k = $get($1.rscws, $1.m); //#22932
            for (var _Kc = 0, _Kb = $1.ecpb - 1; _Kc <= _Kb; _Kc += 1) { //#22936
                $1.j = _Kc; //#22934
                $k[$j++] = $1.rscws; //#22935
                $k[$j++] = ($1.m + $1.j) + 1; //#22935
                $k[$j++] = $get($1.coeffs, ($1.ecpb - $1.j) - 1); //#22935
                $k[$j++] = $1.k; //#22935
                $1.rsprod(); //#22935
                var _Kp = $k[--$j]; //#22935
                var _Kq = $k[--$j]; //#22935
                $put($k[--$j], _Kq, $xo(_Kp, $get($1.rscws, ($1.m + $1.j) + 1))); //#22935
            } //#22935
        } //#22935
        $put($1.ecbs, $1.i, $geti($1.rscws, $1.dcpb, $1.ecpb)); //#22938
    } //#22938
    $k[$j++] = Infinity; //#22942
    $aload($1.cws); //#22942
    for (var _L0 = 0, _L1 = $1.rscw; _L0 < _L1; _L0++) { //#22942
        $k[$j++] = 0; //#22942
    } //#22942
    $1.cws = $a(); //#22942
    for (var _L5 = 0, _L4 = $f($1.rscw - 1); _L5 <= _L4; _L5 += 1) { //#22946
        $1.i = _L5; //#22944
        $put($1.cws, $f($1.dcws + $1.i), $get($get($1.ecbs, $1.i % $1.rsbl), ~~($1.i / $1.rsbl))); //#22945
    } //#22945
    var _LJ = $1.stype ? 5 : 8; //#22949
    $1.mmat = $a($f($1.dcws + $1.rscw) * _LJ); //#22949
    $1.r = 0; //#22950
    $1.c = 0; //#22950
    var _LM = $1.stype ? 2 : 1; //#22951
    for (var _LP = 0, _LQ = _LM, _LO = $1.cws.length - 1; _LQ < 0 ? _LP >= _LO : _LP <= _LO; _LP += _LQ) { //#22972
        $1.i = _LP; //#22952
        if (!$1.stype) { //#22966
            var _LT = $strcpy($s(8), "00000000"); //#22954
            var _LY = $cvrs($s(8), $get($1.cws, $1.i), 2); //#22954
            $puti(_LT, 8 - _LY.length, _LY); //#22955
            $k[$j++] = _LT; //#22955
            $k[$j++] = Infinity; //#22955
            var _LZ = $k[--$j]; //#22955
            var _La = $k[--$j]; //#22955
            $k[$j++] = _LZ; //#22955
            $forall(_La, function() { //#22955
                var _Lb = $k[--$j]; //#22955
                $k[$j++] = $f(_Lb - 48); //#22955
            }); //#22955
            var _Lc = $a(); //#22955
            $1.top = $geti(_Lc, 0, 4); //#22956
            $1.bot = $geti(_Lc, 4, 4); //#22957
        } else { //#22966
            var _Lg = $strcpy($s(5), "00000"); //#22959
            var _Ll = $cvrs($s(5), $get($1.cws, $1.i), 2); //#22959
            $puti(_Lg, 5 - _Ll.length, _Ll); //#22960
            $k[$j++] = _Lg; //#22960
            $k[$j++] = Infinity; //#22960
            var _Lm = $k[--$j]; //#22960
            var _Ln = $k[--$j]; //#22960
            $k[$j++] = _Lm; //#22960
            $forall(_Ln, function() { //#22960
                var _Lo = $k[--$j]; //#22960
                $k[$j++] = $f(_Lo - 48); //#22960
            }); //#22960
            $1.c1 = $a(); //#22961
            var _Lr = $strcpy($s(5), "00000"); //#22962
            var _Lw = $cvrs($s(5), $get($1.cws, $1.i + 1), 2); //#22962
            $puti(_Lr, 5 - _Lw.length, _Lw); //#22963
            $k[$j++] = _Lr; //#22963
            $k[$j++] = Infinity; //#22963
            var _Lx = $k[--$j]; //#22963
            var _Ly = $k[--$j]; //#22963
            $k[$j++] = _Lx; //#22963
            $forall(_Ly, function() { //#22963
                var _Lz = $k[--$j]; //#22963
                $k[$j++] = $f(_Lz - 48); //#22963
            }); //#22963
            $1.c2 = $a(); //#22964
            $k[$j++] = Infinity; //#22965
            $aload($geti($1.c1, 0, 3)); //#22965
            $aload($geti($1.c2, 0, 2)); //#22965
            $1.top = $a(); //#22965
            $k[$j++] = Infinity; //#22966
            $aload($geti($1.c1, 3, 2)); //#22966
            $aload($geti($1.c2, 2, 3)); //#22966
            $1.bot = $a(); //#22966
        } //#22966
        $puti($1.mmat, $f(($1.r * $1.dcol) + $1.c), $1.top); //#22968
        $puti($1.mmat, $f((($1.r + 1) * $1.dcol) + $1.c), $1.bot); //#22969
        $1.c = $1.c + $1.top.length; //#22970
        if ($1.c == $1.dcol) { //#22971
            $1.c = 0; //#22971
            $1.r = $1.r + 2; //#22971
        } //#22971
    } //#22971
    $1.mmv = function() {
        var _MR = $k[--$j]; //#22975
        var _MS = $k[--$j]; //#22975
        $k[$j++] = $f(_MS + (_MR * $1.cols)); //#22975
    }; //#22975
    $k[$j++] = Infinity; //#22976
    for (var _MV = 0, _MW = $1.rows * $1.cols; _MV < _MW; _MV++) { //#22976
        $k[$j++] = -1; //#22976
    } //#22976
    $1.pixs = $a(); //#22976
    var _N2 = $a([function() {
        for (var _MZ = 0, _Ma = $1.cols; _MZ < _Ma; _MZ++) { //#22980
            $k[$j++] = 0; //#22980
        } //#22980
    }, function() {
        for (var _Mc = 0, _Md = $1.cols; _Mc < _Md; _Mc++) { //#22981
            $k[$j++] = 1; //#22981
        } //#22981
    }, function() {
        $k[$j++] = 0; //#22982
        for (var _Mf = 0, _Mg = $f($1.cols - 2); _Mf < _Mg; _Mf++) { //#22982
            $k[$j++] = 1; //#22982
        } //#22982
        $k[$j++] = 0; //#22982
    }, function() {
        $k[$j++] = 0; //#22983
        $k[$j++] = 1; //#22983
        for (var _Mi = 0, _Mj = $f($1.cols - 4); _Mi < _Mj; _Mi++) { //#22983
            $k[$j++] = 0; //#22983
        } //#22983
        $k[$j++] = 1; //#22983
        $k[$j++] = 0; //#22983
    }, function() {
        for (var _Ml = 0, _Mm = ~~($f($1.cols - 1) / 2); _Ml < _Mm; _Ml++) { //#22984
            $k[$j++] = -1; //#22984
        } //#22984
        $k[$j++] = 1; //#22984
        for (var _Mo = 0, _Mp = ~~($f($1.cols - 1) / 2); _Mo < _Mp; _Mo++) { //#22984
            $k[$j++] = -1; //#22984
        } //#22984
    }, function() {
        for (var _Mr = 0, _Ms = ~~($f($1.cols - 1) / 2); _Mr < _Ms; _Mr++) { //#22985
            $k[$j++] = -1; //#22985
        } //#22985
        $k[$j++] = 0; //#22985
        for (var _Mu = 0, _Mv = ~~($f($1.cols - 1) / 2); _Mu < _Mv; _Mu++) { //#22985
            $k[$j++] = -1; //#22985
        } //#22985
    }, function() {
        $k[$j++] = 1; //#22986
        for (var _Mx = 0, _My = $f($1.cols - 2); _Mx < _My; _Mx++) { //#22986
            $k[$j++] = 0; //#22986
        } //#22986
        $k[$j++] = 1; //#22986
    }, function() {
        $k[$j++] = 1; //#22987
        $k[$j++] = 0; //#22987
        for (var _N0 = 0, _N1 = $f($1.cols - 4); _N0 < _N1; _N0++) { //#22987
            $k[$j++] = 1; //#22987
        } //#22987
        $k[$j++] = 0; //#22987
        $k[$j++] = 1; //#22987
    }]); //#22987
    $1.artifact = _N2; //#22988
    var _N3 = new Map([
        ["A", "121343"],
        ["B", "12134343"],
        ["C", "12121343"],
        ["D", "1213434343"],
        ["E", "1212134343"],
        ["F", "1212121343"],
        ["G", "121213434343"],
        ["H", "121212134343"],
        ["S", "56661278"],
        ["T", "5666666666127878"]
    ]); //#23000
    $1.cpatmap = _N3; //#23001
    $1.cpat = $get($1.cpatmap, $geti($1.vers, 0, 1)); //#23003
    $k[$j++] = $1.pixs; //#23004
    $k[$j++] = 0; //#23004
    $k[$j++] = ~~($f($1.rows - $1.cpat.length) / 2); //#23004
    $1.mmv(); //#23004
    $k[$j++] = Infinity; //#23005
    $forall($1.cpat, function() { //#23005
        if ($get($1.artifact, $f($k[--$j] - 49))() === true) {
            return true;
        } //#23005
    }); //#23005
    var _NF = $a(); //#23005
    var _NG = $k[--$j]; //#23005
    $puti($k[--$j], _NG, _NF); //#23005
    for (var _NK = 0, _NJ = $f($1.risl - 1); _NK <= _NJ; _NK += 1) { //#23020
        $1.i = _NK; //#23009
        for (var _NP = $1.riso, _NQ = $1.risi, _NO = $f($1.cols - 1); _NQ < 0 ? _NP >= _NO : _NP <= _NO; _NP += _NQ) { //#23019
            $1.j = _NP; //#23011
            var _NS = (($1.i % 12) == 0) ? 1 : 0; //#23012
            var _NT = $a([1, _NS]); //#23012
            $k[$j++] = _NT; //#23013
            $k[$j++] = _NT; //#23013
            $k[$j++] = $1.pixs; //#23013
            $k[$j++] = $1.j; //#23013
            $k[$j++] = $1.i; //#23013
            $1.mmv(); //#23013
            var _NX = $k[--$j]; //#23014
            var _NY = $k[--$j]; //#23014
            $puti(_NY, _NX, $k[--$j]); //#23014
            if ($1.i != $f($1.risl - 1)) { //#23018
                $k[$j++] = $1.pixs; //#23016
                $k[$j++] = $f($f($1.cols - $1.j) - 2); //#23016
                $k[$j++] = $f($f($1.rows - $1.i) - 1); //#23016
                $1.mmv(); //#23016
                var _Nh = $k[--$j]; //#23017
                var _Ni = $k[--$j]; //#23017
                $puti(_Ni, _Nh, $k[--$j]); //#23017
            } else { //#23018
                $j--; //#23018
            } //#23018
        } //#23018
    } //#23018
    var _ON = new Map([
        ["A", $a([$a([12, 5])])],
        ["B", $a([$a([16, 7])])],
        ["C", $a([$a([26, 12])])],
        ["D", $a([])],
        ["E", $a([$a([26, 23])])],
        ["F", $a([$a([26, 32]), $a([70, 32]), $a([26, 34]), $a([70, 34])])],
        ["G", $a([$a([27, 48]), $a([69, 48])])],
        ["H", $a([$a([26, 70]), $a([66, 70]), $a([106, 70]), $a([26, 72]), $a([66, 72]), $a([106, 72])])],
        ["S-10", $a([])],
        ["S-20", $a([$a([10, 4])])],
        ["S-30", $a([$a([15, 4]), $a([15, 6])])],
        ["T-16", $a([$a([8, 10])])],
        ["T-32", $a([$a([16, 10]), $a([16, 12])])],
        ["T-48", $a([$a([24, 10]), $a([24, 12]), $a([24, 14])])]
    ]); //#23038
    $1.blackdotmap = _ON; //#23039
    $forall($get($1.blackdotmap, $1.vers), function() { //#23041
        var _OS = $k[--$j]; //#23041
        $k[$j++] = $1.pixs; //#23041
        $aload(_OS); //#23041
        $1.mmv(); //#23041
        var _OT = $k[--$j]; //#23041
        $put($k[--$j], _OT, 1); //#23041
    }); //#23041
    $1.j = 0; //#23044
    for (var _OX = 0, _OW = $1.pixs.length - 1; _OX <= _OW; _OX += 1) { //#23051
        $1.i = _OX; //#23046
        if ($get($1.pixs, $1.i) == -1) { //#23050
            $put($1.pixs, $1.i, $get($1.mmat, $1.j)); //#23048
            $1.j = $1.j + 1; //#23049
        } //#23049
    } //#23049
    var _On = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.cols],
        ["pixy", $1.rows],
        ["height", ($1.rows / 72) * 2],
        ["width", ($1.cols / 72) * 2],
        ["opt", $1.options]
    ]); //#23061
    $k[$j++] = _On; //#23064
    if (!$1.dontdraw) { //#23064
        bwipp_renmatrix(); //#23064
    } //#23064
}

function bwipp_hanxin() {
    var $1 = {}; //#23099
    $1.ctx = null; //#23101
    $1.dontdraw = false; //#23102
    $1.version = "unset"; //#23103
    $1.eclevel = "unset"; //#23104
    $1.parse = false; //#23105
    $1.parsefnc = false; //#23106
    $1.mask = -1; //#23107
    $k[$j++] = $1; //#23109
    bwipp_processoptions(); //#23109
    $1.options = $k[--$j]; //#23109
    $1.barcode = $k[--$j]; //#23110
    var _4 = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc]
    ]); //#23117
    $1.fncvals = _4; //#23119
    $k[$j++] = 'msg'; //#23120
    $k[$j++] = $1.barcode; //#23120
    $k[$j++] = $1.fncvals; //#23120
    bwipp_parseinput(); //#23120
    var _7 = $k[--$j]; //#23120
    $1[$k[--$j]] = _7; //#23120
    $1.msglen = $1.msg.length; //#23121
    if ($eq($1.eclevel, "unset")) { //#23124
        $1.eclevel = "L2"; //#23124
    } //#23124
    $1.tobin = function() {
        var _C = $s($k[--$j]); //#23127
        $k[$j++] = _C; //#23127
        for (var _E = 0, _D = _C.length - 1; _E <= _D; _E += 1) { //#23127
            var _F = $k[--$j]; //#23127
            $put(_F, _E, 48); //#23127
            $k[$j++] = _F; //#23127
        } //#23127
        var _G = $k[--$j]; //#23128
        var _J = $cvrs($s(_G.length), $k[--$j], 2); //#23128
        $puti(_G, _G.length - _J.length, _J); //#23129
        $k[$j++] = _G; //#23129
    }; //#23129
    $1.bits = $s((4 + 13) + ($1.msglen * 8)); //#23133
    $puti($1.bits, 0, "0011"); //#23134
    $k[$j++] = $1.bits; //#23135
    $k[$j++] = 4; //#23135
    $k[$j++] = $1.msglen; //#23135
    $k[$j++] = 13; //#23135
    $1.tobin(); //#23135
    var _P = $k[--$j]; //#23135
    var _Q = $k[--$j]; //#23135
    $puti($k[--$j], _Q, _P); //#23135
    for (var _U = 0, _T = $1.msglen - 1; _U <= _T; _U += 1) { //#23139
        $1.i = _U; //#23137
        $k[$j++] = $1.bits; //#23138
        $k[$j++] = 17 + ($1.i * 8); //#23138
        $k[$j++] = $get($1.msg, $1.i); //#23138
        $k[$j++] = 8; //#23138
        $1.tobin(); //#23138
        var _a = $k[--$j]; //#23138
        var _b = $k[--$j]; //#23138
        $puti($k[--$j], _b, _a); //#23138
    } //#23138
    $1.metrics = $a([$a(["1", 23, -1, 0, 205, $a([1, 21, 4]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 17, 8]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 13, 12]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 9, 16]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["2", 25, -1, 0, 301, $a([1, 31, 6]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 25, 12]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 19, 18]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 15, 22]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["3", 27, -1, 0, 405, $a([1, 42, 8]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 34, 16]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 26, 24]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 20, 30]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["4", 29, 14, 1, 439, $a([1, 46, 8]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 38, 16]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 30, 24]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 22, 32]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["5", 31, 16, 1, 555, $a([1, 57, 12]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 49, 20]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 37, 32]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 14, 20]), $a([1, 13, 22]), $a([0, -1, -1])]), $a(["6", 33, 16, 1, 675, $a([1, 70, 14]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 58, 26]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 24, 20]), $a([1, 22, 18]), $a([0, -1, -1]), $a([1, 16, 24]), $a([1, 18, 26]), $a([0, -1, -1])]), $a(["7", 35, 17, 1, 805, $a([1, 84, 16]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 70, 30]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 26, 22]), $a([1, 28, 24]), $a([0, -1, -1]), $a([2, 14, 20]), $a([1, 12, 20]), $a([0, -1, -1])]), $a(["8", 37, 18, 1, 943, $a([1, 99, 18]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 40, 18]), $a([1, 41, 18]), $a([0, -1, -1]), $a([1, 31, 26]), $a([1, 32, 28]), $a([0, -1, -1]), $a([2, 16, 24]), $a([1, 15, 22]), $a([0, -1, -1])]), $a(["9", 39, 19, 1, 1089, $a([1, 114, 22]), $a([0, -1, -1]), $a([0, -1, -1]), $a([2, 48, 20]), $a([0, -1, -1]), $a([0, -1, -1]), $a([2, 24, 20]), $a([1, 26, 22]), $a([0, -1, -1]), $a([2, 18, 28]), $a([1, 18, 26]), $a([0, -1, -1])]), $a(["10", 41, 20, 1, 1243, $a([1, 131, 24]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 52, 22]), $a([1, 57, 24]), $a([0, -1, -1]), $a([2, 27, 24]), $a([1, 29, 24]), $a([0, -1, -1]), $a([2, 21, 32]), $a([1, 19, 30]), $a([0, -1, -1])]), $a(["11", 43, 14, 2, 1289, $a([1, 135, 26]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 56, 24]), $a([1, 57, 24]), $a([0, -1, -1]), $a([2, 28, 24]), $a([1, 31, 26]), $a([0, -1, -1]), $a([2, 22, 32]), $a([1, 21, 32]), $a([0, -1, -1])]), $a(["12", 45, 15, 2, 1455, $a([1, 153, 28]), $a([0, -1, -1]), $a([0, -1, -1]), $a([1, 62, 26]), $a([1, 65, 28]), $a([0, -1, -1]), $a([2, 32, 28]), $a([1, 33, 28]), $a([0, -1, -1]), $a([3, 17, 26]), $a([1, 22, 30]), $a([0, -1, -1])]), $a(["13", 47, 16, 2, 1629, $a([1, 86, 16]), $a([1, 85, 16]), $a([0, -1, -1]), $a([1, 71, 30]), $a([1, 72, 30]), $a([0, -1, -1]), $a([2, 37, 32]), $a([1, 35, 30]), $a([0, -1, -1]), $a([3, 20, 30]), $a([1, 21, 32]), $a([0, -1, -1])]), $a(["14", 49, 16, 2, 1805, $a([1, 94, 18]), $a([1, 95, 18]), $a([0, -1, -1]), $a([2, 51, 22]), $a([1, 55, 24]), $a([0, -1, -1]), $a([3, 30, 26]), $a([1, 31, 26]), $a([0, -1, -1]), $a([4, 18, 28]), $a([1, 17, 24]), $a([0, -1, -1])]), $a(["15", 51, 17, 2, 1995, $a([1, 104, 20]), $a([1, 105, 20]), $a([0, -1, -1]), $a([2, 57, 24]), $a([1, 61, 26]), $a([0, -1, -1]), $a([3, 33, 28]), $a([1, 36, 30]), $a([0, -1, -1]), $a([4, 20, 30]), $a([1, 19, 30]), $a([0, -1, -1])]), $a(["16", 53, 17, 2, 2187, $a([1, 115, 22]), $a([1, 114, 22]), $a([0, -1, -1]), $a([2, 65, 28]), $a([1, 61, 26]), $a([0, -1, -1]), $a([3, 38, 32]), $a([1, 33, 30]), $a([0, -1, -1]), $a([5, 19, 28]), $a([1, 14, 24]), $a([0, -1, -1])]), $a(["17", 55, 18, 2, 2393, $a([1, 126, 24]), $a([1, 125, 24]), $a([0, -1, -1]), $a([2, 70, 30]), $a([1, 69, 30]), $a([0, -1, -1]), $a([4, 33, 28]), $a([1, 29, 26]), $a([0, -1, -1]), $a([5, 20, 30]), $a([1, 19, 30]), $a([0, -1, -1])]), $a(["18", 57, 19, 2, 2607, $a([1, 136, 26]), $a([1, 137, 26]), $a([0, -1, -1]), $a([3, 56, 24]), $a([1, 59, 26]), $a([0, -1, -1]), $a([5, 35, 30]), $a([0, -1, -1]), $a([0, -1, -1]), $a([6, 18, 28]), $a([1, 21, 28]), $a([0, -1, -1])]), $a(["19", 59, 20, 2, 2829, $a([1, 148, 28]), $a([1, 149, 28]), $a([0, -1, -1]), $a([3, 61, 26]), $a([1, 64, 28]), $a([0, -1, -1]), $a([7, 24, 20]), $a([1, 23, 22]), $a([0, -1, -1]), $a([6, 20, 30]), $a([1, 21, 32]), $a([0, -1, -1])]), $a(["20", 61, 20, 2, 3053, $a([3, 107, 20]), $a([0, -1, -1]), $a([0, -1, -1]), $a([3, 65, 28]), $a([1, 72, 30]), $a([0, -1, -1]), $a([7, 26, 22]), $a([1, 23, 22]), $a([0, -1, -1]), $a([7, 19, 28]), $a([1, 20, 32]), $a([0, -1, -1])]), $a(["21", 63, 21, 2, 3291, $a([3, 115, 22]), $a([0, -1, -1]), $a([0, -1, -1]), $a([4, 56, 24]), $a([1, 63, 28]), $a([0, -1, -1]), $a([7, 28, 24]), $a([1, 25, 22]), $a([0, -1, -1]), $a([8, 18, 28]), $a([1, 21, 22]), $a([0, -1, -1])]), $a(["22", 65, 16, 3, 3383, $a([2, 116, 22]), $a([1, 122, 24]), $a([0, -1, -1]), $a([4, 56, 24]), $a([1, 72, 30]), $a([0, -1, -1]), $a([7, 28, 24]), $a([1, 32, 26]), $a([0, -1, -1]), $a([8, 18, 28]), $a([1, 24, 30]), $a([0, -1, -1])]), $a(["23", 67, 17, 3, 3631, $a([3, 127, 24]), $a([0, -1, -1]), $a([0, -1, -1]), $a([5, 51, 22]), $a([1, 62, 26]), $a([0, -1, -1]), $a([7, 30, 26]), $a([1, 35, 26]), $a([0, -1, -1]), $a([8, 20, 30]), $a([1, 21, 32]), $a([0, -1, -1])]), $a(["24", 69, 17, 3, 3887, $a([2, 135, 26]), $a([1, 137, 26]), $a([0, -1, -1]), $a([5, 56, 24]), $a([1, 59, 26]), $a([0, -1, -1]), $a([7, 33, 28]), $a([1, 30, 28]), $a([0, -1, -1]), $a([11, 16, 24]), $a([1, 19, 26]), $a([0, -1, -1])]), $a(["25", 71, 18, 3, 4151, $a([3, 105, 20]), $a([1, 121, 22]), $a([0, -1, -1]), $a([5, 61, 26]), $a([1, 57, 26]), $a([0, -1, -1]), $a([9, 28, 24]), $a([1, 28, 22]), $a([0, -1, -1]), $a([10, 19, 28]), $a([1, 18, 30]), $a([0, -1, -1])]), $a(["26", 73, 18, 3, 4423, $a([2, 157, 30]), $a([1, 150, 28]), $a([0, -1, -1]), $a([5, 65, 28]), $a([1, 61, 26]), $a([0, -1, -1]), $a([8, 33, 28]), $a([1, 34, 30]), $a([0, -1, -1]), $a([10, 19, 28]), $a([2, 15, 26]), $a([0, -1, -1])]), $a(["27", 75, 19, 3, 4703, $a([3, 126, 24]), $a([1, 115, 22]), $a([0, -1, -1]), $a([7, 51, 22]), $a([1, 54, 22]), $a([0, -1, -1]), $a([8, 35, 30]), $a([1, 37, 30]), $a([0, -1, -1]), $a([15, 15, 22]), $a([1, 10, 22]), $a([0, -1, -1])]), $a(["28", 77, 19, 3, 4991, $a([4, 105, 20]), $a([1, 103, 20]), $a([0, -1, -1]), $a([7, 56, 24]), $a([1, 45, 18]), $a([0, -1, -1]), $a([10, 31, 26]), $a([1, 27, 26]), $a([0, -1, -1]), $a([10, 17, 26]), $a([3, 20, 28]), $a([1, 21, 28])]), $a(["29", 79, 20, 3, 5287, $a([3, 139, 26]), $a([1, 137, 28]), $a([0, -1, -1]), $a([6, 66, 28]), $a([1, 66, 30]), $a([0, -1, -1]), $a([9, 36, 30]), $a([1, 34, 32]), $a([0, -1, -1]), $a([13, 19, 28]), $a([1, 17, 32]), $a([0, -1, -1])]), $a(["30", 81, 20, 3, 5591, $a([6, 84, 16]), $a([1, 82, 16]), $a([0, -1, -1]), $a([6, 70, 30]), $a([1, 68, 30]), $a([0, -1, -1]), $a([7, 35, 30]), $a([3, 33, 28]), $a([1, 32, 28]), $a([13, 20, 30]), $a([1, 20, 28]), $a([0, -1, -1])]), $a(["31", 83, 21, 3, 5903, $a([5, 105, 20]), $a([1, 94, 18]), $a([0, -1, -1]), $a([6, 74, 32]), $a([1, 71, 30]), $a([0, -1, -1]), $a([11, 33, 28]), $a([1, 34, 32]), $a([0, -1, -1]), $a([13, 19, 28]), $a([3, 16, 26]), $a([0, -1, -1])]), $a(["32", 85, 17, 4, 6033, $a([4, 127, 24]), $a([1, 126, 24]), $a([0, -1, -1]), $a([7, 66, 28]), $a([1, 66, 30]), $a([0, -1, -1]), $a([12, 30, 24]), $a([1, 24, 28]), $a([1, 24, 30]), $a([15, 19, 28]), $a([1, 17, 32]), $a([0, -1, -1])]), $a(["33", 87, 17, 4, 6353, $a([7, 84, 16]), $a([1, 78, 16]), $a([0, -1, -1]), $a([7, 70, 30]), $a([1, 66, 28]), $a([0, -1, -1]), $a([12, 33, 28]), $a([1, 32, 30]), $a([0, -1, -1]), $a([14, 21, 32]), $a([1, 24, 28]), $a([0, -1, -1])]), $a(["34", 89, 18, 4, 6689, $a([5, 117, 22]), $a([1, 117, 24]), $a([0, -1, -1]), $a([8, 66, 28]), $a([1, 58, 26]), $a([0, -1, -1]), $a([11, 38, 32]), $a([1, 34, 32]), $a([0, -1, -1]), $a([15, 20, 30]), $a([2, 17, 26]), $a([0, -1, -1])]), $a(["35", 91, 18, 4, 7025, $a([4, 148, 28]), $a([1, 146, 28]), $a([0, -1, -1]), $a([8, 68, 30]), $a([1, 70, 24]), $a([0, -1, -1]), $a([10, 36, 32]), $a([3, 38, 28]), $a([0, -1, -1]), $a([16, 19, 28]), $a([3, 16, 26]), $a([0, -1, -1])]), $a(["36", 93, 19, 4, 7377, $a([4, 126, 24]), $a([2, 135, 26]), $a([0, -1, -1]), $a([8, 70, 28]), $a([2, 43, 26]), $a([0, -1, -1]), $a([13, 32, 28]), $a([2, 41, 30]), $a([0, -1, -1]), $a([17, 19, 28]), $a([3, 15, 26]), $a([0, -1, -1])]), $a(["37", 95, 19, 4, 7729, $a([5, 136, 26]), $a([1, 132, 24]), $a([0, -1, -1]), $a([5, 67, 30]), $a([4, 68, 28]), $a([1, 69, 28]), $a([14, 35, 30]), $a([1, 32, 24]), $a([0, -1, -1]), $a([18, 18, 26]), $a([3, 16, 28]), $a([1, 14, 28])]), $a(["38", 97, 19, 4, 8089, $a([3, 142, 26]), $a([3, 141, 28]), $a([0, -1, -1]), $a([8, 70, 30]), $a([1, 73, 32]), $a([1, 74, 32]), $a([12, 34, 30]), $a([3, 34, 26]), $a([1, 35, 28]), $a([18, 21, 32]), $a([1, 27, 30]), $a([0, -1, -1])]), $a(["39", 99, 20, 4, 8465, $a([5, 116, 22]), $a([2, 103, 20]), $a([1, 102, 20]), $a([9, 74, 32]), $a([1, 74, 30]), $a([0, -1, -1]), $a([14, 34, 28]), $a([2, 32, 32]), $a([1, 32, 30]), $a([19, 21, 32]), $a([1, 25, 26]), $a([0, -1, -1])]), $a(["40", 101, 20, 4, 8841, $a([7, 116, 22]), $a([1, 117, 22]), $a([0, -1, -1]), $a([11, 65, 28]), $a([1, 58, 24]), $a([0, -1, -1]), $a([15, 38, 32]), $a([1, 27, 28]), $a([0, -1, -1]), $a([20, 20, 30]), $a([1, 20, 32]), $a([1, 21, 32])]), $a(["41", 103, 17, 5, 9009, $a([6, 136, 26]), $a([1, 130, 24]), $a([0, -1, -1]), $a([11, 66, 28]), $a([1, 62, 30]), $a([0, -1, -1]), $a([14, 34, 28]), $a([3, 34, 32]), $a([1, 30, 30]), $a([18, 20, 30]), $a([3, 20, 28]), $a([2, 15, 26])]), $a(["42", 105, 17, 5, 9401, $a([5, 105, 20]), $a([2, 115, 22]), $a([2, 116, 22]), $a([10, 75, 32]), $a([1, 73, 32]), $a([0, -1, -1]), $a([16, 38, 32]), $a([1, 27, 28]), $a([0, -1, -1]), $a([22, 19, 28]), $a([2, 16, 30]), $a([1, 19, 30])]), $a(["43", 107, 18, 5, 9799, $a([6, 147, 28]), $a([1, 146, 28]), $a([0, -1, -1]), $a([11, 66, 28]), $a([2, 65, 30]), $a([0, -1, -1]), $a([18, 33, 28]), $a([2, 33, 30]), $a([0, -1, -1]), $a([22, 21, 32]), $a([1, 28, 30]), $a([0, -1, -1])]), $a(["44", 109, 18, 5, 10207, $a([6, 116, 22]), $a([3, 125, 24]), $a([0, -1, -1]), $a([11, 75, 32]), $a([1, 68, 30]), $a([0, -1, -1]), $a([13, 35, 28]), $a([6, 34, 32]), $a([1, 30, 30]), $a([23, 21, 32]), $a([1, 26, 30]), $a([0, -1, -1])]), $a(["45", 111, 18, 5, 10623, $a([7, 105, 20]), $a([4, 95, 18]), $a([0, -1, -1]), $a([12, 67, 28]), $a([1, 63, 30]), $a([1, 62, 32]), $a([21, 31, 26]), $a([2, 33, 32]), $a([0, -1, -1]), $a([23, 21, 32]), $a([2, 24, 30]), $a([0, -1, -1])]), $a(["46", 113, 19, 5, 11045, $a([10, 116, 22]), $a([0, -1, -1]), $a([0, -1, -1]), $a([12, 74, 32]), $a([1, 78, 30]), $a([0, -1, -1]), $a([18, 37, 32]), $a([1, 39, 30]), $a([1, 41, 28]), $a([25, 21, 32]), $a([1, 27, 28]), $a([0, -1, -1])]), $a(["47", 115, 19, 5, 11477, $a([5, 126, 24]), $a([4, 115, 22]), $a([1, 114, 22]), $a([12, 67, 28]), $a([2, 66, 32]), $a([1, 68, 30]), $a([21, 35, 30]), $a([1, 39, 30]), $a([0, -1, -1]), $a([26, 21, 32]), $a([1, 28, 28]), $a([0, -1, -1])]), $a(["48", 117, 19, 5, 11917, $a([9, 126, 24]), $a([1, 117, 22]), $a([0, -1, -1]), $a([13, 75, 32]), $a([1, 68, 30]), $a([0, -1, -1]), $a([20, 35, 30]), $a([3, 35, 28]), $a([0, -1, -1]), $a([27, 21, 32]), $a([1, 28, 30]), $a([0, -1, -1])]), $a(["49", 119, 17, 6, 12111, $a([9, 126, 24]), $a([1, 137, 26]), $a([0, -1, -1]), $a([13, 71, 30]), $a([2, 68, 32]), $a([0, -1, -1]), $a([20, 37, 32]), $a([1, 39, 28]), $a([1, 38, 28]), $a([24, 20, 32]), $a([5, 25, 28]), $a([0, -1, -1])]), $a(["50", 121, 17, 6, 12559, $a([8, 147, 28]), $a([1, 141, 28]), $a([0, -1, -1]), $a([10, 73, 32]), $a([4, 74, 30]), $a([1, 73, 30]), $a([16, 36, 32]), $a([6, 39, 30]), $a([1, 37, 30]), $a([27, 21, 32]), $a([3, 20, 26]), $a([0, -1, -1])]), $a(["51", 123, 18, 6, 13025, $a([9, 137, 26]), $a([1, 135, 26]), $a([0, -1, -1]), $a([12, 70, 30]), $a([4, 75, 32]), $a([0, -1, -1]), $a([24, 35, 30]), $a([1, 40, 28]), $a([0, -1, -1]), $a([23, 20, 32]), $a([8, 24, 30]), $a([0, -1, -1])]), $a(["52", 125, 18, 6, 13489, $a([14, 95, 18]), $a([1, 86, 18]), $a([0, -1, -1]), $a([13, 73, 32]), $a([3, 77, 30]), $a([0, -1, -1]), $a([24, 35, 30]), $a([2, 35, 28]), $a([0, -1, -1]), $a([26, 21, 32]), $a([5, 21, 30]), $a([1, 23, 30])]), $a(["53", 127, 18, 6, 13961, $a([9, 147, 28]), $a([1, 142, 28]), $a([0, -1, -1]), $a([10, 73, 30]), $a([6, 70, 32]), $a([1, 71, 32]), $a([25, 35, 30]), $a([2, 34, 26]), $a([0, -1, -1]), $a([29, 21, 32]), $a([4, 22, 30]), $a([0, -1, -1])]), $a(["54", 129, 18, 6, 14441, $a([11, 126, 24]), $a([1, 131, 24]), $a([0, -1, -1]), $a([16, 74, 32]), $a([1, 79, 30]), $a([0, -1, -1]), $a([25, 38, 32]), $a([1, 25, 30]), $a([0, -1, -1]), $a([33, 21, 32]), $a([1, 28, 28]), $a([0, -1, -1])]), $a(["55", 131, 19, 6, 14939, $a([14, 105, 20]), $a([1, 99, 18]), $a([0, -1, -1]), $a([19, 65, 28]), $a([1, 72, 28]), $a([0, -1, -1]), $a([24, 37, 32]), $a([2, 40, 30]), $a([1, 41, 30]), $a([31, 21, 32]), $a([4, 24, 32]), $a([0, -1, -1])]), $a(["56", 133, 19, 6, 15435, $a([10, 147, 28]), $a([1, 151, 28]), $a([0, -1, -1]), $a([15, 71, 30]), $a([3, 71, 32]), $a([1, 73, 32]), $a([24, 37, 32]), $a([3, 38, 30]), $a([1, 39, 30]), $a([36, 19, 30]), $a([3, 29, 26]), $a([0, -1, -1])]), $a(["57", 135, 19, 6, 15939, $a([15, 105, 20]), $a([1, 99, 18]), $a([0, -1, -1]), $a([19, 70, 30]), $a([1, 64, 28]), $a([0, -1, -1]), $a([27, 38, 32]), $a([2, 25, 26]), $a([0, -1, -1]), $a([38, 20, 30]), $a([2, 18, 28]), $a([0, -1, -1])]), $a(["58", 137, 17, 7, 16171, $a([14, 105, 20]), $a([1, 113, 22]), $a([1, 114, 22]), $a([17, 67, 30]), $a([3, 92, 32]), $a([0, -1, -1]), $a([30, 35, 30]), $a([1, 41, 30]), $a([0, -1, -1]), $a([36, 21, 32]), $a([1, 26, 30]), $a([1, 27, 30])]), $a(["59", 139, 17, 7, 16691, $a([11, 146, 28]), $a([1, 146, 26]), $a([0, -1, -1]), $a([20, 70, 30]), $a([1, 60, 26]), $a([0, -1, -1]), $a([29, 38, 32]), $a([1, 24, 32]), $a([0, -1, -1]), $a([40, 20, 30]), $a([2, 17, 26]), $a([0, -1, -1])]), $a(["60", 141, 18, 7, 17215, $a([3, 137, 26]), $a([1, 136, 26]), $a([10, 126, 24]), $a([22, 65, 28]), $a([1, 75, 30]), $a([0, -1, -1]), $a([30, 37, 32]), $a([1, 51, 30]), $a([0, -1, -1]), $a([42, 20, 30]), $a([1, 21, 30]), $a([0, -1, -1])]), $a(["61", 143, 18, 7, 17751, $a([12, 126, 24]), $a([2, 118, 22]), $a([1, 116, 22]), $a([19, 74, 32]), $a([1, 74, 30]), $a([1, 72, 28]), $a([30, 38, 32]), $a([2, 29, 30]), $a([0, -1, -1]), $a([39, 20, 32]), $a([2, 37, 26]), $a([1, 38, 26])]), $a(["62", 145, 18, 7, 18295, $a([12, 126, 24]), $a([3, 136, 26]), $a([0, -1, -1]), $a([21, 70, 30]), $a([2, 65, 28]), $a([0, -1, -1]), $a([34, 35, 30]), $a([1, 44, 32]), $a([0, -1, -1]), $a([42, 20, 30]), $a([2, 19, 28]), $a([2, 18, 28])]), $a(["63", 147, 18, 7, 18847, $a([12, 126, 24]), $a([3, 117, 22]), $a([1, 116, 22]), $a([25, 61, 26]), $a([2, 62, 28]), $a([0, -1, -1]), $a([34, 35, 30]), $a([1, 40, 32]), $a([1, 41, 32]), $a([45, 20, 30]), $a([1, 20, 32]), $a([1, 21, 32])]), $a(["64", 149, 19, 7, 19403, $a([15, 105, 20]), $a([2, 115, 22]), $a([2, 116, 22]), $a([25, 65, 28]), $a([1, 72, 28]), $a([0, -1, -1]), $a([18, 35, 30]), $a([17, 37, 32]), $a([1, 50, 32]), $a([42, 20, 30]), $a([6, 19, 28]), $a([1, 15, 28])]), $a(["65", 151, 19, 7, 19971, $a([19, 105, 20]), $a([1, 101, 20]), $a([0, -1, -1]), $a([33, 51, 22]), $a([1, 65, 22]), $a([0, -1, -1]), $a([40, 33, 28]), $a([1, 28, 28]), $a([0, -1, -1]), $a([49, 20, 30]), $a([1, 18, 28]), $a([0, -1, -1])]), $a(["66", 153, 17, 8, 20229, $a([18, 105, 20]), $a([2, 117, 22]), $a([0, -1, -1]), $a([26, 65, 28]), $a([1, 80, 30]), $a([0, -1, -1]), $a([35, 35, 30]), $a([3, 35, 28]), $a([1, 36, 28]), $a([52, 18, 28]), $a([2, 38, 30]), $a([0, -1, -1])]), $a(["67", 155, 17, 8, 20805, $a([26, 84, 16]), $a([0, -1, -1]), $a([0, -1, -1]), $a([26, 70, 30]), $a([0, -1, -1]), $a([0, -1, -1]), $a([45, 31, 26]), $a([1, 9, 26]), $a([0, -1, -1]), $a([52, 20, 30]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["68", 157, 17, 8, 21389, $a([16, 126, 24]), $a([1, 114, 22]), $a([1, 115, 22]), $a([23, 70, 30]), $a([3, 65, 28]), $a([1, 66, 28]), $a([40, 35, 30]), $a([1, 43, 30]), $a([0, -1, -1]), $a([46, 20, 30]), $a([7, 19, 28]), $a([1, 16, 28])]), $a(["69", 159, 18, 8, 21993, $a([19, 116, 22]), $a([1, 105, 22]), $a([0, -1, -1]), $a([20, 70, 30]), $a([7, 66, 28]), $a([1, 63, 28]), $a([40, 35, 30]), $a([1, 42, 32]), $a([1, 43, 32]), $a([54, 20, 30]), $a([1, 19, 30]), $a([0, -1, -1])]), $a(["70", 161, 18, 8, 22593, $a([17, 126, 24]), $a([2, 115, 22]), $a([0, -1, -1]), $a([24, 70, 30]), $a([4, 74, 32]), $a([0, -1, -1]), $a([48, 31, 26]), $a([2, 18, 26]), $a([0, -1, -1]), $a([54, 19, 28]), $a([6, 15, 26]), $a([1, 14, 26])]), $a(["71", 163, 18, 8, 23201, $a([29, 84, 16]), $a([0, -1, -1]), $a([0, -1, -1]), $a([29, 70, 30]), $a([0, -1, -1]), $a([0, -1, -1]), $a([6, 34, 30]), $a([3, 36, 30]), $a([38, 33, 28]), $a([58, 20, 30]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["72", 165, 18, 8, 23817, $a([16, 147, 28]), $a([1, 149, 28]), $a([0, -1, -1]), $a([31, 66, 28]), $a([1, 37, 26]), $a([0, -1, -1]), $a([48, 33, 28]), $a([1, 23, 26]), $a([0, -1, -1]), $a([53, 20, 30]), $a([6, 19, 28]), $a([1, 17, 28])]), $a(["73", 167, 19, 8, 24453, $a([20, 115, 22]), $a([2, 134, 24]), $a([0, -1, -1]), $a([29, 66, 28]), $a([2, 56, 26]), $a([2, 57, 26]), $a([45, 36, 30]), $a([2, 15, 28]), $a([0, -1, -1]), $a([59, 20, 30]), $a([2, 21, 32]), $a([0, -1, -1])]), $a(["74", 169, 19, 8, 25085, $a([17, 147, 28]), $a([1, 134, 26]), $a([0, -1, -1]), $a([26, 70, 30]), $a([5, 75, 32]), $a([0, -1, -1]), $a([47, 35, 30]), $a([1, 48, 32]), $a([0, -1, -1]), $a([64, 18, 28]), $a([2, 33, 30]), $a([1, 35, 30])]), $a(["75", 171, 17, 9, 25373, $a([22, 115, 22]), $a([1, 133, 24]), $a([0, -1, -1]), $a([33, 65, 28]), $a([1, 74, 28]), $a([0, -1, -1]), $a([43, 36, 30]), $a([5, 27, 28]), $a([1, 30, 28]), $a([57, 20, 30]), $a([5, 21, 32]), $a([1, 24, 32])]), $a(["76", 173, 17, 9, 26021, $a([18, 136, 26]), $a([2, 142, 26]), $a([0, -1, -1]), $a([33, 66, 28]), $a([2, 49, 26]), $a([0, -1, -1]), $a([48, 35, 30]), $a([2, 38, 28]), $a([0, -1, -1]), $a([64, 20, 30]), $a([1, 20, 32]), $a([0, -1, -1])]), $a(["77", 175, 17, 9, 26677, $a([19, 126, 24]), $a([2, 135, 26]), $a([1, 136, 26]), $a([32, 66, 28]), $a([2, 55, 26]), $a([2, 56, 26]), $a([49, 36, 30]), $a([2, 18, 32]), $a([0, -1, -1]), $a([65, 18, 28]), $a([5, 27, 30]), $a([1, 29, 30])]), $a(["78", 177, 18, 9, 27335, $a([20, 137, 26]), $a([1, 130, 26]), $a([0, -1, -1]), $a([30, 75, 32]), $a([2, 71, 32]), $a([0, -1, -1]), $a([46, 35, 30]), $a([6, 39, 32]), $a([0, -1, -1]), $a([3, 12, 30]), $a([70, 19, 28]), $a([0, -1, -1])]), $a(["79", 179, 18, 9, 28007, $a([20, 147, 28]), $a([0, -1, -1]), $a([0, -1, -1]), $a([35, 70, 30]), $a([0, -1, -1]), $a([0, -1, -1]), $a([49, 35, 30]), $a([5, 35, 28]), $a([0, -1, -1]), $a([70, 20, 30]), $a([0, -1, -1]), $a([0, -1, -1])]), $a(["80", 181, 18, 9, 28687, $a([21, 136, 26]), $a([1, 155, 28]), $a([0, -1, -1]), $a([34, 70, 30]), $a([1, 64, 28]), $a([1, 65, 28]), $a([54, 35, 30]), $a([1, 45, 30]), $a([0, -1, -1]), $a([68, 20, 30]), $a([3, 18, 28]), $a([1, 19, 28])]), $a(["81", 183, 18, 9, 29375, $a([19, 126, 24]), $a([5, 115, 22]), $a([1, 114, 22]), $a([33, 70, 30]), $a([3, 65, 28]), $a([1, 64, 28]), $a([52, 35, 30]), $a([3, 41, 32]), $a([1, 40, 32]), $a([67, 20, 30]), $a([5, 21, 32]), $a([1, 24, 32])]), $a(["82", 185, 18, 9, 30071, $a([2, 150, 28]), $a([21, 136, 26]), $a([0, -1, -1]), $a([32, 70, 30]), $a([6, 65, 28]), $a([0, -1, -1]), $a([52, 38, 32]), $a([2, 27, 32]), $a([0, -1, -1]), $a([73, 20, 30]), $a([2, 22, 32]), $a([0, -1, -1])]), $a(["83", 187, 17, 10, 30387, $a([21, 126, 24]), $a([4, 136, 26]), $a([0, -1, -1]), $a([30, 74, 32]), $a([6, 73, 30]), $a([0, -1, -1]), $a([54, 35, 30]), $a([4, 40, 32]), $a([0, -1, -1]), $a([75, 20, 30]), $a([1, 20, 28]), $a([0, -1, -1])]), $a(["84", 189, 17, 10, 31091, $a([30, 105, 20]), $a([1, 114, 22]), $a([0, -1, -1]), $a([3, 45, 22]), $a([55, 47, 20]), $a([0, -1, -1]), $a([2, 26, 26]), $a([62, 33, 28]), $a([0, -1, -1]), $a([79, 18, 28]), $a([4, 33, 30]), $a([0, -1, -1])])]); //#23481
    $1.eclval = $get($1.eclevel, 1) - 49; //#23484
    for (var _II = 0; _II <= 83; _II += 1) { //#23504
        $1.i = _II; //#23486
        $1.m = $get($1.metrics, $1.i); //#23487
        $1.vers = $get($1.m, 0); //#23488
        $1.size = $get($1.m, 1); //#23489
        $1.alnk = $get($1.m, 2); //#23490
        $1.alnn = $get($1.m, 3); //#23491
        $1.alnr = $f($1.size - ($1.alnk * $1.alnn)); //#23492
        $1.nmod = $get($1.m, 4); //#23493
        $1.ncws = ~~($1.nmod / 8); //#23494
        $1.rbit = $1.nmod % 8; //#23495
        $1.ecbs = $geti($1.m, 5 + ($1.eclval * 3), 3); //#23496
        var _Ie = $1.ecbs; //#23497
        $k[$j++] = 'ecws'; //#23497
        $k[$j++] = 0; //#23497
        for (var _If = 0, _Ig = _Ie.length; _If < _Ig; _If++) { //#23497
            var _Ih = $get(_Ie, _If); //#23497
            var _Ik = $k[--$j]; //#23497
            $k[$j++] = $f(_Ik + ($get(_Ih, 0) * $get(_Ih, 2))); //#23497
        } //#23497
        var _Il = $k[--$j]; //#23497
        $1[$k[--$j]] = _Il; //#23497
        $1.dcws = $f($1.ncws - $1.ecws); //#23498
        $1.dmod = $1.dcws * 8; //#23499
        $1.okay = true; //#23500
        if ($ne($1.version, "unset") && $ne($1.version, $1.vers)) { //#23501
            $1.okay = false; //#23501
        } //#23501
        if ($1.bits.length > $1.dmod) { //#23502
            $1.okay = false; //#23502
        } //#23502
        if ($1.okay) { //#23503
            break; //#23503
        } //#23503
    } //#23503
    if (!$1.okay) { //#23508
        $k[$j++] = 'bwipp.hanxinNoValidSymbol'; //#23507
        $k[$j++] = "Maximum length exceeded or invalid content"; //#23507
        bwipp_raiseerror(); //#23507
    } //#23507
    $1.version = $1.vers; //#23510
    $1.msgbits = $1.bits; //#23511
    $1.e1nb = $get($get($1.ecbs, 0), 0); //#23512
    $1.e2nb = $get($get($1.ecbs, 1), 0); //#23512
    $1.e3nb = $get($get($1.ecbs, 2), 0); //#23512
    $1.e1dcws = $get($get($1.ecbs, 0), 1); //#23513
    $1.e2dcws = $get($get($1.ecbs, 1), 1); //#23513
    $1.e3dcws = $get($get($1.ecbs, 2), 1); //#23513
    $1.e1ecws = $get($get($1.ecbs, 0), 2); //#23514
    $1.e2ecws = $get($get($1.ecbs, 1), 2); //#23514
    $1.e3ecws = $get($get($1.ecbs, 2), 2); //#23514
    $1.pad = $s($1.dmod); //#23517
    for (var _JU = 0, _JT = $1.pad.length - 1; _JU <= _JT; _JU += 1) { //#23518
        $put($1.pad, _JU, 48); //#23518
    } //#23518
    $puti($1.pad, 0, $1.msgbits); //#23519
    $1.cws = $a($1.dcws); //#23522
    for (var _Jc = 0, _Jb = $1.cws.length - 1; _Jc <= _Jb; _Jc += 1) { //#23532
        $1.c = _Jc; //#23524
        $1.cwb = $geti($1.pad, $1.c * 8, 8); //#23525
        $1.cw = 0; //#23526
        for (var _Jg = 0; _Jg <= 7; _Jg += 1) { //#23530
            $1.i = _Jg; //#23528
            $1.cw = $f($1.cw + ((~~(Math.pow(2, (8 - $1.i) - 1))) * $f($get($1.cwb, $1.i) - 48))); //#23529
        } //#23529
        $put($1.cws, $1.c, $1.cw); //#23531
    } //#23531
    $1.rscodes = function() {
        $1.rspm = $k[--$j]; //#23536
        $1.rsgf = $k[--$j]; //#23537
        $1.rsnc = $k[--$j]; //#23538
        $1.rscws = $k[--$j]; //#23539
        $k[$j++] = Infinity; //#23542
        $k[$j++] = 1; //#23542
        for (var _Ju = 0, _Jv = $f($1.rsgf - 1); _Ju < _Jv; _Ju++) { //#23542
            var _Jw = $k[--$j]; //#23542
            var _Jx = _Jw * 2; //#23542
            $k[$j++] = _Jw; //#23542
            $k[$j++] = _Jx; //#23542
            if (_Jx >= $1.rsgf) { //#23542
                var _K0 = $k[--$j]; //#23542
                $k[$j++] = $xo(_K0, $1.rspm); //#23542
            } //#23542
        } //#23542
        $1.rsalog = $a(); //#23542
        $1.rslog = $a($1.rsgf); //#23543
        for (var _K6 = 1, _K5 = $f($1.rsgf - 1); _K6 <= _K5; _K6 += 1) { //#23544
            $put($1.rslog, $get($1.rsalog, _K6), _K6); //#23544
        } //#23544
        $1.rsprod = function() {
            var _KA = $k[--$j]; //#23548
            var _KB = $k[--$j]; //#23548
            $k[$j++] = _KB; //#23552
            $k[$j++] = _KA; //#23552
            if ((_KA != 0) && (_KB != 0)) { //#23551
                var _KE = $get($1.rslog, $k[--$j]); //#23549
                var _KK = $get($1.rsalog, $f(_KE + $get($1.rslog, $k[--$j])) % $f($1.rsgf - 1)); //#23549
                $k[$j++] = _KK; //#23549
            } else { //#23551
                $j -= 2; //#23551
                $k[$j++] = 0; //#23551
            } //#23551
        }; //#23551
        $k[$j++] = Infinity; //#23556
        $k[$j++] = 1; //#23556
        for (var _KM = 0, _KN = $1.rsnc; _KM < _KN; _KM++) { //#23556
            $k[$j++] = 0; //#23556
        } //#23556
        $1.coeffs = $a(); //#23556
        for (var _KR = 1, _KQ = $1.rsnc; _KR <= _KQ; _KR += 1) { //#23565
            $1.i = _KR; //#23558
            $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#23559
            for (var _KY = $1.i - 1; _KY >= 1; _KY -= 1) { //#23563
                $1.j = _KY; //#23561
                $k[$j++] = $1.coeffs; //#23562
                $k[$j++] = $1.j; //#23562
                $k[$j++] = $get($1.coeffs, $1.j - 1); //#23562
                $k[$j++] = $get($1.coeffs, $1.j); //#23562
                $k[$j++] = $get($1.rsalog, $1.i); //#23562
                $1.rsprod(); //#23562
                var _Kk = $k[--$j]; //#23562
                var _Kl = $k[--$j]; //#23562
                var _Km = $k[--$j]; //#23562
                $put($k[--$j], _Km, $xo(_Kl, _Kk)); //#23562
            } //#23562
            $k[$j++] = $1.coeffs; //#23564
            $k[$j++] = 0; //#23564
            $k[$j++] = $get($1.coeffs, 0); //#23564
            $k[$j++] = $get($1.rsalog, $1.i); //#23564
            $1.rsprod(); //#23564
            var _Ku = $k[--$j]; //#23564
            var _Kv = $k[--$j]; //#23564
            $put($k[--$j], _Kv, _Ku); //#23564
        } //#23564
        $1.nd = $1.rscws.length; //#23568
        $k[$j++] = Infinity; //#23569
        $forall($1.rscws); //#23569
        for (var _L0 = 0, _L1 = $1.rsnc; _L0 < _L1; _L0++) { //#23569
            $k[$j++] = 0; //#23569
        } //#23569
        $k[$j++] = 0; //#23569
        $1.rscws = $a(); //#23569
        for (var _L5 = 0, _L4 = $1.nd - 1; _L5 <= _L4; _L5 += 1) { //#23576
            $1.k = $xo($get($1.rscws, _L5), $get($1.rscws, $1.nd)); //#23571
            for (var _LD = 0, _LC = $f($1.rsnc - 1); _LD <= _LC; _LD += 1) { //#23575
                $1.j = _LD; //#23573
                $k[$j++] = $1.rscws; //#23574
                $k[$j++] = $1.nd + $1.j; //#23574
                $k[$j++] = $get($1.rscws, ($1.nd + $1.j) + 1); //#23574
                $k[$j++] = $1.k; //#23574
                $k[$j++] = $get($1.coeffs, $f($f($1.rsnc - $1.j) - 1)); //#23574
                $1.rsprod(); //#23574
                var _LQ = $k[--$j]; //#23574
                var _LR = $k[--$j]; //#23574
                var _LS = $k[--$j]; //#23574
                $put($k[--$j], _LS, $xo(_LR, _LQ)); //#23574
            } //#23574
        } //#23574
        $k[$j++] = $geti($1.rscws, 0, $1.rscws.length - 1); //#23579
    }; //#23579
    $1.dcwsb = $a($f($f($1.e1nb + $1.e2nb) + $1.e3nb)); //#23584
    $1.ecwsb = $a($1.dcwsb.length); //#23585
    $1.in = 0; //#23586
    $1.out = 0; //#23586
    for (var _Le = 0, _Lf = $1.e1nb; _Le < _Lf; _Le++) { //#23592
        $k[$j++] = $geti($1.cws, $1.in, $1.e1dcws); //#23588
        $k[$j++] = $1.e1ecws; //#23588
        $k[$j++] = 256; //#23588
        $k[$j++] = 355; //#23588
        $1.rscodes(); //#23588
        var _Ll = $k[--$j]; //#23589
        $put($1.dcwsb, $1.out, $geti(_Ll, 0, $1.e1dcws)); //#23589
        $put($1.ecwsb, $1.out, $geti(_Ll, $1.e1dcws, $1.e1ecws)); //#23590
        $1.in = $f($1.in + $1.e1dcws); //#23591
        $1.out = $1.out + 1; //#23591
    } //#23591
    for (var _Lz = 0, _M0 = $1.e2nb; _Lz < _M0; _Lz++) { //#23598
        $k[$j++] = $geti($1.cws, $1.in, $1.e2dcws); //#23594
        $k[$j++] = $1.e2ecws; //#23594
        $k[$j++] = 256; //#23594
        $k[$j++] = 355; //#23594
        $1.rscodes(); //#23594
        var _M6 = $k[--$j]; //#23595
        $put($1.dcwsb, $1.out, $geti(_M6, 0, $1.e2dcws)); //#23595
        $put($1.ecwsb, $1.out, $geti(_M6, $1.e2dcws, $1.e2ecws)); //#23596
        $1.in = $f($1.in + $1.e2dcws); //#23597
        $1.out = $1.out + 1; //#23597
    } //#23597
    for (var _MK = 0, _ML = $1.e3nb; _MK < _ML; _MK++) { //#23604
        $k[$j++] = $geti($1.cws, $1.in, $1.e3dcws); //#23600
        $k[$j++] = $1.e3ecws; //#23600
        $k[$j++] = 256; //#23600
        $k[$j++] = 355; //#23600
        $1.rscodes(); //#23600
        var _MR = $k[--$j]; //#23601
        $put($1.dcwsb, $1.out, $geti(_MR, 0, $1.e3dcws)); //#23601
        $put($1.ecwsb, $1.out, $geti(_MR, $1.e3dcws, $1.e3ecws)); //#23602
        $1.in = $f($1.in + $1.e3dcws); //#23603
        $1.out = $1.out + 1; //#23603
    } //#23603
    $1.cws = $a($1.ncws); //#23607
    $1.cw = 0; //#23608
    for (var _Mi = 0, _Mh = $1.dcwsb.length - 1; _Mi <= _Mh; _Mi += 1) { //#23613
        $1.i = _Mi; //#23610
        var _Ml = $get($1.dcwsb, $1.i); //#23611
        $puti($1.cws, $1.cw, _Ml); //#23611
        $1.cw = _Ml.length + $1.cw; //#23611
        var _Mr = $get($1.ecwsb, $1.i); //#23612
        $puti($1.cws, $1.cw, _Mr); //#23612
        $1.cw = _Mr.length + $1.cw; //#23612
    } //#23612
    $k[$j++] = Infinity; //#23618
    var _Mv = $1.ncws; //#23617
    var _Mw = 12; //#23617
    var _Mx = _Mv - 1; //#23617
    if ((_Mv - 1) > 12) { //#23617
        var _ = _Mw; //#23617
        _Mw = _Mx; //#23617
        _Mx = _; //#23617
    } //#23617
    for (var _Mz = 0, _My = _Mx; _Mz <= _My; _Mz += 1) { //#23619
        for (var _N2 = _Mz, _N1 = $1.ncws - 1; _N2 <= _N1; _N2 += 13) { //#23618
            $k[$j++] = _N2; //#23618
            if (_N2 < $1.ncws) { //#23618
                var _N6 = $get($1.cws, $k[--$j]); //#23618
                $k[$j++] = _N6; //#23618
            } else { //#23618
                $j--; //#23618
            } //#23618
        } //#23618
    } //#23618
    $1.cws = $a(); //#23618
    if ($1.rbit > 0) { //#23628
        $1.pad = $a($1.cws.length + 1); //#23624
        $puti($1.pad, 0, $1.cws); //#23625
        $put($1.pad, $1.pad.length - 1, 0); //#23626
        $1.cws = $1.pad; //#23627
    } //#23627
    $k[$j++] = Infinity; //#23631
    for (var _NI = 0, _NJ = $1.size * $1.size; _NI < _NJ; _NI++) { //#23631
        $k[$j++] = -1; //#23631
    } //#23631
    $1.pixs = $a(); //#23631
    $1.qmv = function() {
        var _NM = $k[--$j]; //#23632
        var _NN = $k[--$j]; //#23632
        $k[$j++] = $f(_NN + (_NM * $1.size)); //#23632
    }; //#23632
    if ($1.alnn != 0) { //#23691
        $1.trmv = function() {
            var _NQ = $k[--$j]; //#23636
            var _NS = $k[--$j]; //#23636
            $k[$j++] = $f(($f(($f((_NQ * $1.size) + $1.size)) - 1)) - _NS); //#23636
        }; //#23636
        $1.aplot = function() {
            var _NT = $k[--$j]; //#23638
            var _NU = $k[--$j]; //#23638
            var _NV = $k[--$j]; //#23638
            $k[$j++] = _NT; //#23638
            $k[$j++] = _NV; //#23638
            $k[$j++] = _NU; //#23638
            $k[$j++] = _NT; //#23638
            $k[$j++] = _NU; //#23638
            $k[$j++] = _NV; //#23638
            $1.trmv(); //#23638
            var _NX = $k[--$j]; //#23638
            $put($1.pixs, _NX, $k[--$j]); //#23638
            $1.trmv(); //#23639
            var _Na = $k[--$j]; //#23639
            $put($1.pixs, _Na, $k[--$j]); //#23639
        }; //#23639
        $1.i = 0; //#23641
        $1.stag = 0; //#23641
        for (;;) { //#23663
            if ($1.i >= $1.size) { //#23642
                break; //#23642
            } //#23642
            for (var _Ng = 0, _Nf = $f($1.size - 1); _Ng <= _Nf; _Ng += 1) { //#23656
                $1.j = _Ng; //#23644
                if ($f($1.j + $1.alnr) < $1.size) { //#23650
                    $k[$j++] = (((((~~($1.j / $1.alnk)) + $1.stag) % 2) == 0) && (!(($1.i == 0) && ($1.j < $1.alnk)))) || (($1.j % $1.alnk) == 0); //#23648
                } else { //#23650
                    $k[$j++] = ($f($1.alnn + $1.stag) % 2) == 0; //#23650
                } //#23650
                if ($k[--$j]) { //#23655
                    $k[$j++] = $1.j; //#23653
                    $k[$j++] = $1.i; //#23653
                    $k[$j++] = 1; //#23653
                    $1.aplot(); //#23653
                    var _Nx = $1.j; //#23654
                    var _Ny = $1.i; //#23654
                    $k[$j++] = _Nx + 1; //#23654
                    $k[$j++] = _Ny + 1; //#23654
                    if (((_Ny + 1) < $1.size) && ((_Nx + 1) < $1.size)) { //#23654
                        $k[$j++] = 0; //#23654
                        $1.aplot(); //#23654
                    } else { //#23654
                        $j -= 2; //#23654
                    } //#23654
                } //#23654
            } //#23654
            if ($f($1.i + $1.alnr) == $1.size) { //#23660
                $1.i = $f($f($1.i + $1.alnr) - 1); //#23658
            } else { //#23660
                $1.i = $f($1.i + $1.alnk); //#23660
            } //#23660
            $1.stag = 1 - $1.stag; //#23662
        } //#23662
        for (var _OD = $1.alnk, _OE = $1.alnk, _OC = $f($1.size - 2); _OE < 0 ? _OD >= _OC : _OD <= _OC; _OD += _OE) { //#23690
            $1.i = _OD; //#23665
            if (((~~($1.i / $1.alnk)) % 2) != 0) { //#23677
                $k[$j++] = $1.pixs; //#23667
                $k[$j++] = 0; //#23667
                $k[$j++] = $1.i - 1; //#23667
                $1.trmv(); //#23667
                var _OJ = $k[--$j]; //#23667
                $put($k[--$j], _OJ, 0); //#23667
                $k[$j++] = $1.pixs; //#23668
                $k[$j++] = 0; //#23668
                $k[$j++] = $1.i + 1; //#23668
                $1.trmv(); //#23668
                var _ON = $k[--$j]; //#23668
                $put($k[--$j], _ON, 0); //#23668
                $k[$j++] = $1.pixs; //#23669
                $k[$j++] = 1; //#23669
                $k[$j++] = $1.i - 1; //#23669
                $1.trmv(); //#23669
                var _OR = $k[--$j]; //#23669
                $put($k[--$j], _OR, 0); //#23669
                $k[$j++] = $1.pixs; //#23670
                $k[$j++] = 1; //#23670
                $k[$j++] = $1.i; //#23670
                $1.trmv(); //#23670
                var _OV = $k[--$j]; //#23670
                $put($k[--$j], _OV, 0); //#23670
                $k[$j++] = $1.pixs; //#23671
                $k[$j++] = 1; //#23671
                $k[$j++] = $1.i + 1; //#23671
                $1.trmv(); //#23671
                var _OZ = $k[--$j]; //#23671
                $put($k[--$j], _OZ, 0); //#23671
                $k[$j++] = $1.pixs; //#23672
                $k[$j++] = $1.i - 1; //#23672
                $k[$j++] = 0; //#23672
                $1.trmv(); //#23672
                var _Od = $k[--$j]; //#23672
                $put($k[--$j], _Od, 0); //#23672
                $k[$j++] = $1.pixs; //#23673
                $k[$j++] = $1.i + 1; //#23673
                $k[$j++] = 0; //#23673
                $1.trmv(); //#23673
                var _Oh = $k[--$j]; //#23673
                $put($k[--$j], _Oh, 0); //#23673
                $k[$j++] = $1.pixs; //#23674
                $k[$j++] = $1.i - 1; //#23674
                $k[$j++] = 1; //#23674
                $1.trmv(); //#23674
                var _Ol = $k[--$j]; //#23674
                $put($k[--$j], _Ol, 0); //#23674
                $k[$j++] = $1.pixs; //#23675
                $k[$j++] = $1.i; //#23675
                $k[$j++] = 1; //#23675
                $1.trmv(); //#23675
                var _Op = $k[--$j]; //#23675
                $put($k[--$j], _Op, 0); //#23675
                $k[$j++] = $1.pixs; //#23676
                $k[$j++] = $1.i + 1; //#23676
                $k[$j++] = 1; //#23676
                $1.trmv(); //#23676
                var _Ot = $k[--$j]; //#23676
                $put($k[--$j], _Ot, 0); //#23676
            } //#23676
            $k[$j++] = $1.pixs; //#23678
            $k[$j++] = $f($1.size - 1); //#23678
            $k[$j++] = $1.i - 1; //#23678
            $1.trmv(); //#23678
            var _Oy = $k[--$j]; //#23678
            if ($get($k[--$j], _Oy) != 1) { //#23689
                $k[$j++] = $1.pixs; //#23679
                $k[$j++] = $f($1.size - 1); //#23679
                $k[$j++] = $1.i - 1; //#23679
                $1.trmv(); //#23679
                var _P4 = $k[--$j]; //#23679
                $put($k[--$j], _P4, 0); //#23679
                $k[$j++] = $1.pixs; //#23680
                $k[$j++] = $f($1.size - 2); //#23680
                $k[$j++] = $1.i - 1; //#23680
                $1.trmv(); //#23680
                var _P9 = $k[--$j]; //#23680
                $put($k[--$j], _P9, 0); //#23680
                $k[$j++] = $1.pixs; //#23681
                $k[$j++] = $f($1.size - 2); //#23681
                $k[$j++] = $1.i; //#23681
                $1.trmv(); //#23681
                var _PE = $k[--$j]; //#23681
                $put($k[--$j], _PE, 0); //#23681
                $k[$j++] = $1.pixs; //#23682
                $k[$j++] = $f($1.size - 2); //#23682
                $k[$j++] = $1.i + 1; //#23682
                $1.trmv(); //#23682
                var _PJ = $k[--$j]; //#23682
                $put($k[--$j], _PJ, 0); //#23682
                $k[$j++] = $1.pixs; //#23683
                $k[$j++] = $f($1.size - 1); //#23683
                $k[$j++] = $1.i + 1; //#23683
                $1.trmv(); //#23683
                var _PO = $k[--$j]; //#23683
                $put($k[--$j], _PO, 0); //#23683
                $k[$j++] = $1.pixs; //#23684
                $k[$j++] = $1.i - 1; //#23684
                $k[$j++] = $f($1.size - 1); //#23684
                $1.trmv(); //#23684
                var _PT = $k[--$j]; //#23684
                $put($k[--$j], _PT, 0); //#23684
                $k[$j++] = $1.pixs; //#23685
                $k[$j++] = $1.i - 1; //#23685
                $k[$j++] = $f($1.size - 2); //#23685
                $1.trmv(); //#23685
                var _PY = $k[--$j]; //#23685
                $put($k[--$j], _PY, 0); //#23685
                $k[$j++] = $1.pixs; //#23686
                $k[$j++] = $1.i; //#23686
                $k[$j++] = $f($1.size - 2); //#23686
                $1.trmv(); //#23686
                var _Pd = $k[--$j]; //#23686
                $put($k[--$j], _Pd, 0); //#23686
                $k[$j++] = $1.pixs; //#23687
                $k[$j++] = $1.i + 1; //#23687
                $k[$j++] = $f($1.size - 2); //#23687
                $1.trmv(); //#23687
                var _Pi = $k[--$j]; //#23687
                $put($k[--$j], _Pi, 0); //#23687
                $k[$j++] = $1.pixs; //#23688
                $k[$j++] = $1.i + 1; //#23688
                $k[$j++] = $f($1.size - 1); //#23688
                $1.trmv(); //#23688
                var _Pn = $k[--$j]; //#23688
                $put($k[--$j], _Pn, 0); //#23688
            } //#23688
        } //#23688
    } //#23688
    $1.fpat = $a([$a([1, 1, 1, 1, 1, 1, 1, 0]), $a([1, 0, 0, 0, 0, 0, 0, 0]), $a([1, 0, 1, 1, 1, 1, 1, 0]), $a([1, 0, 1, 0, 0, 0, 0, 0]), $a([1, 0, 1, 0, 1, 1, 1, 0]), $a([1, 0, 1, 0, 1, 1, 1, 0]), $a([1, 0, 1, 0, 1, 1, 1, 0]), $a([0, 0, 0, 0, 0, 0, 0, 0])]); //#23704
    $1.fpat2 = $a([$a([1, 1, 1, 0, 1, 0, 1, 0]), $a([1, 1, 1, 0, 1, 0, 1, 0]), $a([1, 1, 1, 0, 1, 0, 1, 0]), $a([0, 0, 0, 0, 1, 0, 1, 0]), $a([1, 1, 1, 1, 1, 0, 1, 0]), $a([0, 0, 0, 0, 0, 0, 1, 0]), $a([1, 1, 1, 1, 1, 1, 1, 0]), $a([0, 0, 0, 0, 0, 0, 0, 0])]); //#23714
    for (var _Q9 = 0, _Q8 = $1.fpat.length - 1; _Q9 <= _Q8; _Q9 += 1) { //#23727
        $1.y = _Q9; //#23717
        for (var _QD = 0, _QC = $get($1.fpat, 0).length - 1; _QD <= _QC; _QD += 1) { //#23726
            $1.x = _QD; //#23719
            $1.fpb = $get($get($1.fpat, $1.y), $1.x); //#23720
            $1.fpb2 = $get($get($1.fpat2, $1.y), $1.x); //#23721
            $k[$j++] = $1.pixs; //#23722
            $k[$j++] = $1.x; //#23722
            $k[$j++] = $1.y; //#23722
            $1.qmv(); //#23722
            var _QS = $k[--$j]; //#23722
            $put($k[--$j], _QS, $1.fpb); //#23722
            $k[$j++] = $1.pixs; //#23723
            $k[$j++] = $f($f($1.size - $1.x) - 1); //#23723
            $k[$j++] = $1.y; //#23723
            $1.qmv(); //#23723
            var _QZ = $k[--$j]; //#23723
            $put($k[--$j], _QZ, $1.fpb); //#23723
            $k[$j++] = $1.pixs; //#23724
            $k[$j++] = $f($f($1.size - $1.x) - 1); //#23724
            $k[$j++] = $f($f($1.size - $1.y) - 1); //#23724
            $1.qmv(); //#23724
            var _Qh = $k[--$j]; //#23724
            $put($k[--$j], _Qh, $1.fpb); //#23724
            $k[$j++] = $1.pixs; //#23725
            $k[$j++] = $1.x; //#23725
            $k[$j++] = $f($f($1.size - $1.y) - 1); //#23725
            $1.qmv(); //#23725
            var _Qo = $k[--$j]; //#23725
            $put($k[--$j], _Qo, $1.fpb2); //#23725
        } //#23725
    } //#23725
    $1.functionmap = $a([$a([$a([0, 8]), $a([$f($1.size - 1), $f($1.size - 9)])]), $a([$a([1, 8]), $a([$f($1.size - 2), $f($1.size - 9)])]), $a([$a([2, 8]), $a([$f($1.size - 3), $f($1.size - 9)])]), $a([$a([3, 8]), $a([$f($1.size - 4), $f($1.size - 9)])]), $a([$a([4, 8]), $a([$f($1.size - 5), $f($1.size - 9)])]), $a([$a([5, 8]), $a([$f($1.size - 6), $f($1.size - 9)])]), $a([$a([6, 8]), $a([$f($1.size - 7), $f($1.size - 9)])]), $a([$a([7, 8]), $a([$f($1.size - 8), $f($1.size - 9)])]), $a([$a([8, 8]), $a([$f($1.size - 9), $f($1.size - 9)])]), $a([$a([8, 7]), $a([$f($1.size - 9), $f($1.size - 8)])]), $a([$a([8, 6]), $a([$f($1.size - 9), $f($1.size - 7)])]), $a([$a([8, 5]), $a([$f($1.size - 9), $f($1.size - 6)])]), $a([$a([8, 4]), $a([$f($1.size - 9), $f($1.size - 5)])]), $a([$a([8, 3]), $a([$f($1.size - 9), $f($1.size - 4)])]), $a([$a([8, 2]), $a([$f($1.size - 9), $f($1.size - 3)])]), $a([$a([8, 1]), $a([$f($1.size - 9), $f($1.size - 2)])]), $a([$a([8, 0]), $a([$f($1.size - 9), $f($1.size - 1)])]), $a([$a([$f($1.size - 9), 0]), $a([8, $f($1.size - 1)])]), $a([$a([$f($1.size - 9), 1]), $a([8, $f($1.size - 2)])]), $a([$a([$f($1.size - 9), 2]), $a([8, $f($1.size - 3)])]), $a([$a([$f($1.size - 9), 3]), $a([8, $f($1.size - 4)])]), $a([$a([$f($1.size - 9), 4]), $a([8, $f($1.size - 5)])]), $a([$a([$f($1.size - 9), 5]), $a([8, $f($1.size - 6)])]), $a([$a([$f($1.size - 9), 6]), $a([8, $f($1.size - 7)])]), $a([$a([$f($1.size - 9), 7]), $a([8, $f($1.size - 8)])]), $a([$a([$f($1.size - 9), 8]), $a([8, $f($1.size - 9)])]), $a([$a([$f($1.size - 8), 8]), $a([7, $f($1.size - 9)])]), $a([$a([$f($1.size - 7), 8]), $a([6, $f($1.size - 9)])]), $a([$a([$f($1.size - 6), 8]), $a([5, $f($1.size - 9)])]), $a([$a([$f($1.size - 5), 8]), $a([4, $f($1.size - 9)])]), $a([$a([$f($1.size - 4), 8]), $a([3, $f($1.size - 9)])]), $a([$a([$f($1.size - 3), 8]), $a([2, $f($1.size - 9)])]), $a([$a([$f($1.size - 2), 8]), $a([1, $f($1.size - 9)])]), $a([$a([$f($1.size - 1), 8]), $a([0, $f($1.size - 9)])])]); //#23749
    var _Tb = $1.functionmap; //#23750
    for (var _Tc = 0, _Td = _Tb.length; _Tc < _Td; _Tc++) { //#23752
        $forall($get(_Tb, _Tc), function() { //#23751
            $forall($k[--$j]); //#23751
            $1.qmv(); //#23751
            $put($1.pixs, $k[--$j], 0); //#23751
        }); //#23751
    } //#23751
    var _To = $a([function() {
        $j -= 2; //#23755
        $k[$j++] = 1; //#23755
    }, function() {
        var _Ti = $k[--$j]; //#23756
        var _Tj = $k[--$j]; //#23756
        $k[$j++] = $f(_Tj + _Ti) % 2; //#23756
    }, function() {
        var _Tk = $k[--$j]; //#23757
        var _Tl = $k[--$j]; //#23757
        $k[$j++] = ($f(($f(_Tk + _Tl) % 3) + (_Tl % 3))) % 2; //#23757
    }, function() {
        var _Tm = $k[--$j]; //#23758
        var _Tn = $k[--$j]; //#23758
        $k[$j++] = ($f((_Tn % _Tm) + ($f((_Tm % _Tn) + ($f((_Tm % 3) + (_Tn % 3))))))) % 2; //#23759
    }]); //#23759
    $1.maskfuncs = _To; //#23760
    if ($1.mask != -1) { //#23764
        $1.maskfuncs = $a([$get($1.maskfuncs, $1.mask - 1)]); //#23762
        $1.bestmaskval = $1.mask - 1; //#23763
    } //#23763
    $1.masks = $a($1.maskfuncs.length); //#23765
    for (var _Tz = 0, _Ty = $1.masks.length - 1; _Tz <= _Ty; _Tz += 1) { //#23779
        $1.m = _Tz; //#23767
        $1.mask = $a($1.size * $1.size); //#23768
        for (var _U5 = 0, _U4 = $f($1.size - 1); _U5 <= _U4; _U5 += 1) { //#23777
            $1.j = _U5; //#23770
            for (var _U8 = 0, _U7 = $f($1.size - 1); _U8 <= _U7; _U8 += 1) { //#23776
                $1.i = _U8; //#23772
                $k[$j++] = $1.i + 1; //#23773
                $k[$j++] = $1.j + 1; //#23773
                if ($get($1.maskfuncs, $1.m)() === true) {
                    break;
                } //#23773
                var _UE = $k[--$j]; //#23773
                $k[$j++] = _UE == 0; //#23774
                $k[$j++] = $1.pixs; //#23774
                $k[$j++] = $1.i; //#23774
                $k[$j++] = $1.j; //#23774
                $1.qmv(); //#23774
                var _UI = $k[--$j]; //#23774
                var _UK = $get($k[--$j], _UI); //#23774
                var _UL = $k[--$j]; //#23774
                var _UM = (_UL && (_UK == -1)) ? 1 : 0; //#23774
                $k[$j++] = _UM; //#23775
                $k[$j++] = $1.mask; //#23775
                $k[$j++] = $1.i; //#23775
                $k[$j++] = $1.j; //#23775
                $1.qmv(); //#23775
                var _UQ = $k[--$j]; //#23775
                var _UR = $k[--$j]; //#23775
                $put(_UR, _UQ, $k[--$j]); //#23775
            } //#23775
        } //#23775
        $put($1.masks, $1.m, $1.mask); //#23778
    } //#23778
    $1.posx = 0; //#23782
    $1.posy = 0; //#23783
    $1.num = 0; //#23784
    for (;;) { //#23794
        if ($1.posy == $1.size) { //#23786
            break; //#23786
        } //#23786
        $k[$j++] = $1.pixs; //#23787
        $k[$j++] = $1.posx; //#23787
        $k[$j++] = $1.posy; //#23787
        $1.qmv(); //#23787
        var _Ub = $k[--$j]; //#23787
        if ($get($k[--$j], _Ub) == -1) { //#23791
            var _Ug = $get($1.cws, ~~($1.num / 8)); //#23788
            var _Ui = -(7 - ($1.num % 8)); //#23788
            $k[$j++] = ((_Ui < 0 ? _Ug >>> -_Ui : _Ug << _Ui)) & 1; //#23789
            $k[$j++] = $1.pixs; //#23789
            $k[$j++] = $1.posx; //#23789
            $k[$j++] = $1.posy; //#23789
            $1.qmv(); //#23789
            var _Um = $k[--$j]; //#23789
            var _Un = $k[--$j]; //#23789
            $put(_Un, _Um, $k[--$j]); //#23789
            $1.num = $1.num + 1; //#23790
        } //#23790
        $1.posx = $1.posx + 1; //#23792
        if ($1.posx == $1.size) { //#23793
            $1.posx = 0; //#23793
            $1.posy = $1.posy + 1; //#23793
        } //#23793
    } //#23793
    $1.evalfulln1n3 = function() {
        $1.scrle = $k[--$j]; //#23798
        $k[$j++] = 'scr1'; //#23800
        $k[$j++] = 0; //#23800
        $forall($1.scrle, function() { //#23800
            var _Uw = $k[--$j]; //#23800
            $k[$j++] = _Uw; //#23800
            if (_Uw >= 3) { //#23800
                var _Ux = $k[--$j]; //#23800
                var _Uz = $f($k[--$j] + (_Ux * 4)); //#23800
                $k[$j++] = _Uz; //#23800
                $k[$j++] = _Uz; //#23800
            } //#23800
            $j--; //#23800
        }); //#23800
        var _V0 = $k[--$j]; //#23800
        $1[$k[--$j]] = _V0; //#23800
        $1.scr3 = 0; //#23801
        for (var _V4 = 5, _V3 = $1.scrle.length - 1; _V4 <= _V3; _V4 += 2) { //#23817
            $1.j = _V4; //#23804
            if (($get($1.scrle, $1.j) % 3) == 0) { //#23816
                $1.fact = ~~($get($1.scrle, $1.j) / 3); //#23806
                var _VD = $geti($1.scrle, $1.j - 4, 4); //#23807
                for (var _VE = 0, _VF = _VD.length; _VE < _VF; _VE++) { //#23807
                    $k[$j++] = $get(_VD, _VE) == $1.fact; //#23807
                } //#23807
                var _VI = $k[--$j]; //#23807
                var _VJ = $k[--$j]; //#23807
                var _VK = $k[--$j]; //#23807
                var _VL = $k[--$j]; //#23807
                if (_VL && (_VK && (_VJ && _VI))) { //#23815
                    if (($1.j == 5) || (($1.j + 2) >= $1.scrle.length)) { //#23812
                        $1.scr3 = $1.scr3 + 50; //#23809
                    } else { //#23812
                        if (($get($1.scrle, $1.j - 5) >= 3) || ($get($1.scrle, $1.j + 1) >= 3)) { //#23813
                            $1.scr3 = $1.scr3 + 50; //#23812
                        } //#23812
                    } //#23812
                } //#23812
            } //#23812
        } //#23812
        for (var _VZ = 1, _VY = $1.scrle.length - 5; _VZ <= _VY; _VZ += 2) { //#23833
            $1.j = _VZ; //#23820
            if (($get($1.scrle, $1.j) % 3) == 0) { //#23832
                $1.fact = ~~($get($1.scrle, $1.j) / 3); //#23822
                var _Vi = $geti($1.scrle, $1.j + 1, 4); //#23823
                for (var _Vj = 0, _Vk = _Vi.length; _Vj < _Vk; _Vj++) { //#23823
                    $k[$j++] = $get(_Vi, _Vj) == $1.fact; //#23823
                } //#23823
                var _Vn = $k[--$j]; //#23823
                var _Vo = $k[--$j]; //#23823
                var _Vp = $k[--$j]; //#23823
                var _Vq = $k[--$j]; //#23823
                if (_Vq && (_Vp && (_Vo && _Vn))) { //#23831
                    if (($1.j == 1) || (($1.j + 6) >= $1.scrle.length)) { //#23828
                        $1.scr3 = $1.scr3 + 50; //#23825
                    } else { //#23828
                        if (($get($1.scrle, $1.j - 1) >= 3) || ($get($1.scrle, $1.j + 5) >= 3)) { //#23829
                            $1.scr3 = $1.scr3 + 50; //#23828
                        } //#23828
                    } //#23828
                } //#23828
            } //#23828
        } //#23828
        $k[$j++] = $1.scr1; //#23834
        $k[$j++] = $1.scr3; //#23834
    }; //#23834
    $1.evalfull = function() {
        $1.sym = $k[--$j]; //#23839
        $1.n1 = 0; //#23841
        $1.n3 = 0; //#23841
        $1.rle = $a($f($1.size + 1)); //#23842
        $1.lastpairs = $a($1.size); //#23843
        $1.thispairs = $a($1.size); //#23844
        $1.sizeadd1 = $f($1.size + 1); //#23845
        for (var _WE = 0, _WD = $f($1.size - 1); _WE <= _WD; _WE += 1) { //#23870
            $1.i = _WE; //#23847
            $k[$j++] = Infinity; //#23850
            var _WG = $1.size; //#23851
            $k[$j++] = 0; //#23853
            $k[$j++] = 0; //#23853
            for (var _WI = $1.i, _WJ = _WG, _WH = $f((_WG * _WG) - 1); _WJ < 0 ? _WI >= _WH : _WI <= _WH; _WI += _WJ) { //#23853
                var _WL = $get($1.sym, _WI); //#23852
                var _WM = $k[--$j]; //#23852
                $k[$j++] = _WL; //#23852
                if ($eq(_WM, _WL)) { //#23852
                    var _WN = $k[--$j]; //#23852
                    var _WO = $k[--$j]; //#23852
                    $k[$j++] = $f(_WO + 1); //#23852
                    $k[$j++] = _WN; //#23852
                } else { //#23852
                    var _WP = $k[--$j]; //#23852
                    $k[$j++] = 1; //#23852
                    $k[$j++] = _WP; //#23852
                } //#23852
            } //#23852
            $j--; //#23854
            var _WR = $counttomark() + 2; //#23855
            $astore($geti($1.rle, 0, _WR - 2)); //#23855
            $1.evalfulln1n3(); //#23856
            $1.n3 = $f($k[--$j] + $1.n3); //#23856
            $1.n1 = $f($k[--$j] + $1.n1); //#23856
            $j--; //#23857
            $1.symrow = $geti($1.sym, $1.i * $1.size, $1.size); //#23860
            $k[$j++] = Infinity; //#23861
            var _Wc = $1.symrow; //#23862
            $k[$j++] = 0; //#23864
            $k[$j++] = 0; //#23864
            for (var _Wd = 0, _We = _Wc.length; _Wd < _We; _Wd++) { //#23864
                var _Wf = $get(_Wc, _Wd); //#23864
                var _Wg = $k[--$j]; //#23863
                $k[$j++] = _Wf; //#23863
                if ($eq(_Wg, _Wf)) { //#23863
                    var _Wh = $k[--$j]; //#23863
                    var _Wi = $k[--$j]; //#23863
                    $k[$j++] = $f(_Wi + 1); //#23863
                    $k[$j++] = _Wh; //#23863
                } else { //#23863
                    var _Wj = $k[--$j]; //#23863
                    $k[$j++] = 1; //#23863
                    $k[$j++] = _Wj; //#23863
                } //#23863
            } //#23863
            $j--; //#23865
            var _Wl = $counttomark() + 2; //#23866
            $astore($geti($1.rle, 0, _Wl - 2)); //#23866
            $1.evalfulln1n3(); //#23867
            $1.n3 = $f($k[--$j] + $1.n3); //#23867
            $1.n1 = $f($k[--$j] + $1.n1); //#23867
            $j--; //#23868
        } //#23868
        $k[$j++] = $f($1.n1 + $1.n3); //#23872
    }; //#23872
    $1.bestscore = 999999999; //#23876
    for (var _Wv = 0, _Wu = $1.masks.length - 1; _Wv <= _Wu; _Wv += 1) { //#23894
        $1.m = _Wv; //#23878
        $1.masksym = $a($1.size * $1.size); //#23879
        for (var _X2 = 0, _X1 = $f(($1.size * $1.size) - 1); _X2 <= _X1; _X2 += 1) { //#23883
            $1.i = _X2; //#23881
            $put($1.masksym, $1.i, $xo($get($1.pixs, $1.i), $get($get($1.masks, $1.m), $1.i))); //#23882
        } //#23882
        if ($1.masks.length != 1) { //#23892
            $k[$j++] = $1.masksym; //#23885
            $1.evalfull(); //#23885
            $1.score = $k[--$j]; //#23885
            if ($1.score < $1.bestscore) { //#23890
                $1.bestsym = $1.masksym; //#23887
                $1.bestmaskval = $1.m; //#23888
                $1.bestscore = $1.score; //#23889
            } //#23889
        } else { //#23892
            $1.bestsym = $1.masksym; //#23892
        } //#23892
    } //#23892
    $1.pixs = $1.bestsym; //#23895
    $1.funval = (((((~~($f($1.size - 21) / 2)) + 20) * 4) + $1.eclval) * 4) + $1.bestmaskval; //#23898
    $k[$j++] = $a([($1.funval & 3840) >>> 8, ($1.funval & 240) >>> 4, $1.funval & 15]); //#23902
    $k[$j++] = 4; //#23902
    $k[$j++] = 16; //#23902
    $k[$j++] = 19; //#23902
    $1.rscodes(); //#23902
    $1.funvals = $k[--$j]; //#23902
    $k[$j++] = Infinity; //#23907
    $forall($1.funvals, function() { //#23906
        $k[$j++] = 4; //#23905
        $1.tobin(); //#23905
        $forall($k[--$j], function() { //#23905
            var _XX = $k[--$j]; //#23905
            $k[$j++] = $f(_XX - 48); //#23905
        }); //#23905
    }); //#23905
    $k[$j++] = 0; //#23907
    $k[$j++] = 1; //#23907
    $k[$j++] = 0; //#23907
    $k[$j++] = 1; //#23907
    $k[$j++] = 0; //#23907
    $k[$j++] = 1; //#23907
    $1.funbits = $a(); //#23907
    for (var _Xb = 0, _Xa = $1.functionmap.length - 1; _Xb <= _Xa; _Xb += 1) { //#23914
        $1.i = _Xb; //#23910
        $forall($get($1.functionmap, $1.i), function() { //#23913
            var _Xg = $k[--$j]; //#23912
            $k[$j++] = $1.pixs; //#23912
            $aload(_Xg); //#23912
            $1.qmv(); //#23912
            var _Xk = $k[--$j]; //#23912
            $put($k[--$j], _Xk, $get($1.funbits, $1.i)); //#23912
        }); //#23912
    } //#23912
    var _Xs = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.size],
        ["pixy", $1.size],
        ["height", ($1.size * 2) / 72],
        ["width", ($1.size * 2) / 72],
        ["opt", $1.options]
    ]); //#23924
    $k[$j++] = _Xs; //#23927
    if (!$1.dontdraw) { //#23927
        bwipp_renmatrix(); //#23927
    } //#23927
}

function bwipp_dotcode() {
    var $1 = {}; //#23962
    $1.ctx = null; //#23964
    $1.dontdraw = false; //#23965
    $1.rows = -1; //#23966
    $1.columns = -1; //#23967
    $1.ratio = -1; //#23968
    $1.parse = false; //#23969
    $1.parsefnc = false; //#23970
    $1.raw = false; //#23971
    $1.fast = false; //#23972
    $1.mask = -1; //#23973
    $k[$j++] = $1; //#23975
    bwipp_processoptions(); //#23975
    $1.options = $k[--$j]; //#23975
    $1.barcode = $k[--$j]; //#23976
    if ((($1.ratio == -1) && ($1.rows == -1)) && ($1.columns == -1)) { //#23983
        $1.ratio = 3 / 2; //#23982
    } //#23982
    $1.laa = -1; //#23987
    $1.lab = -2; //#23987
    $1.lac = -3; //#23987
    $1.bin = -4; //#23987
    $1.sfa = -5; //#23988
    $1.sfb = -6; //#23988
    $1.sb2 = -7; //#23988
    $1.sb3 = -8; //#23988
    $1.sb4 = -9; //#23989
    $1.sb5 = -10; //#23989
    $1.sb6 = -11; //#23989
    $1.sfc = -12; //#23989
    $1.sc2 = -13; //#23990
    $1.sc3 = -14; //#23990
    $1.sc4 = -15; //#23990
    $1.sc5 = -16; //#23990
    $1.sc6 = -17; //#23991
    $1.sc7 = -18; //#23991
    $1.bsa = -19; //#23991
    $1.bsb = -20; //#23991
    $1.tma = -21; //#23992
    $1.tmb = -22; //#23992
    $1.tmc = -23; //#23992
    $1.tms = -24; //#23992
    $1.fn1 = -25; //#23993
    $1.fn2 = -26; //#23993
    $1.fn3 = -27; //#23993
    $1.crl = -28; //#23993
    $1.aim = -29; //#23994
    $1.m05 = -30; //#23994
    $1.m06 = -31; //#23994
    $1.m12 = -32; //#23994
    $1.mac = -33; //#23995
    var _9 = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["eci", true],
        ["FNC1", $1.fn1],
        ["FNC3", $1.fn3]
    ]); //#24005
    $1.fncvals = _9; //#24006
    $k[$j++] = 'msg'; //#24007
    $k[$j++] = $1.barcode; //#24007
    $k[$j++] = $1.fncvals; //#24007
    bwipp_parseinput(); //#24007
    var _C = $k[--$j]; //#24007
    $1[$k[--$j]] = _C; //#24007
    $1.msglen = $1.msg.length; //#24008
    var _F = $1.msg; //#24011
    $k[$j++] = 'numecis'; //#24011
    $k[$j++] = 0; //#24011
    for (var _G = 0, _H = _F.length; _G < _H; _G++) { //#24011
        if ($get(_F, _G) <= -1000000) { //#24011
            var _J = $k[--$j]; //#24011
            $k[$j++] = $f(_J + 1); //#24011
        } //#24011
    } //#24011
    var _K = $k[--$j]; //#24011
    $1[$k[--$j]] = _K; //#24011
    $1.msgtmp = $a($f($1.msg.length + ($1.numecis * 6))); //#24012
    $1.j = 0; //#24013
    for (var _R = 0, _Q = $1.msg.length - 1; _R <= _Q; _R += 1) { //#24024
        var _T = $get($1.msg, _R); //#24015
        $k[$j++] = _T; //#24023
        if (_T <= -1000000) { //#24022
            var _X = $geti($cvrs($s(7), -$k[--$j], 10), 1, 6); //#24016
            for (var _Y = 0, _Z = _X.length; _Y < _Z; _Y++) { //#24016
                $k[$j++] = $get(_X, _Y); //#24016
            } //#24016
            $astore($a(6)); //#24016
            $puti($1.msgtmp, $1.j + 1, $k[--$j]); //#24017
            $put($1.msgtmp, $1.j, $1.fn2); //#24018
            $1.j = $1.j + 7; //#24019
        } else { //#24022
            $put($1.msgtmp, $1.j, $k[--$j]); //#24021
            $1.j = $1.j + 1; //#24022
        } //#24022
    } //#24022
    $1.msg = $1.msgtmp; //#24025
    $1.msglen = $1.msg.length; //#24026
    $1.charmaps = $a([$a([32, 32, "00"]), $a(["!", "!", "01"]), $a(["\"", "\"", "02"]), $a(["#", "#", "03"]), $a(["$", "$", "04"]), $a(["%", "%", "05"]), $a(["&", "&", "06"]), $a(["'", "'", "07"]), $a([40, 40, "08"]), $a([41, 41, "09"]), $a(["*", "*", "10"]), $a(["+", "+", "11"]), $a([",", ",", "12"]), $a(["-", "-", "13"]), $a([".", ".", "14"]), $a(["/", "/", "15"]), $a(["0", "0", "16"]), $a(["1", "1", "17"]), $a(["2", "2", "18"]), $a(["3", "3", "19"]), $a(["4", "4", "20"]), $a(["5", "5", "21"]), $a(["6", "6", "22"]), $a(["7", "7", "23"]), $a(["8", "8", "24"]), $a(["9", "9", "25"]), $a([":", ":", "26"]), $a([";", ";", "27"]), $a(["<", "<", "28"]), $a(["=", "=", "29"]), $a([">", ">", "30"]), $a(["?", "?", "31"]), $a(["@", "@", "32"]), $a(["A", "A", "33"]), $a(["B", "B", "34"]), $a(["C", "C", "35"]), $a(["D", "D", "36"]), $a(["E", "E", "37"]), $a(["F", "F", "38"]), $a(["G", "G", "39"]), $a(["H", "H", "40"]), $a(["I", "I", "41"]), $a(["J", "J", "42"]), $a(["K", "K", "43"]), $a(["L", "L", "44"]), $a(["M", "M", "45"]), $a(["N", "N", "46"]), $a(["O", "O", "47"]), $a(["P", "P", "48"]), $a(["Q", "Q", "49"]), $a(["R", "R", "50"]), $a(["S", "S", "51"]), $a(["T", "T", "52"]), $a(["U", "U", "53"]), $a(["V", "V", "54"]), $a(["W", "W", "55"]), $a(["X", "X", "56"]), $a(["Y", "Y", "57"]), $a(["Z", "Z", "58"]), $a(["[", "[", "59"]), $a([92, 92, "60"]), $a(["]", "]", "61"]), $a(["^", "^", "62"]), $a(["_", "_", "63"]), $a([0, "`", "64"]), $a([1, "a", "65"]), $a([2, "b", "66"]), $a([3, "c", "67"]), $a([4, "d", "68"]), $a([5, "e", "69"]), $a([6, "f", "70"]), $a([7, "g", "71"]), $a([8, "h", "72"]), $a([9, "i", "73"]), $a([10, "j", "74"]), $a([11, "k", "75"]), $a([12, "l", "76"]), $a([13, "m", "77"]), $a([14, "n", "78"]), $a([15, "o", "79"]), $a([16, "p", "80"]), $a([17, "q", "81"]), $a([18, "r", "82"]), $a([19, "s", "83"]), $a([20, "t", "84"]), $a([21, "u", "85"]), $a([22, "v", "86"]), $a([23, "w", "87"]), $a([24, "x", "88"]), $a([25, "y", "89"]), $a([26, "z", "90"]), $a([27, "{", "91"]), $a([28, "|", "92"]), $a([29, "}", "93"]), $a([30, "~", "94"]), $a([31, 127, "95"]), $a([$1.sfb, $1.crl, "96"]), $a([$1.sb2, 9, "97"]), $a([$1.sb3, 28, "98"]), $a([$1.sb4, 29, "99"]), $a([$1.sb5, 30, $1.aim]), $a([$1.sb6, $1.sfa, $1.laa]), $a([$1.lab, $1.laa, $1.sfb]), $a([$1.sc2, $1.sc2, $1.sb2]), $a([$1.sc3, $1.sc3, $1.sb3]), $a([$1.sc4, $1.sc4, $1.sb4]), $a([$1.lac, $1.lac, $1.lab]), $a([$1.fn1, $1.fn1, $1.fn1]), $a([$1.fn2, $1.fn2, $1.fn2]), $a([$1.fn3, $1.fn3, $1.fn3]), $a([$1.bsa, $1.bsa, $1.bsa]), $a([$1.bsb, $1.bsb, $1.bsb]), $a([$1.bin, $1.bin, $1.bin])]); //#24070
    $1.charvals = $a([new Map, new Map, new Map]); //#24073
    for (var _3P = 0, _3O = $1.charmaps.length - 1; _3P <= _3O; _3P += 1) { //#24082
        $1.i = _3P; //#24075
        $1.encs = $get($1.charmaps, $1.i); //#24076
        for (var _3T = 0; _3T <= 2; _3T += 1) { //#24081
            $1.j = _3T; //#24078
            var _3W = $get($1.encs, $1.j); //#24079
            $k[$j++] = _3W; //#24079
            if ($eq($type(_3W), 'stringtype')) { //#24079
                var _3Z = $get($k[--$j], 0); //#24079
                $k[$j++] = _3Z; //#24079
            } //#24079
            $put($get($1.charvals, $1.j), $k[--$j], $1.i); //#24080
        } //#24080
    } //#24080
    $1.Avals = $get($1.charvals, 0); //#24083
    $1.Bvals = $get($1.charvals, 1); //#24084
    $put($1.Bvals, $1.m05, 97); //#24085
    $put($1.Bvals, $1.m06, 98); //#24086
    $put($1.Bvals, $1.m12, 99); //#24087
    $put($1.Bvals, $1.mac, 100); //#24088
    $1.Cvals = $get($1.charvals, 2); //#24089
    $k[$j++] = Infinity; //#24091
    var _43 = $a([$1.sc2, $1.sc3, $1.sc4, $1.sc5, $1.sc6, $1.sc7, $1.tma, $1.tmb, $1.tmc, $1.tms]); //#24091
    $k[$j++] = 102; //#24091
    for (var _44 = 0, _45 = _43.length; _44 < _45; _44++) { //#24091
        var _48 = $f($k[--$j] + 1); //#24091
        $k[$j++] = $get(_43, _44); //#24091
        $k[$j++] = _48; //#24091
        $k[$j++] = _48; //#24091
    } //#24091
    $j--; //#24091
    $1.BINvals = $d(); //#24092
    $1.A = 0; //#24094
    $1.B = 1; //#24094
    $1.C = 2; //#24094
    $1.BIN = 3; //#24094
    $k[$j++] = Infinity; //#24098
    for (var _4B = 0, _4C = $1.msglen + 1; _4B < _4C; _4B++) { //#24098
        $k[$j++] = 0; //#24098
    } //#24098
    $1.nDigits = $a(); //#24098
    $k[$j++] = Infinity; //#24099
    for (var _4F = 0, _4G = $1.msglen + 1; _4F < _4G; _4F++) { //#24099
        $k[$j++] = false; //#24099
    } //#24099
    $1.SeventeenTen = $a(); //#24099
    $k[$j++] = Infinity; //#24100
    for (var _4J = 0, _4K = $1.msglen + 1; _4J < _4K; _4J++) { //#24100
        $k[$j++] = false; //#24100
    } //#24100
    $1.ECI = $a(); //#24100
    $k[$j++] = Infinity; //#24101
    for (var _4N = 0, _4O = $1.msglen + 1; _4N < _4O; _4N++) { //#24101
        $k[$j++] = false; //#24101
    } //#24101
    $1.DatumA = $a(); //#24101
    $k[$j++] = Infinity; //#24102
    for (var _4R = 0, _4S = $1.msglen + 1; _4R < _4S; _4R++) { //#24102
        $k[$j++] = false; //#24102
    } //#24102
    $1.DatumB = $a(); //#24102
    $k[$j++] = Infinity; //#24103
    for (var _4V = 0, _4W = $1.msglen + 1; _4V < _4W; _4V++) { //#24103
        $k[$j++] = false; //#24103
    } //#24103
    $1.DatumC = $a(); //#24103
    $k[$j++] = Infinity; //#24104
    for (var _4Z = 0, _4a = $1.msglen + 8; _4Z < _4a; _4Z++) { //#24104
        $k[$j++] = false; //#24104
    } //#24104
    $1.Binary = $a(); //#24104
    $k[$j++] = Infinity; //#24105
    for (var _4d = 0, _4e = $1.msglen + 1; _4d < _4e; _4d++) { //#24105
        $k[$j++] = 0; //#24105
    } //#24105
    $1.AheadC = $a(); //#24105
    $k[$j++] = Infinity; //#24106
    for (var _4h = 0, _4i = $1.msglen + 1; _4h < _4i; _4h++) { //#24106
        $k[$j++] = 0; //#24106
    } //#24106
    $1.TryC = $a(); //#24106
    $k[$j++] = Infinity; //#24107
    for (var _4l = 0, _4m = $1.msglen + 1; _4l < _4m; _4l++) { //#24107
        $k[$j++] = 0; //#24107
    } //#24107
    $1.AheadA = $a(); //#24107
    $k[$j++] = Infinity; //#24108
    for (var _4p = 0, _4q = $1.msglen + 1; _4p < _4q; _4p++) { //#24108
        $k[$j++] = 0; //#24108
    } //#24108
    $1.AheadB = $a(); //#24108
    $k[$j++] = Infinity; //#24109
    for (var _4t = 0, _4u = $1.msglen + 1; _4t < _4u; _4t++) { //#24109
        $k[$j++] = 0; //#24109
    } //#24109
    $1.UntilEndSeg = $a(); //#24109
    for (var _4x = $1.msglen - 1; _4x >= 0; _4x -= 1) { //#24164
        $1.i = _4x; //#24111
        $1.barchar = $get($1.msg, $1.i); //#24112
        if (($1.barchar >= 48) && ($1.barchar <= 57)) { //#24115
            $put($1.nDigits, $1.i, $f($get($1.nDigits, $1.i + 1) + 1)); //#24114
        } //#24114
        var _5A = $get($1.Avals, $1.barchar) !== undefined; //#24116
        if (_5A) { //#24116
            $put($1.DatumA, $1.i, true); //#24116
        } //#24116
        var _5F = $get($1.Bvals, $1.barchar) !== undefined; //#24117
        if (_5F) { //#24117
            $put($1.DatumB, $1.i, true); //#24117
        } //#24117
        $1.CRLF = false; //#24118
        if (($1.barchar == 13) && ($1.i < ($1.msglen - 1))) { //#24121
            if ($get($1.msg, $1.i + 1) == 10) { //#24120
                $1.CRLF = true; //#24120
            } //#24120
        } //#24120
        if ($1.CRLF) { //#24122
            $put($1.DatumB, $1.i, true); //#24122
        } //#24122
        if ($get($1.nDigits, $1.i) >= 2) { //#24123
            $put($1.DatumC, $1.i, true); //#24123
        } //#24123
        if ($1.barchar < 0) { //#24124
            $put($1.DatumC, $1.i, true); //#24124
        } //#24124
        if ($1.barchar >= 128) { //#24125
            $put($1.Binary, $1.i, true); //#24125
        } //#24125
        if ($get($1.nDigits, $1.i) >= 10) { //#24139
            $k[$j++] = Infinity; //#24127
            $aload($geti($1.msg, $1.i, 10)); //#24128
            for (var _5i = 0, _5j = 1; _5i < _5j; _5i++) { //#24136
                if ($k[--$j] != 48) { //#24130
                    $k[$j++] = false; //#24130
                    break; //#24130
                } //#24130
                if ($k[--$j] != 49) { //#24131
                    $k[$j++] = false; //#24131
                    break; //#24131
                } //#24131
                $j -= 6; //#24132
                if ($k[--$j] != 55) { //#24133
                    $k[$j++] = false; //#24133
                    break; //#24133
                } //#24133
                if ($k[--$j] != 49) { //#24134
                    $k[$j++] = false; //#24134
                    break; //#24134
                } //#24134
                $k[$j++] = true; //#24135
            } //#24135
            $put($1.SeventeenTen, $1.i, $k[--$j]); //#24137
            $cleartomark(); //#24138
        } //#24138
        if (($get($1.nDigits, $1.i + 1) >= 6) && ($get($1.msg, $1.i) == $1.fn2)) { //#24142
            $put($1.ECI, $1.i, true); //#24141
        } //#24141
        if (($1.barchar < 0) && ($1.barchar != $1.fn3)) { //#24149
            $put($1.AheadC, $1.i, $f($get($1.AheadC, $1.i + 1) + 1)); //#24144
        } else { //#24149
            if ($get($1.nDigits, $1.i) <= 1) { //#24149
                $put($1.AheadC, $1.i, 0); //#24147
            } else { //#24149
                $put($1.AheadC, $1.i, $f($get($1.AheadC, $1.i + 2) + 1)); //#24149
            } //#24149
        } //#24149
        if (($get($1.nDigits, $1.i) > 0) && $gt($get($1.AheadC, $1.i), $get($1.AheadC, $1.i + 1))) { //#24154
            $put($1.TryC, $1.i, $get($1.AheadC, $1.i)); //#24153
        } //#24153
        if (($get($1.DatumA, $1.i) && ($get($1.TryC, $1.i) < 2)) && ($1.barchar != $1.fn3)) { //#24157
            $put($1.AheadA, $1.i, $f($get($1.AheadA, $1.i + 1) + 1)); //#24156
        } //#24156
        if (($get($1.DatumB, $1.i) && ($get($1.TryC, $1.i) < 2)) && ($1.barchar != $1.fn3)) { //#24160
            $k[$j++] = $1.AheadB; //#24159
            $k[$j++] = $1.i; //#24159
            $k[$j++] = $1.AheadB; //#24159
            $k[$j++] = $1.i + 1; //#24159
            if ($1.CRLF) { //#24159
                var _6w = $k[--$j]; //#24159
                $k[$j++] = $f(_6w + 1); //#24159
            } //#24159
            var _6x = $k[--$j]; //#24159
            var _6z = $get($k[--$j], _6x); //#24159
            var _70 = $k[--$j]; //#24159
            $put($k[--$j], _70, $f(_6z + 1)); //#24159
        } //#24159
        if ($1.barchar != $1.fn3) { //#24163
            $put($1.UntilEndSeg, $1.i, $f($get($1.UntilEndSeg, $1.i + 1) + 1)); //#24162
        } //#24162
    } //#24162
    $1.addtocws = function() {
        var _79 = $k[--$j]; //#24167
        $puti($1.cws, $1.j, _79); //#24167
        $1.j = _79.length + $1.j; //#24168
    }; //#24168
    $1.base259to103 = function() {
        $1.in = $k[--$j]; //#24173
        $1.inlen = $1.in.length; //#24174
        $k[$j++] = Infinity; //#24175
        for (var _7G = 0, _7H = 5 - $1.inlen; _7G < _7H; _7G++) { //#24175
            $k[$j++] = 0; //#24175
        } //#24175
        $aload($1.in); //#24175
        $1.in = $a(); //#24175
        $1.out = $a(6); //#24176
        $k[$j++] = Infinity; //#24177
        $aload($geti($1.in, 0, 2)); //#24177
        $1.msbs = $a(); //#24177
        $k[$j++] = Infinity; //#24180
        $aload($1.msbs); //#24179
        var _7P = $k[--$j]; //#24179
        var _7Q = $k[--$j]; //#24179
        $k[$j++] = $f(_7P + (_7Q * 259)); //#24180
        for (var _7R = 0, _7S = 2; _7R < _7S; _7R++) { //#24180
            var _7T = $k[--$j]; //#24180
            $k[$j++] = _7T % 103; //#24180
            $k[$j++] = ~~(_7T / 103); //#24180
        } //#24180
        $1.mscs = $a(); //#24180
        $k[$j++] = Infinity; //#24182
        $aload($geti($1.in, 2, 3)); //#24182
        $1.lsbs = $a(); //#24182
        $k[$j++] = Infinity; //#24185
        $aload($1.lsbs); //#24184
        var _7Z = $k[--$j]; //#24184
        var _7a = $k[--$j]; //#24184
        var _7b = $k[--$j]; //#24184
        $k[$j++] = $f(($f(_7Z + (_7a * 259))) + (_7b * 67081)); //#24185
        for (var _7c = 0, _7d = 3; _7c < _7d; _7c++) { //#24185
            var _7e = $k[--$j]; //#24185
            $k[$j++] = _7e % 103; //#24185
            $k[$j++] = ~~(_7e / 103); //#24185
        } //#24185
        $1.lscs = $a(); //#24185
        var _7h = $get($1.lscs, 0); //#24187
        var _7j = $get($1.mscs, 0); //#24187
        $put($1.out, 5, ($f(_7h + (_7j * 42))) % 103); //#24188
        var _7m = $get($1.lscs, 1); //#24189
        var _7o = $get($1.mscs, 0); //#24189
        var _7q = $get($1.mscs, 1); //#24189
        $put($1.out, 4, ($f(($f(($f((~~(($f(_7h + (_7j * 42))) / 103)) + _7m)) + (_7o * 68))) + (_7q * 42))) % 103); //#24190
        var _7t = $get($1.lscs, 2); //#24191
        var _7v = $get($1.mscs, 0); //#24191
        var _7x = $get($1.mscs, 1); //#24191
        var _7z = $get($1.mscs, 2); //#24191
        $put($1.out, 3, ($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_7h + (_7j * 42))) / 103)) + _7m)) + (_7o * 68))) + (_7q * 42))) / 103)) + _7t)) + (_7v * 92))) + (_7x * 68))) + (_7z * 42))) % 103); //#24192
        var _82 = $get($1.lscs, 3); //#24193
        var _84 = $get($1.mscs, 0); //#24193
        var _86 = $get($1.mscs, 1); //#24193
        var _88 = $get($1.mscs, 2); //#24193
        $put($1.out, 2, ($f(($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_7h + (_7j * 42))) / 103)) + _7m)) + (_7o * 68))) + (_7q * 42))) / 103)) + _7t)) + (_7v * 92))) + (_7x * 68))) + (_7z * 42))) / 103)) + _82)) + (_84 * 15))) + (_86 * 92))) + (_88 * 68))) % 103); //#24194
        var _8B = $get($1.mscs, 1); //#24195
        var _8D = $get($1.mscs, 2); //#24195
        $put($1.out, 1, ($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_7h + (_7j * 42))) / 103)) + _7m)) + (_7o * 68))) + (_7q * 42))) / 103)) + _7t)) + (_7v * 92))) + (_7x * 68))) + (_7z * 42))) / 103)) + _82)) + (_84 * 15))) + (_86 * 92))) + (_88 * 68))) / 103)) + (_8B * 15))) + (_8D * 92))) % 103); //#24196
        $put($1.out, 0, ($f((~~(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f(($f((~~(($f(($f(($f((~~(($f(_7h + (_7j * 42))) / 103)) + _7m)) + (_7o * 68))) + (_7q * 42))) / 103)) + _7t)) + (_7v * 92))) + (_7x * 68))) + (_7z * 42))) / 103)) + _82)) + (_84 * 15))) + (_86 * 92))) + (_88 * 68))) / 103)) + (_8B * 15))) + (_8D * 92))) / 103)) + ($get($1.mscs, 2) * 15))) % 103); //#24198
        $k[$j++] = $geti($1.out, (6 - $1.inlen) - 1, $1.inlen + 1); //#24199
    }; //#24199
    $1.finaliseBIN = function() {
        if ($1.bpos != 0) { //#24206
            $k[$j++] = $geti($1.bvals, 0, $1.bpos); //#24204
            $1.base259to103(); //#24204
            $aload($k[--$j]); //#24204
            $1.bpos = 0; //#24205
        } //#24205
    }; //#24205
    $1.addtobin = function() {
        $put($1.bvals, $1.bpos, $k[--$j]); //#24210
        $1.bpos = $1.bpos + 1; //#24211
        if ($1.bpos == 5) { //#24212
            $1.finaliseBIN(); //#24212
        } //#24212
    }; //#24212
    $1.ECIabc = function() {
        var _8Y = $geti($1.msg, $1.i + 1, 6); //#24216
        $k[$j++] = 0; //#24216
        for (var _8Z = 0, _8a = _8Y.length; _8Z < _8a; _8Z++) { //#24216
            var _8c = $k[--$j]; //#24216
            $k[$j++] = ($f(_8c + $f($get(_8Y, _8Z) - 48))) * 10; //#24216
        } //#24216
        var _8e = ~~($k[--$j] / 10); //#24217
        $k[$j++] = _8e; //#24221
        if (_8e >= 40) { //#24221
            var _8g = $f($k[--$j] - 40); //#24219
            var _8h = _8g % 12769; //#24220
            $k[$j++] = (~~(_8g / 12769)) + 40; //#24220
            $k[$j++] = ~~(_8h / 113); //#24220
            $k[$j++] = _8h % 113; //#24220
        } //#24220
    }; //#24220
    $1.ECIbin = function() {
        $k[$j++] = Infinity; //#24233
        var _8k = $geti($1.msg, $1.i + 1, 6); //#24226
        $k[$j++] = 0; //#24226
        for (var _8l = 0, _8m = _8k.length; _8l < _8m; _8l++) { //#24226
            var _8o = $k[--$j]; //#24226
            $k[$j++] = ($f(_8o + $f($get(_8k, _8l) - 48))) * 10; //#24226
        } //#24226
        var _8q = ~~($k[--$j] / 10); //#24227
        $k[$j++] = _8q; //#24235
        if (_8q >= 65536) { //#24233
            var _8r = $k[--$j]; //#24228
            var _8s = _8r % 65536; //#24228
            $k[$j++] = 258; //#24228
            $k[$j++] = ~~(_8r / 65536); //#24228
            $k[$j++] = ~~(_8s / 256); //#24228
            $k[$j++] = _8s % 256; //#24228
        } else { //#24233
            var _8t = $k[--$j]; //#24230
            $k[$j++] = _8t; //#24234
            if (_8t >= 256) { //#24233
                var _8u = $k[--$j]; //#24231
                $k[$j++] = 257; //#24231
                $k[$j++] = ~~(_8u / 256); //#24231
                $k[$j++] = _8u % 256; //#24231
            } else { //#24233
                var _8v = $k[--$j]; //#24233
                $k[$j++] = 256; //#24233
                $k[$j++] = _8v; //#24233
            } //#24233
        } //#24233
        var _8w = $a(); //#24233
        for (var _8x = 0, _8y = _8w.length; _8x < _8y; _8x++) { //#24238
            $k[$j++] = $get(_8w, _8x); //#24237
            $1.addtobin(); //#24237
        } //#24237
    }; //#24237
    $1.encC = function() {
        for (var _90 = 0, _91 = 1; _90 < _91; _90++) { //#24362
            if ($1.i == $1.segstart) { //#24275
                for (var _94 = 0, _95 = 1; _94 < _95; _94++) { //#24260
                    if ($1.i > $f($1.segend - 7)) { //#24245
                        $k[$j++] = 0; //#24245
                        break; //#24245
                    } //#24245
                    if ($get($1.msg, $1.segstart) != 91) { //#24246
                        $k[$j++] = 0; //#24246
                        break; //#24246
                    } //#24246
                    if ($get($1.msg, $1.segstart + 1) != 41) { //#24247
                        $k[$j++] = 0; //#24247
                        break; //#24247
                    } //#24247
                    if ($get($1.msg, $1.segstart + 2) != 62) { //#24248
                        $k[$j++] = 0; //#24248
                        break; //#24248
                    } //#24248
                    if ($get($1.msg, $1.segstart + 3) != 30) { //#24249
                        $k[$j++] = 0; //#24249
                        break; //#24249
                    } //#24249
                    var _9M = $get($1.msg, $1.segstart + 4); //#24250
                    if ((_9M < 48) || (_9M > 57)) { //#24250
                        $k[$j++] = 0; //#24250
                        break; //#24250
                    } //#24250
                    var _9P = $get($1.msg, $1.segstart + 5); //#24251
                    if ((_9P < 48) || (_9P > 57)) { //#24251
                        $k[$j++] = 0; //#24251
                        break; //#24251
                    } //#24251
                    if ($get($1.msg, $f($1.segend - 1)) != 4) { //#24252
                        $k[$j++] = 0; //#24252
                        break; //#24252
                    } //#24252
                    var _9Z = $f(($f($get($1.msg, $1.segstart + 4) - 48) * 10) + $f($get($1.msg, $1.segstart + 5) - 48)); //#24254
                    $k[$j++] = _9Z; //#24254
                    if ((_9Z != 5) && ((_9Z != 6) && (_9Z != 12))) { //#24254
                        $j--; //#24254
                        $k[$j++] = $1.mac; //#24254
                        break; //#24254
                    } //#24254
                    if ($get($1.msg, $1.segstart + 6) != 29) { //#24255
                        $j--; //#24255
                        $k[$j++] = 0; //#24255
                        break; //#24255
                    } //#24255
                    if ($get($1.msg, $f($1.segend - 2)) != 30) { //#24256
                        $j--; //#24256
                        $k[$j++] = 0; //#24256
                        break; //#24256
                    } //#24256
                    var _9h = $k[--$j]; //#24257
                    $k[$j++] = _9h; //#24257
                    if (_9h == 5) { //#24257
                        $j--; //#24257
                        $k[$j++] = $1.m05; //#24257
                        break; //#24257
                    } //#24257
                    if ($k[--$j] == 6) { //#24258
                        $k[$j++] = $1.m06; //#24258
                        break; //#24258
                    } //#24258
                    $k[$j++] = $1.m12; //#24259
                    break; //#24259
                } //#24259
                $1.inmac = $k[--$j]; //#24261
                if ($1.inmac != 0) { //#24274
                    $k[$j++] = $a([$get($1.Cvals, $1.lab)]); //#24263
                    $1.addtocws(); //#24263
                    $1.mode = $1.B; //#24264
                    $k[$j++] = $a([$get($1.Bvals, $1.inmac)]); //#24265
                    $1.addtocws(); //#24265
                    if ($1.inmac == $1.mac) { //#24271
                        $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.segstart + 4))]); //#24267
                        $1.addtocws(); //#24267
                        $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.segstart + 5))]); //#24268
                        $1.addtocws(); //#24268
                        $1.i = $1.i + 6; //#24269
                    } else { //#24271
                        $1.i = $1.i + 7; //#24271
                    } //#24271
                    break; //#24273
                } //#24273
            } //#24273
            if ($1.i == $1.segstart) { //#24286
                if ($get($1.nDigits, $1.i) >= 2) { //#24281
                    $k[$j++] = $a([$get($1.Cvals, $1.fn1)]); //#24280
                    $1.addtocws(); //#24280
                } //#24280
                if (($get($1.msg, $1.i) == $1.fn1) && ($get($1.nDigits, $1.i + 1) >= 2)) { //#24285
                    $1.i = $1.i + 1; //#24284
                } //#24284
            } //#24284
            if ($get($1.SeventeenTen, $1.i)) { //#24296
                $k[$j++] = $a([$get($1.Cvals, $1.aim), $f(($f($get($1.msg, $1.i + 2) - 48) * 10) + $f($get($1.msg, $1.i + 3) - 48)), $f(($f($get($1.msg, $1.i + 4) - 48) * 10) + $f($get($1.msg, $1.i + 5) - 48)), $f(($f($get($1.msg, $1.i + 6) - 48) * 10) + $f($get($1.msg, $1.i + 7) - 48))]); //#24293
                $1.addtocws(); //#24293
                $1.i = $1.i + 10; //#24294
                break; //#24295
            } //#24295
            if ($get($1.DatumC, $1.i)) { //#24318
                var _Az = $get($1.msg, $1.i); //#24298
                if ((_Az == $1.fn1) || ((_Az == $1.fn2) || (_Az == $1.fn3))) { //#24314
                    $k[$j++] = $a([$get($1.Cvals, $get($1.msg, $1.i))]); //#24299
                    $1.addtocws(); //#24299
                    if ($get($1.ECI, $1.i)) { //#24304
                        $k[$j++] = Infinity; //#24301
                        $1.ECIabc(); //#24301
                        var _BC = $a(); //#24301
                        $k[$j++] = _BC; //#24301
                        $1.addtocws(); //#24301
                        $1.i = $1.i + 7; //#24302
                        break; //#24303
                    } //#24303
                    if (($get($1.msg, $1.i) == $1.fn3) && ($1.segstart != $1.i)) { //#24311
                        $1.i = $1.i + 1; //#24306
                        $1.inmac = 0; //#24307
                        $1.segstart = $1.i; //#24308
                        $1.segend = $f($1.i + $get($1.UntilEndSeg, $1.i)); //#24309
                        break; //#24310
                    } //#24310
                    $1.i = $1.i + 1; //#24312
                    break; //#24313
                } //#24313
                $k[$j++] = $a([$f(($f($get($1.msg, $1.i) - 48) * 10) + $f($get($1.msg, $1.i + 1) - 48))]); //#24315
                $1.addtocws(); //#24315
                $1.i = $1.i + 2; //#24316
                break; //#24317
            } //#24317
            if ($get($1.Binary, $1.i)) { //#24332
                if ($get($1.nDigits, $1.i + 1) > 0) { //#24328
                    if ($get($1.msg, $1.i) < 160) { //#24324
                        $k[$j++] = $a([$get($1.Cvals, $1.bsa), $get($1.Avals, $f($get($1.msg, $1.i) - 128))]); //#24322
                        $1.addtocws(); //#24322
                    } else { //#24324
                        $k[$j++] = $a([$get($1.Cvals, $1.bsb), $get($1.Bvals, $f($get($1.msg, $1.i) - 128))]); //#24324
                        $1.addtocws(); //#24324
                    } //#24324
                    $1.i = $1.i + 1; //#24326
                    break; //#24327
                } //#24327
                $k[$j++] = $a([$get($1.Cvals, $1.bin)]); //#24329
                $1.addtocws(); //#24329
                $1.mode = $1.BIN; //#24330
                break; //#24331
            } //#24331
            $1.m = $get($1.AheadA, $1.i); //#24333
            $1.n = $get($1.AheadB, $1.i); //#24333
            if ($gt($1.m, $1.n)) { //#24338
                $k[$j++] = $a([$get($1.Cvals, $1.laa)]); //#24335
                $1.addtocws(); //#24335
                $1.mode = $1.A; //#24336
                break; //#24337
            } //#24337
            if ($1.i == $1.segstart) { //#24345
                var _CN = $get($1.msg, $1.i); //#24340
                if ((_CN == 9) || ((_CN == 28) || ((_CN == 29) || (_CN == 30)))) { //#24344
                    $k[$j++] = $a([$get($1.Cvals, $1.laa)]); //#24341
                    $1.addtocws(); //#24341
                    $1.mode = $1.A; //#24342
                    break; //#24343
                } //#24343
            } //#24343
            if ($1.n > 4) { //#24350
                $k[$j++] = $a([$get($1.Cvals, $1.lab)]); //#24347
                $1.addtocws(); //#24347
                $1.mode = $1.B; //#24348
                break; //#24349
            } //#24349
            $k[$j++] = $a([$get($1.Cvals, $get($a([$1.sfb, $1.sb2, $1.sb3, $1.sb4]), $f($1.n - 1)))]); //#24351
            $1.addtocws(); //#24351
            for (var _Ck = 0, _Cl = $1.n; _Ck < _Cl; _Ck++) { //#24360
                if ($get($1.msg, $1.i) == 13) { //#24358
                    $k[$j++] = $a([$get($1.Bvals, $1.crl)]); //#24354
                    $1.addtocws(); //#24354
                    $1.i = $1.i + 2; //#24355
                } else { //#24358
                    $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.i))]); //#24357
                    $1.addtocws(); //#24357
                    $1.i = $1.i + 1; //#24358
                } //#24358
            } //#24358
            break; //#24361
        } //#24361
    }; //#24361
    $1.encB = function() {
        for (var _D1 = 0, _D2 = 1; _D1 < _D2; _D1++) { //#24438
            $1.n = $get($1.TryC, $1.i); //#24367
            if ($1.n >= 2) { //#24385
                if ($1.n > 4) { //#24373
                    $k[$j++] = $a([$get($1.Bvals, $1.lac)]); //#24370
                    $1.addtocws(); //#24370
                    $1.mode = $1.C; //#24371
                    break; //#24372
                } //#24372
                $k[$j++] = $a([$get($1.Bvals, $get($a([$1.sfc, $1.sc2, $1.sc3, $1.sc4]), $f($1.n - 1)))]); //#24374
                $1.addtocws(); //#24374
                for (var _DO = 0, _DP = $1.n; _DO < _DP; _DO++) { //#24383
                    if ($get($1.msg, $1.i) < 0) { //#24381
                        $k[$j++] = $a([$get($1.Cvals, $get($1.msg, $1.i))]); //#24377
                        $1.addtocws(); //#24377
                        $1.i = $1.i + 1; //#24378
                    } else { //#24381
                        $k[$j++] = $a([$f(($f($get($1.msg, $1.i) - 48) * 10) + $f($get($1.msg, $1.i + 1) - 48))]); //#24380
                        $1.addtocws(); //#24380
                        $1.i = $1.i + 2; //#24381
                    } //#24381
                } //#24381
                break; //#24384
            } //#24384
            if ($get($1.DatumB, $1.i)) { //#24415
                var _Dn = $get($1.msg, $1.i); //#24387
                if ((_Dn == $1.fn1) || ((_Dn == $1.fn2) || (_Dn == $1.fn3))) { //#24404
                    $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.i))]); //#24388
                    $1.addtocws(); //#24388
                    if ($get($1.ECI, $1.i)) { //#24393
                        $k[$j++] = Infinity; //#24390
                        $1.ECIabc(); //#24390
                        var _E0 = $a(); //#24390
                        $k[$j++] = _E0; //#24390
                        $1.addtocws(); //#24390
                        $1.i = $1.i + 7; //#24391
                        break; //#24392
                    } //#24392
                    if (($get($1.msg, $1.i) == $1.fn3) && ($1.i != $1.segstart)) { //#24401
                        $1.i = $1.i + 1; //#24395
                        $1.mode = $1.C; //#24396
                        $1.inmac = 0; //#24397
                        $1.segstart = $1.i; //#24398
                        $1.segend = $f($1.i + $get($1.UntilEndSeg, $1.i)); //#24399
                        break; //#24400
                    } //#24400
                    $1.i = $1.i + 1; //#24402
                    break; //#24403
                } //#24403
                if (($get($1.msg, $1.i) == 13) && ($1.i < ($1.msglen - 1))) { //#24411
                    if ($get($1.msg, $1.i + 1) == 10) { //#24410
                        $k[$j++] = $a([$get($1.Bvals, $1.crl)]); //#24407
                        $1.addtocws(); //#24407
                        $1.i = $1.i + 2; //#24408
                        break; //#24409
                    } //#24409
                } //#24409
                $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.i))]); //#24412
                $1.addtocws(); //#24412
                $1.i = $1.i + 1; //#24413
                break; //#24414
            } //#24414
            if ($get($1.Binary, $1.i)) { //#24429
                if ($get($1.DatumB, $1.i + 1)) { //#24425
                    if ($get($1.msg, $1.i) < 160) { //#24421
                        $k[$j++] = $a([$get($1.Bvals, $1.bsa), $get($1.Avals, $f($get($1.msg, $1.i) - 128))]); //#24419
                        $1.addtocws(); //#24419
                    } else { //#24421
                        $k[$j++] = $a([$get($1.Bvals, $1.bsb), $get($1.Bvals, $f($get($1.msg, $1.i) - 128))]); //#24421
                        $1.addtocws(); //#24421
                    } //#24421
                    $1.i = $1.i + 1; //#24423
                    break; //#24424
                } //#24424
                $k[$j++] = $a([$get($1.Bvals, $1.bin)]); //#24426
                $1.addtocws(); //#24426
                $1.mode = $1.BIN; //#24427
                break; //#24428
            } //#24428
            if ($get($1.AheadA, $1.i) == 1) { //#24434
                $k[$j++] = $a([$get($1.Bvals, $1.sfa), $get($1.Avals, $get($1.msg, $1.i))]); //#24431
                $1.addtocws(); //#24431
                $1.i = $1.i + 1; //#24432
                break; //#24433
            } //#24433
            $k[$j++] = $a([$get($1.Bvals, $1.laa)]); //#24435
            $1.addtocws(); //#24435
            $1.mode = $1.A; //#24436
            break; //#24437
        } //#24437
    }; //#24437
    $1.encA = function() {
        for (var _FP = 0, _FQ = 1; _FP < _FQ; _FP++) { //#24516
            $1.n = $get($1.TryC, $1.i); //#24443
            if ($1.n >= 2) { //#24461
                if ($1.n > 4) { //#24449
                    $k[$j++] = $a([$get($1.Avals, $1.lac)]); //#24446
                    $1.addtocws(); //#24446
                    $1.mode = $1.C; //#24447
                    break; //#24448
                } //#24448
                $k[$j++] = $a([$get($1.Avals, $get($a([$1.sfc, $1.sc2, $1.sc3, $1.sc4]), $f($1.n - 1)))]); //#24450
                $1.addtocws(); //#24450
                for (var _Fm = 0, _Fn = $1.n; _Fm < _Fn; _Fm++) { //#24459
                    if ($get($1.msg, $1.i) < 0) { //#24457
                        $k[$j++] = $a([$get($1.Cvals, $get($1.msg, $1.i))]); //#24453
                        $1.addtocws(); //#24453
                        $1.i = $1.i + 1; //#24454
                    } else { //#24457
                        $k[$j++] = $a([$f(($f($get($1.msg, $1.i) - 48) * 10) + $f($get($1.msg, $1.i + 1) - 48))]); //#24456
                        $1.addtocws(); //#24456
                        $1.i = $1.i + 2; //#24457
                    } //#24457
                } //#24457
                break; //#24460
            } //#24460
            if ($get($1.DatumA, $1.i)) { //#24484
                var _GB = $get($1.msg, $1.i); //#24463
                if ((_GB == $1.fn1) || ((_GB == $1.fn2) || (_GB == $1.fn3))) { //#24480
                    $k[$j++] = $a([$get($1.Avals, $get($1.msg, $1.i))]); //#24464
                    $1.addtocws(); //#24464
                    if ($get($1.ECI, $1.i)) { //#24469
                        $k[$j++] = Infinity; //#24466
                        $1.ECIabc(); //#24466
                        var _GO = $a(); //#24466
                        $k[$j++] = _GO; //#24466
                        $1.addtocws(); //#24466
                        $1.i = $1.i + 7; //#24467
                        break; //#24468
                    } //#24468
                    if (($get($1.msg, $1.i) == $1.fn3) && ($1.i != $1.segstart)) { //#24477
                        $1.i = $1.i + 1; //#24471
                        $1.mode = $1.C; //#24472
                        $1.inmac = 0; //#24473
                        $1.segstart = $1.i; //#24474
                        $1.segend = $f($1.i + $get($1.UntilEndSeg, $1.i)); //#24475
                        break; //#24476
                    } //#24476
                    $1.i = $1.i + 1; //#24478
                    break; //#24479
                } //#24479
                $k[$j++] = $a([$get($1.Avals, $get($1.msg, $1.i))]); //#24481
                $1.addtocws(); //#24481
                $1.i = $1.i + 1; //#24482
                break; //#24483
            } //#24483
            if ($get($1.Binary, $1.i)) { //#24498
                if ($get($1.DatumA, $1.i + 1)) { //#24494
                    if ($get($1.msg, $1.i) < 160) { //#24490
                        $k[$j++] = $a([$get($1.Avals, $1.bsa), $get($1.Avals, $f($get($1.msg, $1.i) - 128))]); //#24488
                        $1.addtocws(); //#24488
                    } else { //#24490
                        $k[$j++] = $a([$get($1.Avals, $1.bsb), $get($1.Bvals, $f($get($1.msg, $1.i) - 128))]); //#24490
                        $1.addtocws(); //#24490
                    } //#24490
                    $1.i = $1.i + 1; //#24492
                    break; //#24493
                } //#24493
                $k[$j++] = $a([$get($1.Avals, $1.bin)]); //#24495
                $1.addtocws(); //#24495
                $1.mode = $1.BIN; //#24496
                break; //#24497
            } //#24497
            $1.n = $get($1.AheadB, $1.i); //#24499
            if ($1.n > 6) { //#24504
                $k[$j++] = $a([$get($1.Avals, $1.lab)]); //#24501
                $1.addtocws(); //#24501
                $1.mode = $1.B; //#24502
                break; //#24503
            } //#24503
            $k[$j++] = $a([$get($1.Avals, $get($a([$1.sfb, $1.sb2, $1.sb3, $1.sb4, $1.sb5, $1.sb6]), $f($1.n - 1)))]); //#24505
            $1.addtocws(); //#24505
            for (var _He = 0, _Hf = $1.n; _He < _Hf; _He++) { //#24514
                if ($get($1.msg, $1.i) == 13) { //#24512
                    $k[$j++] = $a([$get($1.Bvals, $1.crl)]); //#24508
                    $1.addtocws(); //#24508
                    $1.i = $1.i + 2; //#24509
                } else { //#24512
                    $k[$j++] = $a([$get($1.Bvals, $get($1.msg, $1.i))]); //#24511
                    $1.addtocws(); //#24511
                    $1.i = $1.i + 1; //#24512
                } //#24512
            } //#24512
            break; //#24515
        } //#24515
    }; //#24515
    $1.encBIN = function() {
        for (var _Hv = 0, _Hw = 1; _Hv < _Hw; _Hv++) { //#24578
            $1.n = $get($1.TryC, $1.i); //#24521
            if ($1.n >= 2) { //#24540
                $k[$j++] = Infinity; //#24523
                $1.finaliseBIN(); //#24523
                var _I1 = $a(); //#24523
                $k[$j++] = _I1; //#24523
                $1.addtocws(); //#24523
                if ($1.n > 7) { //#24528
                    $k[$j++] = $a([$get($1.BINvals, $1.tmc)]); //#24525
                    $1.addtocws(); //#24525
                    $1.mode = $1.C; //#24526
                    break; //#24527
                } //#24527
                $k[$j++] = $a([$get($1.BINvals, $get($a([$1.sc2, $1.sc3, $1.sc4, $1.sc5, $1.sc6, $1.sc7]), $f($1.n - 2)))]); //#24529
                $1.addtocws(); //#24529
                for (var _IL = 0, _IM = $1.n; _IL < _IM; _IL++) { //#24538
                    if ($get($1.msg, $1.i) < 0) { //#24536
                        $k[$j++] = $a([$get($1.Cvals, $get($1.msg, $1.i))]); //#24532
                        $1.addtocws(); //#24532
                        $1.i = $1.i + 1; //#24533
                    } else { //#24536
                        $k[$j++] = $a([$f(($f($get($1.msg, $1.i) - 48) * 10) + $f($get($1.msg, $1.i + 1) - 48))]); //#24535
                        $1.addtocws(); //#24535
                        $1.i = $1.i + 2; //#24536
                    } //#24536
                } //#24536
                break; //#24539
            } //#24539
            if (($get($1.ECI, $1.i) && $get($1.Binary, $1.i + 7))) { //#24546
                $k[$j++] = Infinity; //#24542
                $1.ECIbin(); //#24542
                var _Il = $a(); //#24542
                $k[$j++] = _Il; //#24542
                $1.addtocws(); //#24542
                $1.i = $1.i + 7; //#24543
                if ($1.i == $1.msglen) { //#24544
                    $k[$j++] = Infinity; //#24544
                    $1.finaliseBIN(); //#24544
                    var _Ip = $a(); //#24544
                    $k[$j++] = _Ip; //#24544
                    $1.addtocws(); //#24544
                } //#24544
                break; //#24545
            } //#24545
            if ($get($1.msg, $1.i) >= 0) { //#24556
                if (((($get($1.Binary, $1.i) || $get($1.Binary, $1.i + 1)) || $get($1.Binary, $1.i + 2)) || $get($1.Binary, $1.i + 3)) || ($get($1.ECI, $1.i + 1) && $get($1.Binary, $1.i + 8))) { //#24555
                    $k[$j++] = Infinity; //#24551
                    $k[$j++] = $get($1.msg, $1.i); //#24551
                    $1.addtobin(); //#24551
                    var _JE = $a(); //#24551
                    $k[$j++] = _JE; //#24551
                    $1.addtocws(); //#24551
                    $1.i = $1.i + 1; //#24552
                    if ($1.i == $1.msglen) { //#24553
                        $k[$j++] = Infinity; //#24553
                        $1.finaliseBIN(); //#24553
                        var _JI = $a(); //#24553
                        $k[$j++] = _JI; //#24553
                        $1.addtocws(); //#24553
                    } //#24553
                    break; //#24554
                } //#24554
            } //#24554
            $k[$j++] = Infinity; //#24557
            $1.finaliseBIN(); //#24557
            var _JJ = $a(); //#24557
            $k[$j++] = _JJ; //#24557
            $1.addtocws(); //#24557
            if ($1.i != ($1.msglen - 1)) { //#24576
                if (($get($1.msg, $1.i) == $1.fn3) && ($1.i != $1.segstart)) { //#24567
                    $k[$j++] = $a([$get($1.BINvals, $1.tms)]); //#24560
                    $1.addtocws(); //#24560
                    $1.i = $1.i + 1; //#24561
                    $1.mode = $1.C; //#24562
                    $1.inmac = 0; //#24563
                    $1.segstart = $1.i; //#24564
                    $1.segend = $f($1.i + $get($1.UntilEndSeg, $1.i)); //#24565
                    break; //#24566
                } //#24566
                if ($gt($get($1.AheadA, $1.i), $get($1.AheadB, $1.i))) { //#24573
                    $k[$j++] = $a([$get($1.BINvals, $1.tma)]); //#24569
                    $1.addtocws(); //#24569
                    $1.mode = $1.A; //#24570
                } else { //#24573
                    $k[$j++] = $a([$get($1.BINvals, $1.tmb)]); //#24572
                    $1.addtocws(); //#24572
                    $1.mode = $1.B; //#24573
                } //#24573
                break; //#24575
            } //#24575
            break; //#24577
        } //#24577
    }; //#24577
    $1.cws = $a(($1.msglen * 2) + 1); //#24581
    $1.mode = $1.C; //#24582
    $1.bvals = $a(5); //#24583
    $1.bpos = 0; //#24583
    $1.inmac = 0; //#24584
    $1.segstart = 0; //#24584
    $1.segend = $get($1.UntilEndSeg, 0); //#24584
    $1.i = 0; //#24585
    $1.j = 0; //#24585
    for (;;) { //#24598
        if ($1.i >= $1.msglen) { //#24586
            break; //#24586
        } //#24586
        if ($1.inmac != 0) { //#24596
            if (($1.inmac != $1.mac) && ($1.i == $f($1.segend - 2))) { //#24591
                $1.i = $1.i + 2; //#24589
                if ($1.i >= $1.msglen) { //#24590
                    break; //#24590
                } //#24590
            } //#24590
            if (($1.inmac == $1.mac) && ($1.i == $f($1.segend - 1))) { //#24595
                $1.i = $1.i + 1; //#24593
                if ($1.i >= $1.msglen) { //#24594
                    break; //#24594
                } //#24594
            } //#24594
        } //#24594
        if ($1[$get($a(['encA', 'encB', 'encC', 'encBIN']), $1.mode)]() === true) {
            break;
        } //#24597
    } //#24597
    $1.cws = $geti($1.cws, 0, $1.j); //#24599
    $1.nd = $1.cws.length; //#24602
    $1.minarea = (((($1.nd + 3) + (~~($1.nd / 2))) * 9) + 2) * 2; //#24603
    if ($1.ratio != -1) { //#24631
        $1.hgt = Math.sqrt($1.minarea / $1.ratio); //#24605
        $1.wid = Math.sqrt($1.minarea * $1.ratio); //#24606
        $1.h = ~~$1.hgt; //#24607
        $1.w = ~~$1.wid; //#24607
        if ((($1.h + $1.w) % 2) == 1) { //#24621
            if (($1.h * $1.w) < $1.minarea) { //#24609
                $1.h = $1.h + 1; //#24609
                $1.w = $1.w + 1; //#24609
            } //#24609
        } else { //#24621
            if (($1.hgt * $1.w) < ($1.wid * $1.h)) { //#24621
                $1.w = $1.w + 1; //#24612
                if (($1.h * $1.w) < $1.minarea) { //#24616
                    $1.w = $1.w - 1; //#24614
                    $1.h = $1.h + 1; //#24614
                    if (($1.h * $1.w) < $1.minarea) { //#24615
                        $1.w = $1.w + 2; //#24615
                    } //#24615
                } //#24615
            } else { //#24621
                $1.h = $1.h + 1; //#24618
                if (($1.h * $1.w) < $1.minarea) { //#24622
                    $1.h = $1.h - 1; //#24620
                    $1.w = $1.w + 1; //#24620
                    if (($1.h * $1.w) < $1.minarea) { //#24621
                        $1.h = $1.h + 2; //#24621
                    } //#24621
                } //#24621
            } //#24621
        } //#24621
        $1.rows = $1.h; //#24625
        $1.columns = $1.w; //#24625
    } else { //#24631
        if ($1.columns == -1) { //#24629
            var _L8 = ~~((($1.minarea + $1.rows) - 1) / $1.rows); //#24628
            $k[$j++] = 'columns'; //#24628
            $k[$j++] = _L8; //#24628
            if (((_L8 + $1.rows) % 2) == 0) { //#24628
                var _LA = $k[--$j]; //#24628
                $k[$j++] = $f(_LA + 1); //#24628
            } //#24628
            var _LB = $k[--$j]; //#24628
            $1[$k[--$j]] = _LB; //#24628
        } //#24628
        if ($1.rows == -1) { //#24632
            var _LH = ~~((($1.minarea + $1.columns) - 1) / $1.columns); //#24631
            $k[$j++] = 'rows'; //#24631
            $k[$j++] = _LH; //#24631
            if (((_LH + $1.columns) % 2) == 0) { //#24631
                var _LJ = $k[--$j]; //#24631
                $k[$j++] = $f(_LJ + 1); //#24631
            } //#24631
            var _LK = $k[--$j]; //#24631
            $1[$k[--$j]] = _LK; //#24631
        } //#24631
    } //#24631
    $1.ndots = ~~(($1.rows * $1.columns) / 2); //#24636
    for (;;) { //#24640
        var _LP = $1.nd + 1; //#24638
        if ((((_LP + ((~~(_LP / 2)) + 3)) * 9) + 2) > $1.ndots) { //#24638
            break; //#24638
        } //#24638
        $1.nd = $1.nd + 1; //#24639
    } //#24639
    $1.nc = (~~($1.nd / 2)) + 3; //#24641
    $1.nw = $1.nd + $1.nc; //#24642
    $1.rembits = $1.ndots - (($1.nw * 9) + 2); //#24643
    if ($1.nd > $1.cws.length) { //#24650
        $k[$j++] = Infinity; //#24648
        $aload($1.cws); //#24646
        var _Lc = ($1.mode == $1.BIN) ? 109 : 106; //#24647
        $k[$j++] = _Lc; //#24648
        for (var _Lf = 0, _Lg = ($1.nd - $1.cws.length) - 1; _Lf < _Lg; _Lf++) { //#24648
            $k[$j++] = 106; //#24648
        } //#24648
        $1.cws = $a(); //#24648
    } //#24649
    var _Lj = $get($1.options, 'debugcws') !== undefined; //#24652
    if (_Lj) { //#24652
        $k[$j++] = 'bwipp.debugcws'; //#24652
        $k[$j++] = $1.cws; //#24652
        bwipp_raiseerror(); //#24652
    } //#24652
    $1.encs = $a(["101010101", "010101011", "010101101", "010110101", "011010101", "101010110", "101011010", "101101010", "110101010", "010101110", "010110110", "010111010", "011010110", "011011010", "011101010", "100101011", "100101101", "100110101", "101001011", "101001101", "101010011", "101011001", "101100101", "101101001", "110010101", "110100101", "110101001", "001010111", "001011011", "001011101", "001101011", "001101101", "001110101", "010010111", "010011011", "010011101", "010100111", "010110011", "010111001", "011001011", "011001101", "011010011", "011011001", "011100101", "011101001", "100101110", "100110110", "100111010", "101001110", "101011100", "101100110", "101101100", "101110010", "101110100", "110010110", "110011010", "110100110", "110101100", "110110010", "110110100", "111001010", "111010010", "111010100", "001011110", "001101110", "001110110", "001111010", "010011110", "010111100", "011001110", "011011100", "011100110", "011101100", "011110010", "011110100", "100010111", "100011011", "100011101", "100100111", "100110011", "100111001", "101000111", "101100011", "101110001", "110001011", "110001101", "110010011", "110011001", "110100011", "110110001", "111000101", "111001001", "111010001", "000101111", "000110111", "000111011", "000111101", "001001111", "001100111", "001110011", "001111001", "010001111", "011000111", "011100011", "011110001", "100011110", "100111100", "101111000", "110001110", "110011100", "110111000", "111000110", "111001100"]); //#24680
    if (($1.rows % 2) == 0) { //#24701
        $1.sixedges = $a([$a([$1.columns - 1, $1.rows - 2]), $a([0, $1.rows - 2]), $a([$1.columns - 2, $1.rows - 1]), $a([1, $1.rows - 1]), $a([$1.columns - 1, 0]), $a([0, 0])]); //#24692
    } else { //#24701
        $1.sixedges = $a([$a([$1.columns - 2, 0]), $a([$1.columns - 2, $1.rows - 1]), $a([$1.columns - 1, 1]), $a([$1.columns - 1, $1.rows - 2]), $a([0, 0]), $a([0, $1.rows - 1])]); //#24701
    } //#24701
    $1.dmv = function() {
        var _MG = $k[--$j]; //#24704
        var _MH = $k[--$j]; //#24704
        $k[$j++] = $f(_MH + (_MG * $1.columns)); //#24704
    }; //#24704
    $1.outline = $a($1.rows * $1.columns); //#24707
    for (var _MN = 0, _MM = $1.rows - 1; _MN <= _MM; _MN += 1) { //#24714
        $1.y = _MN; //#24709
        for (var _MQ = 0, _MP = $1.columns - 1; _MQ <= _MP; _MQ += 1) { //#24713
            $1.x = _MQ; //#24711
            $k[$j++] = $1.outline; //#24712
            $k[$j++] = $1.x; //#24712
            $k[$j++] = $1.y; //#24712
            $1.dmv(); //#24712
            var _MW = $k[--$j]; //#24712
            $put($k[--$j], _MW, (($1.x + $1.y) % 2) - 1); //#24712
        } //#24712
    } //#24712
    var _MY = $1.sixedges; //#24715
    for (var _MZ = 0, _Ma = _MY.length; _MZ < _Ma; _MZ++) { //#24717
        $k[$j++] = $1.outline; //#24716
        $aload($get(_MY, _MZ)); //#24716
        $1.dmv(); //#24716
        var _Md = $k[--$j]; //#24716
        $put($k[--$j], _Md, 1); //#24716
    } //#24716
    $1.clearcol = function() {
        $1.x = $k[--$j]; //#24720
        $k[$j++] = true; //#24724
        for (var _Mj = $1.x & 1, _Mi = $1.rows - 1; _Mj <= _Mi; _Mj += 2) { //#24724
            $k[$j++] = $1.x; //#24723
            $k[$j++] = _Mj; //#24723
            $1.dmv(); //#24723
            if ($get($1.sym, $k[--$j]) == 1) { //#24723
                $j--; //#24723
                $k[$j++] = false; //#24723
                break; //#24723
            } //#24723
        } //#24723
    }; //#24723
    $1.clearrow = function() {
        $1.y = $k[--$j]; //#24728
        $k[$j++] = true; //#24732
        for (var _Ms = $1.y & 1, _Mr = $1.columns - 1; _Ms <= _Mr; _Ms += 2) { //#24732
            $k[$j++] = _Ms; //#24731
            $k[$j++] = $1.y; //#24731
            $1.dmv(); //#24731
            if ($get($1.sym, $k[--$j]) == 1) { //#24731
                $j--; //#24731
                $k[$j++] = false; //#24731
                break; //#24731
            } //#24731
        } //#24731
    }; //#24731
    $1.evalsymbol = function() {
        $1.sym = $k[--$j]; //#24737
        $1.worst = 9999999; //#24740
        var _N2 = $a([$a(['x', 0]), $a(['x', 1]), $a(['y', 0]), $a(['y', 1])]); //#24741
        for (var _N3 = 0, _N4 = _N2.length; _N3 < _N4; _N3++) { //#24759
            $aload($get(_N2, _N3)); //#24742
            $1.fl = $k[--$j]; //#24742
            $1.dir = $k[--$j]; //#24742
            $1.sum = 0; //#24743
            $1.first = -1; //#24743
            $1.last = -1; //#24743
            var _N9 = $eq($1.dir, 'x') ? $1.columns : $1.rows; //#24744
            for (var _NB = 0, _NA = _N9 - 1; _NB <= _NA; _NB += 1) { //#24755
                $1[$1.dir] = _NB; //#24745
                var _ND = $1.sym; //#24746
                var _NF = $1[$1.dir]; //#24747
                var _NH = $eq($1.dir, 'x') ? $1.rows : $1.columns; //#24748
                var _NK = (_NH - 1) * $1.fl; //#24749
                if ($eq($1.dir, 'y')) { //#24749
                    var _ = _NK; //#24749
                    _NK = _NF; //#24749
                    _NF = _; //#24749
                } //#24749
                $k[$j++] = _ND; //#24750
                $k[$j++] = _NF; //#24750
                $k[$j++] = _NK; //#24750
                $1.dmv(); //#24750
                var _NL = $k[--$j]; //#24750
                if ($get($k[--$j], _NL) == 1) { //#24754
                    if ($1.first == -1) { //#24751
                        $1.first = $1[$1.dir]; //#24751
                    } //#24751
                    $1.last = $1[$1.dir]; //#24752
                    $1.sum = $1.sum + 1; //#24753
                } //#24753
            } //#24753
            var _NY = $eq($1.dir, 'x') ? $1.rows : $1.columns; //#24757
            var _NZ = ($f($f($1.sum + $1.last) - $1.first)) * _NY; //#24758
            $k[$j++] = _NZ; //#24758
            if (_NZ < $1.worst) { //#24758
                $1.worst = $k[--$j]; //#24758
            } else { //#24758
                $j--; //#24758
            } //#24758
        } //#24758
        $1.pen = 0; //#24761
        if ((($1.rows % 2) == 1) || ($1.rows <= 12)) { //#24779
            $1.sum = 0; //#24767
            $1.p = 0; //#24767
            for (var _Ng = 1, _Nf = $1.columns - 2; _Ng <= _Nf; _Ng += 1) { //#24777
                $k[$j++] = _Ng; //#24769
                $1.clearcol(); //#24769
                if ($k[--$j]) { //#24775
                    $1.sum = $1.sum + 1; //#24770
                    $k[$j++] = 'p'; //#24771
                    if ($1.sum == 1) { //#24771
                        $k[$j++] = $1.rows; //#24771
                    } else { //#24771
                        $k[$j++] = $1.p * $1.rows; //#24771
                    } //#24771
                    var _Nn = $k[--$j]; //#24771
                    $1[$k[--$j]] = _Nn; //#24771
                } else { //#24775
                    $1.sum = 0; //#24773
                    $1.pen = $1.pen + $1.p; //#24774
                    $1.p = 0; //#24775
                } //#24775
            } //#24775
            $1.pen = $1.pen + $1.p; //#24778
        } //#24778
        if ((($1.rows % 2) == 0) || ($1.columns <= 12)) { //#24797
            $1.sum = 0; //#24785
            $1.p = 0; //#24785
            for (var _Nx = 1, _Nw = $1.rows - 2; _Nx <= _Nw; _Nx += 1) { //#24795
                $k[$j++] = _Nx; //#24787
                $1.clearrow(); //#24787
                if ($k[--$j]) { //#24793
                    $1.sum = $1.sum + 1; //#24788
                    $k[$j++] = 'p'; //#24789
                    if ($1.sum == 1) { //#24789
                        $k[$j++] = $1.columns; //#24789
                    } else { //#24789
                        $k[$j++] = $1.p * $1.columns; //#24789
                    } //#24789
                    var _O4 = $k[--$j]; //#24789
                    $1[$k[--$j]] = _O4; //#24789
                } else { //#24793
                    $1.sum = 0; //#24791
                    $1.pen = $1.pen + $1.p; //#24792
                    $1.p = 0; //#24793
                } //#24793
            } //#24793
            $1.pen = $1.pen + $1.p; //#24796
        } //#24796
        $k[$j++] = Infinity; //#24807
        for (var _OB = 0, _OC = ($1.columns + 4) * 2; _OB < _OC; _OB++) { //#24801
            $k[$j++] = 0; //#24801
        } //#24801
        for (var _OG = 0, _OH = $1.columns, _OF = $1.sym.length - 1; _OH < 0 ? _OG >= _OF : _OG <= _OF; _OG += _OH) { //#24806
            $k[$j++] = 0; //#24804
            $k[$j++] = 0; //#24804
            $aload($geti($1.sym, _OG, $1.columns)); //#24804
            $k[$j++] = 0; //#24805
            $k[$j++] = 0; //#24805
        } //#24805
        for (var _OM = 0, _ON = ($1.columns + 4) * 2; _OM < _ON; _OM++) { //#24807
            $k[$j++] = 0; //#24807
        } //#24807
        $1.symp = $a(); //#24807
        $1.columns = $1.columns + 4; //#24811
        $1.rows = $1.rows + 4; //#24812
        $1.sum = 0; //#24813
        for (var _OT = 2, _OS = $1.rows - 3; _OT <= _OS; _OT += 1) { //#24831
            $1.y = _OT; //#24815
            for (var _OX = ($1.y & 1) + 2, _OW = $1.columns - 3; _OX <= _OW; _OX += 2) { //#24830
                $1.x = _OX; //#24817
                for (var _OY = 0, _OZ = 1; _OY < _OZ; _OY++) { //#24829
                    $k[$j++] = $1.symp; //#24819
                    $k[$j++] = $1.x - 1; //#24819
                    $k[$j++] = $1.y - 1; //#24819
                    $1.dmv(); //#24819
                    var _Od = $k[--$j]; //#24819
                    if ($get($k[--$j], _Od) == 1) { //#24819
                        break; //#24819
                    } //#24819
                    $k[$j++] = $1.symp; //#24820
                    $k[$j++] = $1.x + 1; //#24820
                    $k[$j++] = $1.y - 1; //#24820
                    $1.dmv(); //#24820
                    var _Oj = $k[--$j]; //#24820
                    if ($get($k[--$j], _Oj) == 1) { //#24820
                        break; //#24820
                    } //#24820
                    $k[$j++] = $1.symp; //#24821
                    $k[$j++] = $1.x - 1; //#24821
                    $k[$j++] = $1.y + 1; //#24821
                    $1.dmv(); //#24821
                    var _Op = $k[--$j]; //#24821
                    if ($get($k[--$j], _Op) == 1) { //#24821
                        break; //#24821
                    } //#24821
                    $k[$j++] = $1.symp; //#24822
                    $k[$j++] = $1.x + 1; //#24822
                    $k[$j++] = $1.y + 1; //#24822
                    $1.dmv(); //#24822
                    var _Ov = $k[--$j]; //#24822
                    if ($get($k[--$j], _Ov) == 1) { //#24822
                        break; //#24822
                    } //#24822
                    $k[$j++] = $1.symp; //#24823
                    $k[$j++] = $1.x; //#24823
                    $k[$j++] = $1.y; //#24823
                    $1.dmv(); //#24823
                    var _P1 = $k[--$j]; //#24823
                    if ($get($k[--$j], _P1) == 0) { //#24823
                        $1.sum = $1.sum + 1; //#24823
                        break; //#24823
                    } //#24823
                    $k[$j++] = $1.symp; //#24824
                    $k[$j++] = $1.x - 2; //#24824
                    $k[$j++] = $1.y; //#24824
                    $1.dmv(); //#24824
                    var _P8 = $k[--$j]; //#24824
                    if ($get($k[--$j], _P8) == 1) { //#24824
                        break; //#24824
                    } //#24824
                    $k[$j++] = $1.symp; //#24825
                    $k[$j++] = $1.x; //#24825
                    $k[$j++] = $1.y - 2; //#24825
                    $1.dmv(); //#24825
                    var _PE = $k[--$j]; //#24825
                    if ($get($k[--$j], _PE) == 1) { //#24825
                        break; //#24825
                    } //#24825
                    $k[$j++] = $1.symp; //#24826
                    $k[$j++] = $1.x + 2; //#24826
                    $k[$j++] = $1.y; //#24826
                    $1.dmv(); //#24826
                    var _PK = $k[--$j]; //#24826
                    if ($get($k[--$j], _PK) == 1) { //#24826
                        break; //#24826
                    } //#24826
                    $k[$j++] = $1.symp; //#24827
                    $k[$j++] = $1.x; //#24827
                    $k[$j++] = $1.y + 2; //#24827
                    $1.dmv(); //#24827
                    var _PQ = $k[--$j]; //#24827
                    if ($get($k[--$j], _PQ) == 1) { //#24827
                        break; //#24827
                    } //#24827
                    $1.sum = $1.sum + 1; //#24828
                } //#24828
            } //#24828
        } //#24828
        $1.columns = $1.columns - 4; //#24832
        $1.rows = $1.rows - 4; //#24833
        if ($1.worst == 0) { //#24838
            $k[$j++] = -99999; //#24836
        } else { //#24838
            $k[$j++] = $f(($f($1.worst - ($1.sum * $1.sum))) - $1.pen); //#24838
        } //#24838
    }; //#24838
    $k[$j++] = Infinity; //#24844
    $k[$j++] = 1; //#24844
    for (var _Pb = 0, _Pc = 112; _Pb < _Pc; _Pb++) { //#24844
        var _Pd = $k[--$j]; //#24844
        $k[$j++] = _Pd; //#24844
        $k[$j++] = (_Pd * 3) % 113; //#24844
    } //#24844
    $1.rsalog = $a(); //#24844
    $1.step = (~~($1.nw / 112)) + 1; //#24845
    $1.offset = function() {
        var _Ph = $k[--$j]; //#24846
        $k[$j++] = $f((_Ph * $1.step) + $1.start); //#24846
    }; //#24846
    $1.bestscore = -99999999; //#24854
    $k[$j++] = 'masks'; //#24859
    if ($1.mask != -1) { //#24858
        $k[$j++] = $a([$1.mask]); //#24856
    } else { //#24858
        if ($1.fast) { //#24858
            $k[$j++] = $a([3, 2, 1, 0]); //#24858
        } else { //#24858
            $k[$j++] = $a([0, 1, 2, 3]); //#24858
        } //#24858
    } //#24858
    var _Pp = $k[--$j]; //#24859
    $1[$k[--$j]] = _Pp; //#24859
    $1.litmasks = $a(4); //#24860
    $forall($1.masks, function() { //#24962
        $1.mask = $k[--$j]; //#24863
        $k[$j++] = Infinity; //#24869
        var _Py = $1.cws; //#24868
        $k[$j++] = $1.mask; //#24868
        $k[$j++] = $get($a([0, 3, 7, 17]), $1.mask); //#24868
        $k[$j++] = 0; //#24868
        for (var _Pz = 0, _Q0 = _Py.length; _Pz < _Q0; _Pz++) { //#24868
            var _Q2 = $k[--$j]; //#24868
            var _Q3 = $k[--$j]; //#24868
            $k[$j++] = $f($get(_Py, _Pz) + _Q2) % 113; //#24868
            $k[$j++] = _Q3; //#24868
            $k[$j++] = $f(_Q2 + _Q3); //#24868
        } //#24868
        $j -= 2; //#24868
        for (var _Q5 = 0, _Q6 = $1.nc; _Q5 < _Q6; _Q5++) { //#24869
            $k[$j++] = 0; //#24869
        } //#24869
        $1.rscws = $a(); //#24869
        for (var _QA = 0, _Q9 = $1.step - 1; _QA <= _Q9; _QA += 1) { //#24893
            $1.start = _QA; //#24872
            $1.ND = ~~((((($1.nd + 1) - $1.start) + $1.step) - 1) / $1.step); //#24873
            $1.NW = ~~((((($1.nw + 1) - $1.start) + $1.step) - 1) / $1.step); //#24874
            $1.NC = $1.NW - $1.ND; //#24875
            $k[$j++] = Infinity; //#24876
            $k[$j++] = 1; //#24876
            for (var _QM = 0, _QN = $1.NC; _QM < _QN; _QM++) { //#24876
                $k[$j++] = 0; //#24876
            } //#24876
            $1.coeffs = $a(); //#24876
            for (var _QR = 1, _QQ = $1.NC; _QR <= _QQ; _QR += 1) { //#24883
                $1.i = _QR; //#24878
                for (var _QT = $1.NC; _QT >= 1; _QT -= 1) { //#24882
                    $1.j = _QT; //#24880
                    $put($1.coeffs, $1.j, ($f($f($get($1.coeffs, $1.j) + 113) - (($get($1.rsalog, $1.i) * $get($1.coeffs, $1.j - 1)) % 113))) % 113); //#24881
                } //#24881
            } //#24881
            for (var _Qh = 0, _Qg = $1.ND - 1; _Qh <= _Qg; _Qh += 1) { //#24891
                $k[$j++] = 't'; //#24885
                $k[$j++] = $1.rscws; //#24885
                $k[$j++] = _Qh; //#24885
                $1.offset(); //#24885
                var _Qj = $k[--$j]; //#24885
                var _Ql = $get($k[--$j], _Qj); //#24885
                $k[$j++] = _Ql; //#24885
                $k[$j++] = $1.rscws; //#24885
                $k[$j++] = $1.ND; //#24885
                $1.offset(); //#24885
                var _Qo = $k[--$j]; //#24885
                var _Qq = $get($k[--$j], _Qo); //#24885
                var _Qr = $k[--$j]; //#24885
                $1[$k[--$j]] = $f(_Qr + _Qq) % 113; //#24885
                for (var _Qv = 0, _Qu = $1.NC - 2; _Qv <= _Qu; _Qv += 1) { //#24889
                    $1.j = _Qv; //#24887
                    $k[$j++] = $1.rscws; //#24888
                    $k[$j++] = $1.ND + $1.j; //#24888
                    $1.offset(); //#24888
                    $k[$j++] = $1.rscws; //#24888
                    $k[$j++] = ($1.ND + $1.j) + 1; //#24888
                    $1.offset(); //#24888
                    var _R2 = $k[--$j]; //#24888
                    var _R4 = $get($k[--$j], _R2); //#24888
                    var _R9 = $k[--$j]; //#24888
                    $put($k[--$j], _R9, ($f($f(_R4 + 113) - (($1.t * $get($1.coeffs, $1.j + 1)) % 113))) % 113); //#24888
                } //#24888
                $k[$j++] = $1.rscws; //#24890
                $k[$j++] = ($1.ND + $1.NC) - 1; //#24890
                $1.offset(); //#24890
                var _RI = $k[--$j]; //#24890
                $put($k[--$j], _RI, ($f(113 - (($1.t * $get($1.coeffs, $1.NC)) % 113))) % 113); //#24890
            } //#24890
            for (var _RN = $1.ND, _RM = $1.NW - 1; _RN <= _RM; _RN += 1) { //#24892
                $k[$j++] = _RN; //#24892
                $k[$j++] = $1.rscws; //#24892
                $k[$j++] = _RN; //#24892
                $1.offset(); //#24892
                var _RQ = $k[--$j]; //#24892
                var _RR = $k[--$j]; //#24892
                var _RS = $k[--$j]; //#24892
                $k[$j++] = _RR; //#24892
                $k[$j++] = _RQ; //#24892
                $k[$j++] = 113; //#24892
                $k[$j++] = $1.rscws; //#24892
                $k[$j++] = _RS; //#24892
                $1.offset(); //#24892
                var _RT = $k[--$j]; //#24892
                var _RV = $get($k[--$j], _RT); //#24892
                var _RW = $k[--$j]; //#24892
                var _RX = $k[--$j]; //#24892
                $put($k[--$j], _RX, $f(_RW - _RV) % 113); //#24892
            } //#24892
        } //#24892
        $1.bits = $s($1.ndots); //#24896
        $puti($1.bits, 0, $get($a(["00", "01", "10", "11"]), $1.mask)); //#24897
        for (var _Rh = 1, _Rg = $1.nw; _Rh <= _Rg; _Rh += 1) { //#24901
            $1.i = _Rh; //#24899
            $puti($1.bits, (($1.i - 1) * 9) + 2, $get($1.encs, $get($1.rscws, $1.i))); //#24900
        } //#24900
        if ($1.rembits > 0) { //#24904
            $puti($1.bits, ($1.nw * 9) + 2, $geti("11111111111111111", 0, $1.rembits)); //#24903
        } //#24903
        var _Ru = $1.outline; //#24907
        $1.pixs = $arrcpy($a(_Ru.length), _Ru); //#24907
        $1.posx = 0; //#24908
        $k[$j++] = 'posy'; //#24909
        if (($1.rows % 2) == 0) { //#24909
            $k[$j++] = 0; //#24909
        } else { //#24909
            $k[$j++] = $1.rows - 1; //#24909
        } //#24909
        var _Rz = $k[--$j]; //#24909
        $1[$k[--$j]] = _Rz; //#24909
        var _S3 = $geti($1.bits, 0, $1.bits.length - 6); //#24910
        for (var _S4 = 0, _S5 = _S3.length; _S4 < _S5; _S4++) { //#24928
            $k[$j++] = $get(_S3, _S4); //#24926
            for (;;) { //#24926
                $k[$j++] = $1.pixs; //#24912
                $k[$j++] = $1.posx; //#24912
                $k[$j++] = $1.posy; //#24912
                $1.dmv(); //#24912
                var _SA = $k[--$j]; //#24912
                if ($get($k[--$j], _SA) == -1) { //#24912
                    break; //#24912
                } //#24912
                if (($1.rows % 2) == 0) { //#24923
                    $1.posy = $1.posy + 1; //#24914
                    if ($1.posy == $1.rows) { //#24918
                        $1.posy = 0; //#24916
                        $1.posx = $1.posx + 1; //#24917
                    } //#24917
                } else { //#24923
                    $1.posx = $1.posx + 1; //#24920
                    if ($1.posx == $1.columns) { //#24924
                        $1.posx = 0; //#24922
                        $1.posy = $1.posy - 1; //#24923
                    } //#24923
                } //#24923
            } //#24923
            $k[$j++] = $1.pixs; //#24927
            $k[$j++] = $1.posx; //#24927
            $k[$j++] = $1.posy; //#24927
            $1.dmv(); //#24927
            var _SP = $k[--$j]; //#24927
            var _SQ = $k[--$j]; //#24927
            $put(_SQ, _SP, $f($k[--$j] - 48)); //#24927
        } //#24927
        for (var _SS = 0; _SS <= 5; _SS += 1) { //#24933
            $1.i = _SS; //#24930
            $k[$j++] = $1.pixs; //#24931
            $aload($get($1.sixedges, $1.i)); //#24931
            $1.dmv(); //#24931
            var _Sb = $k[--$j]; //#24932
            $put($k[--$j], _Sb, $get($1.bits, ($1.bits.length - 6) + $1.i) - 48); //#24932
        } //#24932
        $k[$j++] = 'score'; //#24936
        $k[$j++] = $1.pixs; //#24936
        $1.evalsymbol(); //#24936
        var _Se = $k[--$j]; //#24936
        $1[$k[--$j]] = _Se; //#24936
        if ($1.score > $1.bestscore) { //#24941
            $1.bestsym = $1.pixs; //#24938
            $1.bestscore = $1.score; //#24939
            if ($1.fast && ($1.bestscore > (~~(($1.rows * $1.columns) / 2)))) { //#24940
                return true; //#24940
            } //#24940
        } //#24940
        var _So = $1.pixs; //#24944
        $1.litmask = $arrcpy($a(_So.length), _So); //#24944
        for (var _Sr = 0; _Sr <= 5; _Sr += 1) { //#24949
            $1.i = _Sr; //#24946
            $k[$j++] = $1.litmask; //#24947
            $aload($get($1.sixedges, $1.i)); //#24947
            $1.dmv(); //#24947
            var _Sw = $k[--$j]; //#24948
            $put($k[--$j], _Sw, 1); //#24948
        } //#24948
        $put($1.litmasks, $1.mask, $1.litmask); //#24950
        if ($1.fast) { //#24960
            $k[$j++] = 'score'; //#24954
            $k[$j++] = $1.litmask; //#24954
            $1.evalsymbol(); //#24954
            var _T3 = $k[--$j]; //#24954
            $1[$k[--$j]] = _T3; //#24954
            if ($gt($1.score, $1.bestscore)) { //#24959
                $1.bestsym = $1.litmask; //#24956
                $1.bestscore = $1.score; //#24957
                if ($1.bestscore > (~~(($1.rows * $1.columns) / 2))) { //#24958
                    return true; //#24958
                } //#24958
            } //#24958
        } //#24958
    }); //#24958
    $1.pixs = $1.bestsym; //#24963
    if ((!$1.fast) && ($1.bestscore <= (~~(($1.rows * $1.columns) / 2)))) { //#24977
        $1.bestscore = -99999999; //#24967
        $forall($1.masks, function() { //#24975
            $1.litmask = $get($1.litmasks, $k[--$j]); //#24969
            $k[$j++] = 'score'; //#24970
            $k[$j++] = $1.litmask; //#24970
            $1.evalsymbol(); //#24970
            var _TM = $k[--$j]; //#24970
            $1[$k[--$j]] = _TM; //#24970
            if ($1.score > $1.bestscore) { //#24974
                $1.bestsym = $1.litmask; //#24972
                $1.bestscore = $1.score; //#24973
            } //#24973
        }); //#24973
        $1.pixs = $1.bestsym; //#24976
    } //#24976
    var _TZ = new Map([
        ["ren", bwipp_renmatrix],
        ["dotty", true],
        ["pixs", $1.pixs],
        ["pixx", $1.columns],
        ["pixy", $1.rows],
        ["height", ($1.rows * 2) / 72],
        ["width", ($1.columns * 2) / 72],
        ["opt", $1.options]
    ]); //#24988
    $k[$j++] = _TZ; //#24991
    if (!$1.dontdraw) { //#24991
        bwipp_renmatrix(); //#24991
    } //#24991
}

function bwipp_ultracode() {
    var $1 = {}; //#25026
    $1.ctx = null; //#25028
    $1.dontdraw = false; //#25029
    $1.eclevel = "EC2"; //#25030
    $1.encoding = "auto"; //#25031
    $1.parse = false; //#25032
    $1.parsefnc = false; //#25033
    $1.start = 257; //#25034
    $1.link1 = 0; //#25035
    $1.raw = false; //#25036
    $1.rev = 1; //#25037
    $k[$j++] = $1; //#25039
    bwipp_processoptions(); //#25039
    $1.options = $k[--$j]; //#25039
    $1.barcode = $k[--$j]; //#25040
    var _2 = $1.rev; //#25042
    if ((_2 != 1) && (_2 != 2)) { //#25044
        $k[$j++] = 'bwipp.ultracodeInvalidRevision'; //#25043
        $k[$j++] = "Valid revisions are 1 and 2"; //#25043
        bwipp_raiseerror(); //#25043
    } //#25043
    if ($1.raw) { //#25048
        $1.encoding = "raw"; //#25048
    } //#25048
    if ($eq($1.encoding, "raw")) { //#25061
        $1.dcws = $a($1.barcode.length); //#25051
        $1.i = 0; //#25052
        $1.j = 0; //#25052
        for (;;) { //#25059
            if ($1.i == $1.barcode.length) { //#25054
                break; //#25054
            } //#25054
            $1.cw = $cvi($geti($1.barcode, $1.i + 1, 3)); //#25055
            $put($1.dcws, $1.j, $1.cw); //#25056
            $1.i = $1.i + 4; //#25057
            $1.j = $1.j + 1; //#25058
        } //#25058
        $1.dcws = $geti($1.dcws, 0, $1.j); //#25060
    } //#25060
    if ($eq($1.encoding, "auto")) { //#25088
        $1.fn1 = -1; //#25067
        $1.fn3 = -2; //#25067
        var _P = new Map([
            ["parse", $1.parse],
            ["parsefnc", $1.parsefnc],
            ["FNC1", $1.fn1],
            ["FNC3", $1.fn3]
        ]); //#25072
        $1.fncvals = _P; //#25073
        $k[$j++] = 'msg'; //#25074
        $k[$j++] = $1.barcode; //#25074
        $k[$j++] = $1.fncvals; //#25074
        bwipp_parseinput(); //#25074
        var _S = $k[--$j]; //#25074
        $1[$k[--$j]] = _S; //#25074
        $1.msglen = $1.msg.length; //#25075
        $1.scr = $a([]); //#25077
        $1.scp = $a([]); //#25078
        $k[$j++] = Infinity; //#25084
        $aload($1.scr); //#25080
        $aload($1.scp); //#25081
        $forall($1.msg, function() { //#25085
            var _a = $k[--$j]; //#25083
            $k[$j++] = _a; //#25083
            if (_a == $1.fn1) { //#25083
                $j--; //#25083
                $k[$j++] = 268; //#25083
            } //#25083
            var _c = $k[--$j]; //#25084
            $k[$j++] = _c; //#25084
            if (_c == $1.fn3) { //#25084
                $j--; //#25084
                $k[$j++] = 269; //#25084
            } //#25084
        }); //#25084
        $1.dcws = $a(); //#25084
    } //#25086
    var _g = $get($1.options, 'debugcws') !== undefined; //#25090
    if (_g) { //#25090
        $k[$j++] = 'bwipp.debugcws'; //#25090
        $k[$j++] = $1.dcws; //#25090
        bwipp_raiseerror(); //#25090
    } //#25090
    $1.mcc = $1.dcws.length + 3; //#25092
    $1.eclval = $get($1.eclevel, 2) - 48; //#25094
    if ($1.eclval != 0) { //#25098
        $k[$j++] = 'qcc'; //#25096
        $k[$j++] = $get($a([0, 1, 2, 4, 6, 8]), $1.eclval); //#25096
        $k[$j++] = ~~($1.mcc / 25); //#25096
        if (($1.mcc % 25) != 0) { //#25096
            var _r = $k[--$j]; //#25096
            $k[$j++] = $f(_r + 1); //#25096
        } //#25096
        var _s = $k[--$j]; //#25096
        var _t = $k[--$j]; //#25096
        $1[$k[--$j]] = $f((_t * _s) + 5); //#25096
    } else { //#25098
        $1.qcc = 3; //#25098
    } //#25098
    $1.acc = ($1.qcc - 3) + (78 * $1.link1); //#25100
    $1.tcc = $1.mcc + $1.qcc; //#25101
    $1.metrics = $a([$a([2, 7, 37, 5]), $a([3, 36, 84, 13]), $a([4, 85, 161, 22]), $a([5, 142, 282, 29])]); //#25111
    for (var _14 = 0; _14 <= 3; _14 += 1) { //#25124
        $1.i = _14; //#25115
        $1.m = $get($1.metrics, $1.i); //#25116
        $1.rows = $get($1.m, 0); //#25117
        $1.minc = $get($1.m, 1); //#25118
        $1.maxc = $get($1.m, 2); //#25119
        $1.mcol = $get($1.m, 3); //#25120
        $1.okay = true; //#25121
        if (($1.tcc < $1.minc) || ($1.tcc > $1.maxc)) { //#25122
            $1.okay = false; //#25122
        } //#25122
        if ($1.okay) { //#25123
            break; //#25123
        } //#25123
    } //#25123
    if (!$1.okay) { //#25128
        $k[$j++] = 'bwipp.ultracodeNoValidSymbol'; //#25127
        $k[$j++] = "Maximum length exceeded or invalid content"; //#25127
        bwipp_raiseerror(); //#25127
    } //#25127
    for (var _1N = $1.mcol; _1N <= 61; _1N += 1) { //#25142
        $1.columns = _1N; //#25132
        $k[$j++] = $1.columns; //#25134
        if ($1.columns >= 15) { //#25134
            var _1Q = $k[--$j]; //#25134
            $k[$j++] = $f(_1Q - 1); //#25134
        } //#25134
        if ($1.columns >= 31) { //#25135
            var _1S = $k[--$j]; //#25135
            $k[$j++] = $f(_1S - 1); //#25135
        } //#25135
        if ($1.columns >= 47) { //#25136
            var _1U = $k[--$j]; //#25136
            $k[$j++] = $f(_1U - 1); //#25136
        } //#25136
        var _1Y = $f(($f(($k[--$j] * $1.rows) - 3)) - $1.tcc); //#25137
        $k[$j++] = _1Y; //#25140
        if (_1Y >= 0) { //#25140
            $1.pads = $k[--$j]; //#25138
            break; //#25139
        } //#25139
        $j--; //#25141
    } //#25141
    $1.dcc = $f($1.columns - $1.mcol); //#25143
    $k[$j++] = Infinity; //#25152
    $k[$j++] = $1.start; //#25150
    $k[$j++] = $1.mcc; //#25150
    $k[$j++] = $1.acc; //#25150
    $aload($1.dcws); //#25150
    for (var _1h = 0, _1i = $1.qcc; _1h < _1i; _1h++) { //#25151
        $k[$j++] = 0; //#25151
    } //#25151
    $k[$j++] = 0; //#25152
    $1.rsseq = $a(); //#25152
    $k[$j++] = Infinity; //#25156
    $k[$j++] = 1; //#25156
    for (var _1k = 0, _1l = 282; _1k < _1l; _1k++) { //#25156
        var _1m = $k[--$j]; //#25156
        $k[$j++] = _1m; //#25156
        $k[$j++] = (_1m * 3) % 283; //#25156
    } //#25156
    $1.rsalog = $a(); //#25156
    $1.rslog = $a(283); //#25157
    for (var _1p = 1; _1p <= 282; _1p += 1) { //#25158
        $put($1.rslog, $get($1.rsalog, _1p), _1p); //#25158
    } //#25158
    $1.rsprod = function() {
        var _1t = $k[--$j]; //#25162
        var _1u = $k[--$j]; //#25162
        $k[$j++] = _1u; //#25166
        $k[$j++] = _1t; //#25166
        if ((_1t != 0) && (_1u != 0)) { //#25165
            var _1x = $get($1.rslog, $k[--$j]); //#25163
            var _22 = $get($1.rsalog, $f(_1x + $get($1.rslog, $k[--$j])) % 282); //#25163
            $k[$j++] = _22; //#25163
        } else { //#25165
            $j -= 2; //#25165
            $k[$j++] = 0; //#25165
        } //#25165
    }; //#25165
    $1.n = $1.mcc; //#25170
    $1.k = $1.qcc; //#25170
    $k[$j++] = Infinity; //#25171
    $k[$j++] = 1; //#25171
    for (var _26 = 0, _27 = $1.k; _26 < _27; _26++) { //#25171
        $k[$j++] = 0; //#25171
    } //#25171
    $1.coeffs = $a(); //#25171
    for (var _2B = 1, _2A = $1.k; _2B <= _2A; _2B += 1) { //#25180
        $1.i = _2B; //#25173
        $put($1.coeffs, $1.i, $get($1.coeffs, $1.i - 1)); //#25174
        for (var _2I = $1.i - 1; _2I >= 1; _2I -= 1) { //#25178
            $1.j = _2I; //#25176
            $k[$j++] = $1.coeffs; //#25177
            $k[$j++] = $1.j; //#25177
            $k[$j++] = $get($1.coeffs, $1.j - 1); //#25177
            $k[$j++] = $get($1.coeffs, $1.j); //#25177
            $k[$j++] = $get($1.rsalog, $1.i); //#25177
            $1.rsprod(); //#25177
            var _2U = $k[--$j]; //#25177
            var _2V = $k[--$j]; //#25177
            var _2W = $k[--$j]; //#25177
            $put($k[--$j], _2W, $f(_2V + _2U) % 283); //#25177
        } //#25177
        $k[$j++] = $1.coeffs; //#25179
        $k[$j++] = 0; //#25179
        $k[$j++] = $get($1.coeffs, 0); //#25179
        $k[$j++] = $get($1.rsalog, $1.i); //#25179
        $1.rsprod(); //#25179
        var _2e = $k[--$j]; //#25179
        var _2f = $k[--$j]; //#25179
        $put($k[--$j], _2f, _2e); //#25179
    } //#25179
    $1.coeffs = $geti($1.coeffs, 0, $1.coeffs.length - 1); //#25181
    for (var _2l = $1.coeffs.length - 1; _2l >= 0; _2l -= 2) { //#25182
        var _2m = $1.coeffs; //#25182
        $put(_2m, _2l, $f(283 - $get(_2m, _2l))); //#25182
    } //#25182
    for (var _2q = 0, _2p = $1.n - 1; _2q <= _2p; _2q += 1) { //#25191
        $1.t = $f($get($1.rsseq, _2q) + $get($1.rsseq, $1.n)) % 283; //#25186
        for (var _2y = 0, _2x = $1.k - 1; _2y <= _2x; _2y += 1) { //#25190
            $1.j = _2y; //#25188
            $put($1.rsseq, $1.n + $1.j, ($f($get($1.rsseq, ($1.n + $1.j) + 1) + ($f(283 - (($1.t * $get($1.coeffs, ($1.k - $1.j) - 1)) % 283))))) % 283); //#25189
        } //#25189
    } //#25189
    for (var _3F = $1.n, _3E = $1.n + $1.k; _3F <= _3E; _3F += 1) { //#25192
        $put($1.rsseq, _3F, $f(283 - $get($1.rsseq, _3F)) % 283); //#25192
    } //#25192
    $1.ecws = $geti($1.rsseq, $1.n, $1.k); //#25193
    var _3O = $get($1.options, 'debugecc') !== undefined; //#25195
    if (_3O) { //#25195
        $k[$j++] = 'bwipp.debugecc'; //#25195
        $k[$j++] = $1.ecws; //#25195
        bwipp_raiseerror(); //#25195
    } //#25195
    $1.tiles = $a([13135, 13136, 13153, 13156, 13163, 13165, 13513, 13515, 13516, 13531, 13535, 13536, 13561, 13563, 13565, 13613, 13615, 13616, 13631, 13635, 13636, 13651, 13653, 13656, 15135, 15136, 15153, 15163, 15165, 15313, 15315, 15316, 15351, 15353, 15356, 15361, 15363, 15365, 15613, 15615, 15616, 15631, 15635, 15636, 15651, 15653, 15656, 16135, 16136, 16153, 16156, 16165, 16313, 16315, 16316, 16351, 16353, 16356, 16361, 16363, 16365, 16513, 16515, 16516, 16531, 16535, 16536, 16561, 16563, 16565, 31315, 31316, 31351, 31356, 31361, 31365, 31513, 31515, 31516, 31531, 31535, 31536, 31561, 31563, 31565, 31613, 31615, 31631, 31635, 31636, 31651, 31653, 31656, 35131, 35135, 35136, 35151, 35153, 35156, 35161, 35163, 35165, 35315, 35316, 35351, 35356, 35361, 35365, 35613, 35615, 35616, 35631, 35635, 35636, 35651, 35653, 35656, 36131, 36135, 36136, 36151, 36153, 36156, 36163, 36165, 36315, 36316, 36351, 36356, 36361, 36365, 36513, 36515, 36516, 36531, 36535, 36536, 36561, 36563, 36565, 51313, 51315, 51316, 51351, 51353, 51356, 51361, 51363, 51365, 51513, 51516, 51531, 51536, 51561, 51563, 51613, 51615, 51616, 51631, 51635, 51636, 51651, 51653, 51656, 53131, 53135, 53136, 53151, 53153, 53156, 53161, 53163, 53165, 53513, 53516, 53531, 53536, 53561, 53563, 53613, 53615, 53616, 53631, 53635, 53636, 53651, 53653, 53656, 56131, 56135, 56136, 56151, 56153, 56156, 56161, 56163, 56165, 56313, 56315, 56316, 56351, 56353, 56356, 56361, 56363, 56365, 56513, 56516, 56531, 56536, 56561, 56563, 61313, 61315, 61316, 61351, 61353, 61356, 61361, 61363, 61365, 61513, 61515, 61516, 61531, 61535, 61536, 61561, 61563, 61565, 61615, 61631, 61635, 61651, 61653, 63131, 63135, 63136, 63151, 63153, 63156, 63161, 63163, 63165, 63513, 63515, 63516, 63531, 63535, 63536, 63561, 63563, 63565, 63613, 63615, 63631, 63635, 63651, 63653, 65131, 65135, 65136, 65151, 65153, 65156, 65161, 65163, 65165, 65313, 65315, 65316, 65351, 65353, 65356, 65361, 65363, 65365, 65613, 65615, 65631, 65635, 65651, 65653, 56565, 51515]); //#25228
    $1.dccurev1 = $a([51363, 51563, 51653, 53153, 53163, 53513, 53563, 53613, 53653, 56153, 56163, 56313, 56353, 56363, 56513, 56563, 51316, 51356, 51536, 51616, 53156, 53516, 53536, 53616, 53636, 53656, 56136, 56156, 56316, 56356, 56516, 56536]); //#25235
    $1.dcclrev1 = $a([61351, 61361, 61531, 61561, 61631, 61651, 63131, 63151, 63161, 63531, 63561, 63631, 65131, 65161, 65351, 65631, 31351, 31361, 31531, 31561, 31631, 31651, 35131, 35151, 35161, 35361, 35631, 35651, 36131, 36151, 36351, 36531]); //#25241
    $1.dccurev2 = $a([15316, 16316, 13516, 16516, 13616, 15616, 13136, 15136, 16136, 13536, 16536, 13636, 13156, 16156, 15356, 13656, 15313, 16313, 13513, 16513, 13613, 15613, 13153, 15153, 16153, 16353, 13653, 15653, 13163, 15163, 15363, 13563]); //#25247
    $1.dcclrev2 = $a([36315, 36515, 35615, 35135, 36135, 31535, 36535, 31635, 35635, 35165, 36165, 31365, 35365, 36365, 31565, 36565, 61315, 65315, 63515, 61615, 65135, 61535, 63535, 61635, 63635, 65635, 63165, 65165, 61365, 65365, 61565, 63565]); //#25253
    $k[$j++] = 'dccu'; //#25256
    if ($1.rev == 1) { //#25256
        $k[$j++] = $1.dccurev1; //#25256
    } else { //#25256
        $k[$j++] = $1.dccurev2; //#25256
    } //#25256
    var _3Y = $k[--$j]; //#25256
    $1[$k[--$j]] = _3Y; //#25256
    $k[$j++] = 'dccl'; //#25257
    if ($1.rev == 1) { //#25257
        $k[$j++] = $1.dcclrev1; //#25257
    } else { //#25257
        $k[$j++] = $1.dcclrev2; //#25257
    } //#25257
    var _3d = $k[--$j]; //#25257
    $1[$k[--$j]] = _3d; //#25257
    $1.rows = $f(($1.rows * 6) + 1); //#25260
    $1.columns = $1.columns + 6; //#25261
    $k[$j++] = Infinity; //#25262
    for (var _3j = 0, _3k = $1.rows * $1.columns; _3j < _3k; _3j++) { //#25262
        $k[$j++] = -1; //#25262
    } //#25262
    $1.pixs = $a(); //#25262
    $1.qmv = function() {
        var _3n = $k[--$j]; //#25263
        var _3o = $k[--$j]; //#25263
        $k[$j++] = $f(_3o + (_3n * $1.columns)); //#25263
    }; //#25263
    for (var _3r = 0, _3q = $1.columns - 1; _3r <= _3q; _3r += 1) { //#25272
        $1.i = _3r; //#25265
        for (var _3u = 0, _3t = $f($1.rows - 1); _3u <= _3t; _3u += 6) { //#25269
            $1.j = _3u; //#25267
            if ($1.i >= 5) { //#25268
                $k[$j++] = $1.pixs; //#25268
                $k[$j++] = $1.i; //#25268
                $k[$j++] = $1.j; //#25268
                $1.qmv(); //#25268
                var _40 = $k[--$j]; //#25268
                $put($k[--$j], _40, ($1.i % 2) * 9); //#25268
            } //#25268
        } //#25268
        $k[$j++] = $1.pixs; //#25270
        $k[$j++] = $1.i; //#25270
        $k[$j++] = 0; //#25270
        $1.qmv(); //#25270
        var _44 = $k[--$j]; //#25270
        $put($k[--$j], _44, 9); //#25270
        $k[$j++] = $1.pixs; //#25271
        $k[$j++] = $1.i; //#25271
        $k[$j++] = $f($1.rows - 1); //#25271
        $1.qmv(); //#25271
        var _49 = $k[--$j]; //#25271
        $put($k[--$j], _49, 9); //#25271
    } //#25271
    for (var _4D = 1, _4C = $f($1.rows - 2); _4D <= _4C; _4D += 1) { //#25285
        $1.i = _4D; //#25274
        for (var _4G = 3, _4F = $1.columns - 1; _4G <= _4F; _4G += 16) { //#25278
            $1.j = _4G; //#25276
            $k[$j++] = $1.pixs; //#25277
            $k[$j++] = $1.j; //#25277
            $k[$j++] = $1.i; //#25277
            $1.qmv(); //#25277
            var _4L = $k[--$j]; //#25277
            $put($k[--$j], _4L, (1 - ($1.i % 2)) * 9); //#25277
        } //#25277
        $k[$j++] = $1.pixs; //#25279
        $k[$j++] = 0; //#25279
        $k[$j++] = $1.i; //#25279
        $1.qmv(); //#25279
        var _4P = $k[--$j]; //#25279
        $put($k[--$j], _4P, 9); //#25279
        $k[$j++] = $1.pixs; //#25280
        $k[$j++] = 1; //#25280
        $k[$j++] = $1.i; //#25280
        $1.qmv(); //#25280
        var _4U = $k[--$j]; //#25280
        $put($k[--$j], _4U, (1 - ($1.i % 2)) * 9); //#25280
        $k[$j++] = $1.pixs; //#25281
        $k[$j++] = 2; //#25281
        $k[$j++] = $1.i; //#25281
        $1.qmv(); //#25281
        var _4Y = $k[--$j]; //#25281
        $put($k[--$j], _4Y, 0); //#25281
        $k[$j++] = $1.pixs; //#25282
        $k[$j++] = 3; //#25282
        $k[$j++] = $1.i; //#25282
        $1.qmv(); //#25282
        var _4c = $k[--$j]; //#25282
        $put($k[--$j], _4c, 9); //#25282
        $k[$j++] = $1.pixs; //#25283
        $k[$j++] = 4; //#25283
        $k[$j++] = $1.i; //#25283
        $1.qmv(); //#25283
        var _4g = $k[--$j]; //#25283
        $put($k[--$j], _4g, 0); //#25283
        $k[$j++] = $1.pixs; //#25284
        $k[$j++] = $1.columns - 1; //#25284
        $k[$j++] = $1.i; //#25284
        $1.qmv(); //#25284
        var _4l = $k[--$j]; //#25284
        $put($k[--$j], _4l, 9); //#25284
    } //#25284
    $1.i = (~~($1.rows / 2)) - 5; //#25288
    $k[$j++] = Infinity; //#25292
    var _4s = $cvrs($s(5), $get($1.dccu, $1.dcc), 10); //#25290
    for (var _4t = 0, _4u = _4s.length; _4t < _4u; _4t++) { //#25290
        $k[$j++] = $get(_4s, _4t) - 48; //#25290
    } //#25290
    var _50 = $cvrs($s(5), $get($1.dccl, $1.dcc), 10); //#25292
    $k[$j++] = 0; //#25292
    for (var _51 = 0, _52 = _50.length; _51 < _52; _51++) { //#25292
        $k[$j++] = $get(_50, _51) - 48; //#25292
    } //#25292
    var _54 = $a(); //#25292
    for (var _55 = 0, _56 = _54.length; _55 < _56; _55++) { //#25296
        $k[$j++] = $get(_54, _55); //#25294
        $k[$j++] = $1.pixs; //#25294
        $k[$j++] = 2; //#25294
        $k[$j++] = $1.i; //#25294
        $1.qmv(); //#25294
        var _5A = $k[--$j]; //#25294
        var _5B = $k[--$j]; //#25294
        $put(_5B, _5A, $k[--$j]); //#25294
        $1.i = $1.i + 1; //#25295
    } //#25295
    $k[$j++] = Infinity; //#25308
    $k[$j++] = $1.start; //#25302
    $k[$j++] = $1.mcc; //#25302
    $aload($1.ecws); //#25302
    $k[$j++] = $1.tcc; //#25306
    $k[$j++] = 283; //#25306
    $k[$j++] = $1.acc; //#25306
    $aload($1.dcws); //#25306
    for (var _5L = 0, _5M = $1.pads; _5L < _5M; _5L++) { //#25307
        $k[$j++] = 284; //#25307
    } //#25307
    $k[$j++] = $1.qcc; //#25308
    $1.tileseq = $a(); //#25308
    $1.x = 5; //#25311
    $1.y = 1; //#25311
    var _5P = $1.tileseq; //#25312
    for (var _5Q = 0, _5R = _5P.length; _5Q < _5R; _5Q++) { //#25325
        var _5W = $cvrs($s(5), $get($1.tiles, $get(_5P, _5Q)), 10); //#25313
        for (var _5X = 0, _5Y = _5W.length; _5X < _5Y; _5X++) { //#25316
            $k[$j++] = $get(_5W, _5X); //#25314
            $k[$j++] = $1.pixs; //#25314
            $k[$j++] = $1.x; //#25314
            $k[$j++] = $1.y; //#25314
            $1.qmv(); //#25314
            var _5d = $k[--$j]; //#25314
            var _5e = $k[--$j]; //#25314
            $put(_5e, _5d, $f($k[--$j] - 48)); //#25314
            $1.y = $1.y + 1; //#25315
        } //#25315
        if ($1.y != $f($1.rows - 1)) { //#25322
            $1.y = $1.y + 1; //#25318
        } else { //#25322
            $1.x = $1.x + 1; //#25320
            $1.y = 1; //#25320
            $k[$j++] = $1.pixs; //#25321
            $k[$j++] = $1.x; //#25321
            $k[$j++] = $1.y; //#25321
            $1.qmv(); //#25321
            var _5o = $k[--$j]; //#25321
            if ($get($k[--$j], _5o) != -1) { //#25323
                $1.x = $1.x + 1; //#25322
            } //#25322
        } //#25322
    } //#25322
    var _5s = new Map([
        [0, "FFFFFF"],
        [9, "000000"],
        [1, "00FFFF"],
        [3, "FF00FF"],
        [5, "FFFF00"],
        [6, "00FF00"]
    ]); //#25334
    $1.colormap = _5s; //#25335
    var _60 = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.columns],
        ["pixy", $1.rows],
        ["height", ($1.rows / 72) * 2],
        ["width", ($1.columns / 72) * 2],
        ["colormap", $1.colormap],
        ["opt", $1.options]
    ]); //#25347
    $k[$j++] = _60; //#25350
    if (!$1.dontdraw) { //#25350
        bwipp_renmatrix(); //#25350
    } //#25350
}

function bwipp_jabcode() {
    var $1 = {}; //#25383
    $1.ctx = null; //#25385
    $1.dontdraw = false; //#25386
    $1.rows = -1; //#25387
    $1.columns = -1; //#25388
    $1.slave = false; //#25389
    $1.colors = 16; //#25390
    $1.eclevel = 6; //#25391
    $1.raw = false; //#25392
    $1.parse = false; //#25393
    $1.parsefnc = false; //#25394
    $1.mask = -1; //#25395
    $k[$j++] = $1; //#25397
    bwipp_processoptions(); //#25397
    $1.options = $k[--$j]; //#25397
    $1.barcode = $k[--$j]; //#25398
    $1.databpm = ~~(Math.round(Math.log($1.colors) / Math.log(2))); //#25400
    var _3 = $1.colors; //#25401
    $k[$j++] = 'metabpm'; //#25401
    $k[$j++] = _3; //#25401
    if (_3 > 8) { //#25401
        $j--; //#25401
        $k[$j++] = 8; //#25401
    } //#25401
    var _4 = $k[--$j]; //#25401
    $1[$k[--$j]] = ~~(Math.round(Math.log(_4) / Math.log(2))); //#25401
    $1.fn1 = -1; //#25404
    var _9 = new Map([
        ["parse", $1.parse],
        ["parsefnc", $1.parsefnc],
        ["FNC1", $1.fn1]
    ]); //#25408
    $1.fncvals = _9; //#25409
    $k[$j++] = 'msg'; //#25410
    $k[$j++] = $1.barcode; //#25410
    $k[$j++] = $1.fncvals; //#25410
    bwipp_parseinput(); //#25410
    var _C = $k[--$j]; //#25410
    $1[$k[--$j]] = _C; //#25410
    $1.msglen = $1.msg.length; //#25411
    $1.addtobits = function() {
        var _F = $k[--$j]; //#25432
        $puti($1.bits, $1.j, _F); //#25432
        $1.j = _F.length + $1.j; //#25433
    }; //#25433
    $1.tofixedbits = function() {
        var _K = $strcpy($s(13), "0000000000000"); //#25437
        var _L = $k[--$j]; //#25437
        var _O = $cvrs($s(13), $k[--$j], 2); //#25437
        $puti(_K, $f(_L - _O.length), _O); //#25438
        $k[$j++] = $geti(_K, 0, _L); //#25439
    }; //#25439
    var _R = ($1.msglen <= 15) ? 4 : 17; //#25443
    $1.bits = $s(((7 + _R) + ($1.msglen * 8)) + 12); //#25443
    $1.j = 0; //#25444
    $k[$j++] = 31; //#25445
    $k[$j++] = 5; //#25445
    $1.tofixedbits(); //#25445
    $1.addtobits(); //#25445
    $k[$j++] = "00"; //#25446
    $1.addtobits(); //#25446
    if ($1.msglen <= 15) { //#25451
        $k[$j++] = $1.msglen; //#25448
        $k[$j++] = 4; //#25448
        $1.tofixedbits(); //#25448
        $1.addtobits(); //#25448
    } else { //#25451
        $k[$j++] = "0000"; //#25450
        $1.addtobits(); //#25450
        $k[$j++] = $1.msglen - 16; //#25451
        $k[$j++] = 13; //#25451
        $1.tofixedbits(); //#25451
        $1.addtobits(); //#25451
    } //#25451
    for (var _Z = 0, _Y = $1.msglen - 1; _Z <= _Y; _Z += 1) { //#25455
        $k[$j++] = $get($1.msg, _Z); //#25454
        $k[$j++] = 8; //#25454
        $1.tofixedbits(); //#25454
        $1.addtobits(); //#25454
    } //#25454
    $k[$j++] = 28; //#25456
    $k[$j++] = 5; //#25456
    $1.tofixedbits(); //#25456
    $1.addtobits(); //#25456
    $k[$j++] = 31; //#25457
    $k[$j++] = 5; //#25457
    $1.tofixedbits(); //#25457
    $1.addtobits(); //#25457
    $k[$j++] = "11"; //#25458
    $1.addtobits(); //#25458
    $1.diffside = 21; //#25461
    $1.sameshape = false; //#25462
    $1.sameecc = false; //#25463
    $1.hasslaves = false; //#25464
    $1.metrics = function() {
        $1.mc = $k[--$j]; //#25468
        $1.mr = $k[--$j]; //#25468
        var _e = $1.mc; //#25469
        var _f = $1.mr; //#25469
        var _g = $1.mc; //#25470
        var _h = $1.mr; //#25470
        var _i = $1.colors; //#25472
        var _j = 64; //#25472
        if (64 > _i) { //#25472
            var _ = _i; //#25472
            _i = _j; //#25472
            _j = _; //#25472
        } //#25472
        var _l = $1.slave ? 7 : 17; //#25473
        $k[$j++] = _e * _f; //#25501
        $k[$j++] = ((((~~($f(_g - 25) / 16)) + 2) * ((~~($f(_h - 25) / 16)) + 2)) - 4) * 7; //#25501
        $k[$j++] = _j * 2; //#25501
        $k[$j++] = _l * 4; //#25501
        if (!$1.slave) { //#25500
            var _p = $eq($1.mr, $1.mc) ? 0 : 1; //#25477
            $1.metass = _p; //#25477
            var _q = $1.mr; //#25478
            var _r = $1.mc; //#25478
            if ($lt(_q, _r)) { //#25478
                var _ = _r; //#25478
                _r = _q; //#25478
                _q = _; //#25478
            } //#25478
            $1.metavf = $get($a([0, 1, 2, 2, 3, 3, 3, 3]), ~~($f(_q - 21) / 16)); //#25479
            $k[$j++] = 'metavlen'; //#25480
            if ($1.metass == 0) { //#25480
                $k[$j++] = $a([2, 2, 3, 4]); //#25480
            } else { //#25480
                $k[$j++] = $a([4, 6, 8, 10]); //#25480
            } //#25480
            var _z = $get($k[--$j], $1.metavf); //#25480
            $1[$k[--$j]] = _z; //#25480
            $1.metaelen = $f(($1.metavf * 2) + 10); //#25481
            $k[$j++] = $f($f(7 + $1.metavlen) + $1.metaelen); //#25484
            if ($1.hasslaves) { //#25484
                var _15 = $k[--$j]; //#25484
                $k[$j++] = $f(_15 + 4); //#25484
            } //#25484
            var _18 = ~~(Math.ceil(($k[--$j] * 2) / $1.metabpm)); //#25487
            $1.nummetabits = $f((_18 * $1.metabpm) + 6); //#25487
            $k[$j++] = _18 + 6; //#25488
        } else { //#25500
            $k[$j++] = 3; //#25491
            if (!$1.sameshape) { //#25491
                var _1B = $k[--$j]; //#25491
                $k[$j++] = $f(_1B + 5); //#25491
            } //#25491
            if ($1.hasslaves) { //#25492
                var _1D = $k[--$j]; //#25492
                $k[$j++] = $f(_1D + 3); //#25492
            } //#25492
            if (!$1.sameecc) { //#25497
                var _1F = $1.mr; //#25494
                var _1G = $1.mc; //#25494
                if ($lt(_1F, _1G)) { //#25494
                    var _ = _1G; //#25494
                    _1G = _1F; //#25494
                    _1F = _; //#25494
                } //#25494
                var _1J = $k[--$j]; //#25496
                $k[$j++] = $f(_1J + $get($a([10, 12, 14, 14, 16, 16, 16, 16]), ~~($f(_1F - 21) / 16))); //#25496
            } //#25496
            var _1M = ~~(Math.ceil(($k[--$j] * 2) / $1.metabpm)); //#25500
            $1.nummetabits = _1M * $1.metabpm; //#25500
            $k[$j++] = _1M; //#25500
        } //#25500
        var _1O = $k[--$j]; //#25503
        $1.nummetamodules = _1O; //#25503
        var _1P = $k[--$j]; //#25504
        var _1Q = $k[--$j]; //#25504
        var _1R = $k[--$j]; //#25504
        $1.numdatamodules = $f($k[--$j] - ($f(_1R + ($f(_1Q + $f(_1P + _1O)))))); //#25504
        $1.numdatabits = $1.numdatamodules * $1.databpm; //#25505
    }; //#25505
    $1.coderate = $get($a([0.67, 0.63, 0.57, 0.55, 0.5, 0.43, 0.34, 0.25, 0.2, 0.17, 0.14]), $1.eclevel); //#25509
    $1.grosslen = ~~Math.ceil($1.bits.length / $1.coderate); //#25510
    $1.snapsize = function() {
        var _1b = (~~Math.ceil($k[--$j])) - 18; //#25511
        $k[$j++] = _1b; //#25511
        if (_1b < 0) { //#25511
            $j--; //#25511
            $k[$j++] = 0; //#25511
        } //#25511
        var _1c = $k[--$j]; //#25511
        $k[$j++] = ((~~(_1c / 4)) * 4) + 21; //#25511
    }; //#25511
    if (($1.rows == -1) && ($1.columns == -1)) { //#25540
        $k[$j++] = 'size'; //#25514
        $k[$j++] = Math.sqrt($1.grosslen); //#25514
        $1.snapsize(); //#25514
        var _1g = $k[--$j]; //#25514
        $1[$k[--$j]] = _1g; //#25514
        for (;;) { //#25519
            $k[$j++] = $1.size; //#25516
            $k[$j++] = $1.size; //#25516
            $1.metrics(); //#25516
            if ($1.grosslen <= $1.numdatabits) { //#25517
                break; //#25517
            } //#25517
            $1.size = $f($1.size + 4); //#25518
        } //#25518
        $1.rows = $1.size; //#25520
        $1.columns = $1.size; //#25521
    } else { //#25540
        if (($1.columns == -1) && ($1.rows != -1)) { //#25530
            $k[$j++] = 'columns'; //#25524
            $k[$j++] = $1.grosslen / $1.rows; //#25524
            $1.snapsize(); //#25524
            var _1t = $k[--$j]; //#25524
            $1[$k[--$j]] = _1t; //#25524
            for (;;) { //#25529
                $k[$j++] = $1.rows; //#25526
                $k[$j++] = $1.columns; //#25526
                $1.metrics(); //#25526
                if ($1.grosslen <= $1.numdatabits) { //#25527
                    break; //#25527
                } //#25527
                $1.columns = $f($1.columns + 4); //#25528
            } //#25528
        } //#25528
        if (($1.rows == -1) && ($1.columns != -1)) { //#25538
            $k[$j++] = 'rows'; //#25532
            $k[$j++] = $1.grosslen / $1.columns; //#25532
            $1.snapsize(); //#25532
            var _24 = $k[--$j]; //#25532
            $1[$k[--$j]] = _24; //#25532
            for (;;) { //#25537
                $k[$j++] = $1.rows; //#25534
                $k[$j++] = $1.columns; //#25534
                $1.metrics(); //#25534
                if ($1.grosslen <= $1.numdatabits) { //#25535
                    break; //#25535
                } //#25535
                $1.rows = $f($1.rows + 4); //#25536
            } //#25536
        } //#25536
        if (($1.rows != -1) && ($1.columns != -1)) { //#25541
            $k[$j++] = $1.rows; //#25540
            $k[$j++] = $1.columns; //#25540
            $1.metrics(); //#25540
        } //#25540
    } //#25540
    $1.C = $1.numdatabits; //#25543
    $1.cols = $1.columns; //#25544
    if (($1.rows > 145) || ($1.cols > 145)) { //#25549
        $k[$j++] = 'bwipp.jabcodeNoValidSymbol'; //#25548
        $k[$j++] = "Maximum length exceeded or invalid content"; //#25548
        bwipp_raiseerror(); //#25548
    } //#25548
    $1.min = $1.C; //#25552
    for (var _2K = 3; _2K <= 8; _2K += 1) { //#25564
        $1.i = _2K; //#25554
        for (var _2M = $1.i + 1; _2M <= 9; _2M += 1) { //#25563
            $1.j = _2M; //#25556
            $1.dist = (((~~($1.C / $1.j)) * $1.j) - ((~~($1.C / $1.j)) * $1.i)) - $1.bits.length; //#25557
            if (($1.dist < $1.min) && ($1.dist >= 0)) { //#25562
                $1.datawc = $1.i; //#25559
                $1.datawr = $1.j; //#25560
                $1.min = $1.dist; //#25561
            } //#25561
        } //#25561
    } //#25561
    $1.tmpbits = $s(((~~($1.C / $1.datawr)) * $1.datawr) - ((~~($1.C / $1.datawr)) * $1.datawc)); //#25567
    $puti($1.tmpbits, 0, $1.bits); //#25568
    for (var _2m = $1.bits.length, _2l = $1.tmpbits.length - 1; _2m <= _2l; _2m += 1) { //#25572
        var _2o = $get($1.tmpbits, _2m - 1); //#25570
        $k[$j++] = _2m; //#25570
        $k[$j++] = _2o; //#25570
        if ((_2o % 2) == 0) { //#25570
            var _2p = $k[--$j]; //#25570
            $k[$j++] = $f(_2p + 1); //#25570
        } else { //#25570
            var _2q = $k[--$j]; //#25570
            $k[$j++] = $f(_2q - 1); //#25570
        } //#25570
        var _2s = $k[--$j]; //#25571
        $put($1.tmpbits, $k[--$j], _2s); //#25571
    } //#25571
    $1.bits = $1.tmpbits; //#25573
    $1.m0 = 22609 + 1; //#25577
    $1.m1 = 62509 - 65536; //#25577
    $1.m2 = 19605; //#25577
    $1.m3 = 32557; //#25577
    $1.lcg64_temper = function() {
        $1.p00 = $1.m0 * $1.s0; //#25583
        $1.p01 = $1.m0 * $1.s1; //#25583
        $1.p02 = $1.m0 * $1.s2; //#25583
        $1.p03 = $1.m0 * $1.s3; //#25583
        $1.p10 = $1.m1 * $1.s0; //#25584
        $1.p11 = $1.m1 * $1.s1; //#25584
        $1.p12 = $1.m1 * $1.s2; //#25584
        $1.p13 = $1.m1 * $1.s3; //#25584
        $1.p20 = $1.m2 * $1.s0; //#25585
        $1.p21 = $1.m2 * $1.s1; //#25585
        $1.p22 = $1.m2 * $1.s2; //#25585
        $1.p23 = $1.m2 * $1.s3; //#25585
        $1.p30 = $1.m3 * $1.s0; //#25586
        $1.p31 = $1.m3 * $1.s1; //#25586
        $1.p32 = $1.m3 * $1.s2; //#25586
        $1.p33 = $1.m3 * $1.s3; //#25586
        $1.s3 = ($1.p33 % 65536) + 1; //#25588
        $1.s2 = (($1.p32 % 65536) + (~~($1.p33 / 65536))) + ($1.p23 % 65536); //#25590
        $1.s1 = ((($1.p31 % 65536) + (~~($1.p32 / 65536))) + (($1.p22 % 65536) + (~~($1.p23 / 65536)))) + ($1.p13 % 65536); //#25593
        $1.s0 = (((($1.p30 % 65536) + (~~($1.p31 / 65536))) + (($1.p21 % 65536) + (~~($1.p22 / 65536)))) + (($1.p12 % 65536) + (~~($1.p13 / 65536)))) + ($1.p03 % 65536); //#25597
        $1.s3 = $1.s3 + 65536; //#25600
        $1.s2 = $1.s2 + 65535; //#25601
        $1.s1 = $1.s1 + 65535; //#25602
        $1.s0 = $1.s0 + 65535; //#25603
        $1.s2 = (~~($1.s3 / 65536)) + $1.s2; //#25606
        $1.s3 = $1.s3 % 65536; //#25606
        $1.s1 = (~~($1.s2 / 65536)) + $1.s1; //#25607
        $1.s2 = $1.s2 % 65536; //#25607
        $1.s0 = (~~($1.s1 / 65536)) + $1.s0; //#25608
        $1.s1 = $1.s1 % 65536; //#25608
        $1.s0 = $1.s0 % 65536; //#25609
        var _3x = (((($1.s0 - 32768) * 65536) + $1.s1) ^ 2147483648) & 4294967295; //#25614
        var _3y = _3x ^ (_3x >>> 11); //#25615
        var _3z = _3y ^ ((_3y << 7) & -1658038656); //#25616
        var _40 = (_3z ^ ((_3z << 15) & -272236544)) & 4294967295; //#25618
        $k[$j++] = _40 ^ (_40 >>> 18); //#25618
    }; //#25618
    $1.createMatrixA = function() {
        $k[$j++] = 'nb_pcb'; //#25624
        if ($1.wr < 4) { //#25624
            $k[$j++] = ~~($1.Pg_sub_block / 2); //#25624
        } else { //#25624
            $k[$j++] = (~~($1.Pg_sub_block / $1.wr)) * $1.wc; //#25624
        } //#25624
        var _46 = $k[--$j]; //#25624
        $1[$k[--$j]] = _46; //#25624
        $1.offset = ~~Math.ceil($1.Pg_sub_block / 32); //#25625
        $1.effwidth = $1.offset * 32; //#25626
        $1.matrixA = $a($1.offset * $1.nb_pcb); //#25627
        for (var _4G = 0, _4F = ($1.offset * $1.nb_pcb) - 1; _4G <= _4F; _4G += 1) { //#25628
            $put($1.matrixA, _4G, 0); //#25628
        } //#25628
        $1.permutation = $a($1.Pg_sub_block); //#25629
        for (var _4M = 0, _4L = $1.Pg_sub_block - 1; _4M <= _4L; _4M += 1) { //#25630
            $put($1.permutation, _4M, _4M); //#25630
        } //#25630
        for (var _4R = 0, _4Q = (~~($1.Pg_sub_block / $1.wr)) - 1; _4R <= _4Q; _4R += 1) { //#25639
            $1.i = _4R; //#25633
            for (var _4U = 0, _4T = $f($1.wr - 1); _4U <= _4T; _4U += 1) { //#25638
                $1.j = _4U; //#25635
                var _4V = $1.matrixA; //#25636
                var _4W = $1.i; //#25636
                var _4X = $1.effwidth; //#25636
                var _4Y = $1.wr; //#25636
                var _4Z = $1.j; //#25636
                var _4f = $f(31 - (($f(($1.i * $f($1.effwidth + $1.wr)) + $1.j)) % 32)); //#25637
                $put(_4V, ~~(($f((_4W * $f(_4X + _4Y)) + _4Z)) / 32), $get(_4V, ~~(($f((_4W * $f(_4X + _4Y)) + _4Z)) / 32)) | ((_4f < 0 ? 1 >>> -_4f : 1 << _4f))); //#25637
            } //#25637
        } //#25637
        $1.s0 = 0; //#25642
        $1.s1 = 0; //#25642
        $1.s2 = 11; //#25642
        $1.s3 = 64569; //#25642
        for (var _4i = 1, _4h = $f($1.wc - 1); _4i <= _4h; _4i += 1) { //#25665
            $1.i = _4i; //#25644
            $1.off_index = (~~($1.Pg_sub_block / $1.wr)) * $1.i; //#25645
            for (var _4o = 0, _4n = $1.Pg_sub_block - 1; _4o <= _4n; _4o += 1) { //#25664
                $1.j = _4o; //#25647
                $1.lcg64_temper(); //#25648
                var _4p = $k[--$j]; //#25649
                $k[$j++] = _4p; //#25649
                if (_4p < 0) { //#25649
                    var _4q = $k[--$j]; //#25649
                    $k[$j++] = $f((_4q ^ 2147483648) + 2147483648); //#25649
                } //#25649
                $1.pos = ~~(($k[--$j] / 4294967296) * ($1.Pg_sub_block - $1.j)); //#25651
                for (var _4x = 0, _4w = (~~($1.Pg_sub_block / $1.wr)) - 1; _4x <= _4w; _4x += 1) { //#25660
                    $1.k = _4x; //#25653
                    var _4y = $1.matrixA; //#25654
                    var _4z = $1.off_index; //#25654
                    var _50 = $1.k; //#25654
                    var _51 = $1.offset; //#25654
                    var _52 = $1.j; //#25654
                    var _5A = $get($1.matrixA, (~~($get($1.permutation, $1.pos) / 32)) + ($1.k * $1.offset)); //#25656
                    var _5E = -($f(31 - ($get($1.permutation, $1.pos) % 32))); //#25657
                    var _5G = 31 - ($1.j % 32); //#25658
                    $put(_4y, ((_4z + _50) * _51) + (~~(_52 / 32)), $get(_4y, ((_4z + _50) * _51) + (~~(_52 / 32))) | ((_5G < 0 ? (((_5E < 0 ? _5A >>> -_5E : _5A << _5E)) & 1) >>> -_5G : (((_5E < 0 ? _5A >>> -_5E : _5A << _5E)) & 1) << _5G))); //#25659
                } //#25659
                var _5J = $1.permutation; //#25661
                var _5K = $1.Pg_sub_block; //#25661
                var _5L = $1.j; //#25661
                $put(_5J, (_5K - 1) - _5L, $get($1.permutation, $1.pos)); //#25663
                $put($1.permutation, $1.pos, $get(_5J, (_5K - 1) - _5L)); //#25663
            } //#25663
        } //#25663
    }; //#25663
    $1.createMetadataMatrixA = function() {
        $1.nb_pcb = ~~($1.Pg_sub_block / 2); //#25671
        $1.offset = ~~Math.ceil($1.Pg_sub_block / 32); //#25672
        $1.matrixA = $a($1.offset * $1.nb_pcb); //#25673
        for (var _5Y = 0, _5X = ($1.offset * $1.nb_pcb) - 1; _5Y <= _5X; _5Y += 1) { //#25674
            $put($1.matrixA, _5Y, 0); //#25674
        } //#25674
        $1.permutation = $a($1.Pg_sub_block); //#25675
        for (var _5e = 0, _5d = $1.Pg_sub_block - 1; _5e <= _5d; _5e += 1) { //#25676
            $put($1.permutation, _5e, _5e); //#25676
        } //#25676
        $1.s0 = 0; //#25679
        $1.s1 = 0; //#25679
        $1.s2 = 0; //#25679
        $1.s3 = 38545; //#25679
        $1.nb_once = ~~((~~($f((($1.nb_pcb / $1.wc) * $1.Pg_sub_block) + 3))) / $1.nb_pcb); //#25680
        for (var _5m = 0, _5l = $1.nb_pcb - 1; _5m <= _5l; _5m += 1) { //#25695
            $1.i = _5m; //#25682
            for (var _5p = 0, _5o = $1.nb_once - 1; _5p <= _5o; _5p += 1) { //#25694
                $1.j = _5p; //#25684
                $1.lcg64_temper(); //#25685
                var _5q = $k[--$j]; //#25686
                $k[$j++] = _5q; //#25686
                if (_5q < 0) { //#25686
                    var _5r = $k[--$j]; //#25686
                    $k[$j++] = $f((_5r ^ 2147483648) + 2147483648); //#25686
                } //#25686
                $1.pos = ~~(($k[--$j] / 4294967296) * ($1.Pg_sub_block - $1.j)); //#25688
                var _5v = $1.matrixA; //#25689
                var _5w = $1.i; //#25689
                var _5x = $1.offset; //#25689
                var _60 = $get($1.permutation, $1.pos); //#25689
                var _65 = $f(31 - ($get($1.permutation, $1.pos) % 32)); //#25690
                $put(_5v, (_5w * _5x) + (~~(_60 / 32)), $get(_5v, (_5w * _5x) + (~~(_60 / 32))) | ((_65 < 0 ? 1 >>> -_65 : 1 << _65))); //#25690
                var _68 = $1.permutation; //#25691
                var _69 = $1.Pg_sub_block; //#25691
                var _6A = $1.j; //#25691
                $put(_68, (_69 - 1) - _6A, $get($1.permutation, $1.pos)); //#25693
                $put($1.permutation, $1.pos, $get(_68, (_69 - 1) - _6A)); //#25693
            } //#25693
        } //#25693
    }; //#25693
    $1.GaussJordan = function() {
        $k[$j++] = 'nb_pcb'; //#25701
        if ($1.wr < 4) { //#25701
            $k[$j++] = ~~($1.Pg_sub_block / 2); //#25701
        } else { //#25701
            $k[$j++] = (~~($1.Pg_sub_block / $1.wr)) * $1.wc; //#25701
        } //#25701
        var _6K = $k[--$j]; //#25701
        $1[$k[--$j]] = _6K; //#25701
        $1.offset = ~~Math.ceil($1.Pg_sub_block / 32); //#25702
        var _6N = $1.matrixA; //#25703
        $1.matrixH = $arrcpy($a(_6N.length), _6N); //#25703
        $k[$j++] = Infinity; //#25704
        for (var _6R = 0, _6S = $1.Pg_sub_block; _6R < _6S; _6R++) { //#25704
            $k[$j++] = 0; //#25704
        } //#25704
        $1.column_arrangement = $a(); //#25704
        $k[$j++] = Infinity; //#25705
        for (var _6V = 0, _6W = $1.Pg_sub_block; _6V < _6W; _6V++) { //#25705
            $k[$j++] = false; //#25705
        } //#25705
        $1.processed_column = $a(); //#25705
        $k[$j++] = Infinity; //#25706
        for (var _6Z = 0, _6a = $1.nb_pcb; _6Z < _6a; _6Z++) { //#25706
            $k[$j++] = 0; //#25706
        } //#25706
        $1.zero_lines_nb = $a(); //#25706
        $k[$j++] = Infinity; //#25707
        for (var _6d = 0, _6e = $1.Pg_sub_block * 2; _6d < _6e; _6d++) { //#25707
            $k[$j++] = 0; //#25707
        } //#25707
        $1.swap_col = $a(); //#25707
        $1.zero_lines = 0; //#25708
        $1.loop0 = 0; //#25710
        for (var _6i = 0, _6h = $1.nb_pcb - 1; _6i <= _6h; _6i += 1) { //#25748
            $1.i = _6i; //#25712
            $1.pivot_column = $1.Pg_sub_block + 1; //#25713
            for (var _6m = 0, _6l = $1.Pg_sub_block - 1; _6m <= _6l; _6m += 1) { //#25721
                $1.j = _6m; //#25715
                var _6r = $get($1.matrixH, ~~(((($1.offset * 32) * $1.i) + $1.j) / 32)); //#25716
                var _6v = -(31 - (((($1.offset * 32) * $1.i) + $1.j) % 32)); //#25717
                if ((((_6v < 0 ? _6r >>> -_6v : _6r << _6v)) & 1) == 1) { //#25720
                    $1.pivot_column = $1.j; //#25718
                    break; //#25719
                } //#25719
            } //#25719
            if ($1.pivot_column < $1.Pg_sub_block) { //#25746
                $put($1.processed_column, $1.pivot_column, true); //#25723
                $put($1.column_arrangement, $1.pivot_column, $1.i); //#25724
                if ($1.pivot_column >= $1.nb_pcb) { //#25728
                    $put($1.swap_col, $1.loop0 * 2, $1.pivot_column); //#25726
                    $1.loop0 = $1.loop0 + 1; //#25727
                } //#25727
                $1.off_index = ~~($1.pivot_column / 32); //#25729
                $1.off_index1 = $1.pivot_column % 32; //#25730
                for (var _7E = 0, _7D = $1.nb_pcb - 1; _7E <= _7D; _7E += 1) { //#25743
                    $1.j = _7E; //#25732
                    if ($1.i != $1.j) { //#25742
                        var _7L = $get($1.matrixH, $1.off_index + ($1.j * $1.offset)); //#25734
                        var _7N = -(31 - $1.off_index1); //#25735
                        if ((((_7N < 0 ? _7L >>> -_7N : _7L << _7N)) & 1) == 1) { //#25741
                            for (var _7Q = 0, _7P = $1.offset - 1; _7Q <= _7P; _7Q += 1) { //#25740
                                $1.k = _7Q; //#25737
                                var _7R = $1.matrixH; //#25738
                                var _7S = $1.offset; //#25738
                                var _7T = $1.j; //#25738
                                var _7U = $1.k; //#25738
                                $put(_7R, (_7S * _7T) + _7U, $xo($get(_7R, (_7S * _7T) + _7U), $get($1.matrixH, ($1.offset * $1.i) + $1.k))); //#25739
                            } //#25739
                        } //#25739
                    } //#25739
                } //#25739
            } else { //#25746
                $put($1.zero_lines_nb, $1.zero_lines, $1.i); //#25745
                $1.zero_lines = $1.zero_lines + 1; //#25746
            } //#25746
        } //#25746
        $1.matrix_rank = $1.nb_pcb - $1.zero_lines; //#25750
        $1.loop2 = 0; //#25751
        for (var _7k = $1.matrix_rank, _7j = $1.nb_pcb - 1; _7k <= _7j; _7k += 1) { //#25771
            $1.i = _7k; //#25753
            if ($get($1.column_arrangement, $1.i) > 0) { //#25770
                for (var _7q = 0, _7p = $1.nb_pcb - 1; _7q <= _7p; _7q += 1) { //#25769
                    $1.j = _7q; //#25756
                    if ($nt($get($1.processed_column, $1.j))) { //#25768
                        $put($1.column_arrangement, $1.j, $get($1.column_arrangement, $1.i)); //#25758
                        $put($1.column_arrangement, $1.i, 0); //#25759
                        $put($1.processed_column, $1.j, true); //#25760
                        $put($1.processed_column, $1.i, false); //#25761
                        $put($1.swap_col, $1.loop0 * 2, $1.i); //#25762
                        $put($1.swap_col, ($1.loop0 * 2) + 1, $1.j); //#25763
                        $put($1.column_arrangement, $1.i, $1.j); //#25764
                        $1.loop0 = $1.loop0 + 1; //#25765
                        $1.loop2 = $1.loop2 + 1; //#25766
                        break; //#25767
                    } //#25767
                } //#25767
            } //#25767
        } //#25767
        $1.loop1 = 0; //#25773
        for (var _8I = 0, _8H = $1.nb_pcb - 1; _8I <= _8H; _8I += 1) { //#25782
            $1.kl = _8I; //#25775
            if ($nt($get($1.processed_column, $1.kl)) && ($1.loop1 < ($1.loop0 - $1.loop2))) { //#25781
                $put($1.column_arrangement, $1.kl, $get($1.column_arrangement, $get($1.swap_col, $1.loop1 * 2))); //#25777
                $put($1.processed_column, $1.kl, true); //#25778
                $put($1.swap_col, ($1.loop1 * 2) + 1, $1.kl); //#25779
                $1.loop1 = $1.loop1 + 1; //#25780
            } //#25780
        } //#25780
        $1.loop1 = 0; //#25784
        for (var _8e = 0, _8d = $1.nb_pcb - 1; _8e <= _8d; _8e += 1) { //#25791
            $1.kl = _8e; //#25786
            if ($nt($get($1.processed_column, $1.kl))) { //#25790
                $put($1.column_arrangement, $1.kl, $get($1.zero_lines_nb, $1.loop1)); //#25788
                $1.loop1 = $1.loop1 + 1; //#25789
            } //#25789
        } //#25789
        for (var _8q = 0, _8p = $1.nb_pcb - 1; _8q <= _8p; _8q += 1) { //#25800
            $1.i = _8q; //#25794
            for (var _8t = 0, _8s = $1.offset - 1; _8t <= _8s; _8t += 1) { //#25799
                $1.j = _8t; //#25796
                $put($1.matrixA, ($1.i * $1.offset) + $1.j, $get($1.matrixH, $f(($get($1.column_arrangement, $1.i) * $1.offset) + $1.j))); //#25798
            } //#25798
        } //#25798
        $1.tmp = 0; //#25802
        for (var _97 = 0, _96 = $1.loop0 - 1; _97 <= _96; _97 += 1) { //#25824
            $1.i = _97; //#25804
            for (var _9A = 0, _99 = $1.nb_pcb - 1; _9A <= _99; _9A += 1) { //#25823
                $1.j = _9A; //#25806
                var _9H = $get($1.matrixA, (~~($get($1.swap_col, $1.i * 2) / 32)) + ($1.j * $1.offset)); //#25807
                var _9L = -($f(31 - ($get($1.swap_col, $1.i * 2) % 32))); //#25808
                $1.tmp = (((-(((_9L < 0 ? _9H >>> -_9L : _9H << _9L)) & 1)) ^ $1.tmp) & 1) ^ $1.tmp; //#25809
                var _9O = $1.matrixA; //#25810
                var _9R = $get($1.swap_col, $1.i * 2); //#25810
                var _9S = $1.j; //#25810
                var _9T = $1.offset; //#25810
                var _9b = $get($1.matrixA, (~~($get($1.swap_col, ($1.i * 2) + 1) / 32)) + ($1.j * $1.offset)); //#25812
                var _9f = -($f(31 - ($get($1.swap_col, ($1.i * 2) + 1) % 32))); //#25813
                var _9q = $f(31 - ($get($1.swap_col, $1.i * 2) % 32)); //#25815
                $put(_9O, (~~(_9R / 32)) + (_9S * _9T), $get(_9O, (~~(_9R / 32)) + (_9S * _9T)) ^ (((-(((_9f < 0 ? _9b >>> -_9f : _9b << _9f)) & 1)) ^ $get($1.matrixA, (~~($get($1.swap_col, $1.i * 2) / 32)) + ($1.j * $1.offset))) & ((_9q < 0 ? 1 >>> -_9q : 1 << _9q)))); //#25816
                var _9r = $1.matrixA; //#25817
                var _9u = $get($1.swap_col, ($1.i * 2) + 1); //#25817
                var _9v = $1.j; //#25817
                var _9w = $1.offset; //#25817
                var _A9 = $f(31 - ($get($1.swap_col, ($1.i * 2) + 1) % 32)); //#25821
                $put(_9r, (~~(_9u / 32)) + (_9v * _9w), $get(_9r, (~~(_9u / 32)) + (_9v * _9w)) ^ (((-($1.tmp & 1)) ^ $get($1.matrixA, (~~($get($1.swap_col, ($1.i * 2) + 1) / 32)) + ($1.j * $1.offset))) & ((_A9 < 0 ? 1 >>> -_A9 : 1 << _A9)))); //#25822
            } //#25822
        } //#25822
    }; //#25822
    $1.createGeneratorMatrix = function() {
        $1.pn = $1.Pg_sub_block - $1.matrix_rank; //#25830
        $1.offset = ~~Math.ceil($1.pn / 32); //#25831
        $1.effwidth = $1.offset * 32; //#25832
        $1.offset_cap = ~~Math.ceil($1.Pg_sub_block / 32); //#25833
        $1.G = $a($1.offset * $1.Pg_sub_block); //#25834
        for (var _AL = 0, _AK = ($1.offset * $1.Pg_sub_block) - 1; _AL <= _AK; _AL += 1) { //#25837
            $put($1.G, _AL, 0); //#25836
        } //#25836
        for (var _AP = 0, _AO = $1.pn - 1; _AP <= _AO; _AP += 1) { //#25842
            $1.i = _AP; //#25839
            var _AQ = $1.G; //#25840
            var _AR = $1.Pg_sub_block; //#25840
            var _AS = $1.pn; //#25840
            var _AT = $1.i; //#25840
            var _AU = $1.offset; //#25840
            var _AV = $1.i; //#25840
            var _AY = 31 - ($1.i % 32); //#25841
            $put(_AQ, (((_AR - _AS) + _AT) * _AU) + (~~(_AV / 32)), $get(_AQ, (((_AR - _AS) + _AT) * _AU) + (~~(_AV / 32))) | ((_AY < 0 ? 1 >>> -_AY : 1 << _AY))); //#25841
        } //#25841
        $1.matrix_index = $1.Pg_sub_block - $1.pn; //#25843
        $1.loop0 = 0; //#25844
        for (var _Af = 0, _Ae = (($1.Pg_sub_block - $1.pn) * $1.effwidth) - 1; _Af <= _Ae; _Af += 1) { //#25861
            $1.i = _Af; //#25846
            if ($1.matrix_index >= $1.Pg_sub_block) { //#25850
                $1.loop0 = $1.loop0 + 1; //#25848
                $1.matrix_index = $1.Pg_sub_block - $1.pn; //#25849
            } //#25849
            if (($1.i % $1.effwidth) < $1.pn) { //#25860
                var _Ao = $1.G; //#25852
                var _Ap = $1.i; //#25852
                var _Av = $get($1.matrixA, (~~($1.matrix_index / 32)) + ($1.offset_cap * $1.loop0)); //#25854
                var _Ax = -(31 - ($1.matrix_index % 32)); //#25855
                var _B2 = 31 - ($1.i % 32); //#25857
                $put(_Ao, ~~(_Ap / 32), $get(_Ao, ~~(_Ap / 32)) ^ (((-(((_Ax < 0 ? _Av >>> -_Ax : _Av << _Ax)) & 1)) ^ $get($1.G, ~~($1.i / 32))) & ((_B2 < 0 ? 1 >>> -_B2 : 1 << _B2)))); //#25858
                $1.matrix_index = $1.matrix_index + 1; //#25859
            } //#25859
        } //#25859
    }; //#25859
    $1.ldpc = function() {
        $1.wr = $k[--$j]; //#25867
        $1.wc = $k[--$j]; //#25868
        $k[$j++] = Infinity; //#25869
        var _B6 = $k[--$j]; //#25869
        var _B7 = $k[--$j]; //#25869
        $k[$j++] = _B6; //#25869
        $forall(_B7, function() { //#25869
            var _B8 = $k[--$j]; //#25869
            $k[$j++] = $f(_B8 - 48); //#25869
        }); //#25869
        $1.data = $a(); //#25869
        $1.Pn = $1.data.length; //#25871
        if ($1.wr != -1) { //#25886
            $1.Pg = ~~((Math.ceil((Math.ceil(($1.Pn * $1.wr) / $f($1.wr - $1.wc))) / $1.wr)) * $1.wr); //#25873
            $1.nb_sub_blocks = (~~($1.Pg / 2700)) + 1; //#25874
            $1.Pg_sub_block = (~~((~~($1.Pg / $1.nb_sub_blocks)) / $1.wr)) * $1.wr; //#25875
            $1.Pn_sub_block = ~~(($1.Pg_sub_block * $f($1.wr - $1.wc)) / $1.wr); //#25876
            $1.nb_sub_blocks = ~~($1.Pg / $1.Pg_sub_block); //#25877
            $k[$j++] = 'encoding_iterations'; //#25878
            $k[$j++] = ~~($1.Pg / $1.Pg_sub_block); //#25878
            if (($1.Pn_sub_block * $1.nb_sub_blocks) < $1.Pn) { //#25878
                var _BY = $k[--$j]; //#25878
                $k[$j++] = $f(_BY - 1); //#25878
            } //#25878
            var _BZ = $k[--$j]; //#25878
            $1[$k[--$j]] = _BZ; //#25878
            $1.createMatrixA(); //#25879
        } else { //#25886
            $1.Pg = $1.Pn * 2; //#25881
            $1.nb_sub_blocks = 1; //#25882
            $1.Pg_sub_block = $1.Pg; //#25883
            $1.Pn_sub_block = $1.Pn; //#25884
            $1.encoding_iterations = 1; //#25885
            $1.createMetadataMatrixA(); //#25886
        } //#25886
        $1.GaussJordan(); //#25888
        $1.createGeneratorMatrix(); //#25889
        $1.ecc_encoded_data = $a($1.Pg); //#25891
        $1.offset = ~~(Math.ceil(($1.Pg_sub_block - $1.matrix_rank) / 32)); //#25893
        for (var _Bk = 0, _Bj = $1.encoding_iterations - 1; _Bk <= _Bj; _Bk += 1) { //#25909
            $1.iter = _Bk; //#25895
            for (var _Bn = 0, _Bm = $1.Pg_sub_block - 1; _Bn <= _Bm; _Bn += 1) { //#25908
                $1.i = _Bn; //#25897
                $1.temp = 0; //#25898
                $1.loop0 = 0; //#25899
                $1.offset_index = $1.offset * $1.i; //#25900
                for (var _Bv = $1.iter * $1.Pn_sub_block, _Bu = (($1.iter + 1) * $1.Pn_sub_block) - 1; _Bv <= _Bu; _Bv += 1) { //#25906
                    var _C1 = $get($1.G, $1.offset_index + (~~($1.loop0 / 32))); //#25903
                    var _C3 = -(31 - ($1.loop0 % 32)); //#25903
                    $1.temp = ($get($1.data, _Bv) & (((_C3 < 0 ? _C1 >>> -_C3 : _C1 << _C3)) & 1)) ^ $1.temp; //#25904
                    $1.loop0 = $1.loop0 + 1; //#25905
                } //#25905
                $put($1.ecc_encoded_data, $1.i + ($1.iter * $1.Pg_sub_block), $1.temp); //#25907
            } //#25907
        } //#25907
        if ($1.encoding_iterations != $1.nb_sub_blocks) { //#25933
            $1.start = $1.encoding_iterations * $1.Pn_sub_block; //#25912
            $1.last_index = $1.encoding_iterations * $1.Pg_sub_block; //#25913
            $1.Pg_sub_block = $1.Pg - ($1.encoding_iterations * $1.Pg_sub_block); //#25914
            $1.Pn_sub_block = ~~(($1.Pg_sub_block * $f($1.wr - $1.wc)) / $1.wr); //#25915
            $1.createMatrixA(); //#25916
            $1.GaussJordan(); //#25917
            $1.createGeneratorMatrix(); //#25918
            $1.offset = ~~(Math.ceil(($1.Pg_sub_block - $1.matrix_rank) / 32)); //#25919
            for (var _CS = 0, _CR = $1.Pg_sub_block - 1; _CS <= _CR; _CS += 1) { //#25932
                $1.i = _CS; //#25921
                $1.temp = 0; //#25922
                $1.loop0 = 0; //#25923
                $1.offset_index = $1.offset * $1.i; //#25924
                for (var _CY = $1.start, _CX = $1.Pn - 1; _CY <= _CX; _CY += 1) { //#25930
                    var _Ce = $get($1.G, $1.offset_index + (~~($1.loop0 / 32))); //#25927
                    var _Cg = -(31 - ($1.loop0 % 32)); //#25927
                    $1.temp = ($get($1.data, _CY) & (((_Cg < 0 ? _Ce >>> -_Cg : _Ce << _Cg)) & 1)) ^ $1.temp; //#25928
                    $1.loop0 = $1.loop0 + 1; //#25929
                } //#25929
                $put($1.ecc_encoded_data, $1.i + $1.last_index, $1.temp); //#25931
            } //#25931
        } //#25931
        $1.out = $s($1.Pg); //#25935
        for (var _Cr = 0, _Cq = $1.Pg - 1; _Cr <= _Cq; _Cr += 1) { //#25939
            $put($1.out, _Cr, $f($get($1.ecc_encoded_data, _Cr) + 48)); //#25938
        } //#25938
        $k[$j++] = $1.out; //#25940
    }; //#25940
    $k[$j++] = 'bits'; //#25945
    $k[$j++] = $1.bits; //#25945
    $k[$j++] = $1.datawc; //#25945
    $k[$j++] = $1.datawr; //#25945
    $1.ldpc(); //#25945
    var _Cz = $k[--$j]; //#25945
    $1[$k[--$j]] = _Cz; //#25945
    $1.s0 = 0; //#25948
    $1.s1 = 0; //#25948
    $1.s2 = 3; //#25948
    $1.s3 = 30151; //#25948
    for (var _D2 = $1.bits.length - 1; _D2 >= 1; _D2 -= 1) { //#25958
        $1.l = _D2; //#25950
        $1.lcg64_temper(); //#25951
        var _D3 = $k[--$j]; //#25952
        $k[$j++] = _D3; //#25952
        if (_D3 < 0) { //#25952
            var _D4 = $k[--$j]; //#25952
            $k[$j++] = $f((_D4 ^ 2147483648) + 2147483648); //#25952
        } //#25952
        $1.r = ~~(($k[--$j] / 4294967296) * ($1.l + 1)); //#25954
        $put($1.bits, $1.l, $get($1.bits, $1.r)); //#25956
        $put($1.bits, $1.r, $get($1.bits, $1.l)); //#25957
    } //#25957
    $1.tmpbits = $s($1.C); //#25961
    $puti($1.tmpbits, 0, $1.bits); //#25962
    $1.j = $1.bits.length; //#25963
    for (var _DO = 0, _DP = ~~(($f($f($1.C - $1.j) + 1)) / 2); _DO < _DP; _DO++) { //#25968
        $put($1.tmpbits, $1.j, 48); //#25965
        if (($1.j + 1) < $1.C) { //#25966
            $put($1.tmpbits, $1.j + 1, 49); //#25966
        } //#25966
        $1.j = $1.j + 2; //#25967
    } //#25967
    $1.bits = $1.tmpbits; //#25969
    if ($1.colors == 4) { //#26034
        $1.bi = 0; //#25973
        $1.gi = 1; //#25973
        $1.mi = 2; //#25973
        $1.yi = 3; //#25973
        $1.ki = 4; //#25974
        $1.wi = 5; //#25974
        $k[$j++] = Infinity; //#25977
        $k[$j++] = $1.bi; //#25977
        $k[$j++] = "0000FF"; //#25977
        $k[$j++] = $1.gi; //#25977
        $k[$j++] = "00FF00"; //#25977
        $k[$j++] = $1.mi; //#25977
        $k[$j++] = "FF00FF"; //#25977
        $k[$j++] = $1.yi; //#25977
        $k[$j++] = "FFFF00"; //#25977
        $k[$j++] = $1.ki; //#25977
        $k[$j++] = "000000"; //#25977
        $k[$j++] = $1.wi; //#25977
        $k[$j++] = "FFFFFF"; //#25977
        $1.palette = $d(); //#25978
        $1.metacolorindex = $a([$1.bi, $1.gi, $1.mi, $1.yi]); //#25979
        $1.palettelayout = $a([$1.bi, $1.gi, $1.mi, $1.yi]); //#25980
    } else { //#26034
        var _Dw = new Map([
            [8, $a([2, 2, 2])],
            [16, $a([4, 2, 2])],
            [32, $a([4, 4, 2])],
            [64, $a([4, 4, 4])],
            [128, $a([8, 4, 4])],
            [256, $a([8, 8, 4])]
        ]); //#25989
        $1.rgbres = $get(_Dw, $1.colors); //#25990
        $k[$j++] = 'rvals'; //#25992
        $k[$j++] = $get($1.rgbres, 0); //#25992
        $k[$j++] = Infinity; //#25992
        var _E1 = $k[--$j]; //#25992
        var _E3 = $f($k[--$j] - 1); //#25992
        $k[$j++] = _E1; //#25992
        $k[$j++] = _E3; //#25992
        for (var _E5 = 0, _E4 = _E3; _E5 <= _E4; _E5 += 1) { //#25992
            var _E6 = $k[--$j]; //#25992
            $k[$j++] = ~~(Math.round(_E5 * (255 / _E6))); //#25992
            $k[$j++] = _E6; //#25992
        } //#25992
        $j--; //#25992
        var _E7 = $a(); //#25992
        $1[$k[--$j]] = _E7; //#25992
        $k[$j++] = 'gvals'; //#25993
        $k[$j++] = $get($1.rgbres, 1); //#25993
        $k[$j++] = Infinity; //#25993
        var _EB = $k[--$j]; //#25993
        var _ED = $f($k[--$j] - 1); //#25993
        $k[$j++] = _EB; //#25993
        $k[$j++] = _ED; //#25993
        for (var _EF = 0, _EE = _ED; _EF <= _EE; _EF += 1) { //#25993
            var _EG = $k[--$j]; //#25993
            $k[$j++] = ~~(Math.round(_EF * (255 / _EG))); //#25993
            $k[$j++] = _EG; //#25993
        } //#25993
        $j--; //#25993
        var _EH = $a(); //#25993
        $1[$k[--$j]] = _EH; //#25993
        $k[$j++] = 'bvals'; //#25994
        $k[$j++] = $get($1.rgbres, 2); //#25994
        $k[$j++] = Infinity; //#25994
        var _EL = $k[--$j]; //#25994
        var _EN = $f($k[--$j] - 1); //#25994
        $k[$j++] = _EL; //#25994
        $k[$j++] = _EN; //#25994
        for (var _EP = 0, _EO = _EN; _EP <= _EO; _EP += 1) { //#25994
            var _EQ = $k[--$j]; //#25994
            $k[$j++] = ~~(Math.round(_EP * (255 / _EQ))); //#25994
            $k[$j++] = _EQ; //#25994
        } //#25994
        $j--; //#25994
        var _ER = $a(); //#25994
        $1[$k[--$j]] = _ER; //#25994
        var _ET = $1.colors; //#25996
        $1.palette = new Map; //#25996
        var _EU = $1.colors; //#25997
        var _EV = 64; //#25997
        if (64 > _EU) { //#25997
            var _ = _EU; //#25997
            _EU = _EV; //#25997
            _EV = _; //#25997
        } //#25997
        $1.palettelayout = $a(_EV); //#25997
        $1.i = 0; //#25998
        $1.j = 8; //#25998
        $forall($1.rvals, function() { //#26032
            $1.r = $k[--$j]; //#26000
            $forall($1.gvals, function() { //#26031
                $1.g = $k[--$j]; //#26002
                $forall($1.bvals, function() { //#26030
                    $1.b = $k[--$j]; //#26004
                    var _Eh = $strcpy($s(6), "000000"); //#26006
                    var _Ej = $cvrs($s(6), (($1.r << 16) | ($1.g << 8)) | $1.b, 16); //#26006
                    $puti(_Eh, 6 - _Ej.length, _Ej); //#26006
                    $k[$j++] = _Eh; //#26008
                    $k[$j++] = false; //#26008
                    if ($eq(_Eh, "000000")) { //#26008
                        $1.ki = $1.i; //#26008
                        $j--; //#26008
                        $k[$j++] = true; //#26008
                    } //#26008
                    var _El = $k[--$j]; //#26009
                    var _Em = $k[--$j]; //#26009
                    $k[$j++] = _Em; //#26009
                    $k[$j++] = _El; //#26009
                    if ($eq(_Em, "0000FF")) { //#26009
                        $1.bi = $1.i; //#26009
                        $j--; //#26009
                        $k[$j++] = true; //#26009
                    } //#26009
                    var _Eo = $k[--$j]; //#26010
                    var _Ep = $k[--$j]; //#26010
                    $k[$j++] = _Ep; //#26010
                    $k[$j++] = _Eo; //#26010
                    if ($eq(_Ep, "00FF00")) { //#26010
                        $1.gi = $1.i; //#26010
                        $j--; //#26010
                        $k[$j++] = true; //#26010
                    } //#26010
                    var _Er = $k[--$j]; //#26011
                    var _Es = $k[--$j]; //#26011
                    $k[$j++] = _Es; //#26011
                    $k[$j++] = _Er; //#26011
                    if ($eq(_Es, "00FFFF")) { //#26011
                        $1.ci = $1.i; //#26011
                        $j--; //#26011
                        $k[$j++] = true; //#26011
                    } //#26011
                    var _Eu = $k[--$j]; //#26012
                    var _Ev = $k[--$j]; //#26012
                    $k[$j++] = _Ev; //#26012
                    $k[$j++] = _Eu; //#26012
                    if ($eq(_Ev, "FF0000")) { //#26012
                        $1.ri = $1.i; //#26012
                        $j--; //#26012
                        $k[$j++] = true; //#26012
                    } //#26012
                    var _Ex = $k[--$j]; //#26013
                    var _Ey = $k[--$j]; //#26013
                    $k[$j++] = _Ey; //#26013
                    $k[$j++] = _Ex; //#26013
                    if ($eq(_Ey, "FF00FF")) { //#26013
                        $1.mi = $1.i; //#26013
                        $j--; //#26013
                        $k[$j++] = true; //#26013
                    } //#26013
                    var _F0 = $k[--$j]; //#26014
                    var _F1 = $k[--$j]; //#26014
                    $k[$j++] = _F1; //#26014
                    $k[$j++] = _F0; //#26014
                    if ($eq(_F1, "FFFF00")) { //#26014
                        $1.yi = $1.i; //#26014
                        $j--; //#26014
                        $k[$j++] = true; //#26014
                    } //#26014
                    var _F3 = $k[--$j]; //#26015
                    var _F4 = $k[--$j]; //#26015
                    $k[$j++] = _F4; //#26015
                    $k[$j++] = _F3; //#26015
                    if ($eq(_F4, "FFFFFF")) { //#26015
                        $1.wi = $1.i; //#26015
                        $j--; //#26015
                        $k[$j++] = true; //#26015
                    } //#26015
                    if ($nt($k[--$j])) { //#26027
                        if (($1.colors <= 64) || ((($1.colors == 128) && (((($1.r == 0) || ($1.r == 73)) || ($1.r == 182)) || ($1.r == 255))) || ((($1.colors == 256) && (((($1.r == 0) || ($1.r == 73)) || ($1.r == 182)) || ($1.r == 255))) && (((($1.g == 0) || ($1.g == 73)) || ($1.g == 182)) || ($1.g == 255))))) { //#26026
                            $put($1.palettelayout, $1.j, $1.i); //#26024
                            $1.j = $1.j + 1; //#26025
                        } //#26025
                    } //#26025
                    $put($1.palette, $1.i, $k[--$j]); //#26028
                    $1.i = $1.i + 1; //#26029
                }); //#26029
            }); //#26029
        }); //#26029
        $puti($1.palettelayout, 0, $a([$1.ki, $1.bi, $1.gi, $1.ci, $1.ri, $1.mi, $1.yi, $1.wi])); //#26033
        $1.metacolorindex = $a([$1.ki, $1.bi, $1.gi, $1.ci, $1.ri, $1.mi, $1.yi, $1.wi]); //#26034
    } //#26034
    $k[$j++] = Infinity; //#26038
    for (var _Fp = 0, _Fq = $1.rows * $1.cols; _Fp < _Fq; _Fp++) { //#26038
        $k[$j++] = -1; //#26038
    } //#26038
    $1.pixs = $a(); //#26038
    $1.jmv = function() {
        var _Ft = $k[--$j]; //#26039
        var _Fu = $k[--$j]; //#26039
        $k[$j++] = $f(_Fu + (_Ft * $1.cols)); //#26039
    }; //#26039
    if (!$1.slave) { //#26069
        $1.fpat = $a([$a([1, 1, 1, 0, 0]), $a([1, 2, 2, 0, 0]), $a([1, 2, 1, 2, 1]), $a([0, 0, 2, 2, 1]), $a([0, 0, 1, 1, 1])]); //#26049
        $1.fmap = $a([$a([-1, $1.bi, $1.yi]), $a([-1, $1.yi, $1.bi]), $a([-1, $1.gi, $1.mi]), $a([-1, $1.mi, $1.gi])]); //#26055
    } else { //#26069
        $1.fpat = $a([$a([0, 0, 0, 0, 0]), $a([0, 2, 2, 0, 0]), $a([0, 2, 1, 2, 0]), $a([0, 0, 2, 2, 0]), $a([0, 0, 0, 0, 0])]); //#26063
        $1.fmap = $a([$a([-1, $1.ki, $1.wi]), $a([-1, $1.ki, $1.wi]), $a([-1, $1.ki, $1.wi]), $a([-1, $1.ki, $1.wi])]); //#26069
    } //#26069
    for (var _GY = 0; _GY <= 4; _GY += 1) { //#26081
        $1.y = _GY; //#26072
        for (var _GZ = 0; _GZ <= 4; _GZ += 1) { //#26080
            $1.x = _GZ; //#26074
            $1.fpb = $get($get($1.fpat, $1.y), $1.x); //#26075
            $k[$j++] = $1.pixs; //#26076
            $k[$j++] = $1.x + 1; //#26076
            $k[$j++] = $1.y + 1; //#26076
            $1.jmv(); //#26076
            var _Gm = $k[--$j]; //#26076
            $put($k[--$j], _Gm, $get($get($1.fmap, 0), $1.fpb)); //#26076
            $k[$j++] = $1.pixs; //#26077
            $k[$j++] = $1.x + 1; //#26077
            $k[$j++] = $f($f($1.rows - $1.y) - 2); //#26077
            $1.jmv(); //#26077
            var _Gw = $k[--$j]; //#26077
            $put($k[--$j], _Gw, $get($get($1.fmap, 1), $1.fpb)); //#26077
            $k[$j++] = $1.pixs; //#26078
            $k[$j++] = $f($f($1.x + $1.cols) - 6); //#26078
            $k[$j++] = $1.y + 1; //#26078
            $1.jmv(); //#26078
            var _H6 = $k[--$j]; //#26078
            $put($k[--$j], _H6, $get($get($1.fmap, 2), $1.fpb)); //#26078
            $k[$j++] = $1.pixs; //#26079
            $k[$j++] = $f($f($1.x + $1.cols) - 6); //#26079
            $k[$j++] = $f($f($1.rows - $1.y) - 2); //#26079
            $1.jmv(); //#26079
            var _HH = $k[--$j]; //#26079
            $put($k[--$j], _HH, $get($get($1.fmap, 3), $1.fpb)); //#26079
        } //#26079
    } //#26079
    $1.algnpat0 = $a([$a([$1.ki, $1.ki, -1]), $a([$1.ki, $1.wi, $1.ki]), $a([-1, $1.ki, $1.ki])]); //#26088
    $1.algnpat1 = $a([$a([-1, $1.ki, $1.ki]), $a([$1.ki, $1.wi, $1.ki]), $a([$1.ki, $1.ki, -1])]); //#26093
    $1.num = (~~Math.round($1.cols / 16)) - 1; //#26094
    $1.algnrpos = $a([3, 17]); //#26095
    if ($1.num > 0) { //#26098
        $k[$j++] = Infinity; //#26097
        for (var _Hk = 0, _Hj = $1.num; _Hk <= _Hj; _Hk += 1) { //#26097
            $k[$j++] = (~~(_Hk * ($f($1.cols - 7) / $1.num))) + 3; //#26097
        } //#26097
        $1.algnrpos = $a(); //#26097
    } //#26097
    $1.num = (~~Math.round($1.rows / 16)) - 1; //#26099
    $1.algncpos = $a([3, 17]); //#26100
    if ($1.num > 0) { //#26103
        $k[$j++] = Infinity; //#26102
        for (var _Ht = 0, _Hs = $1.num; _Ht <= _Hs; _Ht += 1) { //#26102
            $k[$j++] = (~~(_Ht * ($f($1.rows - 7) / $1.num))) + 3; //#26102
        } //#26102
        $1.algncpos = $a(); //#26102
    } //#26102
    $1.putalgnpat = function() {
        $1.pp = $k[--$j]; //#26105
        $1.py = $k[--$j]; //#26106
        $1.px = $k[--$j]; //#26107
        for (var _I0 = 0; _I0 <= 2; _I0 += 1) { //#26114
            $1.pb = _I0; //#26109
            for (var _I1 = 0; _I1 <= 2; _I1 += 1) { //#26113
                $1.pa = _I1; //#26111
                $k[$j++] = $1.pixs; //#26112
                $k[$j++] = $f($1.px + $1.pa); //#26112
                $k[$j++] = $f($1.py + $1.pb); //#26112
                $1.jmv(); //#26112
                var _IC = $k[--$j]; //#26112
                $put($k[--$j], _IC, $get($get($1.pp, $1.pb), $1.pa)); //#26112
            } //#26112
        } //#26112
    }; //#26112
    for (var _IG = 0, _IF = $1.algncpos.length - 1; _IG <= _IF; _IG += 1) { //#26126
        $1.j = _IG; //#26117
        $1.y = $get($1.algncpos, $1.j); //#26118
        for (var _IM = 0, _IL = $1.algnrpos.length - 1; _IM <= _IL; _IM += 1) { //#26125
            $1.i = _IM; //#26120
            $1.x = $get($1.algnrpos, $1.i); //#26121
            $k[$j++] = $1.pixs; //#26122
            $k[$j++] = $1.x; //#26122
            $k[$j++] = $1.y; //#26122
            $1.jmv(); //#26122
            var _IT = $k[--$j]; //#26122
            if ($get($k[--$j], _IT) == -1) { //#26124
                $k[$j++] = $f($1.x - 1); //#26123
                $k[$j++] = $f($1.y - 1); //#26123
                if ((($1.i + $1.j) % 2) == 0) { //#26123
                    $k[$j++] = $1.algnpat0; //#26123
                } else { //#26123
                    $k[$j++] = $1.algnpat1; //#26123
                } //#26123
                $1.putalgnpat(); //#26123
            } //#26123
        } //#26123
    } //#26123
    if (!$1.slave) { //#26178
        var _JL = $a([$a([6, 1]), $a([6, 2]), $a([6, 3]), $a([6, 4]), $a([6, 5]), $a([6, 6]), $a([5, 6]), $a([4, 6]), $a([3, 6]), $a([2, 6]), $a([1, 6]), $a([7, 1]), $a([7, 2]), $a([7, 3]), $a([7, 4]), $a([7, 5]), $a([7, 6]), $a([7, 7]), $a([6, 7]), $a([5, 7]), $a([4, 7]), $a([3, 7]), $a([2, 7]), $a([1, 7]), $a([8, 1]), $a([8, 2]), $a([8, 3]), $a([8, 4]), $a([8, 5]), $a([8, 6]), $a([8, 7]), $a([8, 8]), $a([7, 8]), $a([6, 8]), $a([5, 8]), $a([4, 8]), $a([3, 8]), $a([2, 8]), $a([1, 8]), $a([9, 1]), $a([9, 2]), $a([9, 3]), $a([9, 4]), $a([9, 5])]); //#26137
        for (var _JM = 0, _JN = _JL.length; _JM < _JN; _JM++) { //#26141
            $aload($get(_JL, _JM)); //#26139
            $1.y = $k[--$j]; //#26139
            $1.x = $k[--$j]; //#26139
            $k[$j++] = $a([$1.x, $1.y]); //#26140
            $k[$j++] = $a([-$1.x, $1.y]); //#26140
            $k[$j++] = $a([-$1.x, -$1.y]); //#26140
            $k[$j++] = $a([$1.x, -$1.y]); //#26140
        } //#26140
        $astore($a(176)); //#26142
        $1.metadatamap = $k[--$j]; //#26142
        $1.palettemap1 = $a([$a([4, 1]), $a([4, 2]), $a([5, 1]), $a([5, 2]), $a([2, 4]), $a([2, 5]), $a([1, 4]), $a([1, 5]), $a([-2, 1]), $a([-2, 2]), $a([-1, 1]), $a([-1, 2]), $a([-4, 4]), $a([-4, 5]), $a([-5, 4]), $a([-5, 5])]); //#26147
        $1.palettemap2 = $a([$a([-4, -5]), $a([-4, -4]), $a([-5, -5]), $a([-5, -4]), $a([-2, -2]), $a([-2, -1]), $a([-1, -2]), $a([-1, -1]), $a([2, -5]), $a([2, -4]), $a([1, -5]), $a([1, -4]), $a([4, -2]), $a([4, -1]), $a([5, -2]), $a([5, -1])]); //#26152
    } else { //#26178
        $k[$j++] = Infinity; //#26165
        for (var _KD = 1; _KD <= 19; _KD += 1) { //#26162
            $1.i = _KD; //#26160
            $k[$j++] = $a([0, $1.i]); //#26161
            $k[$j++] = $a([1, $1.i]); //#26161
        } //#26161
        for (var _KI = 5; _KI <= 12; _KI += 1) { //#26166
            $1.i = _KI; //#26164
            $k[$j++] = $a([2, $1.i]); //#26165
            $k[$j++] = $a([3, $1.i]); //#26165
        } //#26165
        $1.metadatamap = $a(); //#26165
        $k[$j++] = Infinity; //#26173
        for (var _KO = 5; _KO <= 12; _KO += 1) { //#26170
            $k[$j++] = _KO; //#26170
            $k[$j++] = Infinity; //#26170
            var _KP = $k[--$j]; //#26170
            var _KQ = $k[--$j]; //#26170
            $k[$j++] = _KP; //#26170
            $k[$j++] = 4; //#26170
            $k[$j++] = _KQ; //#26170
            var _KR = $a(); //#26170
            $k[$j++] = _KR; //#26170
        } //#26170
        for (var _KS = 12; _KS >= 5; _KS -= 1) { //#26171
            $k[$j++] = _KS; //#26171
            $k[$j++] = Infinity; //#26171
            var _KT = $k[--$j]; //#26171
            var _KU = $k[--$j]; //#26171
            $k[$j++] = _KT; //#26171
            $k[$j++] = 5; //#26171
            $k[$j++] = _KU; //#26171
            var _KV = $a(); //#26171
            $k[$j++] = _KV; //#26171
        } //#26171
        for (var _KW = 5; _KW <= 12; _KW += 1) { //#26172
            $k[$j++] = _KW; //#26172
            $k[$j++] = Infinity; //#26172
            var _KX = $k[--$j]; //#26172
            var _KY = $k[--$j]; //#26172
            $k[$j++] = _KX; //#26172
            $k[$j++] = 6; //#26172
            $k[$j++] = _KY; //#26172
            var _KZ = $a(); //#26172
            $k[$j++] = _KZ; //#26172
        } //#26172
        for (var _Ka = 12; _Ka >= 5; _Ka -= 1) { //#26173
            $k[$j++] = _Ka; //#26173
            $k[$j++] = Infinity; //#26173
            var _Kb = $k[--$j]; //#26173
            var _Kc = $k[--$j]; //#26173
            $k[$j++] = _Kb; //#26173
            $k[$j++] = 7; //#26173
            $k[$j++] = _Kc; //#26173
            var _Kd = $a(); //#26173
            $k[$j++] = _Kd; //#26173
        } //#26173
        $1.palettemap1 = $a(); //#26173
        $k[$j++] = Infinity; //#26177
        var _Kf = $1.palettemap1; //#26177
        for (var _Kg = 0, _Kh = _Kf.length; _Kg < _Kh; _Kg++) { //#26177
            $k[$j++] = $get(_Kf, _Kg); //#26177
            $k[$j++] = Infinity; //#26177
            var _Kj = $k[--$j]; //#26177
            var _Kk = $k[--$j]; //#26177
            $k[$j++] = _Kj; //#26177
            $aload(_Kk); //#26177
            var _Kl = $k[--$j]; //#26177
            var _Km = $k[--$j]; //#26177
            $k[$j++] = -_Km; //#26177
            $k[$j++] = -_Kl; //#26177
            var _Kn = $a(); //#26177
            $k[$j++] = _Kn; //#26177
        } //#26177
        $1.palettemap2 = $a(); //#26177
    } //#26178
    var _Kp = $1.metadatamap; //#26183
    for (var _Kq = 0, _Kr = _Kp.length; _Kq < _Kr; _Kq++) { //#26187
        var _Ks = $get(_Kp, _Kq); //#26187
        var _Kt = $get(_Ks, 0); //#26184
        $k[$j++] = _Ks; //#26184
        $k[$j++] = _Kt; //#26184
        if (_Kt < 0) { //#26184
            var _Kv = $k[--$j]; //#26184
            var _Kw = $k[--$j]; //#26184
            $put(_Kw, 0, $f($f(_Kv + $1.cols) - 1)); //#26184
            $k[$j++] = _Kw; //#26184
        } else { //#26184
            $j--; //#26184
        } //#26184
        var _Kx = $k[--$j]; //#26185
        var _Ky = $get(_Kx, 1); //#26185
        $k[$j++] = _Kx; //#26185
        $k[$j++] = _Ky; //#26185
        if (_Ky < 0) { //#26185
            var _L0 = $k[--$j]; //#26185
            var _L1 = $k[--$j]; //#26185
            $put(_L1, 1, $f($f(_L0 + $1.rows) - 1)); //#26185
            $k[$j++] = _L1; //#26185
        } else { //#26185
            $j--; //#26185
        } //#26185
        $j--; //#26186
    } //#26186
    var _L2 = $1.palettemap1; //#26188
    for (var _L3 = 0, _L4 = _L2.length; _L3 < _L4; _L3++) { //#26192
        var _L5 = $get(_L2, _L3); //#26192
        var _L6 = $get(_L5, 0); //#26189
        $k[$j++] = _L5; //#26189
        $k[$j++] = _L6; //#26189
        if (_L6 < 0) { //#26189
            var _L8 = $k[--$j]; //#26189
            var _L9 = $k[--$j]; //#26189
            $put(_L9, 0, $f($f(_L8 + $1.cols) - 1)); //#26189
            $k[$j++] = _L9; //#26189
        } else { //#26189
            $j--; //#26189
        } //#26189
        var _LA = $k[--$j]; //#26190
        var _LB = $get(_LA, 1); //#26190
        $k[$j++] = _LA; //#26190
        $k[$j++] = _LB; //#26190
        if (_LB < 0) { //#26190
            var _LD = $k[--$j]; //#26190
            var _LE = $k[--$j]; //#26190
            $put(_LE, 1, $f($f(_LD + $1.rows) - 1)); //#26190
            $k[$j++] = _LE; //#26190
        } else { //#26190
            $j--; //#26190
        } //#26190
        $j--; //#26191
    } //#26191
    var _LF = $1.palettemap2; //#26193
    for (var _LG = 0, _LH = _LF.length; _LG < _LH; _LG++) { //#26197
        var _LI = $get(_LF, _LG); //#26197
        var _LJ = $get(_LI, 0); //#26194
        $k[$j++] = _LI; //#26194
        $k[$j++] = _LJ; //#26194
        if (_LJ < 0) { //#26194
            var _LL = $k[--$j]; //#26194
            var _LM = $k[--$j]; //#26194
            $put(_LM, 0, $f($f(_LL + $1.cols) - 1)); //#26194
            $k[$j++] = _LM; //#26194
        } else { //#26194
            $j--; //#26194
        } //#26194
        var _LN = $k[--$j]; //#26195
        var _LO = $get(_LN, 1); //#26195
        $k[$j++] = _LN; //#26195
        $k[$j++] = _LO; //#26195
        if (_LO < 0) { //#26195
            var _LQ = $k[--$j]; //#26195
            var _LR = $k[--$j]; //#26195
            $put(_LR, 1, $f($f(_LQ + $1.rows) - 1)); //#26195
            $k[$j++] = _LR; //#26195
        } else { //#26195
            $j--; //#26195
        } //#26195
        $j--; //#26196
    } //#26196
    for (var _LU = 0, _LT = $f($1.nummetamodules - 1); _LU <= _LT; _LU += 1) { //#26202
        $k[$j++] = $1.pixs; //#26201
        $aload($get($1.metadatamap, _LU)); //#26201
        $1.jmv(); //#26201
        var _LY = $k[--$j]; //#26201
        $put($k[--$j], _LY, 0); //#26201
    } //#26201
    if (!$1.slave) { //#26215
        var _Lb = $1.colors; //#26207
        var _Lc = 16; //#26207
        if (16 > _Lb) { //#26207
            var _ = _Lb; //#26207
            _Lb = _Lc; //#26207
            _Lc = _; //#26207
        } //#26207
        for (var _Le = 0, _Ld = _Lc - 1; _Le <= _Ld; _Le += 1) { //#26212
            $1.i = _Le; //#26208
            var _Lh = $get($1.palettelayout, $1.i); //#26209
            $k[$j++] = _Lh; //#26210
            $k[$j++] = $1.pixs; //#26210
            $k[$j++] = _Lh; //#26210
            $aload($get($1.palettemap1, $1.i)); //#26210
            $1.jmv(); //#26210
            var _Lm = $k[--$j]; //#26210
            var _Ln = $k[--$j]; //#26210
            $put($k[--$j], _Lm, _Ln); //#26210
            var _Lq = $k[--$j]; //#26211
            $k[$j++] = $1.pixs; //#26211
            $k[$j++] = _Lq; //#26211
            $aload($get($1.palettemap2, $1.i)); //#26211
            $1.jmv(); //#26211
            var _Lu = $k[--$j]; //#26211
            var _Lv = $k[--$j]; //#26211
            $put($k[--$j], _Lu, _Lv); //#26211
        } //#26211
        $1.i = 16; //#26213
    } else { //#26215
        $1.i = 0; //#26215
    } //#26215
    $1.j = $1.nummetamodules; //#26219
    for (var _M1 = $1.i, _M0 = $1.palettelayout.length - 1; _M1 <= _M0; _M1 += 2) { //#26229
        $1.i = _M1; //#26221
        var _M4 = $get($1.palettelayout, $1.i); //#26222
        $k[$j++] = _M4; //#26223
        $k[$j++] = $1.pixs; //#26223
        $k[$j++] = _M4; //#26223
        $aload($get($1.metadatamap, $1.j)); //#26223
        $1.jmv(); //#26223
        var _M9 = $k[--$j]; //#26223
        var _MA = $k[--$j]; //#26223
        $put($k[--$j], _M9, _MA); //#26223
        var _MD = $k[--$j]; //#26224
        $k[$j++] = $1.pixs; //#26224
        $k[$j++] = _MD; //#26224
        $aload($get($1.metadatamap, $f($1.j + 2))); //#26224
        $1.jmv(); //#26224
        var _MH = $k[--$j]; //#26224
        var _MI = $k[--$j]; //#26224
        $put($k[--$j], _MH, _MI); //#26224
        var _MM = $get($1.palettelayout, $1.i + 1); //#26225
        $k[$j++] = _MM; //#26226
        $k[$j++] = $1.pixs; //#26226
        $k[$j++] = _MM; //#26226
        $aload($get($1.metadatamap, $f($1.j + 1))); //#26226
        $1.jmv(); //#26226
        var _MR = $k[--$j]; //#26226
        var _MS = $k[--$j]; //#26226
        $put($k[--$j], _MR, _MS); //#26226
        var _MV = $k[--$j]; //#26227
        $k[$j++] = $1.pixs; //#26227
        $k[$j++] = _MV; //#26227
        $aload($get($1.metadatamap, $f($1.j + 3))); //#26227
        $1.jmv(); //#26227
        var _MZ = $k[--$j]; //#26227
        var _Ma = $k[--$j]; //#26227
        $put($k[--$j], _MZ, _Ma); //#26227
        $1.j = $f($1.j + 4); //#26228
    } //#26228
    var _N2 = $a([function() {
        var _Md = $k[--$j]; //#26233
        var _Me = $k[--$j]; //#26233
        $k[$j++] = $f(_Me + _Md) % $1.colors; //#26233
    }, function() {
        $j--; //#26234
        var _Mh = $k[--$j]; //#26234
        $k[$j++] = _Mh % $1.colors; //#26234
    }, function() {
        var _Mi = $k[--$j]; //#26235
        var _Mj = $k[--$j]; //#26235
        $k[$j++] = _Mi; //#26235
        $k[$j++] = _Mj; //#26235
        $j--; //#26235
        var _Ml = $k[--$j]; //#26235
        $k[$j++] = _Ml % $1.colors; //#26235
    }, function() {
        var _Mm = $k[--$j]; //#26236
        var _Mn = $k[--$j]; //#26236
        $k[$j++] = ((~~(_Mm / 3)) + (~~(_Mn / 2))) % $1.colors; //#26236
    }, function() {
        var _Mp = $k[--$j]; //#26237
        var _Mq = $k[--$j]; //#26237
        $k[$j++] = ((~~(_Mp / 2)) + (~~(_Mq / 3))) % $1.colors; //#26237
    }, function() {
        var _Ms = $k[--$j]; //#26238
        var _Mu = $f($k[--$j] + _Ms); //#26238
        $k[$j++] = ((~~(_Mu / 2)) + (~~(_Mu / 3))) % $1.colors; //#26238
    }, function() {
        var _Mw = $k[--$j]; //#26239
        var _Mx = $k[--$j]; //#26239
        $k[$j++] = ($f(((_Mw * (_Mx * _Mx)) % 7) + ((($f(_Mw + (_Mx * _Mx))) * 2) % 19))) % $1.colors; //#26239
    }, function() {
        var _Mz = $k[--$j]; //#26240
        var _N0 = $k[--$j]; //#26240
        $k[$j++] = ($f(((_N0 * (_Mz * _Mz)) % 5) + (($f((_Mz * _Mz) + (_N0 * 2))) % 13))) % $1.colors; //#26240
    }]); //#26240
    $1.maskfuncs = _N2; //#26241
    if ($1.mask != -1) { //#26245
        $1.maskfuncs = $a([$get($1.maskfuncs, $1.mask)]); //#26243
        $1.bestmaskval = $1.mask; //#26244
    } //#26244
    $1.masks = $a($1.maskfuncs.length); //#26246
    for (var _ND = 0, _NC = $1.masks.length - 1; _ND <= _NC; _ND += 1) { //#26259
        $1.m = _ND; //#26248
        $1.mask = $a($1.rows * $1.cols); //#26249
        for (var _NJ = 0, _NI = $f($1.rows - 1); _NJ <= _NI; _NJ += 1) { //#26257
            $1.j = _NJ; //#26251
            for (var _NM = 0, _NL = $f($1.cols - 1); _NM <= _NL; _NM += 1) { //#26256
                $1.i = _NM; //#26253
                $k[$j++] = $1.pixs; //#26254
                $k[$j++] = $1.i; //#26254
                $k[$j++] = $1.j; //#26254
                $1.jmv(); //#26254
                var _NQ = $k[--$j]; //#26254
                if ($get($k[--$j], _NQ) == -1) { //#26254
                    $k[$j++] = $1.i; //#26254
                    $k[$j++] = $1.j; //#26254
                    if ($get($1.maskfuncs, $1.m)() === true) {
                        break;
                    } //#26254
                } else { //#26254
                    $k[$j++] = 0; //#26254
                } //#26254
                $k[$j++] = $1.mask; //#26255
                $k[$j++] = $1.i; //#26255
                $k[$j++] = $1.j; //#26255
                $1.jmv(); //#26255
                var _Nb = $k[--$j]; //#26255
                var _Nc = $k[--$j]; //#26255
                $put(_Nc, _Nb, $k[--$j]); //#26255
            } //#26255
        } //#26255
        $put($1.masks, $1.m, $1.mask); //#26258
    } //#26258
    $1.posx = 0; //#26262
    $1.posy = 0; //#26262
    $1.i = 0; //#26263
    for (;;) { //#26273
        if ($1.posx == $1.cols) { //#26265
            break; //#26265
        } //#26265
        $k[$j++] = $1.pixs; //#26266
        $k[$j++] = $1.posx; //#26266
        $k[$j++] = $1.posy; //#26266
        $1.jmv(); //#26266
        var _Nm = $k[--$j]; //#26266
        if ($get($k[--$j], _Nm) == -1) { //#26270
            var _Ns = $geti($1.bits, $1.i, $1.databpm); //#26267
            $k[$j++] = 0; //#26267
            for (var _Nt = 0, _Nu = _Ns.length; _Nt < _Nu; _Nt++) { //#26267
                var _Nw = $k[--$j]; //#26267
                $k[$j++] = ($f(_Nw + $f($get(_Ns, _Nt) - 48))) * 2; //#26267
            } //#26267
            var _Nx = $k[--$j]; //#26267
            $k[$j++] = ~~(_Nx / 2); //#26268
            $k[$j++] = $1.pixs; //#26268
            $k[$j++] = $1.posx; //#26268
            $k[$j++] = $1.posy; //#26268
            $1.jmv(); //#26268
            var _O1 = $k[--$j]; //#26268
            var _O2 = $k[--$j]; //#26268
            $put(_O2, _O1, $k[--$j]); //#26268
            $1.i = $1.i + $1.databpm; //#26269
        } //#26269
        $1.posy = $1.posy + 1; //#26271
        if ($1.posy == $1.rows) { //#26272
            $1.posy = 0; //#26272
            $1.posx = $1.posx + 1; //#26272
        } //#26272
    } //#26272
    $1.evalrle = function() {
        $1.scrle = $k[--$j]; //#26277
        $1.scr1 = 0; //#26278
        $1.scr3 = 0; //#26278
        for (var _OD = 0, _OC = $1.scrle.length - 2; _OD <= _OC; _OD += 2) { //#26300
            $1.j = _OD; //#26280
            if ($get($1.scrle, $1.j + 1) != -1) { //#26299
                var _OJ = $get($1.scrle, $1.j); //#26283
                $k[$j++] = _OJ; //#26283
                if (_OJ >= 5) { //#26283
                    $1.scr1 = $f($f($k[--$j] - 2) + $1.scr1); //#26283
                } else { //#26283
                    $j--; //#26283
                } //#26283
                if (($1.j >= 4) && ($1.j <= ($1.scrle.length - 5))) { //#26298
                    var _OR = $geti($1.scrle, $1.j - 4, 10); //#26286
                    $k[$j++] = _OR; //#26287
                    for (var _OS = 0, _OT = _OR.length; _OS < _OT; _OS++) { //#26287
                        $k[$j++] = $get(_OR, _OS) == 1; //#26287
                    } //#26287
                    $j--; //#26287
                    for (var _OV = 0, _OW = 4; _OV < _OW; _OV++) { //#26287
                        var _OX = $k[--$j]; //#26287
                        var _OY = $k[--$j]; //#26287
                        $k[$j++] = _OX; //#26287
                        $k[$j++] = _OY; //#26287
                        $j--; //#26287
                        var _OZ = $k[--$j]; //#26287
                        var _Oa = $k[--$j]; //#26287
                        $k[$j++] = $an(_Oa, _OZ); //#26287
                    } //#26287
                    if ($k[--$j]) { //#26297
                        $k[$j++] = Infinity; //#26288
                        var _Oc = $k[--$j]; //#26288
                        var _Od = $k[--$j]; //#26288
                        $k[$j++] = _Oc; //#26288
                        $aload(_Od); //#26288
                        var _Oe = $k[--$j]; //#26289
                        var _Of = $k[--$j]; //#26289
                        var _Og = $k[--$j]; //#26289
                        var _Oh = $k[--$j]; //#26289
                        var _Oi = $k[--$j]; //#26289
                        var _Oj = $k[--$j]; //#26289
                        var _Ok = $k[--$j]; //#26289
                        var _Ol = $k[--$j]; //#26289
                        var _Om = $k[--$j]; //#26289
                        $k[$j++] = _Om; //#26295
                        $k[$j++] = _Ol; //#26295
                        $k[$j++] = _Ok; //#26295
                        $k[$j++] = _Oj; //#26295
                        $k[$j++] = _Oi; //#26295
                        $k[$j++] = _Oh; //#26295
                        $k[$j++] = _Og; //#26295
                        $k[$j++] = _Of; //#26295
                        $k[$j++] = _Oe; //#26295
                        if (($eq(_Om, _Oi) && $eq(_Om, _Oe)) && $eq(_Ok, _Og)) { //#26295
                            var _On = $k[--$j]; //#26291
                            var _Oo = $k[--$j]; //#26291
                            var _Op = $k[--$j]; //#26291
                            $1.c4 = _Op; //#26291
                            $1.c5 = _On; //#26291
                            $k[$j++] = _Op; //#26294
                            $k[$j++] = _Oo; //#26294
                            if ((($1.c4 == $1.bi) && ($1.c5 == $1.yi)) || ((($1.c4 == $1.yi) && ($1.c5 == $1.bi)) || ((($1.c4 == $1.gi) && ($1.c5 == $1.mi)) || (($1.c4 == $1.mi) && ($1.c5 == $1.gi))))) { //#26294
                                $1.scr3 = $1.scr3 + 100; //#26294
                            } //#26294
                        } //#26294
                        $cleartomark(); //#26296
                    } else { //#26297
                        $j--; //#26297
                    } //#26297
                } //#26297
            } //#26297
        } //#26297
        $k[$j++] = $1.scr1; //#26301
        $k[$j++] = $1.scr3; //#26301
    }; //#26301
    $1.evalmask = function() {
        $1.sym = $k[--$j]; //#26305
        $1.n1 = 0; //#26307
        $1.n2 = 0; //#26307
        $1.n3 = 0; //#26307
        var _PA = $1.rows; //#26308
        var _PB = $1.cols; //#26308
        if (_PA < _PB) { //#26308
            var _ = _PB; //#26308
            _PB = _PA; //#26308
            _PA = _; //#26308
        } //#26308
        $1.rle = $a($f((_PA * 2) + 2)); //#26308
        $1.lastpairs = $a($1.cols); //#26309
        $1.thispairs = $a($1.cols); //#26310
        for (var _PJ = 0, _PI = $f($1.cols - 1); _PJ <= _PI; _PJ += 1) { //#26322
            $1.i = _PJ; //#26314
            $k[$j++] = Infinity; //#26315
            $k[$j++] = 0; //#26318
            $k[$j++] = -1; //#26318
            for (var _PP = $1.i, _PQ = $1.cols, _PO = $f(($1.rows * $1.cols) - 1); _PQ < 0 ? _PP >= _PO : _PP <= _PO; _PP += _PQ) { //#26318
                var _PS = $get($1.sym, _PP); //#26317
                var _PT = $k[--$j]; //#26317
                $k[$j++] = _PT; //#26317
                $k[$j++] = _PS; //#26317
                if ($eq(_PT, _PS)) { //#26317
                    $j--; //#26317
                    var _PU = $k[--$j]; //#26317
                    var _PV = $k[--$j]; //#26317
                    $k[$j++] = $f(_PV + 1); //#26317
                    $k[$j++] = _PU; //#26317
                } else { //#26317
                    var _PW = $k[--$j]; //#26317
                    $k[$j++] = 1; //#26317
                    $k[$j++] = _PW; //#26317
                } //#26317
            } //#26317
            var _PY = $counttomark() + 2; //#26319
            $astore($geti($1.rle, 0, _PY - 2)); //#26319
            $1.evalrle(); //#26320
            $1.n3 = $f($k[--$j] + $1.n3); //#26320
            $1.n1 = $f($k[--$j] + $1.n1); //#26320
            $j--; //#26321
        } //#26321
        for (var _Pg = 0, _Pf = $f($1.rows - 1); _Pg <= _Pf; _Pg += 1) { //#26349
            $1.i = _Pg; //#26325
            $1.symrow = $geti($1.sym, $1.i * $1.cols, $1.cols); //#26328
            $k[$j++] = Infinity; //#26329
            var _Pm = $1.symrow; //#26330
            $k[$j++] = 0; //#26332
            $k[$j++] = -1; //#26332
            for (var _Pn = 0, _Po = _Pm.length; _Pn < _Po; _Pn++) { //#26332
                var _Pp = $get(_Pm, _Pn); //#26332
                var _Pq = $k[--$j]; //#26331
                $k[$j++] = _Pq; //#26331
                $k[$j++] = _Pp; //#26331
                if ($eq(_Pq, _Pp)) { //#26331
                    $j--; //#26331
                    var _Pr = $k[--$j]; //#26331
                    var _Ps = $k[--$j]; //#26331
                    $k[$j++] = $f(_Ps + 1); //#26331
                    $k[$j++] = _Pr; //#26331
                } else { //#26331
                    var _Pt = $k[--$j]; //#26331
                    $k[$j++] = 1; //#26331
                    $k[$j++] = _Pt; //#26331
                } //#26331
            } //#26331
            var _Pv = $counttomark() + 2; //#26333
            $astore($geti($1.rle, 0, _Pv - 2)); //#26333
            $1.evalrle(); //#26334
            $1.n3 = $f($k[--$j] + $1.n3); //#26334
            $1.n1 = $f($k[--$j] + $1.n1); //#26334
            $j--; //#26335
            var _Q1 = $1.thispairs; //#26338
            $1.thispairs = $1.lastpairs; //#26338
            $1.lastpairs = _Q1; //#26338
            var _Q3 = $1.symrow; //#26339
            $k[$j++] = -1; //#26339
            for (var _Q4 = 0, _Q5 = _Q3.length; _Q4 < _Q5; _Q4++) { //#26339
                var _Q6 = $get(_Q3, _Q4); //#26339
                var _Q7 = $k[--$j]; //#26339
                $k[$j++] = _Q6; //#26339
                $k[$j++] = _Q7; //#26339
                if ($ne(_Q6, _Q7)) { //#26339
                    $j--; //#26339
                    var _Q8 = $k[--$j]; //#26339
                    $k[$j++] = -1; //#26339
                    $k[$j++] = _Q8; //#26339
                } //#26339
            } //#26339
            $j--; //#26340
            $astore($1.thispairs); //#26341
            $j--; //#26341
            if ($1.i > 0) { //#26348
                $k[$j++] = Infinity; //#26343
                $aload($1.lastpairs); //#26344
                $aload($1.thispairs); //#26344
                $k[$j++] = $1.n2; //#26345
                for (var _QF = 0, _QG = $1.cols; _QF < _QG; _QF++) { //#26345
                    var _QH = $k[--$j]; //#26345
                    var _QI = $k[--$j]; //#26345
                    $k[$j++] = _QH; //#26345
                    $k[$j++] = _QI; //#26345
                    if (_QI != -1) { //#26345
                        var _QK = $k[$j - 1 - $f($1.cols + 1)]; //#26345
                        if ($eq($k[--$j], _QK)) { //#26345
                            var _QM = $k[--$j]; //#26345
                            $k[$j++] = $f(_QM + 3); //#26345
                        } //#26345
                    } else { //#26345
                        $j--; //#26345
                    } //#26345
                } //#26345
                $1.n2 = $k[--$j]; //#26346
                $cleartomark(); //#26347
            } //#26347
        } //#26347
        $k[$j++] = $f($f($1.n1 + $1.n2) + $1.n3); //#26351
    }; //#26351
    $1.bestscore = 999999999; //#26355
    for (var _QT = 0, _QS = $1.masks.length - 1; _QT <= _QS; _QT += 1) { //#26373
        $1.m = _QT; //#26357
        $1.masksym = $a($1.rows * $1.cols); //#26358
        for (var _Qa = 0, _QZ = $f(($1.rows * $1.cols) - 1); _Qa <= _QZ; _Qa += 1) { //#26362
            $1.i = _Qa; //#26360
            $put($1.masksym, $1.i, $xo($get($1.pixs, $1.i), $get($get($1.masks, $1.m), $1.i))); //#26361
        } //#26361
        if ($1.masks.length != 1) { //#26371
            $k[$j++] = $1.masksym; //#26364
            $1.evalmask(); //#26364
            $1.score = $k[--$j]; //#26364
            if ($1.score < $1.bestscore) { //#26369
                $1.bestsym = $1.masksym; //#26366
                $1.bestmaskval = $1.m; //#26367
                $1.bestscore = $1.score; //#26368
            } //#26368
        } else { //#26371
            $1.bestsym = $1.masksym; //#26371
        } //#26371
    } //#26371
    $1.pixs = $1.bestsym; //#26374
    $1.metamask = $1.bestmaskval; //#26375
    $1.addtometapart = function() {
        var _Qw = $k[--$j]; //#26379
        $puti($1.metapart, $1.p, _Qw); //#26379
        $1.p = _Qw.length + $1.p; //#26380
    }; //#26380
    $1.addtometabits = function() {
        var _R0 = $k[--$j]; //#26384
        $puti($1.metabits, $1.q, _R0); //#26384
        $1.q = _R0.length + $1.q; //#26385
    }; //#26385
    $1.metapart = $s(40); //#26388
    $1.metabits = $s($1.nummetabits); //#26389
    $1.p = 0; //#26390
    $1.q = 0; //#26390
    if (!$1.slave) { //#26445
        $k[$j++] = (~~(Math.round(Math.log($1.colors) / Math.log(2)))) - 1; //#26395
        $k[$j++] = 3; //#26395
        $1.tofixedbits(); //#26395
        $1.addtometapart(); //#26395
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26396
        $k[$j++] = 2; //#26396
        $k[$j++] = -1; //#26396
        $1.ldpc(); //#26396
        $1.addtometabits(); //#26396
        $1.p = 0; //#26396
        $k[$j++] = $1.metass; //#26399
        $k[$j++] = 1; //#26399
        $1.tofixedbits(); //#26399
        $1.addtometapart(); //#26399
        $k[$j++] = $1.metavf; //#26400
        $k[$j++] = 2; //#26400
        $1.tofixedbits(); //#26400
        $1.addtometapart(); //#26400
        $k[$j++] = $1.metamask; //#26401
        $k[$j++] = 3; //#26401
        $1.tofixedbits(); //#26401
        $1.addtometapart(); //#26401
        if ($1.hasslaves) { //#26402
            $k[$j++] = "1"; //#26402
        } else { //#26402
            $k[$j++] = "0"; //#26402
        } //#26402
        $1.addtometapart(); //#26402
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26403
        $k[$j++] = 2; //#26403
        $k[$j++] = -1; //#26403
        $1.ldpc(); //#26403
        $1.addtometabits(); //#26403
        $1.p = 0; //#26403
        if ($1.metass == 0) { //#26413
            $k[$j++] = $f(($f((~~($f($1.cols - 17) / 4)) - $get($a([0, 4, 8, 16]), $1.metavf))) - 1); //#26408
            $k[$j++] = $1.metavlen; //#26408
            $1.tofixedbits(); //#26408
            $1.addtometapart(); //#26408
        } else { //#26413
            $k[$j++] = (~~($f($1.cols - 17) / 4)) - 1; //#26411
            $k[$j++] = ~~($1.metavlen / 2); //#26411
            $1.tofixedbits(); //#26411
            $1.addtometapart(); //#26411
            $k[$j++] = (~~($f($1.rows - 17) / 4)) - 1; //#26413
            $k[$j++] = ~~($1.metavlen / 2); //#26413
            $1.tofixedbits(); //#26413
            $1.addtometapart(); //#26413
        } //#26413
        $k[$j++] = $1.datawc - 3; //#26415
        $k[$j++] = ~~($1.metaelen / 2); //#26415
        $1.tofixedbits(); //#26415
        $1.addtometapart(); //#26415
        $k[$j++] = $1.datawr - 4; //#26416
        $k[$j++] = ~~($1.metaelen / 2); //#26416
        $1.tofixedbits(); //#26416
        $1.addtometapart(); //#26416
        if ($1.hasslaves) { //#26419
            $k[$j++] = 0; //#26418
            $k[$j++] = 4; //#26418
            $1.tofixedbits(); //#26418
            $1.addtometapart(); //#26418
        } //#26418
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26420
        $k[$j++] = 2; //#26420
        $k[$j++] = -1; //#26420
        $1.ldpc(); //#26420
        $1.addtometabits(); //#26420
        $1.p = 0; //#26420
    } else { //#26445
        var _Rc = $1.sameshape ? 0 : 1; //#26425
        $k[$j++] = _Rc; //#26425
        $k[$j++] = 1; //#26425
        $1.tofixedbits(); //#26425
        $1.addtometapart(); //#26425
        var _Re = $1.sameecc ? 0 : 1; //#26426
        $k[$j++] = _Re; //#26426
        $k[$j++] = 1; //#26426
        $1.tofixedbits(); //#26426
        $1.addtometapart(); //#26426
        var _Rg = $1.hasslaves ? 1 : 0; //#26427
        $k[$j++] = _Rg; //#26427
        $k[$j++] = 1; //#26427
        $1.tofixedbits(); //#26427
        $1.addtometapart(); //#26427
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26428
        $k[$j++] = 2; //#26428
        $k[$j++] = -1; //#26428
        $1.ldpc(); //#26428
        $1.addtometabits(); //#26428
        $1.p = 0; //#26428
        if (!$1.sameshape) { //#26434
            $k[$j++] = (~~(($1.diffside - 17) / 4)) - 1; //#26433
            $k[$j++] = 5; //#26433
            $1.tofixedbits(); //#26433
            $1.addtometapart(); //#26433
        } //#26433
        if ($1.hasslaves) { //#26437
            $k[$j++] = 0; //#26436
            $k[$j++] = 3; //#26436
            $1.tofixedbits(); //#26436
            $1.addtometapart(); //#26436
        } //#26436
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26438
        $k[$j++] = 2; //#26438
        $k[$j++] = -1; //#26438
        $1.ldpc(); //#26438
        $1.addtometabits(); //#26438
        $1.p = 0; //#26438
        if (!$1.sameecc) { //#26444
            $k[$j++] = $1.datawc - 3; //#26442
            $k[$j++] = ~~($1.metaelen / 2); //#26442
            $1.tofixedbits(); //#26442
            $1.addtometapart(); //#26442
            $k[$j++] = $1.datawr - 4; //#26443
            $k[$j++] = ~~($1.metaelen / 2); //#26443
            $1.tofixedbits(); //#26443
            $1.addtometapart(); //#26443
        } //#26443
        $k[$j++] = $geti($1.metapart, 0, $1.p); //#26445
        $k[$j++] = 2; //#26445
        $k[$j++] = -1; //#26445
        $1.ldpc(); //#26445
        $1.addtometabits(); //#26445
        $1.p = 0; //#26445
    } //#26445
    for (var _S1 = $1.q, _S0 = $f($1.nummetabits - 1); _S1 <= _S0; _S1 += 1) { //#26450
        $put($1.metabits, _S1, 48); //#26449
    } //#26449
    $1.i = 0; //#26453
    $1.j = 0; //#26453
    if (!$1.slave) { //#26461
        var _S6 = $geti($1.metabits, $1.i, 6); //#26455
        for (var _S7 = 0, _S8 = _S6.length; _S7 < _S8; _S7++) { //#26459
            $k[$j++] = $get(_S6, _S7); //#26456
            if ($1.colors == 4) { //#26456
                $k[$j++] = $a([$1.bi, $1.yi]); //#26456
            } else { //#26456
                $k[$j++] = $a([$1.ki, $1.wi]); //#26456
            } //#26456
            var _SH = $k[--$j]; //#26456
            var _SJ = $get(_SH, $f($k[--$j] - 48)); //#26456
            $k[$j++] = _SJ; //#26457
            $k[$j++] = $1.pixs; //#26457
            $aload($get($1.metadatamap, $1.j)); //#26457
            $1.jmv(); //#26457
            var _SO = $k[--$j]; //#26457
            var _SP = $k[--$j]; //#26457
            $put(_SP, _SO, $k[--$j]); //#26457
            $1.j = $1.j + 1; //#26458
        } //#26458
        $1.i = $1.i + 6; //#26460
    } //#26460
    for (var _SW = 0, _SX = ~~($f($1.nummetabits - $1.i) / $1.metabpm); _SW < _SX; _SW++) { //#26468
        var _Sb = $geti($1.metabits, $1.i, $1.metabpm); //#26463
        $k[$j++] = 0; //#26463
        for (var _Sc = 0, _Sd = _Sb.length; _Sc < _Sd; _Sc++) { //#26463
            var _Sf = $k[--$j]; //#26463
            $k[$j++] = ($f(_Sf + $f($get(_Sb, _Sc) - 48))) * 2; //#26463
        } //#26463
        var _Si = $get($1.metacolorindex, ~~($k[--$j] / 2)); //#26464
        $k[$j++] = _Si; //#26465
        $k[$j++] = $1.pixs; //#26465
        $aload($get($1.metadatamap, $1.j)); //#26465
        $1.jmv(); //#26465
        var _Sn = $k[--$j]; //#26465
        var _So = $k[--$j]; //#26465
        $put(_So, _Sn, $k[--$j]); //#26465
        $1.i = $f($1.i + $1.metabpm); //#26466
        $1.j = $1.j + 1; //#26467
    } //#26467
    var _T0 = new Map([
        ["ren", bwipp_renmatrix],
        ["pixs", $1.pixs],
        ["pixx", $1.cols],
        ["pixy", $1.rows],
        ["colormap", $1.palette],
        ["height", ($1.rows * 2) / 72],
        ["width", ($1.cols * 2) / 72],
        ["opt", $1.options]
    ]); //#26478
    $k[$j++] = _T0; //#26481
    if (!$1.dontdraw) { //#26481
        bwipp_renmatrix(); //#26481
    } //#26481
}

function bwipp_gs1_cc() {
    var $1 = {}; //#26516
    $1.ctx = null; //#26518
    $1.parse = false; //#26519
    $1.dontlint = false; //#26520
    $1.lintreqs = false; //#26521
    $1.dontdraw = false; //#26522
    $1.ccversion = "a"; //#26523
    $1.cccolumns = -1; //#26524
    $1.lintype = ""; //#26525
    $1.linwidth = -1; //#26526
    $k[$j++] = $1; //#26528
    bwipp_processoptions(); //#26528
    $1.options = $k[--$j]; //#26528
    $1.barcode = $k[--$j]; //#26529
    if ($1.cccolumns == -1) { //#26550
        $k[$j++] = Infinity; //#26548
        $k[$j++] = 'ean13'; //#26541
        $k[$j++] = 4; //#26541
        $k[$j++] = 'upca'; //#26541
        $k[$j++] = 4; //#26541
        $k[$j++] = 'ean8'; //#26541
        $k[$j++] = 3; //#26541
        $k[$j++] = 'upce'; //#26541
        $k[$j++] = 2; //#26541
        $k[$j++] = 'gs1-128'; //#26541
        if ($ne($1.ccversion, "c")) { //#26541
            $k[$j++] = 4; //#26541
        } else { //#26541
            $k[$j++] = ~~(($1.linwidth - 52) / 17); //#26541
        } //#26541
        $k[$j++] = 'databaromni'; //#26548
        $k[$j++] = 4; //#26548
        $k[$j++] = 'databarstacked'; //#26548
        $k[$j++] = 2; //#26548
        $k[$j++] = 'databarstackedomni'; //#26548
        $k[$j++] = 2; //#26548
        $k[$j++] = 'databartruncated'; //#26548
        $k[$j++] = 4; //#26548
        $k[$j++] = 'databarlimited'; //#26548
        $k[$j++] = 3; //#26548
        $k[$j++] = 'databarexpanded'; //#26548
        $k[$j++] = 4; //#26548
        $k[$j++] = 'databarexpandedstacked'; //#26548
        $k[$j++] = 4; //#26548
        $1.cccolumns = $get($d(), $1.lintype); //#26549
    } //#26549
    $k[$j++] = $1.barcode; //#26552
    $k[$j++] = 'ai'; //#26552
    bwipp_gs1process(); //#26552
    $1.fncs = $k[--$j]; //#26553
    $1.vals = $k[--$j]; //#26554
    $1.ais = $k[--$j]; //#26555
    $1.isupper = function() {
        var _C = $k[--$j]; //#26558
        $k[$j++] = (_C >= 65) && (_C <= 90); //#26558
    }; //#26558
    $1.isnum0 = function() {
        var _D = $k[--$j]; //#26559
        $k[$j++] = (_D >= 48) && (_D <= 57); //#26559
    }; //#26559
    $1.isnum1 = function() {
        var _E = $k[--$j]; //#26560
        $k[$j++] = (_E >= 49) && (_E <= 57); //#26560
    }; //#26560
    for (;;) { //#26606
        if ($1.ais.length >= 1) { //#26568
            if (($eq($get($1.ais, 0), "10") || $eq($get($1.ais, 0), "11")) || $eq($get($1.ais, 0), "17")) { //#26567
                $k[$j++] = -1; //#26566
                $k[$j++] = "10"; //#26566
                break; //#26566
            } //#26566
        } //#26566
        if ($1.ais.length >= 1) { //#26601
            if ($eq($get($1.ais, 0), "90")) { //#26600
                $1.v = $get($1.vals, 0); //#26573
                if ($1.v.length >= 1) { //#26578
                    $k[$j++] = $get($1.v, 0); //#26575
                    $1.isupper(); //#26575
                    if ($k[--$j]) { //#26577
                        $k[$j++] = 0; //#26576
                        $k[$j++] = "11"; //#26576
                        break; //#26576
                    } //#26576
                } //#26576
                if ($1.v.length >= 2) { //#26584
                    $k[$j++] = $get($1.v, 0); //#26580
                    $1.isnum1(); //#26580
                    $k[$j++] = $get($1.v, 1); //#26581
                    $1.isupper(); //#26581
                    var _a = $k[--$j]; //#26581
                    var _b = $k[--$j]; //#26581
                    if ((_b && _a)) { //#26583
                        $k[$j++] = 1; //#26582
                        $k[$j++] = "11"; //#26582
                        break; //#26582
                    } //#26582
                } //#26582
                if ($1.v.length >= 3) { //#26591
                    $k[$j++] = $get($1.v, 0); //#26586
                    $1.isnum1(); //#26586
                    $k[$j++] = $get($1.v, 1); //#26587
                    $1.isnum0(); //#26587
                    var _h = $k[--$j]; //#26587
                    var _i = $k[--$j]; //#26587
                    $k[$j++] = $an(_i, _h); //#26588
                    $k[$j++] = $get($1.v, 2); //#26588
                    $1.isupper(); //#26588
                    var _l = $k[--$j]; //#26588
                    var _m = $k[--$j]; //#26588
                    if ((_m && _l)) { //#26590
                        $k[$j++] = 2; //#26589
                        $k[$j++] = "11"; //#26589
                        break; //#26589
                    } //#26589
                } //#26589
                if ($1.v.length >= 4) { //#26599
                    $k[$j++] = $get($1.v, 0); //#26593
                    $1.isnum1(); //#26593
                    $k[$j++] = $get($1.v, 1); //#26594
                    $1.isnum0(); //#26594
                    var _s = $k[--$j]; //#26594
                    var _t = $k[--$j]; //#26594
                    $k[$j++] = $an(_t, _s); //#26595
                    $k[$j++] = $get($1.v, 2); //#26595
                    $1.isnum0(); //#26595
                    var _w = $k[--$j]; //#26595
                    var _x = $k[--$j]; //#26595
                    $k[$j++] = $an(_x, _w); //#26596
                    $k[$j++] = $get($1.v, 3); //#26596
                    $1.isupper(); //#26596
                    var _10 = $k[--$j]; //#26596
                    var _11 = $k[--$j]; //#26596
                    if ((_11 && _10)) { //#26598
                        $k[$j++] = 3; //#26597
                        $k[$j++] = "11"; //#26597
                        break; //#26597
                    } //#26597
                } //#26597
            } //#26597
        } //#26597
        $k[$j++] = -1; //#26604
        $k[$j++] = "0"; //#26604
        break; //#26604
    } //#26604
    $1.method = $k[--$j]; //#26607
    $1.npre = $k[--$j]; //#26608
    $1.tobin = function() {
        var _15 = $s($k[--$j]); //#26611
        $k[$j++] = _15; //#26611
        for (var _17 = 0, _16 = _15.length - 1; _17 <= _16; _17 += 1) { //#26611
            var _18 = $k[--$j]; //#26611
            $put(_18, _17, 48); //#26611
            $k[$j++] = _18; //#26611
        } //#26611
        var _19 = $k[--$j]; //#26612
        var _1C = $cvrs($s(_19.length), $k[--$j], 2); //#26612
        $puti(_19, _19.length - _1C.length, _1C); //#26612
        $k[$j++] = _19; //#26612
    }; //#26612
    $1.fnc1 = -1; //#26617
    $1.lnumeric = -2; //#26617
    $1.lalphanumeric = -3; //#26617
    $1.liso646 = -4; //#26617
    $k[$j++] = Infinity; //#26622
    for (var _1D = 65; _1D <= 90; _1D += 1) { //#26620
        $k[$j++] = _1D; //#26620
        $k[$j++] = _1D - 65; //#26620
        $k[$j++] = 5; //#26620
        $1.tobin(); //#26620
    } //#26620
    for (var _1E = 48; _1E <= 57; _1E += 1) { //#26621
        $k[$j++] = _1E; //#26621
        $k[$j++] = _1E + 4; //#26621
        $k[$j++] = 6; //#26621
        $1.tobin(); //#26621
    } //#26621
    $k[$j++] = $1.fnc1; //#26622
    $k[$j++] = "11111"; //#26622
    $1.alpha = $d(); //#26623
    $k[$j++] = Infinity; //#26635
    for (var _1H = 0; _1H <= 119; _1H += 1) { //#26634
        var _1J = $strcpy($s(2), "00"); //#26627
        var _1L = $cvrs($s(2), _1H, 11); //#26627
        $puti(_1J, 2 - _1L.length, _1L); //#26628
        $k[$j++] = _1H; //#26629
        $k[$j++] = _1J; //#26629
        if ($get(_1J, 0) == 65) { //#26629
            var _1N = $k[--$j]; //#26629
            $put(_1N, 0, 94); //#26629
            $k[$j++] = _1N; //#26629
        } //#26629
        var _1O = $k[--$j]; //#26630
        $k[$j++] = _1O; //#26630
        if ($get(_1O, 1) == 65) { //#26630
            var _1Q = $k[--$j]; //#26630
            $put(_1Q, 1, 94); //#26630
            $k[$j++] = _1Q; //#26630
        } //#26630
        var _1R = $k[--$j]; //#26631
        var _1U = $strcpy($s(7), "0000000"); //#26632
        var _1W = $cvrs($s(7), $f($k[--$j] + 8), 2); //#26632
        $puti(_1U, 7 - _1W.length, _1W); //#26633
        $k[$j++] = _1R; //#26633
        $k[$j++] = _1U; //#26633
    } //#26633
    $k[$j++] = $1.lalphanumeric; //#26635
    $k[$j++] = "0000"; //#26635
    $1.numeric = $d(); //#26636
    $k[$j++] = Infinity; //#26645
    for (var _1Z = 48; _1Z <= 57; _1Z += 1) { //#26639
        $k[$j++] = _1Z; //#26639
        $k[$j++] = _1Z - 43; //#26639
        $k[$j++] = 5; //#26639
        $1.tobin(); //#26639
    } //#26639
    $k[$j++] = $1.fnc1; //#26641
    $k[$j++] = "01111"; //#26641
    for (var _1b = 65; _1b <= 90; _1b += 1) { //#26641
        $k[$j++] = _1b; //#26641
        $k[$j++] = _1b - 33; //#26641
        $k[$j++] = 6; //#26641
        $1.tobin(); //#26641
    } //#26641
    $k[$j++] = 42; //#26643
    $k[$j++] = "111010"; //#26643
    for (var _1c = 44; _1c <= 47; _1c += 1) { //#26643
        $k[$j++] = _1c; //#26643
        $k[$j++] = _1c + 15; //#26643
        $k[$j++] = 6; //#26643
        $1.tobin(); //#26643
    } //#26643
    $k[$j++] = $1.lnumeric; //#26645
    $k[$j++] = "000"; //#26645
    $k[$j++] = $1.liso646; //#26645
    $k[$j++] = "00100"; //#26645
    $1.alphanumeric = $d(); //#26646
    $k[$j++] = Infinity; //#26660
    for (var _1g = 48; _1g <= 57; _1g += 1) { //#26649
        $k[$j++] = _1g; //#26649
        $k[$j++] = _1g - 43; //#26649
        $k[$j++] = 5; //#26649
        $1.tobin(); //#26649
    } //#26649
    $k[$j++] = $1.fnc1; //#26651
    $k[$j++] = "01111"; //#26651
    for (var _1i = 65; _1i <= 90; _1i += 1) { //#26651
        $k[$j++] = _1i; //#26651
        $k[$j++] = _1i - 1; //#26651
        $k[$j++] = 7; //#26651
        $1.tobin(); //#26651
    } //#26651
    for (var _1j = 97; _1j <= 122; _1j += 1) { //#26652
        $k[$j++] = _1j; //#26652
        $k[$j++] = _1j - 7; //#26652
        $k[$j++] = 7; //#26652
        $1.tobin(); //#26652
    } //#26652
    $k[$j++] = 33; //#26655
    $k[$j++] = "11101000"; //#26655
    $k[$j++] = 34; //#26655
    $k[$j++] = "11101001"; //#26655
    for (var _1k = 37; _1k <= 47; _1k += 1) { //#26655
        $k[$j++] = _1k; //#26655
        $k[$j++] = _1k + 197; //#26655
        $k[$j++] = 8; //#26655
        $1.tobin(); //#26655
    } //#26655
    for (var _1l = 58; _1l <= 63; _1l += 1) { //#26656
        $k[$j++] = _1l; //#26656
        $k[$j++] = _1l + 187; //#26656
        $k[$j++] = 8; //#26656
        $1.tobin(); //#26656
    } //#26656
    $k[$j++] = 95; //#26660
    $k[$j++] = "11111011"; //#26660
    $k[$j++] = 32; //#26660
    $k[$j++] = "11111100"; //#26660
    $k[$j++] = $1.lnumeric; //#26660
    $k[$j++] = "000"; //#26660
    $k[$j++] = $1.lalphanumeric; //#26660
    $k[$j++] = "00100"; //#26660
    $1.iso646 = $d(); //#26661
    if ($eq($1.method, "10")) { //#26698
        if ($eq($get($1.ais, 0), "11") || $eq($get($1.ais, 0), "17")) { //#26681
            var _1v = $get($1.vals, 0); //#26667
            var _20 = $strcpy($s(16), "0000000000000000"); //#26671
            var _22 = $cvrs($s(16), ($cvi($geti(_1v, 0, 2)) * 384) + ((($cvi($geti(_1v, 2, 2)) - 1) * 32) + $cvi($geti(_1v, 4, 2))), 2); //#26671
            $puti(_20, 16 - _22.length, _22); //#26672
            $k[$j++] = _20; //#26675
            $k[$j++] = Infinity; //#26675
            var _23 = $k[--$j]; //#26674
            var _24 = $k[--$j]; //#26674
            $k[$j++] = _23; //#26674
            $k[$j++] = 1; //#26674
            $k[$j++] = 0; //#26674
            $forall(_24, function() { //#26674
                var _25 = $k[--$j]; //#26674
                $k[$j++] = $f(_25 - 48); //#26674
            }); //#26674
            var _28 = $eq($get($1.ais, 0), "11") ? 0 : 1; //#26675
            $k[$j++] = _28; //#26675
            $1.cdf = $a(); //#26676
            $1.ais = $geti($1.ais, 1, $1.ais.length - 1); //#26677
            $1.vals = $geti($1.vals, 1, $1.vals.length - 1); //#26678
            $1.fncs = $geti($1.fncs, 1, $1.fncs.length - 1); //#26679
        } else { //#26681
            $1.cdf = $a([1, 0, 1, 1]); //#26681
        } //#26681
        if ($1.ais.length != 0) { //#26695
            if ($eq($get($1.ais, 0), "10")) { //#26691
                $k[$j++] = Infinity; //#26685
                $forall($get($1.vals, 0)); //#26685
                $1.gpf = $a(); //#26685
                if ($1.ais.length > 1) { //#26686
                    $k[$j++] = Infinity; //#26686
                    $aload($1.gpf); //#26686
                    $k[$j++] = $1.fnc1; //#26686
                    $1.gpf = $a(); //#26686
                } //#26686
                $1.ais = $geti($1.ais, 1, $1.ais.length - 1); //#26687
                $1.vals = $geti($1.vals, 1, $1.vals.length - 1); //#26688
                $1.fncs = $geti($1.fncs, 1, $1.fncs.length - 1); //#26689
            } else { //#26691
                $1.gpf = $a([$1.fnc1]); //#26691
            } //#26691
        } else { //#26695
            $k[$j++] = Infinity; //#26694
            $aload($1.cdf); //#26694
            $k[$j++] = 0; //#26694
            $k[$j++] = 0; //#26694
            $k[$j++] = 0; //#26694
            $k[$j++] = 0; //#26694
            $k[$j++] = 0; //#26694
            $k[$j++] = 1; //#26694
            $k[$j++] = 1; //#26694
            $k[$j++] = 1; //#26694
            $k[$j++] = 1; //#26694
            $1.cdf = $a(); //#26694
            $1.gpf = $a([]); //#26695
        } //#26695
        $1.mode = "numeric"; //#26697
    } //#26697
    if ($eq($1.method, "11")) { //#26792
        $1.cdf = $a([1, 1]); //#26701
        $1.ai90 = $get($1.vals, 0); //#26702
        if ($f($1.npre + 1) != $1.ai90.length) { //#26706
            $k[$j++] = $geti($1.ai90, $f($1.npre + 1), $f($f($1.ai90.length - $1.npre) - 1)); //#26704
        } else { //#26706
            $k[$j++] = ""; //#26706
        } //#26706
        $1.ai90rem = $k[--$j]; //#26708
        $k[$j++] = 'nalpha'; //#26709
        $k[$j++] = 0; //#26709
        $forall($1.ai90rem, function() { //#26709
            var _2v = $k[--$j]; //#26709
            if ((_2v >= 65) && (_2v <= 90)) { //#26709
                var _2w = $k[--$j]; //#26709
                $k[$j++] = $f(_2w + 1); //#26709
            } //#26709
        }); //#26709
        var _2x = $k[--$j]; //#26709
        $1[$k[--$j]] = _2x; //#26709
        $k[$j++] = 'nnums'; //#26710
        $k[$j++] = 0; //#26710
        $forall($1.ai90rem, function() { //#26710
            var _30 = $k[--$j]; //#26710
            if ((_30 >= 48) && (_30 <= 57)) { //#26710
                var _31 = $k[--$j]; //#26710
                $k[$j++] = $f(_31 + 1); //#26710
            } //#26710
        }); //#26710
        var _32 = $k[--$j]; //#26710
        $1[$k[--$j]] = _32; //#26710
        $k[$j++] = 'mode'; //#26711
        if ($gt($1.nalpha, $1.nnums)) { //#26711
            $k[$j++] = "alpha"; //#26711
        } else { //#26711
            if ($1.nalpha == 0) { //#26711
                $k[$j++] = "numeric"; //#26711
            } else { //#26711
                $k[$j++] = "alphanumeric"; //#26711
            } //#26711
        } //#26711
        var _37 = $k[--$j]; //#26711
        $1[$k[--$j]] = _37; //#26711
        if ($f($1.nalpha + $1.nnums) != $1.ai90rem.length) { //#26712
            $1.mode = "alphanumeric"; //#26712
        } //#26712
        $k[$j++] = Infinity; //#26717
        $aload($1.cdf); //#26714
        if ($eq($1.mode, "alphanumeric")) { //#26715
            $k[$j++] = 0; //#26715
        } //#26715
        if ($eq($1.mode, "numeric")) { //#26716
            $k[$j++] = 1; //#26716
            $k[$j++] = 0; //#26716
        } //#26716
        if ($eq($1.mode, "alpha")) { //#26717
            $k[$j++] = 1; //#26717
            $k[$j++] = 1; //#26717
        } //#26717
        $1.cdf = $a(); //#26717
        $k[$j++] = 'ais1'; //#26719
        if ($1.ais.length > 1) { //#26719
            $k[$j++] = $get($1.ais, 1); //#26719
        } else { //#26719
            $k[$j++] = -1; //#26719
        } //#26719
        var _3K = $k[--$j]; //#26719
        $1[$k[--$j]] = _3K; //#26719
        $k[$j++] = 'vals1'; //#26720
        if ($1.vals.length > 1) { //#26720
            $k[$j++] = $get($1.vals, 1); //#26720
        } else { //#26720
            $k[$j++] = -1; //#26720
        } //#26720
        var _3P = $k[--$j]; //#26720
        $1[$k[--$j]] = _3P; //#26720
        if ($eq($1.ais1, "21") || $eq($1.ais1, "8004")) { //#26724
            $k[$j++] = Infinity; //#26722
            $aload($1.cdf); //#26722
            if ($eq($1.ais1, "21")) { //#26722
                $k[$j++] = 1; //#26722
                $k[$j++] = 0; //#26722
            } else { //#26722
                $k[$j++] = 1; //#26722
                $k[$j++] = 1; //#26722
            } //#26722
            $1.cdf = $a(); //#26722
        } else { //#26724
            $k[$j++] = Infinity; //#26724
            $aload($1.cdf); //#26724
            $k[$j++] = 0; //#26724
            $1.cdf = $a(); //#26724
        } //#26724
        $k[$j++] = 'nval'; //#26726
        if ($1.npre != 0) { //#26726
            $k[$j++] = $cvi($geti($1.ai90, 0, $1.npre)); //#26726
        } else { //#26726
            $k[$j++] = 0; //#26726
        } //#26726
        var _3c = $k[--$j]; //#26726
        $1[$k[--$j]] = _3c; //#26726
        $search("BDHIJKLNPQRSTVXZ", $geti($1.ai90, $1.npre, 1)); //#26727
        if ($k[--$j]) { //#26731
            var _3i = $k[--$j]; //#26728
            var _3j = $k[--$j]; //#26728
            $k[$j++] = _3i.length; //#26728
            $k[$j++] = _3j; //#26728
            $j--; //#26728
            var _3k = $k[--$j]; //#26728
            var _3l = $k[--$j]; //#26728
            $k[$j++] = _3k; //#26728
            $k[$j++] = _3l; //#26728
            $j--; //#26728
            $1.aval = $k[--$j]; //#26729
        } else { //#26731
            $j--; //#26731
            $1.aval = -1; //#26731
        } //#26731
        if (($1.nval < 31) && ($1.aval != -1)) { //#26757
            var _3q = $strcpy($s(5), "00000"); //#26734
            var _3t = $cvrs($s(5), $1.nval, 2); //#26734
            $puti(_3q, 5 - _3t.length, _3t); //#26735
            $k[$j++] = _3q; //#26736
            $k[$j++] = Infinity; //#26736
            var _3u = $k[--$j]; //#26736
            var _3v = $k[--$j]; //#26736
            $k[$j++] = _3u; //#26736
            $forall(_3v, function() { //#26736
                var _3w = $k[--$j]; //#26736
                $k[$j++] = $f(_3w - 48); //#26736
            }); //#26736
            $1.nbits = $a(); //#26736
            var _3z = $strcpy($s(4), "0000"); //#26737
            var _42 = $cvrs($s(4), $1.aval, 2); //#26737
            $puti(_3z, 4 - _42.length, _42); //#26738
            $k[$j++] = _3z; //#26739
            $k[$j++] = Infinity; //#26739
            var _43 = $k[--$j]; //#26739
            var _44 = $k[--$j]; //#26739
            $k[$j++] = _43; //#26739
            $forall(_44, function() { //#26739
                var _45 = $k[--$j]; //#26739
                $k[$j++] = $f(_45 - 48); //#26739
            }); //#26739
            $1.abits = $a(); //#26739
            $k[$j++] = Infinity; //#26743
            $aload($1.cdf); //#26741
            $aload($1.nbits); //#26742
            $aload($1.abits); //#26743
            $1.cdf = $a(); //#26743
        } else { //#26757
            var _4C = $strcpy($s(10), "0000000000"); //#26746
            var _4F = $cvrs($s(10), $1.nval, 2); //#26746
            $puti(_4C, 10 - _4F.length, _4F); //#26747
            $k[$j++] = _4C; //#26748
            $k[$j++] = Infinity; //#26748
            var _4G = $k[--$j]; //#26748
            var _4H = $k[--$j]; //#26748
            $k[$j++] = _4G; //#26748
            $forall(_4H, function() { //#26748
                var _4I = $k[--$j]; //#26748
                $k[$j++] = $f(_4I - 48); //#26748
            }); //#26748
            $1.nbits = $a(); //#26748
            var _4L = $strcpy($s(5), "00000"); //#26749
            var _4Q = $cvrs($s(5), $f($get($1.ai90, $1.npre) - 65), 2); //#26749
            $puti(_4L, 5 - _4Q.length, _4Q); //#26750
            $k[$j++] = _4L; //#26751
            $k[$j++] = Infinity; //#26751
            var _4R = $k[--$j]; //#26751
            var _4S = $k[--$j]; //#26751
            $k[$j++] = _4R; //#26751
            $forall(_4S, function() { //#26751
                var _4T = $k[--$j]; //#26751
                $k[$j++] = $f(_4T - 48); //#26751
            }); //#26751
            $1.abits = $a(); //#26751
            $k[$j++] = Infinity; //#26756
            $aload($1.cdf); //#26753
            $k[$j++] = 1; //#26755
            $k[$j++] = 1; //#26755
            $k[$j++] = 1; //#26755
            $k[$j++] = 1; //#26755
            $k[$j++] = 1; //#26755
            $aload($1.nbits); //#26755
            $aload($1.abits); //#26756
            $1.cdf = $a(); //#26756
        } //#26757
        if ($ne($1.mode, "alpha")) { //#26775
            $k[$j++] = Infinity; //#26760
            $forall($1.ai90rem); //#26760
            if ($1.ais.length > 1) { //#26760
                $k[$j++] = $1.fnc1; //#26760
            } //#26760
            $1.gpf = $a(); //#26760
        } else { //#26775
            $k[$j++] = Infinity; //#26762
            $forall($1.ai90rem); //#26762
            if ($1.ais.length > 1) { //#26762
                $k[$j++] = $1.fnc1; //#26762
            } //#26762
            $1.in = $a(); //#26762
            $1.out = $a($1.in.length * 6); //#26763
            $1.j = 0; //#26764
            for (var _4m = 0, _4l = $1.in.length - 1; _4m <= _4l; _4m += 1) { //#26769
                var _4q = $get($1.alpha, $get($1.in, _4m)); //#26766
                $k[$j++] = _4q; //#26767
                $k[$j++] = _4q; //#26767
                $k[$j++] = Infinity; //#26767
                var _4r = $k[--$j]; //#26767
                var _4s = $k[--$j]; //#26767
                $k[$j++] = _4r; //#26767
                $forall(_4s, function() { //#26767
                    var _4t = $k[--$j]; //#26767
                    $k[$j++] = $f(_4t - 48); //#26767
                }); //#26767
                $puti($1.out, $1.j, $a()); //#26767
                $1.j = $k[--$j].length + $1.j; //#26768
            } //#26768
            $k[$j++] = Infinity; //#26772
            $aload($1.cdf); //#26771
            $aload($geti($1.out, 0, $1.j)); //#26772
            $1.cdf = $a(); //#26772
            $1.gpf = $a([]); //#26774
            if ($1.ais.length > 1) { //#26775
                $1.mode = "numeric"; //#26775
            } //#26775
        } //#26775
        $1.ais = $geti($1.ais, 1, $1.ais.length - 1); //#26777
        $1.vals = $geti($1.vals, 1, $1.vals.length - 1); //#26778
        $1.fncs = $geti($1.fncs, 1, $1.fncs.length - 1); //#26779
        if ($1.ais.length != 0) { //#26791
            if ($eq($1.ais1, "21") || $eq($1.ais1, "8004")) { //#26790
                $k[$j++] = Infinity; //#26784
                $aload($1.gpf); //#26783
                $forall($1.vals1); //#26784
                $1.gpf = $a(); //#26784
                $1.ais = $geti($1.ais, 1, $1.ais.length - 1); //#26786
                $1.vals = $geti($1.vals, 1, $1.vals.length - 1); //#26787
                $1.fncs = $geti($1.fncs, 1, $1.fncs.length - 1); //#26788
                if ($1.ais.length != 0) { //#26789
                    $k[$j++] = Infinity; //#26789
                    $aload($1.gpf); //#26789
                    $k[$j++] = $1.fnc1; //#26789
                    $1.gpf = $a(); //#26789
                } //#26789
            } //#26789
        } //#26789
    } //#26789
    if ($eq($1.method, "0")) { //#26798
        $1.cdf = $a([0]); //#26795
        $1.gpf = $a([]); //#26796
        $1.mode = "numeric"; //#26797
    } //#26797
    for (var _5d = 0, _5c = $1.ais.length - 1; _5d <= _5c; _5d += 1) { //#26816
        $1.i = _5d; //#26802
        $1.ai = $get($1.ais, $1.i); //#26803
        $1.val = $get($1.vals, $1.i); //#26804
        var _5n = $a(($1.gpf.length + $1.ai.length) + $1.val.length); //#26805
        $puti(_5n, 0, $1.gpf); //#26806
        $k[$j++] = _5n; //#26807
        $k[$j++] = _5n; //#26807
        $k[$j++] = $1.gpf.length; //#26807
        $k[$j++] = $1.ai; //#26807
        $k[$j++] = Infinity; //#26807
        var _5r = $k[--$j]; //#26807
        var _5s = $k[--$j]; //#26807
        $k[$j++] = _5r; //#26807
        $forall(_5s); //#26807
        var _5t = $a(); //#26807
        var _5u = $k[--$j]; //#26807
        $puti($k[--$j], _5u, _5t); //#26807
        var _5w = $k[--$j]; //#26808
        $k[$j++] = _5w; //#26808
        $k[$j++] = _5w; //#26808
        $k[$j++] = $1.gpf.length + $1.ai.length; //#26808
        $k[$j++] = $1.val; //#26808
        $k[$j++] = Infinity; //#26808
        var _60 = $k[--$j]; //#26808
        var _61 = $k[--$j]; //#26808
        $k[$j++] = _60; //#26808
        $forall(_61); //#26808
        var _62 = $a(); //#26808
        var _63 = $k[--$j]; //#26808
        $puti($k[--$j], _63, _62); //#26808
        $1.gpf = $k[--$j]; //#26809
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#26815
            var _6C = $a($1.gpf.length + 1); //#26811
            $puti(_6C, 0, $1.gpf); //#26812
            $put(_6C, $1.gpf.length, $1.fnc1); //#26813
            $1.gpf = _6C; //#26814
        } //#26814
    } //#26814
    var _6O = new Map([
        ["a", $a([$a([167, 138, 118, 108, 88, 78, 59]), $a([167, 138, 118, 98, 78]), $a([197, 167, 138, 108, 78])])],
        ["b", $a([$a([336, 296, 256, 208, 160, 104, 56]), $a([768, 648, 536, 416, 304, 208, 152, 112, 72, 32]), $a([1184, 1016, 840, 672, 496, 352, 264, 208, 152, 96, 56])])]
    ]); //#26829
    $1.bitcapsmaps = _6O; //#26831
    $1.rembits = function() {
        $1.used = $k[--$j]; //#26835
        if ($ne($1.ccversion, "c")) { //#26858
            $1.bitcaps = $get($get($1.bitcapsmaps, $1.ccversion), $f($1.cccolumns - 2)); //#26837
            $k[$j++] = -1; //#26838
            $forall($1.bitcaps, function() { //#26838
                var _6X = $k[--$j]; //#26838
                $k[$j++] = _6X; //#26838
                if ($ge(_6X, $1.used)) { //#26838
                    var _6Z = $k[--$j]; //#26838
                    var _6a = $k[--$j]; //#26838
                    $k[$j++] = _6Z; //#26838
                    $k[$j++] = _6a; //#26838
                } //#26838
                $j--; //#26838
            }); //#26838
            var _6b = $k[--$j]; //#26839
            $k[$j++] = _6b; //#26839
            if (_6b != -1) { //#26839
                var _6d = $k[--$j]; //#26839
                $k[$j++] = $f(_6d - $1.used); //#26839
            } //#26839
        } else { //#26858
            var _6e = new Map([
                ["c", -1]
            ]); //#26841
            var _6g = $get(_6e, $1.ccversion); //#26841
            var _6i = ~~Math.ceil($1.used / 8); //#26842
            $1.m = ((~~(_6i / 6)) * 5) + (_6i % 6); //#26842
            if ($1.m <= 40) { //#26843
                $k[$j++] = 8; //#26843
            } //#26843
            if (($1.m >= 41) && ($1.m <= 160)) { //#26844
                $k[$j++] = 16; //#26844
            } //#26844
            if (($1.m >= 161) && ($1.m <= 320)) { //#26845
                $k[$j++] = 32; //#26845
            } //#26845
            if (($1.m >= 321) && ($1.m <= 833)) { //#26846
                $k[$j++] = 64; //#26846
            } //#26846
            if ($1.m >= 834) { //#26847
                $k[$j++] = 32; //#26847
            } //#26847
            $1.eccws = $k[--$j]; //#26848
            $1.m = $f($f($1.m + $1.eccws) + 3); //#26849
            if ($1.cccolumns > 30) { //#26850
                $1.cccolumns = 30; //#26850
            } //#26850
            for (;;) { //#26854
                if (((~~Math.ceil($1.m / $1.cccolumns)) <= 30) || ($1.cccolumns >= 30)) { //#26852
                    break; //#26852
                } //#26852
                $1.cccolumns = $1.cccolumns + 1; //#26853
            } //#26853
            $1.r = ~~Math.ceil($1.m / $1.cccolumns); //#26855
            if ($1.r < 3) { //#26856
                $1.r = 3; //#26856
            } //#26856
            var _75 = $f(($f(($1.cccolumns * $1.r) - $1.eccws)) - 3); //#26857
            $1.tgt = ($f(((~~(_75 / 5)) * 6) + (_75 % 5))) * 8; //#26857
            if ($1.used <= 8304) { //#26858
                $k[$j++] = $f($1.tgt - $1.used); //#26858
            } else { //#26858
                $k[$j++] = -1; //#26858
            } //#26858
        } //#26858
        var _79 = $k[--$j]; //#26860
        $k[$j++] = _79; //#26873
        if (_79 == -1) { //#26873
            $j--; //#26861
            if ($eq($1.ccversion, "a")) { //#26869
                $1.ccversion = "b"; //#26863
            } else { //#26869
                if ($eq($1.ccversion, "b") && $eq($1.lintype, "gs1-128")) { //#26869
                    $1.ccversion = "c"; //#26866
                    $1.cccolumns = ~~(($1.linwidth - 52) / 17); //#26867
                } else { //#26869
                    $1.ccversion = -1; //#26869
                } //#26869
            } //#26869
            $k[$j++] = $1.used; //#26872
            $1.rembits(); //#26872
        } //#26872
    }; //#26872
    $1.encode = function() {
        var _7F = $k[--$j]; //#26877
        $k[$j++] = _7F; //#26877
        if ($ne(_7F, 'raw')) { //#26877
            var _7G = $k[--$j]; //#26877
            var _7I = $get(_7G, $k[--$j]); //#26877
            $k[$j++] = _7I; //#26877
        } else { //#26877
            $j--; //#26877
        } //#26877
        $k[$j++] = Infinity; //#26878
        var _7J = $k[--$j]; //#26878
        var _7K = $k[--$j]; //#26878
        $k[$j++] = _7J; //#26878
        $forall(_7K, function() { //#26878
            var _7L = $k[--$j]; //#26878
            $k[$j++] = $f(_7L - 48); //#26878
        }); //#26878
        var _7M = $a(); //#26878
        $puti($1.gpfenc, $1.j, _7M); //#26880
        $1.j = _7M.length + $1.j; //#26881
    }; //#26881
    $k[$j++] = Infinity; //#26885
    for (var _7R = 0, _7S = $1.gpf.length; _7R < _7S; _7R++) { //#26885
        $k[$j++] = 0; //#26885
    } //#26885
    $k[$j++] = 0; //#26885
    $k[$j++] = -1; //#26885
    $1.numericruns = $a(); //#26885
    $k[$j++] = Infinity; //#26886
    for (var _7V = 0, _7W = $1.gpf.length; _7V < _7W; _7V++) { //#26886
        $k[$j++] = 0; //#26886
    } //#26886
    $k[$j++] = 0; //#26886
    $1.alphanumericruns = $a(); //#26886
    $k[$j++] = Infinity; //#26887
    for (var _7Z = 0, _7a = $1.gpf.length; _7Z < _7a; _7Z++) { //#26887
        $k[$j++] = 0; //#26887
    } //#26887
    $k[$j++] = 9999; //#26887
    $1.nextiso646only = $a(); //#26887
    for (var _7d = $1.gpf.length - 1; _7d >= 0; _7d -= 1) { //#26909
        $1.i = _7d; //#26889
        var _7i = $strcpy($s(2), "00"); //#26891
        var _7l = $get($1.gpf, $1.i); //#26892
        $k[$j++] = $get($1.gpf, $1.i); //#26892
        $k[$j++] = _7i; //#26892
        $k[$j++] = _7i; //#26892
        $k[$j++] = 0; //#26892
        $k[$j++] = _7l; //#26892
        if (_7l == $1.fnc1) { //#26892
            $j--; //#26892
            $k[$j++] = 94; //#26892
        } //#26892
        var _7n = $k[--$j]; //#26892
        var _7o = $k[--$j]; //#26892
        $put($k[--$j], _7o, _7n); //#26892
        if ($1.i < ($1.gpf.length - 1)) { //#26893
            var _7s = $k[--$j]; //#26893
            var _7v = $get($1.gpf, $1.i + 1); //#26893
            $k[$j++] = _7s; //#26893
            $k[$j++] = _7s; //#26893
            $k[$j++] = 1; //#26893
            $k[$j++] = _7v; //#26893
            if (_7v == $1.fnc1) { //#26893
                $j--; //#26893
                $k[$j++] = 94; //#26893
            } //#26893
            var _7x = $k[--$j]; //#26893
            var _7y = $k[--$j]; //#26893
            $put($k[--$j], _7y, _7x); //#26893
        } //#26893
        var _82 = $get($1.numeric, $k[--$j]) !== undefined; //#26894
        if (_82) { //#26897
            $put($1.numericruns, $1.i, $f($get($1.numericruns, $1.i + 2) + 2)); //#26895
        } else { //#26897
            $put($1.numericruns, $1.i, 0); //#26897
        } //#26897
        var _8A = $k[--$j]; //#26899
        var _8C = $get($1.alphanumeric, _8A) !== undefined; //#26899
        $k[$j++] = _8A; //#26903
        if (_8C) { //#26902
            $put($1.alphanumericruns, $1.i, $f($get($1.alphanumericruns, $1.i + 1) + 1)); //#26900
        } else { //#26902
            $put($1.alphanumericruns, $1.i, 0); //#26902
        } //#26902
        var _8K = $k[--$j]; //#26904
        var _8M = $get($1.iso646, _8K) !== undefined; //#26904
        var _8O = $get($1.alphanumeric, _8K) !== undefined; //#26904
        if (_8M && (!_8O)) { //#26907
            $put($1.nextiso646only, $1.i, 0); //#26905
        } else { //#26907
            $put($1.nextiso646only, $1.i, $f($get($1.nextiso646only, $1.i + 1) + 1)); //#26907
        } //#26907
    } //#26907
    $1.gpfenc = $a(8304); //#26912
    $1.i = 0; //#26913
    $1.j = 0; //#26913
    for (;;) { //#27003
        if ($1.i == $1.gpf.length) { //#26915
            break; //#26915
        } //#26915
        for (;;) { //#27002
            if ($eq($1.mode, "numeric")) { //#26951
                if ($1.i <= ($1.gpf.length - 2)) { //#26948
                    var _8c = $s(2); //#26920
                    var _8f = $get($1.gpf, $1.i); //#26921
                    $k[$j++] = _8c; //#26921
                    $k[$j++] = _8c; //#26921
                    $k[$j++] = 0; //#26921
                    $k[$j++] = _8f; //#26921
                    if (_8f == $1.fnc1) { //#26921
                        $j--; //#26921
                        $k[$j++] = 94; //#26921
                    } //#26921
                    var _8h = $k[--$j]; //#26921
                    var _8i = $k[--$j]; //#26921
                    $put($k[--$j], _8i, _8h); //#26921
                    var _8k = $k[--$j]; //#26922
                    var _8n = $get($1.gpf, $1.i + 1); //#26922
                    $k[$j++] = _8k; //#26922
                    $k[$j++] = _8k; //#26922
                    $k[$j++] = 1; //#26922
                    $k[$j++] = _8n; //#26922
                    if (_8n == $1.fnc1) { //#26922
                        $j--; //#26922
                        $k[$j++] = 94; //#26922
                    } //#26922
                    var _8p = $k[--$j]; //#26922
                    var _8q = $k[--$j]; //#26922
                    $put($k[--$j], _8q, _8p); //#26922
                    var _8s = $k[--$j]; //#26923
                    var _8u = $get($1.numeric, _8s) !== undefined; //#26923
                    $k[$j++] = _8s; //#26927
                    if (_8u) { //#26927
                        $k[$j++] = $1.numeric; //#26924
                        $1.encode(); //#26924
                        $1.i = $1.i + 2; //#26925
                        break; //#26926
                    } //#26926
                    $j--; //#26928
                    $k[$j++] = $1.lalphanumeric; //#26929
                    $k[$j++] = $1.numeric; //#26929
                    $1.encode(); //#26929
                    $1.mode = "alphanumeric"; //#26930
                    break; //#26931
                } else { //#26948
                    var _91 = $get($1.gpf, $1.i); //#26933
                    if ((_91 < 48) || (_91 > 57)) { //#26937
                        $k[$j++] = $1.lalphanumeric; //#26934
                        $k[$j++] = $1.numeric; //#26934
                        $1.encode(); //#26934
                        $1.mode = "alphanumeric"; //#26935
                        break; //#26936
                    } //#26936
                    $k[$j++] = 'rem'; //#26938
                    $k[$j++] = $1.cdf.length + $1.j; //#26938
                    $1.rembits(); //#26938
                    var _96 = $k[--$j]; //#26938
                    $1[$k[--$j]] = _96; //#26938
                    if (($1.rem >= 4) && ($1.rem <= 6)) { //#26948
                        var _9D = $geti($strcpy($s(6), "000000"), 0, $1.rem); //#26940
                        var _9I = $cvrs($s(4), $f($get($1.gpf, $1.i) - 47), 2); //#26941
                        $puti(_9D, 4 - _9I.length, _9I); //#26942
                        $k[$j++] = _9D; //#26942
                        $k[$j++] = 'raw'; //#26942
                        $1.encode(); //#26942
                        $1.i = $1.i + 1; //#26943
                        break; //#26944
                    } else { //#26948
                        var _9K = $s(2); //#26946
                        $put(_9K, 0, $get($1.gpf, $1.i)); //#26946
                        $put(_9K, 1, 94); //#26946
                        $k[$j++] = _9K; //#26946
                        $k[$j++] = $1.numeric; //#26946
                        $1.encode(); //#26946
                        $1.i = $1.i + 1; //#26947
                        break; //#26948
                    } //#26948
                } //#26948
            } //#26948
            if ($eq($1.mode, "alphanumeric")) { //#26978
                if ($get($1.gpf, $1.i) == $1.fnc1) { //#26959
                    $k[$j++] = $1.fnc1; //#26955
                    $k[$j++] = $1.alphanumeric; //#26955
                    $1.encode(); //#26955
                    $1.mode = "numeric"; //#26956
                    $1.i = $1.i + 1; //#26957
                    break; //#26958
                } //#26958
                var _9a = $get($1.gpf, $1.i); //#26960
                var _9c = $get($1.iso646, _9a) !== undefined; //#26960
                var _9e = $get($1.alphanumeric, _9a) !== undefined; //#26960
                if (_9c && (!_9e)) { //#26964
                    $k[$j++] = $1.liso646; //#26961
                    $k[$j++] = $1.alphanumeric; //#26961
                    $1.encode(); //#26961
                    $1.mode = "iso646"; //#26962
                    break; //#26963
                } //#26963
                if ($get($1.numericruns, $1.i) >= 6) { //#26969
                    $k[$j++] = $1.lnumeric; //#26966
                    $k[$j++] = $1.alphanumeric; //#26966
                    $1.encode(); //#26966
                    $1.mode = "numeric"; //#26967
                    break; //#26968
                } //#26968
                var _9o = $get($1.numericruns, $1.i); //#26970
                if ((_9o >= 4) && ($f(_9o + $1.i) == $1.gpf.length)) { //#26974
                    $k[$j++] = $1.lnumeric; //#26971
                    $k[$j++] = $1.alphanumeric; //#26971
                    $1.encode(); //#26971
                    $1.mode = "numeric"; //#26972
                    break; //#26973
                } //#26973
                $k[$j++] = $get($1.gpf, $1.i); //#26975
                $k[$j++] = $1.alphanumeric; //#26975
                $1.encode(); //#26975
                $1.i = $1.i + 1; //#26976
                break; //#26977
            } //#26977
            if ($eq($1.mode, "iso646")) { //#27000
                if ($get($1.gpf, $1.i) == $1.fnc1) { //#26986
                    $k[$j++] = $1.fnc1; //#26982
                    $k[$j++] = $1.iso646; //#26982
                    $1.encode(); //#26982
                    $1.mode = "numeric"; //#26983
                    $1.i = $1.i + 1; //#26984
                    break; //#26985
                } //#26985
                if (($get($1.numericruns, $1.i) >= 4) && ($get($1.nextiso646only, $1.i) >= 10)) { //#26991
                    $k[$j++] = $1.lnumeric; //#26988
                    $k[$j++] = $1.iso646; //#26988
                    $1.encode(); //#26988
                    $1.mode = "numeric"; //#26989
                    break; //#26990
                } //#26990
                if (($get($1.alphanumericruns, $1.i) >= 5) && ($get($1.nextiso646only, $1.i) >= 10)) { //#26996
                    $k[$j++] = $1.lalphanumeric; //#26993
                    $k[$j++] = $1.iso646; //#26993
                    $1.encode(); //#26993
                    $1.mode = "alphanumeric"; //#26994
                    break; //#26995
                } //#26995
                $k[$j++] = $get($1.gpf, $1.i); //#26997
                $k[$j++] = $1.iso646; //#26997
                $1.encode(); //#26997
                $1.i = $1.i + 1; //#26998
                break; //#26999
            } //#26999
        } //#26999
    } //#26999
    $1.gpf = $geti($1.gpfenc, 0, $1.j); //#27004
    $k[$j++] = 'pad'; //#27007
    $k[$j++] = $1.cdf.length + $1.gpf.length; //#27007
    $1.rembits(); //#27007
    var _AX = $a($k[--$j]); //#27007
    $1[$k[--$j]] = _AX; //#27007
    if ($1.pad.length > 0) { //#27019
        for (var _Ac = 0, _Ab = $1.pad.length - 1; _Ac <= _Ab; _Ac += 5) { //#27012
            $1.i = _Ac; //#27010
            var _Ad = $1.pad; //#27011
            var _Ae = $1.i; //#27011
            var _Af = $a([0, 0, 1, 0, 0]); //#27011
            var _Ag = $1.pad; //#27011
            var _Ah = $1.i; //#27011
            var _Ai = 5; //#27011
            var _Aj = _Ag.length - _Ah; //#27011
            if ((_Ag.length - _Ah) > 5) { //#27011
                var _ = _Ai; //#27011
                _Ai = _Aj; //#27011
                _Aj = _; //#27011
            } //#27011
            $puti(_Ad, _Ae, $geti(_Af, 0, _Aj)); //#27011
        } //#27011
        if ($eq($1.mode, "numeric")) { //#27015
            $k[$j++] = Infinity; //#27014
            $k[$j++] = 0; //#27014
            $k[$j++] = 0; //#27014
            $k[$j++] = 0; //#27014
            $k[$j++] = 0; //#27014
            $aload($1.pad); //#27014
            $1.pad = $geti($a(), 0, $1.pad.length); //#27014
        } //#27014
        if ($eq($1.mode, "alpha")) { //#27018
            $k[$j++] = Infinity; //#27017
            $k[$j++] = 1; //#27017
            $k[$j++] = 1; //#27017
            $k[$j++] = 1; //#27017
            $k[$j++] = 1; //#27017
            $k[$j++] = 1; //#27017
            $k[$j++] = 0; //#27017
            $k[$j++] = 0; //#27017
            $k[$j++] = 0; //#27017
            $k[$j++] = 0; //#27017
            $aload($1.pad); //#27017
            $1.pad = $geti($a(), 0, $1.pad.length); //#27017
        } //#27017
    } //#27017
    $k[$j++] = Infinity; //#27025
    $aload($1.cdf); //#27023
    $aload($1.gpf); //#27024
    $aload($1.pad); //#27025
    $1.bits = $a(); //#27025
    $k[$j++] = Infinity; //#27031
    $k[$j++] = $a([0, 0, 0, 0, 0, 0, 1]); //#27031
    for (var _B0 = 0, _B1 = 68; _B0 < _B1; _B0++) { //#27031
        $k[$j++] = $a(7); //#27031
    } //#27031
    $1.pwr928 = $a(); //#27031
    for (var _B4 = 1; _B4 <= 68; _B4 += 1) { //#27042
        $1.j = _B4; //#27034
        $1.v = 0; //#27035
        for (var _B5 = 6; _B5 >= 1; _B5 -= 1) { //#27040
            $1.i = _B5; //#27037
            $1.v = $f(($get($get($1.pwr928, $1.j - 1), $1.i) * 2) + (~~($1.v / 928))); //#27038
            $put($get($1.pwr928, $1.j), $1.i, $1.v % 928); //#27039
        } //#27039
        $put($get($1.pwr928, $1.j), 0, $f(($get($get($1.pwr928, $1.j - 1), 0) * 2) + (~~($1.v / 928)))); //#27041
    } //#27041
    if ($1.ccversion == "a") { //#27085
        $k[$j++] = Infinity; //#27046
        for (var _BQ = 0, _BR = 28; _BQ < _BR; _BQ++) { //#27046
            $k[$j++] = 0; //#27046
        } //#27046
        $1.cws = $a(); //#27046
        $1.b = 0; //#27047
        $1.c = 0; //#27047
        for (;;) { //#27071
            if ($1.b == $1.bits.length) { //#27049
                break; //#27049
            } //#27049
            var _BV = $1.bits; //#27050
            var _BW = $1.b; //#27050
            var _BX = $1.bits; //#27050
            var _BY = $1.b; //#27050
            var _BZ = _BX.length - _BY; //#27050
            var _Ba = 69; //#27050
            if (69 > (_BX.length - _BY)) { //#27050
                var _ = _BZ; //#27050
                _BZ = _Ba; //#27050
                _Ba = _; //#27050
            } //#27050
            $1.bs = $geti(_BV, _BW, _Ba); //#27050
            $1.bsl = $1.bs.length; //#27051
            $1.cs = $geti($1.cws, $1.c, (~~($1.bsl / 10)) + 1); //#27052
            $1.csl = $1.cs.length; //#27053
            for (var _Bk = 0, _Bj = $1.bsl - 1; _Bk <= _Bj; _Bk += 1) { //#27063
                $1.i = _Bk; //#27055
                for (var _Bn = 0, _Bm = $1.csl - 1; _Bn <= _Bm; _Bn += 1) { //#27062
                    $1.j = _Bn; //#27057
                    var _Bo = $1.cs; //#27058
                    var _Bp = $1.j; //#27058
                    $put(_Bo, _Bp, $f($get(_Bo, _Bp) + ($get($get($1.pwr928, $1.i), ($1.j + 7) - $1.csl) * $get($1.bs, ($1.bsl - $1.i) - 1)))); //#27061
                } //#27061
            } //#27061
            for (var _C2 = $1.csl - 1; _C2 >= 1; _C2 -= 1) { //#27068
                $1.i = _C2; //#27065
                var _C3 = $1.cs; //#27066
                var _C4 = $1.i; //#27066
                $put(_C3, _C4 - 1, $f($get(_C3, _C4 - 1) + (~~($get($1.cs, $1.i) / 928)))); //#27066
                var _C9 = $1.cs; //#27067
                var _CA = $1.i; //#27067
                $put(_C9, _CA, $get(_C9, _CA) % 928); //#27067
            } //#27067
            $1.b = $1.b + $1.bsl; //#27069
            $1.c = $1.c + $1.csl; //#27070
        } //#27070
        $1.cws = $geti($1.cws, 0, $1.c); //#27072
        $1.barcode = $s($1.cws.length * 4); //#27073
        for (var _CN = 0, _CM = $1.cws.length - 1; _CN <= _CM; _CN += 1) { //#27079
            $1.i = _CN; //#27075
            var _CP = $strcpy($s(4), "^   "); //#27076
            var _CU = $cvrs($s(4), $get($1.cws, $1.i), 10); //#27076
            $puti(_CP, 4 - _CU.length, _CU); //#27077
            $puti($1.barcode, $1.i * 4, _CP); //#27078
        } //#27078
        delete $1.options["parse"]; //#27080
        $put($1.options, "dontdraw", true); //#27081
        $put($1.options, "cca", true); //#27082
        $put($1.options, "columns", $1.cccolumns); //#27083
        $k[$j++] = 'args'; //#27084
        $k[$j++] = $1.barcode; //#27084
        $k[$j++] = $1.options; //#27084
        bwipp_micropdf417(); //#27084
        var _Ce = $k[--$j]; //#27084
        $1[$k[--$j]] = _Ce; //#27084
    } //#27084
    if ($1.ccversion == "b") { //#27099
        $1.barcode = $s(~~($1.bits.length / 8)); //#27088
        for (var _Cl = 0, _Ck = $1.barcode.length - 1; _Cl <= _Ck; _Cl += 1) { //#27093
            $1.i = _Cl; //#27090
            var _Co = $geti($1.bits, $1.i * 8, 8); //#27091
            $k[$j++] = 0; //#27091
            for (var _Cp = 0, _Cq = _Co.length; _Cp < _Cq; _Cp++) { //#27091
                var _Cs = $k[--$j]; //#27091
                $k[$j++] = $f(_Cs + $get(_Co, _Cp)) * 2; //#27091
            } //#27091
            $put($1.barcode, $1.i, ~~($k[--$j] / 2)); //#27092
        } //#27092
        delete $1.options["parse"]; //#27094
        $put($1.options, "dontdraw", true); //#27095
        $put($1.options, "ccb", true); //#27096
        $put($1.options, "columns", $1.cccolumns); //#27097
        $k[$j++] = 'args'; //#27098
        $k[$j++] = $1.barcode; //#27098
        $k[$j++] = $1.options; //#27098
        bwipp_micropdf417(); //#27098
        var _D3 = $k[--$j]; //#27098
        $1[$k[--$j]] = _D3; //#27098
    } //#27098
    if ($1.ccversion == "c") { //#27114
        $1.barcode = $s(~~($1.bits.length / 8)); //#27102
        for (var _DA = 0, _D9 = $1.barcode.length - 1; _DA <= _D9; _DA += 1) { //#27107
            $1.i = _DA; //#27104
            var _DD = $geti($1.bits, $1.i * 8, 8); //#27105
            $k[$j++] = 0; //#27105
            for (var _DE = 0, _DF = _DD.length; _DE < _DF; _DE++) { //#27105
                var _DH = $k[--$j]; //#27105
                $k[$j++] = $f(_DH + $get(_DD, _DE)) * 2; //#27105
            } //#27105
            $put($1.barcode, $1.i, ~~($k[--$j] / 2)); //#27106
        } //#27106
        delete $1.options["parse"]; //#27108
        $put($1.options, "dontdraw", true); //#27109
        $put($1.options, "ccc", true); //#27110
        $put($1.options, "columns", $1.cccolumns); //#27111
        $put($1.options, "eclevel", (~~(Math.log($1.eccws) / Math.log(2))) - 1); //#27112
        $k[$j++] = 'args'; //#27113
        $k[$j++] = $1.barcode; //#27113
        $k[$j++] = $1.options; //#27113
        bwipp_pdf417(); //#27113
        var _DU = $k[--$j]; //#27113
        $1[$k[--$j]] = _DU; //#27113
    } //#27113
    $k[$j++] = $1.args; //#27117
    if (!$1.dontdraw) { //#27117
        bwipp_renmatrix(); //#27117
    } //#27117
}

function bwipp_ean13composite() {
    var $1 = {}; //#27153
    $1.ctx = null; //#27155
    $1.dontdraw = false; //#27156
    $1.usematrix = false; //#27157
    $1.parse = false; //#27158
    $1.dontlint = false; //#27159
    $1.lintreqs = true; //#27160
    $k[$j++] = $1; //#27162
    bwipp_processoptions(); //#27162
    $1.options = $k[--$j]; //#27162
    $1.barcode = $k[--$j]; //#27163
    if ($1.dontdraw) { //#27165
        $1.usematrix = true; //#27165
    } //#27165
    $search($1.barcode, "|"); //#27168
    if ($k[--$j]) { //#27173
        $1.linear = $k[--$j]; //#27169
        $j--; //#27170
        $1.comp = $k[--$j]; //#27171
    } else { //#27173
        $j--; //#27173
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27173
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27173
        bwipp_raiseerror(); //#27173
    } //#27173
    $put($1.options, "lintype", "ean13"); //#27176
    $put($1.options, "inkspread", "0"); //#27177
    $put($1.options, "dontdraw", true); //#27178
    $put($1.options, "dontlint", true); //#27179
    var _C = $s($1.comp.length + 18); //#27182
    $puti(_C, 0, "(01)00000000000000"); //#27183
    $puti(_C, 18, $1.comp); //#27184
    $k[$j++] = _C; //#27185
    $k[$j++] = 'ai'; //#27185
    bwipp_gs1process(); //#27185
    $j -= 3; //#27185
    $k[$j++] = $1.linear; //#27188
    $k[$j++] = $1.options; //#27188
    bwipp_ean13(); //#27188
    if (!$1.usematrix) { //#27278
        $$.save(); //#27190
        bwipp_renlinear(); //#27192
        $$.rmoveto(-1, 72); //#27195
        $k[$j++] = Infinity; //#27206
        $k[$j++] = Infinity; //#27200
        $k[$j++] = 0; //#27198
        $k[$j++] = 1; //#27198
        for (var _H = 0, _I = 93; _H < _I; _H++) { //#27198
            $k[$j++] = 0; //#27198
        } //#27198
        $k[$j++] = 1; //#27199
        $k[$j++] = 0; //#27199
        $k[$j++] = 1; //#27199
        $k[$j++] = 0; //#27199
        for (var _J = 0, _K = 93; _J < _K; _J++) { //#27199
            $k[$j++] = 0; //#27199
        } //#27199
        $k[$j++] = 0; //#27200
        $k[$j++] = 1; //#27200
        $k[$j++] = 0; //#27200
        $k[$j++] = 1; //#27200
        for (var _L = 0, _M = 93; _L < _M; _L++) { //#27200
            $k[$j++] = 0; //#27200
        } //#27200
        $k[$j++] = 1; //#27200
        $k[$j++] = 0; //#27200
        var _N = $a(); //#27200
        $k[$j++] = 'ren'; //#27206
        $k[$j++] = bwipp_renmatrix; //#27206
        $k[$j++] = 'pixs'; //#27206
        $k[$j++] = _N; //#27206
        $k[$j++] = 'pixx'; //#27206
        $k[$j++] = 97; //#27206
        $k[$j++] = 'pixy'; //#27206
        $k[$j++] = 3; //#27206
        $k[$j++] = 'height'; //#27206
        $k[$j++] = 6 / 72; //#27206
        $k[$j++] = 'width'; //#27206
        $k[$j++] = 97 / 72; //#27206
        $k[$j++] = 'opt'; //#27206
        $k[$j++] = $1.options; //#27206
        var _P = $d(); //#27206
        $k[$j++] = _P; //#27207
        bwipp_renmatrix(); //#27207
        $$.rmoveto(-2, 6); //#27210
        $k[$j++] = $1.comp; //#27210
        $k[$j++] = $1.options; //#27210
        bwipp_gs1_cc(); //#27210
        bwipp_renmatrix(); //#27210
        $$.restore(); //#27212
    } else { //#27278
        $1.linsym = $k[--$j]; //#27214
        $1.sbs = $get($1.linsym, 'sbs'); //#27215
        $1.bhs = $get($1.linsym, 'bhs'); //#27216
        $1.bbs = $get($1.linsym, 'bbs'); //#27217
        $k[$j++] = 'linwidth'; //#27218
        $k[$j++] = 0; //#27218
        $forall($1.sbs, function() { //#27218
            var _a = $k[--$j]; //#27218
            var _b = $k[--$j]; //#27218
            $k[$j++] = $f(_b + $cvi(_a)); //#27218
        }); //#27218
        var _c = $k[--$j]; //#27218
        $1[$k[--$j]] = _c; //#27218
        $k[$j++] = 'compsym'; //#27220
        $k[$j++] = $1.comp; //#27220
        $k[$j++] = $1.options; //#27220
        bwipp_gs1_cc(); //#27220
        var _g = $k[--$j]; //#27220
        $1[$k[--$j]] = _g; //#27220
        $1.ccpixs = $get($1.compsym, 'pixs'); //#27221
        $1.ccpixx = $get($1.compsym, 'pixx'); //#27222
        $k[$j++] = Infinity; //#27224
        for (var _n = 0, _o = $f($1.ccpixx - 97); _n < _o; _n++) { //#27224
            $k[$j++] = 0; //#27224
        } //#27224
        $1.linpad = $a(); //#27224
        $1.diff = $f(($f($f($1.linwidth + $1.linpad.length) + 2)) - $1.ccpixx); //#27226
        if ($1.diff > 0) { //#27232
            $k[$j++] = Infinity; //#27228
            for (var _v = 0, _w = $1.diff; _v < _w; _v++) { //#27228
                $k[$j++] = 0; //#27228
            } //#27228
            $1.ccrpad = $a(); //#27228
            $1.pixx = $f($1.ccpixx + $1.diff); //#27229
        } else { //#27232
            $1.ccrpad = $a(0); //#27231
            $1.pixx = $1.ccpixx; //#27232
        } //#27232
        $k[$j++] = Infinity; //#27260
        for (var _15 = 0, _16 = $1.ccpixx, _14 = $1.ccpixs.length - 1; _16 < 0 ? _15 >= _14 : _15 <= _14; _15 += _16) { //#27239
            $1.i = _15; //#27237
            for (var _17 = 0, _18 = 2; _17 < _18; _17++) { //#27238
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#27238
                $aload($1.ccrpad); //#27238
            } //#27238
        } //#27238
        for (var _1E = 0, _1F = 2; _1E < _1F; _1E++) { //#27240
            $aload($1.linpad); //#27240
            $k[$j++] = 0; //#27240
            $k[$j++] = 1; //#27240
            for (var _1H = 0, _1I = 93; _1H < _1I; _1H++) { //#27240
                $k[$j++] = 0; //#27240
            } //#27240
            $k[$j++] = 1; //#27240
            $k[$j++] = 0; //#27240
            $aload($1.ccrpad); //#27240
        } //#27240
        for (var _1K = 0, _1L = 2; _1K < _1L; _1K++) { //#27241
            $aload($1.linpad); //#27241
            $k[$j++] = 1; //#27241
            $k[$j++] = 0; //#27241
            for (var _1N = 0, _1O = 93; _1N < _1O; _1N++) { //#27241
                $k[$j++] = 0; //#27241
            } //#27241
            $k[$j++] = 0; //#27241
            $k[$j++] = 1; //#27241
            $aload($1.ccrpad); //#27241
        } //#27241
        for (var _1Q = 0, _1R = 2; _1Q < _1R; _1Q++) { //#27242
            $aload($1.linpad); //#27242
            $k[$j++] = 0; //#27242
            $k[$j++] = 1; //#27242
            for (var _1T = 0, _1U = 93; _1T < _1U; _1T++) { //#27242
                $k[$j++] = 0; //#27242
            } //#27242
            $k[$j++] = 1; //#27242
            $k[$j++] = 0; //#27242
            $aload($1.ccrpad); //#27242
        } //#27242
        for (var _1W = 71; _1W >= 0; _1W -= 1) { //#27261
            $1.y = _1W; //#27244
            $aload($1.linpad); //#27245
            $k[$j++] = 0; //#27259
            for (var _1a = 0, _1Z = $1.sbs.length - 1; _1a <= _1Z; _1a += 1) { //#27259
                $1.i = _1a; //#27248
                if (($1.i % 2) == 0) { //#27257
                    var _1f = $get($1.bbs, ~~($1.i / 2)) * 72; //#27251
                    if ((_1f > $1.y) || (($f(_1f + ($get($1.bhs, ~~($1.i / 2)) * 72))) < $1.y)) { //#27254
                        for (var _1o = 0, _1p = $cvi($get($1.sbs, $1.i)); _1o < _1p; _1o++) { //#27252
                            $k[$j++] = 0; //#27252
                        } //#27252
                    } else { //#27254
                        for (var _1t = 0, _1u = $cvi($get($1.sbs, $1.i)); _1t < _1u; _1t++) { //#27254
                            $k[$j++] = 1; //#27254
                        } //#27254
                    } //#27254
                } else { //#27257
                    for (var _1y = 0, _1z = $cvi($get($1.sbs, $1.i)); _1y < _1z; _1y++) { //#27257
                        $k[$j++] = 0; //#27257
                    } //#27257
                } //#27257
            } //#27257
            $k[$j++] = 0; //#27260
        } //#27260
        $1.pixs = $a(); //#27260
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#27264
        var _29 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#27272
        $k[$j++] = _29; //#27279
        if (!$1.dontdraw) { //#27279
            $$.save(); //#27276
            bwipp_renmatrix(); //#27277
            $$.restore(); //#27278
        } //#27278
    } //#27278
}

function bwipp_ean8composite() {
    var $1 = {}; //#27314
    $1.ctx = null; //#27316
    $1.dontdraw = false; //#27317
    $1.usematrix = false; //#27318
    $1.parse = false; //#27319
    $1.dontlint = false; //#27320
    $1.lintreqs = true; //#27321
    $k[$j++] = $1; //#27323
    bwipp_processoptions(); //#27323
    $1.options = $k[--$j]; //#27323
    $1.barcode = $k[--$j]; //#27324
    if ($1.dontdraw) { //#27326
        $1.usematrix = true; //#27326
    } //#27326
    $search($1.barcode, "|"); //#27329
    if ($k[--$j]) { //#27334
        $1.linear = $k[--$j]; //#27330
        $j--; //#27331
        $1.comp = $k[--$j]; //#27332
    } else { //#27334
        $j--; //#27334
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27334
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27334
        bwipp_raiseerror(); //#27334
    } //#27334
    $put($1.options, "lintype", "ean8"); //#27338
    $put($1.options, "inkspread", "0"); //#27339
    $put($1.options, "dontdraw", true); //#27340
    $put($1.options, "dontlint", true); //#27341
    var _C = $s($1.comp.length + 18); //#27344
    $puti(_C, 0, "(01)00000000000000"); //#27345
    $puti(_C, 18, $1.comp); //#27346
    $k[$j++] = _C; //#27347
    $k[$j++] = 'ai'; //#27347
    bwipp_gs1process(); //#27347
    $j -= 3; //#27347
    $k[$j++] = $1.linear; //#27350
    $k[$j++] = $1.options; //#27350
    bwipp_ean8(); //#27350
    if (!$1.usematrix) { //#27442
        $$.save(); //#27352
        bwipp_renlinear(); //#27354
        $$.rmoveto(-1, 72); //#27357
        $k[$j++] = Infinity; //#27368
        $k[$j++] = Infinity; //#27362
        $k[$j++] = 0; //#27360
        $k[$j++] = 1; //#27360
        for (var _H = 0, _I = 65; _H < _I; _H++) { //#27360
            $k[$j++] = 0; //#27360
        } //#27360
        $k[$j++] = 1; //#27361
        $k[$j++] = 0; //#27361
        $k[$j++] = 1; //#27361
        $k[$j++] = 0; //#27361
        for (var _J = 0, _K = 65; _J < _K; _J++) { //#27361
            $k[$j++] = 0; //#27361
        } //#27361
        $k[$j++] = 0; //#27362
        $k[$j++] = 1; //#27362
        $k[$j++] = 0; //#27362
        $k[$j++] = 1; //#27362
        for (var _L = 0, _M = 65; _L < _M; _L++) { //#27362
            $k[$j++] = 0; //#27362
        } //#27362
        $k[$j++] = 1; //#27362
        $k[$j++] = 0; //#27362
        var _N = $a(); //#27362
        $k[$j++] = 'ren'; //#27368
        $k[$j++] = bwipp_renmatrix; //#27368
        $k[$j++] = 'pixs'; //#27368
        $k[$j++] = _N; //#27368
        $k[$j++] = 'pixx'; //#27368
        $k[$j++] = 69; //#27368
        $k[$j++] = 'pixy'; //#27368
        $k[$j++] = 3; //#27368
        $k[$j++] = 'height'; //#27368
        $k[$j++] = 6 / 72; //#27368
        $k[$j++] = 'width'; //#27368
        $k[$j++] = 69 / 72; //#27368
        $k[$j++] = 'opt'; //#27368
        $k[$j++] = $1.options; //#27368
        var _P = $d(); //#27368
        $k[$j++] = _P; //#27369
        bwipp_renmatrix(); //#27369
        $k[$j++] = $1.comp; //#27372
        $k[$j++] = $1.options; //#27372
        bwipp_gs1_cc(); //#27372
        var _S = $k[--$j]; //#27373
        $$.rmoveto($f(69 - $get(_S, "pixx")), 6); //#27373
        $k[$j++] = _S; //#27374
        bwipp_renmatrix(); //#27374
        $$.restore(); //#27376
    } else { //#27442
        $1.linsym = $k[--$j]; //#27378
        $1.sbs = $get($1.linsym, 'sbs'); //#27379
        $1.bhs = $get($1.linsym, 'bhs'); //#27380
        $1.bbs = $get($1.linsym, 'bbs'); //#27381
        $k[$j++] = 'linwidth'; //#27382
        $k[$j++] = 0; //#27382
        $forall($1.sbs, function() { //#27382
            var _c = $k[--$j]; //#27382
            var _d = $k[--$j]; //#27382
            $k[$j++] = $f(_d + $cvi(_c)); //#27382
        }); //#27382
        var _e = $k[--$j]; //#27382
        $1[$k[--$j]] = _e; //#27382
        var _g = $1.comp; //#27384
        $k[$j++] = 'compsym'; //#27384
        $k[$j++] = _g; //#27384
        $k[$j++] = $1.options; //#27384
        bwipp_gs1_cc(); //#27384
        var _i = $k[--$j]; //#27384
        $1[$k[--$j]] = _i; //#27384
        $1.ccpixs = $get($1.compsym, 'pixs'); //#27385
        $1.ccpixx = $get($1.compsym, 'pixx'); //#27386
        $k[$j++] = Infinity; //#27388
        for (var _p = 0, _q = $f($1.ccpixx - 69); _p < _q; _p++) { //#27388
            $k[$j++] = 0; //#27388
        } //#27388
        $1.linpad = $a(); //#27388
        $1.diff = $f(($f($f($1.linwidth + $1.linpad.length) + 2)) - $1.ccpixx); //#27390
        if ($1.diff > 0) { //#27396
            $k[$j++] = Infinity; //#27392
            for (var _x = 0, _y = $1.diff; _x < _y; _x++) { //#27392
                $k[$j++] = 0; //#27392
            } //#27392
            $1.ccrpad = $a(); //#27392
            $1.pixx = $f($1.ccpixx + $1.diff); //#27393
        } else { //#27396
            $1.ccrpad = $a(0); //#27395
            $1.pixx = $1.ccpixx; //#27396
        } //#27396
        $k[$j++] = Infinity; //#27424
        for (var _17 = 0, _18 = $1.ccpixx, _16 = $1.ccpixs.length - 1; _18 < 0 ? _17 >= _16 : _17 <= _16; _17 += _18) { //#27403
            $1.i = _17; //#27401
            for (var _19 = 0, _1A = 2; _19 < _1A; _19++) { //#27402
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#27402
                $aload($1.ccrpad); //#27402
            } //#27402
        } //#27402
        for (var _1G = 0, _1H = 2; _1G < _1H; _1G++) { //#27404
            $aload($1.linpad); //#27404
            $k[$j++] = 0; //#27404
            $k[$j++] = 1; //#27404
            for (var _1J = 0, _1K = 65; _1J < _1K; _1J++) { //#27404
                $k[$j++] = 0; //#27404
            } //#27404
            $k[$j++] = 1; //#27404
            $k[$j++] = 0; //#27404
            $aload($1.ccrpad); //#27404
        } //#27404
        for (var _1M = 0, _1N = 2; _1M < _1N; _1M++) { //#27405
            $aload($1.linpad); //#27405
            $k[$j++] = 1; //#27405
            $k[$j++] = 0; //#27405
            for (var _1P = 0, _1Q = 65; _1P < _1Q; _1P++) { //#27405
                $k[$j++] = 0; //#27405
            } //#27405
            $k[$j++] = 0; //#27405
            $k[$j++] = 1; //#27405
            $aload($1.ccrpad); //#27405
        } //#27405
        for (var _1S = 0, _1T = 2; _1S < _1T; _1S++) { //#27406
            $aload($1.linpad); //#27406
            $k[$j++] = 0; //#27406
            $k[$j++] = 1; //#27406
            for (var _1V = 0, _1W = 65; _1V < _1W; _1V++) { //#27406
                $k[$j++] = 0; //#27406
            } //#27406
            $k[$j++] = 1; //#27406
            $k[$j++] = 0; //#27406
            $aload($1.ccrpad); //#27406
        } //#27406
        for (var _1Y = 71; _1Y >= 0; _1Y -= 1) { //#27425
            $1.y = _1Y; //#27408
            $aload($1.linpad); //#27409
            $k[$j++] = 0; //#27423
            for (var _1c = 0, _1b = $1.sbs.length - 1; _1c <= _1b; _1c += 1) { //#27423
                $1.i = _1c; //#27412
                if (($1.i % 2) == 0) { //#27421
                    var _1h = $get($1.bbs, ~~($1.i / 2)) * 72; //#27415
                    if ((_1h > $1.y) || (($f(_1h + ($get($1.bhs, ~~($1.i / 2)) * 72))) < $1.y)) { //#27418
                        for (var _1q = 0, _1r = $cvi($get($1.sbs, $1.i)); _1q < _1r; _1q++) { //#27416
                            $k[$j++] = 0; //#27416
                        } //#27416
                    } else { //#27418
                        for (var _1v = 0, _1w = $cvi($get($1.sbs, $1.i)); _1v < _1w; _1v++) { //#27418
                            $k[$j++] = 1; //#27418
                        } //#27418
                    } //#27418
                } else { //#27421
                    for (var _20 = 0, _21 = $cvi($get($1.sbs, $1.i)); _20 < _21; _20++) { //#27421
                        $k[$j++] = 0; //#27421
                    } //#27421
                } //#27421
            } //#27421
            $k[$j++] = 0; //#27424
        } //#27424
        $1.pixs = $a(); //#27424
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#27428
        var _2B = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#27436
        $k[$j++] = _2B; //#27443
        if (!$1.dontdraw) { //#27443
            $$.save(); //#27440
            bwipp_renmatrix(); //#27441
            $$.restore(); //#27442
        } //#27442
    } //#27442
}

function bwipp_upcacomposite() {
    var $1 = {}; //#27478
    $1.ctx = null; //#27480
    $1.dontdraw = false; //#27481
    $1.usematrix = false; //#27482
    $1.parse = false; //#27483
    $1.dontlint = false; //#27484
    $1.lintreqs = true; //#27485
    $k[$j++] = $1; //#27487
    bwipp_processoptions(); //#27487
    $1.options = $k[--$j]; //#27487
    $1.barcode = $k[--$j]; //#27488
    if ($1.dontdraw) { //#27490
        $1.usematrix = true; //#27490
    } //#27490
    $search($1.barcode, "|"); //#27493
    if ($k[--$j]) { //#27498
        $1.linear = $k[--$j]; //#27494
        $j--; //#27495
        $1.comp = $k[--$j]; //#27496
    } else { //#27498
        $j--; //#27498
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27498
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27498
        bwipp_raiseerror(); //#27498
    } //#27498
    $put($1.options, "lintype", "ean13"); //#27501
    $put($1.options, "inkspread", "0"); //#27502
    $put($1.options, "dontdraw", true); //#27503
    $put($1.options, "dontlint", true); //#27504
    var _C = $s($1.comp.length + 18); //#27507
    $puti(_C, 0, "(01)00000000000000"); //#27508
    $puti(_C, 18, $1.comp); //#27509
    $k[$j++] = _C; //#27510
    $k[$j++] = 'ai'; //#27510
    bwipp_gs1process(); //#27510
    $j -= 3; //#27510
    $k[$j++] = $1.linear; //#27513
    $k[$j++] = $1.options; //#27513
    bwipp_upca(); //#27513
    if (!$1.usematrix) { //#27603
        $$.save(); //#27515
        bwipp_renlinear(); //#27517
        $$.rmoveto(-1, 72); //#27520
        $k[$j++] = Infinity; //#27531
        $k[$j++] = Infinity; //#27525
        $k[$j++] = 0; //#27523
        $k[$j++] = 1; //#27523
        for (var _H = 0, _I = 93; _H < _I; _H++) { //#27523
            $k[$j++] = 0; //#27523
        } //#27523
        $k[$j++] = 1; //#27524
        $k[$j++] = 0; //#27524
        $k[$j++] = 1; //#27524
        $k[$j++] = 0; //#27524
        for (var _J = 0, _K = 93; _J < _K; _J++) { //#27524
            $k[$j++] = 0; //#27524
        } //#27524
        $k[$j++] = 0; //#27525
        $k[$j++] = 1; //#27525
        $k[$j++] = 0; //#27525
        $k[$j++] = 1; //#27525
        for (var _L = 0, _M = 93; _L < _M; _L++) { //#27525
            $k[$j++] = 0; //#27525
        } //#27525
        $k[$j++] = 1; //#27525
        $k[$j++] = 0; //#27525
        var _N = $a(); //#27525
        $k[$j++] = 'ren'; //#27531
        $k[$j++] = bwipp_renmatrix; //#27531
        $k[$j++] = 'pixs'; //#27531
        $k[$j++] = _N; //#27531
        $k[$j++] = 'pixx'; //#27531
        $k[$j++] = 97; //#27531
        $k[$j++] = 'pixy'; //#27531
        $k[$j++] = 3; //#27531
        $k[$j++] = 'height'; //#27531
        $k[$j++] = 6 / 72; //#27531
        $k[$j++] = 'width'; //#27531
        $k[$j++] = 97 / 72; //#27531
        $k[$j++] = 'opt'; //#27531
        $k[$j++] = $1.options; //#27531
        var _P = $d(); //#27531
        $k[$j++] = _P; //#27532
        bwipp_renmatrix(); //#27532
        $$.rmoveto(-2, 6); //#27535
        $k[$j++] = $1.comp; //#27535
        $k[$j++] = $1.options; //#27535
        bwipp_gs1_cc(); //#27535
        bwipp_renmatrix(); //#27535
        $$.restore(); //#27537
    } else { //#27603
        $1.linsym = $k[--$j]; //#27539
        $1.sbs = $get($1.linsym, 'sbs'); //#27540
        $1.bhs = $get($1.linsym, 'bhs'); //#27541
        $1.bbs = $get($1.linsym, 'bbs'); //#27542
        $k[$j++] = 'linwidth'; //#27543
        $k[$j++] = 0; //#27543
        $forall($1.sbs, function() { //#27543
            var _a = $k[--$j]; //#27543
            var _b = $k[--$j]; //#27543
            $k[$j++] = $f(_b + $cvi(_a)); //#27543
        }); //#27543
        var _c = $k[--$j]; //#27543
        $1[$k[--$j]] = _c; //#27543
        $k[$j++] = 'compsym'; //#27545
        $k[$j++] = $1.comp; //#27545
        $k[$j++] = $1.options; //#27545
        bwipp_gs1_cc(); //#27545
        var _g = $k[--$j]; //#27545
        $1[$k[--$j]] = _g; //#27545
        $1.ccpixs = $get($1.compsym, 'pixs'); //#27546
        $1.ccpixx = $get($1.compsym, 'pixx'); //#27547
        $k[$j++] = Infinity; //#27549
        for (var _n = 0, _o = $f($1.ccpixx - 97); _n < _o; _n++) { //#27549
            $k[$j++] = 0; //#27549
        } //#27549
        $1.linpad = $a(); //#27549
        $1.diff = $f(($f($f($1.linwidth + $1.linpad.length) + 2)) - $1.ccpixx); //#27551
        if ($1.diff > 0) { //#27557
            $k[$j++] = Infinity; //#27553
            for (var _v = 0, _w = $1.diff; _v < _w; _v++) { //#27553
                $k[$j++] = 0; //#27553
            } //#27553
            $1.ccrpad = $a(); //#27553
            $1.pixx = $f($1.ccpixx + $1.diff); //#27554
        } else { //#27557
            $1.ccrpad = $a(0); //#27556
            $1.pixx = $1.ccpixx; //#27557
        } //#27557
        $k[$j++] = Infinity; //#27585
        for (var _15 = 0, _16 = $1.ccpixx, _14 = $1.ccpixs.length - 1; _16 < 0 ? _15 >= _14 : _15 <= _14; _15 += _16) { //#27564
            $1.i = _15; //#27562
            for (var _17 = 0, _18 = 2; _17 < _18; _17++) { //#27563
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#27563
                $aload($1.ccrpad); //#27563
            } //#27563
        } //#27563
        for (var _1E = 0, _1F = 2; _1E < _1F; _1E++) { //#27565
            $aload($1.linpad); //#27565
            $k[$j++] = 0; //#27565
            $k[$j++] = 1; //#27565
            for (var _1H = 0, _1I = 93; _1H < _1I; _1H++) { //#27565
                $k[$j++] = 0; //#27565
            } //#27565
            $k[$j++] = 1; //#27565
            $k[$j++] = 0; //#27565
            $aload($1.ccrpad); //#27565
        } //#27565
        for (var _1K = 0, _1L = 2; _1K < _1L; _1K++) { //#27566
            $aload($1.linpad); //#27566
            $k[$j++] = 1; //#27566
            $k[$j++] = 0; //#27566
            for (var _1N = 0, _1O = 93; _1N < _1O; _1N++) { //#27566
                $k[$j++] = 0; //#27566
            } //#27566
            $k[$j++] = 0; //#27566
            $k[$j++] = 1; //#27566
            $aload($1.ccrpad); //#27566
        } //#27566
        for (var _1Q = 0, _1R = 2; _1Q < _1R; _1Q++) { //#27567
            $aload($1.linpad); //#27567
            $k[$j++] = 0; //#27567
            $k[$j++] = 1; //#27567
            for (var _1T = 0, _1U = 93; _1T < _1U; _1T++) { //#27567
                $k[$j++] = 0; //#27567
            } //#27567
            $k[$j++] = 1; //#27567
            $k[$j++] = 0; //#27567
            $aload($1.ccrpad); //#27567
        } //#27567
        for (var _1W = 71; _1W >= 0; _1W -= 1) { //#27586
            $1.y = _1W; //#27569
            $aload($1.linpad); //#27570
            $k[$j++] = 0; //#27584
            for (var _1a = 0, _1Z = $1.sbs.length - 1; _1a <= _1Z; _1a += 1) { //#27584
                $1.i = _1a; //#27573
                if (($1.i % 2) == 0) { //#27582
                    var _1f = $get($1.bbs, ~~($1.i / 2)) * 72; //#27576
                    if ((_1f > $1.y) || (($f(_1f + ($get($1.bhs, ~~($1.i / 2)) * 72))) < $1.y)) { //#27579
                        for (var _1o = 0, _1p = $cvi($get($1.sbs, $1.i)); _1o < _1p; _1o++) { //#27577
                            $k[$j++] = 0; //#27577
                        } //#27577
                    } else { //#27579
                        for (var _1t = 0, _1u = $cvi($get($1.sbs, $1.i)); _1t < _1u; _1t++) { //#27579
                            $k[$j++] = 1; //#27579
                        } //#27579
                    } //#27579
                } else { //#27582
                    for (var _1y = 0, _1z = $cvi($get($1.sbs, $1.i)); _1y < _1z; _1y++) { //#27582
                        $k[$j++] = 0; //#27582
                    } //#27582
                } //#27582
            } //#27582
            $k[$j++] = 0; //#27585
        } //#27585
        $1.pixs = $a(); //#27585
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#27589
        var _29 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#27597
        $k[$j++] = _29; //#27604
        if (!$1.dontdraw) { //#27604
            $$.save(); //#27601
            bwipp_renmatrix(); //#27602
            $$.restore(); //#27603
        } //#27603
    } //#27603
}

function bwipp_upcecomposite() {
    var $1 = {}; //#27639
    $1.ctx = null; //#27641
    $1.dontdraw = false; //#27642
    $1.usematrix = false; //#27643
    $1.parse = false; //#27644
    $1.dontlint = false; //#27645
    $1.lintreqs = true; //#27646
    $k[$j++] = $1; //#27648
    bwipp_processoptions(); //#27648
    $1.options = $k[--$j]; //#27648
    $1.barcode = $k[--$j]; //#27649
    if ($1.dontdraw) { //#27651
        $1.usematrix = true; //#27651
    } //#27651
    $search($1.barcode, "|"); //#27654
    if ($k[--$j]) { //#27659
        $1.linear = $k[--$j]; //#27655
        $j--; //#27656
        $1.comp = $k[--$j]; //#27657
    } else { //#27659
        $j--; //#27659
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27659
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27659
        bwipp_raiseerror(); //#27659
    } //#27659
    $put($1.options, "lintype", "upce"); //#27662
    $put($1.options, "inkspread", "0"); //#27663
    $put($1.options, "dontdraw", true); //#27664
    $put($1.options, "dontlint", true); //#27665
    var _C = $s($1.comp.length + 18); //#27668
    $puti(_C, 0, "(01)00000000000000"); //#27669
    $puti(_C, 18, $1.comp); //#27670
    $k[$j++] = _C; //#27671
    $k[$j++] = 'ai'; //#27671
    bwipp_gs1process(); //#27671
    $j -= 3; //#27671
    $k[$j++] = $1.linear; //#27674
    $k[$j++] = $1.options; //#27674
    bwipp_upce(); //#27674
    if (!$1.usematrix) { //#27764
        $$.save(); //#27676
        bwipp_renlinear(); //#27678
        $$.rmoveto(-1, 72); //#27681
        $k[$j++] = Infinity; //#27692
        $k[$j++] = Infinity; //#27686
        $k[$j++] = 0; //#27684
        $k[$j++] = 1; //#27684
        for (var _H = 0, _I = 49; _H < _I; _H++) { //#27684
            $k[$j++] = 0; //#27684
        } //#27684
        $k[$j++] = 1; //#27685
        $k[$j++] = 0; //#27685
        $k[$j++] = 1; //#27685
        $k[$j++] = 0; //#27685
        for (var _J = 0, _K = 49; _J < _K; _J++) { //#27685
            $k[$j++] = 0; //#27685
        } //#27685
        $k[$j++] = 0; //#27686
        $k[$j++] = 1; //#27686
        $k[$j++] = 0; //#27686
        $k[$j++] = 1; //#27686
        for (var _L = 0, _M = 49; _L < _M; _L++) { //#27686
            $k[$j++] = 0; //#27686
        } //#27686
        $k[$j++] = 1; //#27686
        $k[$j++] = 0; //#27686
        var _N = $a(); //#27686
        $k[$j++] = 'ren'; //#27692
        $k[$j++] = bwipp_renmatrix; //#27692
        $k[$j++] = 'pixs'; //#27692
        $k[$j++] = _N; //#27692
        $k[$j++] = 'pixx'; //#27692
        $k[$j++] = 53; //#27692
        $k[$j++] = 'pixy'; //#27692
        $k[$j++] = 3; //#27692
        $k[$j++] = 'height'; //#27692
        $k[$j++] = 6 / 72; //#27692
        $k[$j++] = 'width'; //#27692
        $k[$j++] = 53 / 72; //#27692
        $k[$j++] = 'opt'; //#27692
        $k[$j++] = $1.options; //#27692
        var _P = $d(); //#27692
        $k[$j++] = _P; //#27693
        bwipp_renmatrix(); //#27693
        $$.rmoveto(-2, 6); //#27696
        $k[$j++] = $1.comp; //#27696
        $k[$j++] = $1.options; //#27696
        bwipp_gs1_cc(); //#27696
        bwipp_renmatrix(); //#27696
        $$.restore(); //#27698
    } else { //#27764
        $1.linsym = $k[--$j]; //#27700
        $1.sbs = $get($1.linsym, 'sbs'); //#27701
        $1.bhs = $get($1.linsym, 'bhs'); //#27702
        $1.bbs = $get($1.linsym, 'bbs'); //#27703
        $k[$j++] = 'linwidth'; //#27704
        $k[$j++] = 0; //#27704
        $forall($1.sbs, function() { //#27704
            var _a = $k[--$j]; //#27704
            var _b = $k[--$j]; //#27704
            $k[$j++] = $f(_b + $cvi(_a)); //#27704
        }); //#27704
        var _c = $k[--$j]; //#27704
        $1[$k[--$j]] = _c; //#27704
        $k[$j++] = 'compsym'; //#27706
        $k[$j++] = $1.comp; //#27706
        $k[$j++] = $1.options; //#27706
        bwipp_gs1_cc(); //#27706
        var _g = $k[--$j]; //#27706
        $1[$k[--$j]] = _g; //#27706
        $1.ccpixs = $get($1.compsym, 'pixs'); //#27707
        $1.ccpixx = $get($1.compsym, 'pixx'); //#27708
        $k[$j++] = Infinity; //#27710
        for (var _n = 0, _o = $f($1.ccpixx - 53); _n < _o; _n++) { //#27710
            $k[$j++] = 0; //#27710
        } //#27710
        $1.linpad = $a(); //#27710
        $1.diff = $f(($f($f($1.linwidth + $1.linpad.length) + 2)) - $1.ccpixx); //#27712
        if ($1.diff > 0) { //#27718
            $k[$j++] = Infinity; //#27714
            for (var _v = 0, _w = $1.diff; _v < _w; _v++) { //#27714
                $k[$j++] = 0; //#27714
            } //#27714
            $1.ccrpad = $a(); //#27714
            $1.pixx = $f($1.ccpixx + $1.diff); //#27715
        } else { //#27718
            $1.ccrpad = $a(0); //#27717
            $1.pixx = $1.ccpixx; //#27718
        } //#27718
        $k[$j++] = Infinity; //#27746
        for (var _15 = 0, _16 = $1.ccpixx, _14 = $1.ccpixs.length - 1; _16 < 0 ? _15 >= _14 : _15 <= _14; _15 += _16) { //#27725
            $1.i = _15; //#27723
            for (var _17 = 0, _18 = 2; _17 < _18; _17++) { //#27724
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#27724
                $aload($1.ccrpad); //#27724
            } //#27724
        } //#27724
        for (var _1E = 0, _1F = 2; _1E < _1F; _1E++) { //#27726
            $aload($1.linpad); //#27726
            $k[$j++] = 0; //#27726
            $k[$j++] = 1; //#27726
            for (var _1H = 0, _1I = 49; _1H < _1I; _1H++) { //#27726
                $k[$j++] = 0; //#27726
            } //#27726
            $k[$j++] = 1; //#27726
            $k[$j++] = 0; //#27726
            $aload($1.ccrpad); //#27726
        } //#27726
        for (var _1K = 0, _1L = 2; _1K < _1L; _1K++) { //#27727
            $aload($1.linpad); //#27727
            $k[$j++] = 1; //#27727
            $k[$j++] = 0; //#27727
            for (var _1N = 0, _1O = 49; _1N < _1O; _1N++) { //#27727
                $k[$j++] = 0; //#27727
            } //#27727
            $k[$j++] = 0; //#27727
            $k[$j++] = 1; //#27727
            $aload($1.ccrpad); //#27727
        } //#27727
        for (var _1Q = 0, _1R = 2; _1Q < _1R; _1Q++) { //#27728
            $aload($1.linpad); //#27728
            $k[$j++] = 0; //#27728
            $k[$j++] = 1; //#27728
            for (var _1T = 0, _1U = 49; _1T < _1U; _1T++) { //#27728
                $k[$j++] = 0; //#27728
            } //#27728
            $k[$j++] = 1; //#27728
            $k[$j++] = 0; //#27728
            $aload($1.ccrpad); //#27728
        } //#27728
        for (var _1W = 71; _1W >= 0; _1W -= 1) { //#27747
            $1.y = _1W; //#27730
            $aload($1.linpad); //#27731
            $k[$j++] = 0; //#27745
            for (var _1a = 0, _1Z = $1.sbs.length - 1; _1a <= _1Z; _1a += 1) { //#27745
                $1.i = _1a; //#27734
                if (($1.i % 2) == 0) { //#27743
                    var _1f = $get($1.bbs, ~~($1.i / 2)) * 72; //#27737
                    if ((_1f > $1.y) || (($f(_1f + ($get($1.bhs, ~~($1.i / 2)) * 72))) < $1.y)) { //#27740
                        for (var _1o = 0, _1p = $cvi($get($1.sbs, $1.i)); _1o < _1p; _1o++) { //#27738
                            $k[$j++] = 0; //#27738
                        } //#27738
                    } else { //#27740
                        for (var _1t = 0, _1u = $cvi($get($1.sbs, $1.i)); _1t < _1u; _1t++) { //#27740
                            $k[$j++] = 1; //#27740
                        } //#27740
                    } //#27740
                } else { //#27743
                    for (var _1y = 0, _1z = $cvi($get($1.sbs, $1.i)); _1y < _1z; _1y++) { //#27743
                        $k[$j++] = 0; //#27743
                    } //#27743
                } //#27743
            } //#27743
            $k[$j++] = 0; //#27746
        } //#27746
        $1.pixs = $a(); //#27746
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#27750
        var _29 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#27758
        $k[$j++] = _29; //#27765
        if (!$1.dontdraw) { //#27765
            $$.save(); //#27762
            bwipp_renmatrix(); //#27763
            $$.restore(); //#27764
        } //#27764
    } //#27764
}

function bwipp_databaromnicomposite() {
    var $1 = {}; //#27800
    $1.ctx = null; //#27802
    $1.dontdraw = false; //#27803
    $1.usematrix = false; //#27804
    $1.parse = false; //#27805
    $1.dontlint = false; //#27806
    $1.lintreqs = true; //#27807
    $k[$j++] = $1; //#27809
    bwipp_processoptions(); //#27809
    $1.options = $k[--$j]; //#27809
    $1.barcode = $k[--$j]; //#27810
    if ($1.dontdraw) { //#27812
        $1.usematrix = true; //#27812
    } //#27812
    $search($1.barcode, "|"); //#27815
    if ($k[--$j]) { //#27820
        $1.linear = $k[--$j]; //#27816
        $j--; //#27817
        $1.comp = $k[--$j]; //#27818
    } else { //#27820
        $j--; //#27820
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27820
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27820
        bwipp_raiseerror(); //#27820
    } //#27820
    if (!$1.usematrix) { //#27823
        $$.save(); //#27823
    } //#27823
    $put($1.options, "lintype", "databaromni"); //#27825
    $put($1.options, "linkage", true); //#27826
    $put($1.options, "inkspread", "0"); //#27827
    $put($1.options, "dontdraw", true); //#27828
    $put($1.options, "dontlint", true); //#27829
    var _F = $s($1.linear.length + $1.comp.length); //#27832
    $puti(_F, 0, $1.linear); //#27833
    $puti(_F, $1.linear.length, $1.comp); //#27834
    $k[$j++] = _F; //#27835
    $k[$j++] = 'ai'; //#27835
    bwipp_gs1process(); //#27835
    $j -= 3; //#27835
    $k[$j++] = $1.linear; //#27838
    $k[$j++] = $1.options; //#27838
    bwipp_databaromni(); //#27838
    var _L = $k[--$j]; //#27839
    $1.linsbs = $get(_L, "sbs"); //#27839
    $1.linheight = $get($get(_L, "bhs"), 0) * 72; //#27840
    $k[$j++] = _L; //#27841
    if (!$1.usematrix) { //#27841
        bwipp_renlinear(); //#27841
    } else { //#27841
        $j--; //#27841
    } //#27841
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#27845
        for (var _U = $1.fp, _T = $f($1.fp + 12); _U <= _T; _U += 1) { //#27858
            $1.i = _U; //#27847
            if ($get($1.bot, $1.i) == 0) { //#27855
                if ($get($1.bot, $1.i - 1) == 1) { //#27852
                    $k[$j++] = 1; //#27850
                } else { //#27852
                    var _e = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#27852
                    $k[$j++] = _e; //#27852
                } //#27852
            } else { //#27855
                $k[$j++] = 0; //#27855
            } //#27855
            $put($1.sep, $1.i, $k[--$j]); //#27857
        } //#27857
        $1.f3 = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1]); //#27859
        $k[$j++] = true; //#27860
        for (var _j = 0; _j <= 12; _j += 1) { //#27860
            var _p = $k[--$j]; //#27860
            $k[$j++] = _p && $eq($get($1.bot, $f(_j + $1.fp)), $get($1.f3, _j)); //#27860
        } //#27860
        if ($k[--$j]) { //#27863
            $puti($1.sep, $1.fp, $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0])); //#27862
        } //#27862
    }; //#27862
    $k[$j++] = Infinity; //#27865
    $k[$j++] = 0; //#27866
    $forall($1.linsbs, function() { //#27866
        var _v = $k[--$j]; //#27866
        var _w = $k[--$j]; //#27866
        var _x = (_w == 1) ? 0 : 1; //#27866
        $k[$j++] = _w; //#27866
        for (var _y = 0, _z = _v; _y < _z; _y++) { //#27866
            $k[$j++] = _x //#27866
        } //#27866
    }); //#27866
    $astore($a($counttomark() - 1)); //#27867
    $1.bot = $k[--$j]; //#27867
    $j -= 2; //#27867
    $k[$j++] = Infinity; //#27868
    $forall($1.bot, function() { //#27868
        var _14 = $k[--$j]; //#27868
        $k[$j++] = $f(1 - _14); //#27868
    }); //#27868
    $1.sep = $a(); //#27868
    $puti($1.sep, 0, $a([0, 0, 0])); //#27869
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#27870
    $k[$j++] = 18; //#27871
    $1.sepfinder(); //#27871
    $k[$j++] = 64; //#27871
    $1.sepfinder(); //#27871
    if (!$1.usematrix) { //#27922
        $$.rmoveto(0, $1.linheight); //#27873
        var _1H = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#27880
        $k[$j++] = _1H; //#27881
        bwipp_renmatrix(); //#27881
        $$.rmoveto(-5, 1); //#27884
        $k[$j++] = $1.comp; //#27884
        $k[$j++] = $1.options; //#27884
        bwipp_gs1_cc(); //#27884
        bwipp_renmatrix(); //#27884
        $$.restore(); //#27886
    } else { //#27922
        $k[$j++] = 'compsym'; //#27888
        $k[$j++] = $1.comp; //#27888
        $k[$j++] = $1.options; //#27888
        bwipp_gs1_cc(); //#27888
        var _1M = $k[--$j]; //#27888
        $1[$k[--$j]] = _1M; //#27888
        $1.ccpixs = $get($1.compsym, 'pixs'); //#27889
        $1.ccpixx = $get($1.compsym, 'pixx'); //#27890
        $k[$j++] = Infinity; //#27893
        $k[$j++] = 0; //#27893
        $forall($1.linsbs, function() { //#27893
            var _1T = $k[--$j]; //#27893
            var _1U = $k[--$j]; //#27893
            var _1V = (_1U == 0) ? 1 : 0; //#27893
            $k[$j++] = _1U; //#27893
            for (var _1W = 0, _1X = $cvi(_1T); _1W < _1X; _1W++) { //#27893
                $k[$j++] = _1V //#27893
            } //#27893
        }); //#27893
        $1.linpixs = $a(); //#27893
        $k[$j++] = Infinity; //#27895
        $k[$j++] = 0; //#27895
        $aload($1.sep); //#27895
        $1.sep = $a(); //#27895
        $1.linheight = ~~$1.linheight; //#27897
        $k[$j++] = Infinity; //#27904
        for (var _1f = 0, _1g = $1.ccpixx, _1e = $1.ccpixs.length - 1; _1g < 0 ? _1f >= _1e : _1f <= _1e; _1f += _1g) { //#27903
            $1.i = _1f; //#27901
            for (var _1h = 0, _1i = 2; _1h < _1i; _1h++) { //#27902
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#27902
                $k[$j++] = 0; //#27902
            } //#27902
        } //#27902
        $k[$j++] = 0; //#27904
        $k[$j++] = 0; //#27904
        $k[$j++] = 0; //#27904
        $k[$j++] = 0; //#27904
        $aload($1.sep); //#27904
        for (var _1p = 0, _1q = $1.linheight; _1p < _1q; _1p++) { //#27904
            $k[$j++] = 0; //#27904
            $k[$j++] = 0; //#27904
            $k[$j++] = 0; //#27904
            $k[$j++] = 0; //#27904
            $aload($1.linpixs); //#27904
        } //#27904
        $1.pixs = $a(); //#27904
        $1.pixx = $f($1.ccpixx + 1); //#27906
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#27908
        var _22 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#27916
        $k[$j++] = _22; //#27923
        if (!$1.dontdraw) { //#27923
            $$.save(); //#27920
            bwipp_renmatrix(); //#27921
            $$.restore(); //#27922
        } //#27922
    } //#27922
}

function bwipp_databarstackedcomposite() {
    var $1 = {}; //#27957
    $1.ctx = null; //#27959
    $1.dontdraw = false; //#27960
    $1.usematrix = false; //#27961
    $1.parse = false; //#27962
    $1.dontlint = false; //#27963
    $1.lintreqs = true; //#27964
    $k[$j++] = $1; //#27966
    bwipp_processoptions(); //#27966
    $1.options = $k[--$j]; //#27966
    $1.barcode = $k[--$j]; //#27967
    if ($1.dontdraw) { //#27969
        $1.usematrix = true; //#27969
    } //#27969
    $search($1.barcode, "|"); //#27972
    if ($k[--$j]) { //#27977
        $1.linear = $k[--$j]; //#27973
        $j--; //#27974
        $1.comp = $k[--$j]; //#27975
    } else { //#27977
        $j--; //#27977
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#27977
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#27977
        bwipp_raiseerror(); //#27977
    } //#27977
    if (!$1.usematrix) { //#27980
        $$.save(); //#27980
    } //#27980
    $put($1.options, "lintype", "databarstacked"); //#27982
    $put($1.options, "linkage", true); //#27983
    $put($1.options, "inkspread", "0"); //#27984
    $put($1.options, "dontdraw", true); //#27985
    $put($1.options, "dontlint", true); //#27986
    var _F = $s($1.linear.length + $1.comp.length); //#27989
    $puti(_F, 0, $1.linear); //#27990
    $puti(_F, $1.linear.length, $1.comp); //#27991
    $k[$j++] = _F; //#27992
    $k[$j++] = 'ai'; //#27992
    bwipp_gs1process(); //#27992
    $j -= 3; //#27992
    $k[$j++] = $1.linear; //#27995
    $k[$j++] = $1.options; //#27995
    bwipp_databarstacked(); //#27995
    var _L = $k[--$j]; //#27996
    $1.bot = $geti($get(_L, "pixs"), 0, $get(_L, "pixx")); //#27996
    $1.linheight = $get(_L, "pixy"); //#27997
    $k[$j++] = _L; //#27998
    if (!$1.usematrix) { //#27998
        bwipp_renmatrix(); //#27998
    } else { //#27998
        $1.linpixs = $get($k[--$j], 'pixs'); //#27998
    } //#27998
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#28002
        for (var _X = $1.fp, _W = $f($1.fp + 12); _X <= _W; _X += 1) { //#28015
            $1.i = _X; //#28004
            if ($get($1.bot, $1.i) == 0) { //#28012
                if ($get($1.bot, $1.i - 1) == 1) { //#28009
                    $k[$j++] = 1; //#28007
                } else { //#28009
                    var _h = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#28009
                    $k[$j++] = _h; //#28009
                } //#28009
            } else { //#28012
                $k[$j++] = 0; //#28012
            } //#28012
            $put($1.sep, $1.i, $k[--$j]); //#28014
        } //#28014
        $1.f3 = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1]); //#28016
        $k[$j++] = true; //#28017
        for (var _m = 0; _m <= 12; _m += 1) { //#28017
            var _s = $k[--$j]; //#28017
            $k[$j++] = _s && $eq($get($1.bot, $f(_m + $1.fp)), $get($1.f3, _m)); //#28017
        } //#28017
        if ($k[--$j]) { //#28020
            $puti($1.sep, $1.fp, $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0])); //#28019
        } //#28019
    }; //#28019
    $k[$j++] = Infinity; //#28022
    var _x = $1.bot; //#28022
    for (var _y = 0, _z = _x.length; _y < _z; _y++) { //#28022
        $k[$j++] = $f(1 - $get(_x, _y)); //#28022
    } //#28022
    $1.sep = $a(); //#28022
    $puti($1.sep, 0, $a([0, 0, 0, 0])); //#28023
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#28024
    $k[$j++] = 18; //#28025
    $1.sepfinder(); //#28025
    if (!$1.usematrix) { //#28075
        $$.rmoveto(0, $1.linheight); //#28027
        var _1D = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28034
        $k[$j++] = _1D; //#28035
        bwipp_renmatrix(); //#28035
        $$.rmoveto(1, 1); //#28038
        $k[$j++] = $1.comp; //#28038
        $k[$j++] = $1.options; //#28038
        bwipp_gs1_cc(); //#28038
        bwipp_renmatrix(); //#28038
        $$.restore(); //#28040
    } else { //#28075
        $k[$j++] = 'compsym'; //#28042
        $k[$j++] = $1.comp; //#28042
        $k[$j++] = $1.options; //#28042
        bwipp_gs1_cc(); //#28042
        var _1I = $k[--$j]; //#28042
        $1[$k[--$j]] = _1I; //#28042
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28043
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28044
        $1.linwidth = $1.sep.length; //#28046
        $k[$j++] = Infinity; //#28056
        for (var _1S = 0, _1T = $1.ccpixx, _1R = $1.ccpixs.length - 1; _1T < 0 ? _1S >= _1R : _1S <= _1R; _1S += _1T) { //#28052
            $1.i = _1S; //#28050
            for (var _1U = 0, _1V = 2; _1U < _1V; _1U++) { //#28051
                $k[$j++] = 0; //#28051
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28051
            } //#28051
        } //#28051
        $aload($1.sep); //#28053
        $k[$j++] = 0; //#28057
        $k[$j++] = 0; //#28057
        $k[$j++] = 0; //#28057
        $k[$j++] = 0; //#28057
        $k[$j++] = 0; //#28057
        $k[$j++] = 0; //#28057
        for (var _1e = 0, _1f = $1.linwidth, _1d = $1.linpixs.length - 1; _1f < 0 ? _1e >= _1d : _1e <= _1d; _1e += _1f) { //#28057
            $1.i = _1e; //#28055
            $aload($geti($1.linpixs, $1.i, $1.linwidth)); //#28056
            $k[$j++] = 0; //#28056
            $k[$j++] = 0; //#28056
            $k[$j++] = 0; //#28056
            $k[$j++] = 0; //#28056
            $k[$j++] = 0; //#28056
            $k[$j++] = 0; //#28056
        } //#28056
        $1.pixs = $a(); //#28056
        $1.pixx = $f($1.ccpixx + 1); //#28059
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28061
        var _1u = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28069
        $k[$j++] = _1u; //#28076
        if (!$1.dontdraw) { //#28076
            $$.save(); //#28073
            bwipp_renmatrix(); //#28074
            $$.restore(); //#28075
        } //#28075
    } //#28075
}

function bwipp_databarstackedomnicomposite() {
    var $1 = {}; //#28110
    $1.ctx = null; //#28112
    $1.dontdraw = false; //#28113
    $1.usematrix = false; //#28114
    $1.parse = false; //#28115
    $1.dontlint = false; //#28116
    $1.lintreqs = true; //#28117
    $k[$j++] = $1; //#28119
    bwipp_processoptions(); //#28119
    $1.options = $k[--$j]; //#28119
    $1.barcode = $k[--$j]; //#28120
    if ($1.dontdraw) { //#28122
        $1.usematrix = true; //#28122
    } //#28122
    $search($1.barcode, "|"); //#28125
    if ($k[--$j]) { //#28130
        $1.linear = $k[--$j]; //#28126
        $j--; //#28127
        $1.comp = $k[--$j]; //#28128
    } else { //#28130
        $j--; //#28130
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28130
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28130
        bwipp_raiseerror(); //#28130
    } //#28130
    if (!$1.usematrix) { //#28133
        $$.save(); //#28133
    } //#28133
    $put($1.options, "lintype", "databarstackedomni"); //#28135
    $put($1.options, "linkage", true); //#28136
    $put($1.options, "inkspread", "0"); //#28137
    $put($1.options, "dontdraw", true); //#28138
    $put($1.options, "dontlint", true); //#28139
    var _F = $s($1.linear.length + $1.comp.length); //#28142
    $puti(_F, 0, $1.linear); //#28143
    $puti(_F, $1.linear.length, $1.comp); //#28144
    $k[$j++] = _F; //#28145
    $k[$j++] = 'ai'; //#28145
    bwipp_gs1process(); //#28145
    $j -= 3; //#28145
    $k[$j++] = $1.linear; //#28148
    $k[$j++] = $1.options; //#28148
    bwipp_databarstackedomni(); //#28148
    var _L = $k[--$j]; //#28149
    $1.bot = $geti($get(_L, "pixs"), 0, $get(_L, "pixx")); //#28149
    $1.linheight = $get(_L, "pixy"); //#28150
    $k[$j++] = _L; //#28151
    if (!$1.usematrix) { //#28151
        bwipp_renmatrix(); //#28151
    } else { //#28151
        $1.linpixs = $get($k[--$j], 'pixs'); //#28151
    } //#28151
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#28155
        for (var _X = $1.fp, _W = $f($1.fp + 12); _X <= _W; _X += 1) { //#28168
            $1.i = _X; //#28157
            if ($get($1.bot, $1.i) == 0) { //#28165
                if ($get($1.bot, $1.i - 1) == 1) { //#28162
                    $k[$j++] = 1; //#28160
                } else { //#28162
                    var _h = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#28162
                    $k[$j++] = _h; //#28162
                } //#28162
            } else { //#28165
                $k[$j++] = 0; //#28165
            } //#28165
            $put($1.sep, $1.i, $k[--$j]); //#28167
        } //#28167
        $1.f3 = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1]); //#28169
        $k[$j++] = true; //#28170
        for (var _m = 0; _m <= 12; _m += 1) { //#28170
            var _s = $k[--$j]; //#28170
            $k[$j++] = _s && $eq($get($1.bot, $f(_m + $1.fp)), $get($1.f3, _m)); //#28170
        } //#28170
        if ($k[--$j]) { //#28173
            $puti($1.sep, $1.fp, $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0])); //#28172
        } //#28172
    }; //#28172
    $k[$j++] = Infinity; //#28175
    var _x = $1.bot; //#28175
    for (var _y = 0, _z = _x.length; _y < _z; _y++) { //#28175
        $k[$j++] = $f(1 - $get(_x, _y)); //#28175
    } //#28175
    $1.sep = $a(); //#28175
    $puti($1.sep, 0, $a([0, 0, 0, 0])); //#28176
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#28177
    $k[$j++] = 18; //#28178
    $1.sepfinder(); //#28178
    if (!$1.usematrix) { //#28228
        $$.rmoveto(0, $1.linheight); //#28180
        var _1D = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28187
        $k[$j++] = _1D; //#28188
        bwipp_renmatrix(); //#28188
        $$.rmoveto(1, 1); //#28191
        $k[$j++] = $1.comp; //#28191
        $k[$j++] = $1.options; //#28191
        bwipp_gs1_cc(); //#28191
        bwipp_renmatrix(); //#28191
        $$.restore(); //#28193
    } else { //#28228
        $k[$j++] = 'compsym'; //#28195
        $k[$j++] = $1.comp; //#28195
        $k[$j++] = $1.options; //#28195
        bwipp_gs1_cc(); //#28195
        var _1I = $k[--$j]; //#28195
        $1[$k[--$j]] = _1I; //#28195
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28196
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28197
        $1.linwidth = $1.sep.length; //#28199
        $k[$j++] = Infinity; //#28209
        for (var _1S = 0, _1T = $1.ccpixx, _1R = $1.ccpixs.length - 1; _1T < 0 ? _1S >= _1R : _1S <= _1R; _1S += _1T) { //#28205
            $1.i = _1S; //#28203
            for (var _1U = 0, _1V = 2; _1U < _1V; _1U++) { //#28204
                $k[$j++] = 0; //#28204
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28204
            } //#28204
        } //#28204
        $aload($1.sep); //#28206
        $k[$j++] = 0; //#28210
        $k[$j++] = 0; //#28210
        $k[$j++] = 0; //#28210
        $k[$j++] = 0; //#28210
        $k[$j++] = 0; //#28210
        $k[$j++] = 0; //#28210
        for (var _1e = 0, _1f = $1.linwidth, _1d = $1.linpixs.length - 1; _1f < 0 ? _1e >= _1d : _1e <= _1d; _1e += _1f) { //#28210
            $1.i = _1e; //#28208
            $aload($geti($1.linpixs, $1.i, $1.linwidth)); //#28209
            $k[$j++] = 0; //#28209
            $k[$j++] = 0; //#28209
            $k[$j++] = 0; //#28209
            $k[$j++] = 0; //#28209
            $k[$j++] = 0; //#28209
            $k[$j++] = 0; //#28209
        } //#28209
        $1.pixs = $a(); //#28209
        $1.pixx = $f($1.ccpixx + 1); //#28212
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28214
        var _1u = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28222
        $k[$j++] = _1u; //#28229
        if (!$1.dontdraw) { //#28229
            $$.save(); //#28226
            bwipp_renmatrix(); //#28227
            $$.restore(); //#28228
        } //#28228
    } //#28228
}

function bwipp_databartruncatedcomposite() {
    var $1 = {}; //#28264
    $1.ctx = null; //#28266
    $1.dontdraw = false; //#28267
    $1.usematrix = false; //#28268
    $1.parse = false; //#28269
    $1.dontlint = false; //#28270
    $1.lintreqs = true; //#28271
    $k[$j++] = $1; //#28273
    bwipp_processoptions(); //#28273
    $1.options = $k[--$j]; //#28273
    $1.barcode = $k[--$j]; //#28274
    if ($1.dontdraw) { //#28276
        $1.usematrix = true; //#28276
    } //#28276
    $search($1.barcode, "|"); //#28279
    if ($k[--$j]) { //#28284
        $1.linear = $k[--$j]; //#28280
        $j--; //#28281
        $1.comp = $k[--$j]; //#28282
    } else { //#28284
        $j--; //#28284
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28284
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28284
        bwipp_raiseerror(); //#28284
    } //#28284
    if (!$1.usematrix) { //#28287
        $$.save(); //#28287
    } //#28287
    $put($1.options, "lintype", "databartruncated"); //#28289
    $put($1.options, "linkage", true); //#28290
    $put($1.options, "inkspread", "0"); //#28291
    $put($1.options, "dontdraw", true); //#28292
    $put($1.options, "dontlint", true); //#28293
    var _F = $s($1.linear.length + $1.comp.length); //#28296
    $puti(_F, 0, $1.linear); //#28297
    $puti(_F, $1.linear.length, $1.comp); //#28298
    $k[$j++] = _F; //#28299
    $k[$j++] = 'ai'; //#28299
    bwipp_gs1process(); //#28299
    $j -= 3; //#28299
    $k[$j++] = $1.linear; //#28302
    $k[$j++] = $1.options; //#28302
    bwipp_databartruncated(); //#28302
    var _L = $k[--$j]; //#28303
    $1.linsbs = $get(_L, "sbs"); //#28303
    $1.linheight = $get($get(_L, "bhs"), 0) * 72; //#28304
    $k[$j++] = _L; //#28305
    if (!$1.usematrix) { //#28305
        bwipp_renlinear(); //#28305
    } else { //#28305
        $j--; //#28305
    } //#28305
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#28309
        for (var _U = $1.fp, _T = $f($1.fp + 12); _U <= _T; _U += 1) { //#28322
            $1.i = _U; //#28311
            if ($get($1.bot, $1.i) == 0) { //#28319
                if ($get($1.bot, $1.i - 1) == 1) { //#28316
                    $k[$j++] = 1; //#28314
                } else { //#28316
                    var _e = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#28316
                    $k[$j++] = _e; //#28316
                } //#28316
            } else { //#28319
                $k[$j++] = 0; //#28319
            } //#28319
            $put($1.sep, $1.i, $k[--$j]); //#28321
        } //#28321
        $1.f3 = $a([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1]); //#28323
        $k[$j++] = true; //#28324
        for (var _j = 0; _j <= 12; _j += 1) { //#28324
            var _p = $k[--$j]; //#28324
            $k[$j++] = _p && $eq($get($1.bot, $f(_j + $1.fp)), $get($1.f3, _j)); //#28324
        } //#28324
        if ($k[--$j]) { //#28327
            $puti($1.sep, $1.fp, $a([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0])); //#28326
        } //#28326
    }; //#28326
    $k[$j++] = Infinity; //#28329
    $k[$j++] = 0; //#28330
    $forall($1.linsbs, function() { //#28330
        var _v = $k[--$j]; //#28330
        var _w = $k[--$j]; //#28330
        var _x = (_w == 1) ? 0 : 1; //#28330
        $k[$j++] = _w; //#28330
        for (var _y = 0, _z = _v; _y < _z; _y++) { //#28330
            $k[$j++] = _x //#28330
        } //#28330
    }); //#28330
    $astore($a($counttomark() - 1)); //#28331
    $1.bot = $k[--$j]; //#28331
    $j -= 2; //#28331
    $k[$j++] = Infinity; //#28332
    $forall($1.bot, function() { //#28332
        var _14 = $k[--$j]; //#28332
        $k[$j++] = $f(1 - _14); //#28332
    }); //#28332
    $1.sep = $a(); //#28332
    $puti($1.sep, 0, $a([0, 0, 0])); //#28333
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#28334
    $k[$j++] = 18; //#28335
    $1.sepfinder(); //#28335
    $k[$j++] = 64; //#28335
    $1.sepfinder(); //#28335
    if (!$1.usematrix) { //#28386
        $$.rmoveto(0, $1.linheight); //#28337
        var _1H = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28344
        $k[$j++] = _1H; //#28345
        bwipp_renmatrix(); //#28345
        $$.rmoveto(-5, 1); //#28348
        $k[$j++] = $1.comp; //#28348
        $k[$j++] = $1.options; //#28348
        bwipp_gs1_cc(); //#28348
        bwipp_renmatrix(); //#28348
        $$.restore(); //#28350
    } else { //#28386
        $k[$j++] = 'compsym'; //#28352
        $k[$j++] = $1.comp; //#28352
        $k[$j++] = $1.options; //#28352
        bwipp_gs1_cc(); //#28352
        var _1M = $k[--$j]; //#28352
        $1[$k[--$j]] = _1M; //#28352
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28353
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28354
        $k[$j++] = Infinity; //#28357
        $k[$j++] = 0; //#28357
        $forall($1.linsbs, function() { //#28357
            var _1T = $k[--$j]; //#28357
            var _1U = $k[--$j]; //#28357
            var _1V = (_1U == 0) ? 1 : 0; //#28357
            $k[$j++] = _1U; //#28357
            for (var _1W = 0, _1X = $cvi(_1T); _1W < _1X; _1W++) { //#28357
                $k[$j++] = _1V //#28357
            } //#28357
        }); //#28357
        $1.linpixs = $a(); //#28357
        $k[$j++] = Infinity; //#28359
        $k[$j++] = 0; //#28359
        $aload($1.sep); //#28359
        $1.sep = $a(); //#28359
        $1.linheight = ~~$1.linheight; //#28361
        $k[$j++] = Infinity; //#28368
        for (var _1f = 0, _1g = $1.ccpixx, _1e = $1.ccpixs.length - 1; _1g < 0 ? _1f >= _1e : _1f <= _1e; _1f += _1g) { //#28367
            $1.i = _1f; //#28365
            for (var _1h = 0, _1i = 2; _1h < _1i; _1h++) { //#28366
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28366
                $k[$j++] = 0; //#28366
            } //#28366
        } //#28366
        $k[$j++] = 0; //#28368
        $k[$j++] = 0; //#28368
        $k[$j++] = 0; //#28368
        $k[$j++] = 0; //#28368
        $aload($1.sep); //#28368
        for (var _1p = 0, _1q = $1.linheight; _1p < _1q; _1p++) { //#28368
            $k[$j++] = 0; //#28368
            $k[$j++] = 0; //#28368
            $k[$j++] = 0; //#28368
            $k[$j++] = 0; //#28368
            $aload($1.linpixs); //#28368
        } //#28368
        $1.pixs = $a(); //#28368
        $1.pixx = $f($1.ccpixx + 1); //#28370
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28372
        var _22 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28380
        $k[$j++] = _22; //#28387
        if (!$1.dontdraw) { //#28387
            $$.save(); //#28384
            bwipp_renmatrix(); //#28385
            $$.restore(); //#28386
        } //#28386
    } //#28386
}

function bwipp_databarlimitedcomposite() {
    var $1 = {}; //#28422
    $1.ctx = null; //#28424
    $1.dontdraw = false; //#28425
    $1.usematrix = false; //#28426
    $1.parse = false; //#28427
    $1.dontlint = false; //#28428
    $1.lintreqs = true; //#28429
    $k[$j++] = $1; //#28431
    bwipp_processoptions(); //#28431
    $1.options = $k[--$j]; //#28431
    $1.barcode = $k[--$j]; //#28432
    if ($1.dontdraw) { //#28434
        $1.usematrix = true; //#28434
    } //#28434
    $search($1.barcode, "|"); //#28437
    if ($k[--$j]) { //#28442
        $1.linear = $k[--$j]; //#28438
        $j--; //#28439
        $1.comp = $k[--$j]; //#28440
    } else { //#28442
        $j--; //#28442
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28442
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28442
        bwipp_raiseerror(); //#28442
    } //#28442
    if (!$1.usematrix) { //#28445
        $$.save(); //#28445
    } //#28445
    $put($1.options, "lintype", "databarlimited"); //#28447
    $put($1.options, "linkage", true); //#28448
    $put($1.options, "inkspread", "0"); //#28449
    $put($1.options, "dontdraw", true); //#28450
    $put($1.options, "dontlint", true); //#28451
    var _F = $s($1.linear.length + $1.comp.length); //#28454
    $puti(_F, 0, $1.linear); //#28455
    $puti(_F, $1.linear.length, $1.comp); //#28456
    $k[$j++] = _F; //#28457
    $k[$j++] = 'ai'; //#28457
    bwipp_gs1process(); //#28457
    $j -= 3; //#28457
    $k[$j++] = $1.linear; //#28460
    $k[$j++] = $1.options; //#28460
    bwipp_databarlimited(); //#28460
    var _L = $k[--$j]; //#28461
    $1.linsbs = $get(_L, "sbs"); //#28461
    $1.linheight = $get($get(_L, "bhs"), 0) * 72; //#28462
    $k[$j++] = _L; //#28463
    if (!$1.usematrix) { //#28463
        bwipp_renlinear(); //#28463
    } else { //#28463
        $j--; //#28463
    } //#28463
    $k[$j++] = Infinity; //#28466
    $k[$j++] = 1; //#28467
    $forall($1.linsbs, function() { //#28467
        var _R = $k[--$j]; //#28467
        var _S = $k[--$j]; //#28467
        var _T = (_S == 0) ? 1 : 0; //#28467
        $k[$j++] = _S; //#28467
        for (var _U = 0, _V = _R; _U < _V; _U++) { //#28467
            $k[$j++] = _T //#28467
        } //#28467
    }); //#28467
    $astore($a($counttomark() - 1)); //#28468
    $1.sep = $k[--$j]; //#28468
    $j -= 2; //#28468
    $puti($1.sep, 0, $a([0, 0, 0])); //#28469
    var _c = $1.sep; //#28470
    $puti($1.sep, _c.length - 9, $a([0, 0, 0, 0, 0, 0, 0, 0, 0])); //#28470
    if (!$1.usematrix) { //#28535
        $$.rmoveto(0, $1.linheight); //#28473
        var _g = $1.sep; //#28475
        var _k = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", _g],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28480
        $k[$j++] = _k; //#28481
        bwipp_renmatrix(); //#28481
        $k[$j++] = $1.comp; //#28484
        $k[$j++] = $1.options; //#28484
        bwipp_gs1_cc(); //#28484
        var _n = $k[--$j]; //#28485
        $$.rmoveto($f(72 - $get(_n, "pixx")), 1); //#28485
        $k[$j++] = _n; //#28486
        bwipp_renmatrix(); //#28486
        $$.restore(); //#28488
    } else { //#28535
        $k[$j++] = 'compsym'; //#28490
        $k[$j++] = $1.comp; //#28490
        $k[$j++] = $1.options; //#28490
        bwipp_gs1_cc(); //#28490
        var _r = $k[--$j]; //#28490
        $1[$k[--$j]] = _r; //#28490
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28491
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28492
        $k[$j++] = Infinity; //#28495
        $k[$j++] = 0; //#28495
        $forall($1.linsbs, function() { //#28495
            var _y = $k[--$j]; //#28495
            var _z = $k[--$j]; //#28495
            var _10 = (_z == 0) ? 1 : 0; //#28495
            $k[$j++] = _z; //#28495
            for (var _11 = 0, _12 = $cvi(_y); _11 < _12; _11++) { //#28495
                $k[$j++] = _10 //#28495
            } //#28495
        }); //#28495
        $1.linpixs = $a(); //#28495
        $k[$j++] = Infinity; //#28497
        $k[$j++] = 0; //#28497
        $aload($1.sep); //#28497
        $1.sep = $a(); //#28497
        $1.linheight = ~~$1.linheight; //#28499
        if ($1.ccpixx == 72) { //#28518
            $k[$j++] = Infinity; //#28507
            for (var _1B = 0, _1C = $1.ccpixx, _1A = $1.ccpixs.length - 1; _1C < 0 ? _1B >= _1A : _1B <= _1A; _1B += _1C) { //#28506
                $1.i = _1B; //#28504
                for (var _1D = 0, _1E = 2; _1D < _1E; _1D++) { //#28505
                    $k[$j++] = 0; //#28505
                    $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28505
                    $k[$j++] = 0; //#28505
                    $k[$j++] = 0; //#28505
                    $k[$j++] = 0; //#28505
                    $k[$j++] = 0; //#28505
                    $k[$j++] = 0; //#28505
                    $k[$j++] = 0; //#28505
                } //#28505
            } //#28505
            $aload($1.sep); //#28507
            for (var _1L = 0, _1M = $1.linheight; _1L < _1M; _1L++) { //#28507
                $aload($1.linpixs); //#28507
            } //#28507
            $1.pixs = $a(); //#28507
            $1.pixx = $1.linpixs.length; //#28509
        } else { //#28518
            $k[$j++] = Infinity; //#28516
            for (var _1T = 0, _1U = $1.ccpixx, _1S = $1.ccpixs.length - 1; _1U < 0 ? _1T >= _1S : _1T <= _1S; _1T += _1U) { //#28515
                $1.i = _1T; //#28513
                for (var _1V = 0, _1W = 2; _1V < _1W; _1V++) { //#28514
                    $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28514
                    $k[$j++] = 0; //#28514
                    $k[$j++] = 0; //#28514
                    $k[$j++] = 0; //#28514
                    $k[$j++] = 0; //#28514
                    $k[$j++] = 0; //#28514
                    $k[$j++] = 0; //#28514
                } //#28514
            } //#28514
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $k[$j++] = 0; //#28516
            $aload($1.sep); //#28516
            for (var _1d = 0, _1e = $1.linheight; _1d < _1e; _1d++) { //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $k[$j++] = 0; //#28516
                $aload($1.linpixs); //#28516
            } //#28516
            $1.pixs = $a(); //#28516
            $1.pixx = $f($1.ccpixx + 6); //#28518
        } //#28518
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28521
        var _1q = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28529
        $k[$j++] = _1q; //#28536
        if (!$1.dontdraw) { //#28536
            $$.save(); //#28533
            bwipp_renmatrix(); //#28534
            $$.restore(); //#28535
        } //#28535
    } //#28535
}

function bwipp_databarexpandedcomposite() {
    var $1 = {}; //#28571
    $1.ctx = null; //#28573
    $1.dontdraw = false; //#28574
    $1.usematrix = false; //#28575
    $1.parse = false; //#28576
    $1.dontlint = false; //#28577
    $1.lintreqs = true; //#28578
    $k[$j++] = $1; //#28580
    bwipp_processoptions(); //#28580
    $1.options = $k[--$j]; //#28580
    $1.barcode = $k[--$j]; //#28581
    if ($1.dontdraw) { //#28583
        $1.usematrix = true; //#28583
    } //#28583
    $search($1.barcode, "|"); //#28586
    if ($k[--$j]) { //#28591
        $1.linear = $k[--$j]; //#28587
        $j--; //#28588
        $1.comp = $k[--$j]; //#28589
    } else { //#28591
        $j--; //#28591
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28591
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28591
        bwipp_raiseerror(); //#28591
    } //#28591
    if (!$1.usematrix) { //#28594
        $$.save(); //#28594
    } //#28594
    $put($1.options, "lintype", "databarexpanded"); //#28596
    $put($1.options, "linkage", true); //#28597
    $put($1.options, "inkspread", "0"); //#28598
    $put($1.options, "dontdraw", true); //#28599
    $put($1.options, "dontlint", true); //#28600
    var _F = $s($1.linear.length + $1.comp.length); //#28603
    $puti(_F, 0, $1.linear); //#28604
    $puti(_F, $1.linear.length, $1.comp); //#28605
    $k[$j++] = _F; //#28606
    $k[$j++] = 'ai'; //#28606
    bwipp_gs1process(); //#28606
    $j -= 3; //#28606
    $k[$j++] = $1.linear; //#28609
    $k[$j++] = $1.options; //#28609
    bwipp_databarexpanded(); //#28609
    var _L = $k[--$j]; //#28610
    $1.linsbs = $get(_L, "sbs"); //#28610
    $1.linheight = $get($get(_L, "bhs"), 0) * 72; //#28611
    $k[$j++] = _L; //#28612
    if (!$1.usematrix) { //#28612
        bwipp_renlinear(); //#28612
    } else { //#28612
        $j--; //#28612
    } //#28612
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#28616
        for (var _U = $1.fp, _T = $f($1.fp + 12); _U <= _T; _U += 1) { //#28629
            $1.i = _U; //#28618
            if ($get($1.bot, $1.i) == 0) { //#28626
                if ($get($1.bot, $1.i - 1) == 1) { //#28623
                    $k[$j++] = 1; //#28621
                } else { //#28623
                    var _e = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#28623
                    $k[$j++] = _e; //#28623
                } //#28623
            } else { //#28626
                $k[$j++] = 0; //#28626
            } //#28626
            $put($1.sep, $1.i, $k[--$j]); //#28628
        } //#28628
    }; //#28628
    $k[$j++] = Infinity; //#28631
    $k[$j++] = 0; //#28632
    $forall($1.linsbs, function() { //#28632
        var _j = $k[--$j]; //#28632
        var _k = $k[--$j]; //#28632
        var _l = (_k == 1) ? 0 : 1; //#28632
        $k[$j++] = _k; //#28632
        for (var _m = 0, _n = _j; _m < _n; _m++) { //#28632
            $k[$j++] = _l //#28632
        } //#28632
    }); //#28632
    $astore($a($counttomark() - 1)); //#28633
    $1.bot = $k[--$j]; //#28633
    $j -= 2; //#28633
    $k[$j++] = Infinity; //#28634
    $forall($1.bot, function() { //#28634
        var _s = $k[--$j]; //#28634
        $k[$j++] = $f(1 - _s); //#28634
    }); //#28634
    $1.sep = $a(); //#28634
    $puti($1.sep, 0, $a([0, 0, 0])); //#28635
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#28636
    $k[$j++] = Infinity; //#28639
    for (var _11 = 18, _10 = $1.bot.length - 13; _11 <= _10; _11 += 98) { //#28638
        $k[$j++] = _11; //#28638
    } //#28638
    for (var _14 = 69, _13 = $1.bot.length - 13; _14 <= _13; _14 += 98) { //#28639
        $k[$j++] = _14; //#28639
    } //#28639
    var _15 = $a(); //#28639
    for (var _16 = 0, _17 = _15.length; _16 < _17; _16++) { //#28640
        $k[$j++] = $get(_15, _16); //#28640
        $1.sepfinder(); //#28640
    } //#28640
    if (!$1.usematrix) { //#28693
        $$.rmoveto(0, $1.linheight); //#28643
        var _1F = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28650
        $k[$j++] = _1F; //#28651
        bwipp_renmatrix(); //#28651
        $$.rmoveto(1, 1); //#28654
        $k[$j++] = $1.comp; //#28654
        $k[$j++] = $1.options; //#28654
        bwipp_gs1_cc(); //#28654
        bwipp_renmatrix(); //#28654
        $$.restore(); //#28656
    } else { //#28693
        $k[$j++] = 'compsym'; //#28658
        $k[$j++] = $1.comp; //#28658
        $k[$j++] = $1.options; //#28658
        bwipp_gs1_cc(); //#28658
        var _1K = $k[--$j]; //#28658
        $1[$k[--$j]] = _1K; //#28658
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28659
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28660
        $k[$j++] = Infinity; //#28663
        $k[$j++] = 0; //#28663
        $forall($1.linsbs, function() { //#28663
            var _1R = $k[--$j]; //#28663
            var _1S = $k[--$j]; //#28663
            var _1T = (_1S == 0) ? 1 : 0; //#28663
            $k[$j++] = _1S; //#28663
            for (var _1U = 0, _1V = $cvi(_1R); _1U < _1V; _1U++) { //#28663
                $k[$j++] = _1T //#28663
            } //#28663
        }); //#28663
        $1.linpixs = $a(); //#28663
        $k[$j++] = Infinity; //#28665
        $k[$j++] = 0; //#28665
        $aload($1.sep); //#28665
        $1.sep = $a(); //#28665
        $1.linheight = ~~$1.linheight; //#28667
        $1.diff = $f($1.linpixs.length - $1.ccpixx); //#28668
        $k[$j++] = Infinity; //#28669
        for (var _1d = 0, _1e = $f($1.diff - 2); _1d < _1e; _1d++) { //#28669
            $k[$j++] = 0; //#28669
        } //#28669
        $1.ccrpad = $a(); //#28669
        $k[$j++] = Infinity; //#28675
        for (var _1j = 0, _1k = $1.ccpixx, _1i = $1.ccpixs.length - 1; _1k < 0 ? _1j >= _1i : _1j <= _1i; _1j += _1k) { //#28674
            $1.i = _1j; //#28672
            for (var _1l = 0, _1m = 2; _1l < _1m; _1l++) { //#28673
                $k[$j++] = 0; //#28673
                $k[$j++] = 0; //#28673
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28673
                $aload($1.ccrpad); //#28673
            } //#28673
        } //#28673
        $aload($1.sep); //#28675
        for (var _1u = 0, _1v = $1.linheight; _1u < _1v; _1u++) { //#28675
            $aload($1.linpixs); //#28675
        } //#28675
        $1.pixs = $a(); //#28675
        $1.pixx = $1.linpixs.length; //#28678
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28679
        var _27 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28687
        $k[$j++] = _27; //#28694
        if (!$1.dontdraw) { //#28694
            $$.save(); //#28691
            bwipp_renmatrix(); //#28692
            $$.restore(); //#28693
        } //#28693
    } //#28693
}

function bwipp_databarexpandedstackedcomposite() {
    var $1 = {}; //#28728
    $1.ctx = null; //#28730
    $1.dontdraw = false; //#28731
    $1.usematrix = false; //#28732
    $1.parse = false; //#28733
    $1.dontlint = false; //#28734
    $1.lintreqs = true; //#28735
    $k[$j++] = $1; //#28737
    bwipp_processoptions(); //#28737
    $1.options = $k[--$j]; //#28737
    $1.barcode = $k[--$j]; //#28738
    if ($1.dontdraw) { //#28740
        $1.usematrix = true; //#28740
    } //#28740
    $search($1.barcode, "|"); //#28743
    if ($k[--$j]) { //#28748
        $1.linear = $k[--$j]; //#28744
        $j--; //#28745
        $1.comp = $k[--$j]; //#28746
    } else { //#28748
        $j--; //#28748
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28748
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28748
        bwipp_raiseerror(); //#28748
    } //#28748
    if (!$1.usematrix) { //#28751
        $$.save(); //#28751
    } //#28751
    $put($1.options, "lintype", "databarexpandedstacked"); //#28753
    $put($1.options, "linkage", true); //#28754
    $put($1.options, "inkspread", "0"); //#28755
    $put($1.options, "dontdraw", true); //#28756
    $put($1.options, "dontlint", true); //#28757
    var _F = $s($1.linear.length + $1.comp.length); //#28760
    $puti(_F, 0, $1.linear); //#28761
    $puti(_F, $1.linear.length, $1.comp); //#28762
    $k[$j++] = _F; //#28763
    $k[$j++] = 'ai'; //#28763
    bwipp_gs1process(); //#28763
    $j -= 3; //#28763
    $k[$j++] = $1.linear; //#28766
    $k[$j++] = $1.options; //#28766
    bwipp_databarexpandedstacked(); //#28766
    var _L = $k[--$j]; //#28767
    $1.bot = $geti($get(_L, "pixs"), 0, $get(_L, "pixx")); //#28767
    $1.linheight = $get(_L, "pixy"); //#28768
    $k[$j++] = _L; //#28769
    if (!$1.usematrix) { //#28769
        bwipp_renmatrix(); //#28769
    } else { //#28769
        $1.linpixs = $get($k[--$j], 'pixs'); //#28769
    } //#28769
    $1.sepfinder = function() {
        $1.fp = $k[--$j]; //#28773
        for (var _X = $1.fp, _W = $f($1.fp + 12); _X <= _W; _X += 1) { //#28786
            $1.i = _X; //#28775
            if ($get($1.bot, $1.i) == 0) { //#28783
                if ($get($1.bot, $1.i - 1) == 1) { //#28780
                    $k[$j++] = 1; //#28778
                } else { //#28780
                    var _h = ($get($1.sep, $1.i - 1) == 0) ? 1 : 0; //#28780
                    $k[$j++] = _h; //#28780
                } //#28780
            } else { //#28783
                $k[$j++] = 0; //#28783
            } //#28783
            $put($1.sep, $1.i, $k[--$j]); //#28785
        } //#28785
    }; //#28785
    $k[$j++] = Infinity; //#28788
    var _l = $1.bot; //#28788
    for (var _m = 0, _n = _l.length; _m < _n; _m++) { //#28788
        $k[$j++] = $f(1 - $get(_l, _m)); //#28788
    } //#28788
    $1.sep = $a(); //#28788
    $puti($1.sep, 0, $a([0, 0, 0, 0])); //#28789
    $puti($1.sep, $1.sep.length - 4, $a([0, 0, 0, 0])); //#28790
    $k[$j++] = Infinity; //#28793
    for (var _x = 19, _w = $1.bot.length - 13; _x <= _w; _x += 98) { //#28792
        $k[$j++] = _x; //#28792
    } //#28792
    for (var _10 = 70, _z = $1.bot.length - 13; _10 <= _z; _10 += 98) { //#28793
        $k[$j++] = _10; //#28793
    } //#28793
    var _11 = $a(); //#28793
    for (var _12 = 0, _13 = _11.length; _12 < _13; _12++) { //#28794
        $k[$j++] = $get(_11, _12); //#28794
        $1.sepfinder(); //#28794
    } //#28794
    if (!$1.usematrix) { //#28841
        $$.rmoveto(0, $1.linheight); //#28796
        var _1B = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28803
        $k[$j++] = _1B; //#28804
        bwipp_renmatrix(); //#28804
        var _1E = ($get($1.bot, 0) == 0) ? 2 : 0; //#28807
        $$.rmoveto(_1E, 1); //#28807
        $k[$j++] = $1.comp; //#28808
        $k[$j++] = $1.options; //#28808
        bwipp_gs1_cc(); //#28808
        bwipp_renmatrix(); //#28808
        $$.restore(); //#28810
    } else { //#28841
        $k[$j++] = 'compsym'; //#28812
        $k[$j++] = $1.comp; //#28812
        $k[$j++] = $1.options; //#28812
        bwipp_gs1_cc(); //#28812
        var _1J = $k[--$j]; //#28812
        $1[$k[--$j]] = _1J; //#28812
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28813
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28814
        $1.pixx = $1.sep.length; //#28816
        $k[$j++] = Infinity; //#28817
        for (var _1S = 0, _1T = ~~(($f($f($1.pixx - $1.ccpixx) + 1)) / 2); _1S < _1T; _1S++) { //#28817
            $k[$j++] = 0; //#28817
        } //#28817
        $1.cclpad = $a(); //#28817
        $k[$j++] = Infinity; //#28818
        for (var _1X = 0, _1Y = ~~($f($1.pixx - $1.ccpixx) / 2); _1X < _1Y; _1X++) { //#28818
            $k[$j++] = 0; //#28818
        } //#28818
        $1.ccrpad = $a(); //#28818
        $k[$j++] = Infinity; //#28824
        for (var _1d = 0, _1e = $1.ccpixx, _1c = $1.ccpixs.length - 1; _1e < 0 ? _1d >= _1c : _1d <= _1c; _1d += _1e) { //#28823
            $1.i = _1d; //#28821
            for (var _1f = 0, _1g = 2; _1f < _1g; _1f++) { //#28822
                $aload($1.cclpad); //#28822
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28822
                $aload($1.ccrpad); //#28822
            } //#28822
        } //#28822
        $aload($1.sep); //#28824
        $aload($1.linpixs); //#28824
        $1.pixs = $a(); //#28824
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#28827
        var _1y = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#28835
        $k[$j++] = _1y; //#28842
        if (!$1.dontdraw) { //#28842
            $$.save(); //#28839
            bwipp_renmatrix(); //#28840
            $$.restore(); //#28841
        } //#28841
    } //#28841
}

function bwipp_gs1_128composite() {
    var $1 = {}; //#28877
    $1.ctx = null; //#28879
    $1.dontdraw = false; //#28880
    $1.usematrix = false; //#28881
    $1.parse = false; //#28882
    $1.dontlint = false; //#28883
    $1.lintreqs = true; //#28884
    $k[$j++] = $1; //#28886
    bwipp_processoptions(); //#28886
    $1.options = $k[--$j]; //#28886
    $1.barcode = $k[--$j]; //#28887
    if ($1.dontdraw) { //#28889
        $1.usematrix = true; //#28889
    } //#28889
    $search($1.barcode, "|"); //#28892
    if ($k[--$j]) { //#28897
        $1.linear = $k[--$j]; //#28893
        $j--; //#28894
        $1.comp = $k[--$j]; //#28895
    } else { //#28897
        $j--; //#28897
        $k[$j++] = 'bwipp.missingCompositeComponent'; //#28897
        $k[$j++] = "A Composite Component must be provided following a pipe character"; //#28897
        bwipp_raiseerror(); //#28897
    } //#28897
    if (!$1.usematrix) { //#28900
        $$.save(); //#28900
    } //#28900
    $put($1.options, "inkspread", "0"); //#28902
    $put($1.options, "dontdraw", true); //#28903
    $put($1.options, "dontlint", true); //#28904
    var _D = $s($1.linear.length + $1.comp.length); //#28907
    $puti(_D, 0, $1.linear); //#28908
    $puti(_D, $1.linear.length, $1.comp); //#28909
    $k[$j++] = _D; //#28910
    $k[$j++] = 'ai'; //#28910
    bwipp_gs1process(); //#28910
    $j -= 3; //#28910
    $put($1.options, "linkagea", true); //#28913
    $k[$j++] = $1.linear; //#28914
    $k[$j++] = Infinity; //#28914
    $forall($1.options); //#28914
    var _K = $d(); //#28914
    $k[$j++] = _K; //#28914
    bwipp_gs1_128(); //#28914
    var _M = $get($k[--$j], "sbs"); //#28915
    $k[$j++] = 0; //#28915
    $forall(_M, function() { //#28915
        var _N = $k[--$j]; //#28915
        var _O = $k[--$j]; //#28915
        $k[$j++] = $f(_O + _N); //#28915
    }); //#28915
    $1.linwidth = $k[--$j]; //#28915
    $put($1.options, "lintype", "gs1-128"); //#28918
    $put($1.options, "linwidth", $1.linwidth); //#28919
    $k[$j++] = $1.comp; //#28920
    $k[$j++] = $1.options; //#28920
    bwipp_gs1_cc(); //#28920
    $1.compsym = $k[--$j]; //#28920
    if ($get($1.compsym, "pixx") == 99) { //#28921
        $k[$j++] = "a"; //#28921
    } else { //#28921
        $k[$j++] = "c"; //#28921
    } //#28921
    $1.linktype = $k[--$j]; //#28921
    if ($eq($1.linktype, "a")) { //#28929
        $put($1.options, "linkagea", true); //#28925
        $put($1.options, "linkagec", false); //#28926
    } else { //#28929
        $put($1.options, "linkagea", false); //#28928
        $put($1.options, "linkagec", true); //#28929
    } //#28929
    $k[$j++] = $1.linear; //#28931
    $k[$j++] = Infinity; //#28931
    $forall($1.options); //#28931
    var _g = $d(); //#28931
    $k[$j++] = _g; //#28931
    bwipp_gs1_128(); //#28931
    var _h = $k[--$j]; //#28932
    $1.linsbs = $get(_h, "sbs"); //#28932
    $1.linheight = $get($get(_h, "bhs"), 0) * 72; //#28933
    $k[$j++] = _h; //#28934
    if (!$1.usematrix) { //#28934
        bwipp_renlinear(); //#28934
    } else { //#28934
        $j--; //#28934
    } //#28934
    $k[$j++] = Infinity; //#28937
    $k[$j++] = 1; //#28938
    $forall($1.linsbs, function() { //#28938
        var _n = $k[--$j]; //#28938
        var _o = $k[--$j]; //#28938
        var _p = (_o == 0) ? 1 : 0; //#28938
        $k[$j++] = _o; //#28938
        for (var _q = 0, _r = _n; _q < _r; _q++) { //#28938
            $k[$j++] = _p //#28938
        } //#28938
    }); //#28938
    $astore($a($counttomark() - 1)); //#28939
    $1.sep = $k[--$j]; //#28939
    $j -= 2; //#28939
    if (!$1.usematrix) { //#28950
        $$.rmoveto(0, $1.linheight); //#28941
        var _11 = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.sep],
            ["pixx", $1.sep.length],
            ["pixy", 1],
            ["height", 1 / 72],
            ["width", $1.sep.length / 72],
            ["opt", $1.options]
        ]); //#28948
        $k[$j++] = _11; //#28949
        bwipp_renmatrix(); //#28949
    } //#28949
    if ($eq($1.linktype, "a")) { //#28958
        $1.s = ~~($f($1.linwidth - 2) / 11); //#28954
        $1.p = ~~(($1.s - 9) / 2); //#28955
        $k[$j++] = 'x'; //#28956
        $k[$j++] = ((($1.s - $1.p) - 1) * 11) + 10; //#28956
        if ($1.p == 0) { //#28956
            var _18 = $k[--$j]; //#28956
            $k[$j++] = $f(_18 + 2); //#28956
        } //#28956
        var _19 = $k[--$j]; //#28956
        $1[$k[--$j]] = $f(_19 - 99); //#28956
    } else { //#28958
        $1.x = -7; //#28958
    } //#28958
    if (!$1.usematrix) { //#29016
        $$.rmoveto($1.x, 1); //#28962
        $k[$j++] = $1.compsym; //#28962
        bwipp_renmatrix(); //#28962
        $$.restore(); //#28964
    } else { //#29016
        $1.ccpixs = $get($1.compsym, 'pixs'); //#28966
        $1.ccpixx = $get($1.compsym, 'pixx'); //#28967
        $k[$j++] = Infinity; //#28970
        $forall($1.linsbs, function() { //#28970
            var _1J = $k[--$j]; //#28970
            var _1K = $k[--$j]; //#28970
            var _1L = (_1K == 1) ? 0 : 1; //#28970
            $k[$j++] = _1K; //#28970
            for (var _1M = 0, _1N = _1J; _1M < _1N; _1M++) { //#28970
                $k[$j++] = _1L //#28970
            } //#28970
        }); //#28970
        $1.linpixs = $a(); //#28970
        if ($1.x > 0) { //#28978
            $k[$j++] = Infinity; //#28974
            for (var _1R = 0, _1S = $1.x; _1R < _1S; _1R++) { //#28974
                $k[$j++] = 0; //#28974
            } //#28974
            $1.cclpad = $a(); //#28974
            $1.linlpad = $a(0); //#28975
        } else { //#28978
            $1.cclpad = $a(0); //#28977
            $k[$j++] = Infinity; //#28978
            for (var _1X = 0, _1Y = -$1.x; _1X < _1Y; _1X++) { //#28978
                $k[$j++] = 0; //#28978
            } //#28978
            $1.linlpad = $a(); //#28978
        } //#28978
        $1.diff = $f($1.linwidth - $f($1.ccpixx + $1.x)); //#28981
        if ($1.diff > 0) { //#28987
            $k[$j++] = Infinity; //#28983
            for (var _1f = 0, _1g = $1.diff; _1f < _1g; _1f++) { //#28983
                $k[$j++] = 0; //#28983
            } //#28983
            $1.ccrpad = $a(); //#28983
            $1.linrpad = $a(0); //#28984
        } else { //#28987
            $1.ccrpad = $a(0); //#28986
            $k[$j++] = Infinity; //#28987
            for (var _1l = 0, _1m = -$1.diff; _1l < _1m; _1l++) { //#28987
                $k[$j++] = 0; //#28987
            } //#28987
            $1.linrpad = $a(); //#28987
        } //#28987
        $1.linheight = ~~$1.linheight; //#28990
        var _1q = $eq($1.linktype, "a") ? 2 : 3; //#28991
        $1.ccrepeat = _1q; //#28991
        $k[$j++] = Infinity; //#28998
        for (var _1u = 0, _1v = $1.ccpixx, _1t = $1.ccpixs.length - 1; _1v < 0 ? _1u >= _1t : _1u <= _1t; _1u += _1v) { //#28996
            $1.i = _1u; //#28994
            for (var _1x = 0, _1y = $1.ccrepeat; _1x < _1y; _1x++) { //#28995
                $aload($1.cclpad); //#28995
                $aload($geti($1.ccpixs, $1.i, $1.ccpixx)); //#28995
                $aload($1.ccrpad); //#28995
            } //#28995
        } //#28995
        $aload($1.linlpad); //#28997
        $aload($1.sep); //#28997
        $aload($1.linrpad); //#28997
        for (var _29 = 0, _2A = $1.linheight; _29 < _2A; _29++) { //#28998
            $aload($1.linlpad); //#28998
            $aload($1.linpixs); //#28998
            $aload($1.linrpad); //#28998
        } //#28998
        $1.pixs = $a(); //#28998
        $1.pixx = $f($f($1.cclpad.length + $1.ccpixx) + $1.ccrpad.length); //#29001
        $1.pixy = ~~($1.pixs.length / $1.pixx); //#29002
        var _2Q = new Map([
            ["ren", bwipp_renmatrix],
            ["pixs", $1.pixs],
            ["pixx", $1.pixx],
            ["pixy", $1.pixy],
            ["height", $1.pixy / 72],
            ["width", $1.pixx / 72],
            ["opt", $1.options]
        ]); //#29010
        $k[$j++] = _2Q; //#29017
        if (!$1.dontdraw) { //#29017
            $$.save(); //#29014
            bwipp_renmatrix(); //#29015
            $$.restore(); //#29016
        } //#29016
    } //#29016
}

function bwipp_gs1datamatrix() {
    var $1 = {}; //#29050
    $1.ctx = null; //#29052
    $1.dontdraw = false; //#29053
    $1.parse = false; //#29054
    $1.dontlint = false; //#29055
    $1.lintreqs = true; //#29056
    $1.gssep = false; //#29057
    $k[$j++] = $1; //#29059
    bwipp_processoptions(); //#29059
    $1.options = $k[--$j]; //#29059
    $1.barcode = $k[--$j]; //#29060
    $k[$j++] = $1.barcode; //#29062
    $k[$j++] = 'ai'; //#29062
    bwipp_gs1process(); //#29062
    $1.fncs = $k[--$j]; //#29063
    $1.vals = $k[--$j]; //#29064
    $1.ais = $k[--$j]; //#29065
    $1.fnc1 = -1; //#29068
    $1.dmtx = $a([$1.fnc1]); //#29069
    for (var _A = 0, _9 = $1.ais.length - 1; _A <= _9; _A += 1) { //#29085
        $1.i = _A; //#29071
        $1.ai = $get($1.ais, $1.i); //#29072
        $1.val = $get($1.vals, $1.i); //#29073
        var _K = $a(($1.dmtx.length + $1.ai.length) + $1.val.length); //#29074
        $puti(_K, 0, $1.dmtx); //#29075
        $k[$j++] = _K; //#29076
        $k[$j++] = _K; //#29076
        $k[$j++] = $1.dmtx.length; //#29076
        $k[$j++] = $1.ai; //#29076
        $k[$j++] = Infinity; //#29076
        var _O = $k[--$j]; //#29076
        var _P = $k[--$j]; //#29076
        $k[$j++] = _O; //#29076
        $forall(_P); //#29076
        var _Q = $a(); //#29076
        var _R = $k[--$j]; //#29076
        $puti($k[--$j], _R, _Q); //#29076
        var _T = $k[--$j]; //#29077
        $k[$j++] = _T; //#29077
        $k[$j++] = _T; //#29077
        $k[$j++] = $1.dmtx.length + $1.ai.length; //#29077
        $k[$j++] = $1.val; //#29077
        $k[$j++] = Infinity; //#29077
        var _X = $k[--$j]; //#29077
        var _Y = $k[--$j]; //#29077
        $k[$j++] = _X; //#29077
        $forall(_Y); //#29077
        var _Z = $a(); //#29077
        var _a = $k[--$j]; //#29077
        $puti($k[--$j], _a, _Z); //#29077
        $1.dmtx = $k[--$j]; //#29078
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#29084
            var _j = $a($1.dmtx.length + 1); //#29080
            $puti(_j, 0, $1.dmtx); //#29081
            $k[$j++] = _j; //#29082
            $k[$j++] = _j; //#29082
            $k[$j++] = $1.dmtx.length; //#29082
            if ($1.gssep) { //#29082
                $k[$j++] = 29; //#29082
            } else { //#29082
                $k[$j++] = $1.fnc1; //#29082
            } //#29082
            var _o = $k[--$j]; //#29082
            var _p = $k[--$j]; //#29082
            $put($k[--$j], _p, _o); //#29082
            $1.dmtx = $k[--$j]; //#29083
        } //#29083
    } //#29083
    $1.barcode = $s(($1.dmtx.length + 1) * 5); //#29088
    $1.i = 0; //#29089
    $1.j = 0; //#29089
    for (;;) { //#29099
        if ($1.i == $1.dmtx.length) { //#29090
            break; //#29090
        } //#29090
        var _y = $get($1.dmtx, $1.i); //#29091
        $k[$j++] = _y; //#29096
        if (_y == $1.fnc1) { //#29095
            $j--; //#29092
            $puti($1.barcode, $1.j, "^FNC1"); //#29092
            $1.j = $1.j + 4; //#29093
        } else { //#29095
            $put($1.barcode, $1.j, $k[--$j]); //#29095
        } //#29095
        $1.i = $1.i + 1; //#29097
        $1.j = $1.j + 1; //#29098
    } //#29098
    $1.barcode = $geti($1.barcode, 0, $1.j); //#29100
    delete $1.options["parse"]; //#29103
    $put($1.options, "dontdraw", true); //#29104
    $put($1.options, "parsefnc", true); //#29105
    $k[$j++] = 'args'; //#29106
    $k[$j++] = $1.barcode; //#29106
    $k[$j++] = $1.options; //#29106
    bwipp_datamatrix(); //#29106
    var _1G = $k[--$j]; //#29106
    $1[$k[--$j]] = _1G; //#29106
    $put($1.args, "opt", $1.options); //#29108
    $k[$j++] = $1.args; //#29111
    if (!$1.dontdraw) { //#29111
        bwipp_renmatrix(); //#29111
    } //#29111
}

function bwipp_gs1datamatrixrectangular() {
    var $1 = {}; //#29143
    $1.ctx = null; //#29145
    $1.parse = false; //#29146
    $1.dontlint = false; //#29147
    $1.lintreqs = true; //#29148
    $1.dontdraw = false; //#29149
    $1.gssep = false; //#29150
    $k[$j++] = $1; //#29152
    bwipp_processoptions(); //#29152
    $1.options = $k[--$j]; //#29152
    $1.barcode = $k[--$j]; //#29153
    $k[$j++] = $1.barcode; //#29155
    $k[$j++] = 'ai'; //#29155
    bwipp_gs1process(); //#29155
    $1.fncs = $k[--$j]; //#29156
    $1.vals = $k[--$j]; //#29157
    $1.ais = $k[--$j]; //#29158
    $1.fnc1 = -1; //#29161
    $1.dmtx = $a([$1.fnc1]); //#29162
    for (var _A = 0, _9 = $1.ais.length - 1; _A <= _9; _A += 1) { //#29178
        $1.i = _A; //#29164
        $1.ai = $get($1.ais, $1.i); //#29165
        $1.val = $get($1.vals, $1.i); //#29166
        var _K = $a(($1.dmtx.length + $1.ai.length) + $1.val.length); //#29167
        $puti(_K, 0, $1.dmtx); //#29168
        $k[$j++] = _K; //#29169
        $k[$j++] = _K; //#29169
        $k[$j++] = $1.dmtx.length; //#29169
        $k[$j++] = $1.ai; //#29169
        $k[$j++] = Infinity; //#29169
        var _O = $k[--$j]; //#29169
        var _P = $k[--$j]; //#29169
        $k[$j++] = _O; //#29169
        $forall(_P); //#29169
        var _Q = $a(); //#29169
        var _R = $k[--$j]; //#29169
        $puti($k[--$j], _R, _Q); //#29169
        var _T = $k[--$j]; //#29170
        $k[$j++] = _T; //#29170
        $k[$j++] = _T; //#29170
        $k[$j++] = $1.dmtx.length + $1.ai.length; //#29170
        $k[$j++] = $1.val; //#29170
        $k[$j++] = Infinity; //#29170
        var _X = $k[--$j]; //#29170
        var _Y = $k[--$j]; //#29170
        $k[$j++] = _X; //#29170
        $forall(_Y); //#29170
        var _Z = $a(); //#29170
        var _a = $k[--$j]; //#29170
        $puti($k[--$j], _a, _Z); //#29170
        $1.dmtx = $k[--$j]; //#29171
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#29177
            var _j = $a($1.dmtx.length + 1); //#29173
            $puti(_j, 0, $1.dmtx); //#29174
            $k[$j++] = _j; //#29175
            $k[$j++] = _j; //#29175
            $k[$j++] = $1.dmtx.length; //#29175
            if ($1.gssep) { //#29175
                $k[$j++] = 29; //#29175
            } else { //#29175
                $k[$j++] = $1.fnc1; //#29175
            } //#29175
            var _o = $k[--$j]; //#29175
            var _p = $k[--$j]; //#29175
            $put($k[--$j], _p, _o); //#29175
            $1.dmtx = $k[--$j]; //#29176
        } //#29176
    } //#29176
    $1.barcode = $s(($1.dmtx.length + 1) * 5); //#29181
    $1.i = 0; //#29182
    $1.j = 0; //#29182
    for (;;) { //#29192
        if ($1.i == $1.dmtx.length) { //#29183
            break; //#29183
        } //#29183
        var _y = $get($1.dmtx, $1.i); //#29184
        $k[$j++] = _y; //#29189
        if (_y == $1.fnc1) { //#29188
            $j--; //#29185
            $puti($1.barcode, $1.j, "^FNC1"); //#29185
            $1.j = $1.j + 4; //#29186
        } else { //#29188
            $put($1.barcode, $1.j, $k[--$j]); //#29188
        } //#29188
        $1.i = $1.i + 1; //#29190
        $1.j = $1.j + 1; //#29191
    } //#29191
    $1.barcode = $geti($1.barcode, 0, $1.j); //#29193
    delete $1.options["parse"]; //#29196
    $put($1.options, "dontdraw", true); //#29197
    $put($1.options, "parsefnc", true); //#29198
    $put($1.options, "format", "rectangle"); //#29199
    $k[$j++] = 'args'; //#29200
    $k[$j++] = $1.barcode; //#29200
    $k[$j++] = $1.options; //#29200
    bwipp_datamatrix(); //#29200
    var _1H = $k[--$j]; //#29200
    $1[$k[--$j]] = _1H; //#29200
    $put($1.args, "opt", $1.options); //#29202
    $k[$j++] = $1.args; //#29205
    if (!$1.dontdraw) { //#29205
        bwipp_renmatrix(); //#29205
    } //#29205
}

function bwipp_gs1dldatamatrix() {
    var $1 = {}; //#29237
    $1.ctx = null; //#29239
    $1.parse = false; //#29240
    $1.dontlint = false; //#29241
    $1.lintreqs = true; //#29242
    $1.dontdraw = false; //#29243
    $k[$j++] = $1; //#29245
    bwipp_processoptions(); //#29245
    $1.options = $k[--$j]; //#29245
    $1.barcode = $k[--$j]; //#29246
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#29252
    $1.fncvals = _3; //#29253
    $k[$j++] = 'barcode'; //#29254
    $k[$j++] = $1.barcode; //#29254
    $k[$j++] = $1.fncvals; //#29254
    bwipp_parseinput(); //#29254
    var _6 = $k[--$j]; //#29254
    $1[$k[--$j]] = _6; //#29254
    $k[$j++] = $1.barcode; //#29256
    $k[$j++] = 'dl'; //#29256
    bwipp_gs1process(); //#29256
    $j -= 3; //#29256
    delete $1.options["parse"]; //#29259
    $put($1.options, "dontdraw", true); //#29260
    $k[$j++] = 'args'; //#29261
    $k[$j++] = $1.barcode; //#29261
    $k[$j++] = $1.options; //#29261
    bwipp_datamatrix(); //#29261
    var _D = $k[--$j]; //#29261
    $1[$k[--$j]] = _D; //#29261
    $put($1.args, "opt", $1.options); //#29263
    $k[$j++] = $1.args; //#29266
    if (!$1.dontdraw) { //#29266
        bwipp_renmatrix(); //#29266
    } //#29266
}

function bwipp_gs1qrcode() {
    var $1 = {}; //#29297
    $1.ctx = null; //#29299
    $1.parse = false; //#29300
    $1.dontlint = false; //#29301
    $1.lintreqs = true; //#29302
    $1.dontdraw = false; //#29303
    $k[$j++] = $1; //#29305
    bwipp_processoptions(); //#29305
    $1.options = $k[--$j]; //#29305
    $1.barcode = $k[--$j]; //#29306
    $k[$j++] = $1.barcode; //#29308
    $k[$j++] = 'ai'; //#29308
    bwipp_gs1process(); //#29308
    $1.fncs = $k[--$j]; //#29309
    $1.vals = $k[--$j]; //#29310
    $1.ais = $k[--$j]; //#29311
    $1.fnc1 = -1; //#29314
    $1.qrc = $a([$1.fnc1]); //#29315
    for (var _A = 0, _9 = $1.ais.length - 1; _A <= _9; _A += 1) { //#29331
        $1.i = _A; //#29317
        $1.ai = $get($1.ais, $1.i); //#29318
        $1.val = $get($1.vals, $1.i); //#29319
        var _K = $a(($1.qrc.length + $1.ai.length) + $1.val.length); //#29320
        $puti(_K, 0, $1.qrc); //#29321
        $k[$j++] = _K; //#29322
        $k[$j++] = _K; //#29322
        $k[$j++] = $1.qrc.length; //#29322
        $k[$j++] = $1.ai; //#29322
        $k[$j++] = Infinity; //#29322
        var _O = $k[--$j]; //#29322
        var _P = $k[--$j]; //#29322
        $k[$j++] = _O; //#29322
        $forall(_P); //#29322
        var _Q = $a(); //#29322
        var _R = $k[--$j]; //#29322
        $puti($k[--$j], _R, _Q); //#29322
        var _T = $k[--$j]; //#29323
        $k[$j++] = _T; //#29323
        $k[$j++] = _T; //#29323
        $k[$j++] = $1.qrc.length + $1.ai.length; //#29323
        $k[$j++] = $1.val; //#29323
        $k[$j++] = Infinity; //#29323
        var _X = $k[--$j]; //#29323
        var _Y = $k[--$j]; //#29323
        $k[$j++] = _X; //#29323
        $forall(_Y); //#29323
        var _Z = $a(); //#29323
        var _a = $k[--$j]; //#29323
        $puti($k[--$j], _a, _Z); //#29323
        $1.qrc = $k[--$j]; //#29324
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#29330
            var _j = $a($1.qrc.length + 1); //#29326
            $puti(_j, 0, $1.qrc); //#29327
            $put(_j, $1.qrc.length, $1.fnc1); //#29328
            $1.qrc = _j; //#29329
        } //#29329
    } //#29329
    $1.barcode = $s(($1.qrc.length + 1) * 5); //#29334
    $1.i = 0; //#29335
    $1.j = 0; //#29335
    for (;;) { //#29345
        if ($1.i == $1.qrc.length) { //#29336
            break; //#29336
        } //#29336
        var _t = $get($1.qrc, $1.i); //#29337
        $k[$j++] = _t; //#29342
        if (_t == $1.fnc1) { //#29341
            $j--; //#29338
            $puti($1.barcode, $1.j, "^FNC1"); //#29338
            $1.j = $1.j + 4; //#29339
        } else { //#29341
            $put($1.barcode, $1.j, $k[--$j]); //#29341
        } //#29341
        $1.i = $1.i + 1; //#29343
        $1.j = $1.j + 1; //#29344
    } //#29344
    $1.barcode = $geti($1.barcode, 0, $1.j); //#29346
    delete $1.options["parse"]; //#29349
    $put($1.options, "dontdraw", true); //#29350
    $put($1.options, "parsefnc", true); //#29351
    $k[$j++] = 'args'; //#29352
    $k[$j++] = $1.barcode; //#29352
    $k[$j++] = $1.options; //#29352
    bwipp_qrcode(); //#29352
    var _1B = $k[--$j]; //#29352
    $1[$k[--$j]] = _1B; //#29352
    $put($1.args, "opt", $1.options); //#29354
    $k[$j++] = $1.args; //#29357
    if (!$1.dontdraw) { //#29357
        bwipp_renmatrix(); //#29357
    } //#29357
}

function bwipp_gs1dlqrcode() {
    var $1 = {}; //#29389
    $1.ctx = null; //#29391
    $1.parse = false; //#29392
    $1.dontlint = false; //#29393
    $1.lintreqs = true; //#29394
    $1.dontdraw = false; //#29395
    $k[$j++] = $1; //#29397
    bwipp_processoptions(); //#29397
    $1.options = $k[--$j]; //#29397
    $1.barcode = $k[--$j]; //#29398
    var _3 = new Map([
        ["parse", $1.parse],
        ["parseonly", true],
        ["parsefnc", false]
    ]); //#29404
    $1.fncvals = _3; //#29405
    $k[$j++] = 'barcode'; //#29406
    $k[$j++] = $1.barcode; //#29406
    $k[$j++] = $1.fncvals; //#29406
    bwipp_parseinput(); //#29406
    var _6 = $k[--$j]; //#29406
    $1[$k[--$j]] = _6; //#29406
    $k[$j++] = $1.barcode; //#29408
    $k[$j++] = 'dl'; //#29408
    bwipp_gs1process(); //#29408
    $j -= 3; //#29408
    delete $1.options["parse"]; //#29411
    $put($1.options, "dontdraw", true); //#29412
    $k[$j++] = 'args'; //#29413
    $k[$j++] = $1.barcode; //#29413
    $k[$j++] = $1.options; //#29413
    bwipp_qrcode(); //#29413
    var _D = $k[--$j]; //#29413
    $1[$k[--$j]] = _D; //#29413
    $put($1.args, "opt", $1.options); //#29415
    $k[$j++] = $1.args; //#29418
    if (!$1.dontdraw) { //#29418
        bwipp_renmatrix(); //#29418
    } //#29418
}

function bwipp_gs1dotcode() {
    var $1 = {}; //#29450
    $1.ctx = null; //#29452
    $1.dontdraw = false; //#29453
    $1.parse = false; //#29454
    $1.dontlint = false; //#29455
    $1.lintreqs = true; //#29456
    $k[$j++] = $1; //#29458
    bwipp_processoptions(); //#29458
    $1.options = $k[--$j]; //#29458
    $1.barcode = $k[--$j]; //#29459
    $k[$j++] = $1.barcode; //#29461
    $k[$j++] = 'ai'; //#29461
    bwipp_gs1process(); //#29461
    $1.fncs = $k[--$j]; //#29462
    $1.vals = $k[--$j]; //#29463
    $1.ais = $k[--$j]; //#29464
    $1.fnc1 = -1; //#29467
    $1.dmtx = $a([$1.fnc1]); //#29468
    for (var _A = 0, _9 = $1.ais.length - 1; _A <= _9; _A += 1) { //#29484
        $1.i = _A; //#29470
        $1.ai = $get($1.ais, $1.i); //#29471
        $1.val = $get($1.vals, $1.i); //#29472
        var _K = $a(($1.dmtx.length + $1.ai.length) + $1.val.length); //#29473
        $puti(_K, 0, $1.dmtx); //#29474
        $k[$j++] = _K; //#29475
        $k[$j++] = _K; //#29475
        $k[$j++] = $1.dmtx.length; //#29475
        $k[$j++] = $1.ai; //#29475
        $k[$j++] = Infinity; //#29475
        var _O = $k[--$j]; //#29475
        var _P = $k[--$j]; //#29475
        $k[$j++] = _O; //#29475
        $forall(_P); //#29475
        var _Q = $a(); //#29475
        var _R = $k[--$j]; //#29475
        $puti($k[--$j], _R, _Q); //#29475
        var _T = $k[--$j]; //#29476
        $k[$j++] = _T; //#29476
        $k[$j++] = _T; //#29476
        $k[$j++] = $1.dmtx.length + $1.ai.length; //#29476
        $k[$j++] = $1.val; //#29476
        $k[$j++] = Infinity; //#29476
        var _X = $k[--$j]; //#29476
        var _Y = $k[--$j]; //#29476
        $k[$j++] = _X; //#29476
        $forall(_Y); //#29476
        var _Z = $a(); //#29476
        var _a = $k[--$j]; //#29476
        $puti($k[--$j], _a, _Z); //#29476
        $1.dmtx = $k[--$j]; //#29477
        if (($1.i != ($1.ais.length - 1)) && $get($1.fncs, $1.i)) { //#29483
            var _j = $a($1.dmtx.length + 1); //#29479
            $puti(_j, 0, $1.dmtx); //#29480
            $put(_j, $1.dmtx.length, $1.fnc1); //#29481
            $1.dmtx = _j; //#29482
        } //#29482
    } //#29482
    $1.barcode = $s(($1.dmtx.length + 1) * 5); //#29487
    $1.i = 0; //#29488
    $1.j = 0; //#29488
    for (;;) { //#29498
        if ($1.i == $1.dmtx.length) { //#29489
            break; //#29489
        } //#29489
        var _t = $get($1.dmtx, $1.i); //#29490
        $k[$j++] = _t; //#29495
        if (_t == $1.fnc1) { //#29494
            $j--; //#29491
            $puti($1.barcode, $1.j, "^FNC1"); //#29491
            $1.j = $1.j + 4; //#29492
        } else { //#29494
            $put($1.barcode, $1.j, $k[--$j]); //#29494
        } //#29494
        $1.i = $1.i + 1; //#29496
        $1.j = $1.j + 1; //#29497
    } //#29497
    $1.barcode = $geti($1.barcode, 0, $1.j); //#29499
    delete $1.options["parse"]; //#29502
    $put($1.options, "dontdraw", true); //#29503
    $put($1.options, "parsefnc", true); //#29504
    $k[$j++] = 'args'; //#29505
    $k[$j++] = $1.barcode; //#29505
    $k[$j++] = $1.options; //#29505
    bwipp_dotcode(); //#29505
    var _1B = $k[--$j]; //#29505
    $1[$k[--$j]] = _1B; //#29505
    $put($1.args, "opt", $1.options); //#29507
    $k[$j++] = $1.args; //#29510
    if (!$1.dontdraw) { //#29510
        bwipp_renmatrix(); //#29510
    } //#29510
}

function bwipp_hibccode39() {
    var $1 = {}; //#29543
    $1.ctx = null; //#29545
    $1.dontdraw = false; //#29546
    $1.textfont = "OCR-B"; //#29547
    $1.textsize = 10; //#29548
    $1.textyoffset = -8; //#29549
    $1.textxoffset = 0; //#29550
    $1.validatecheck = false; //#29551
    $k[$j++] = $1; //#29553
    bwipp_processoptions(); //#29553
    $1.options = $k[--$j]; //#29553
    $1.barcode = $k[--$j]; //#29554
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#29560
    $1.charvals = new Map; //#29561
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#29562
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#29562
    } //#29562
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#29570
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#29567
        if (!_C) { //#29569
            $k[$j++] = 'bwipp.hibccode39badCharacter'; //#29568
            $k[$j++] = "HIBC Code 39 must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#29568
            bwipp_raiseerror(); //#29568
        } //#29568
    } //#29568
    $k[$j++] = 'barlen'; //#29572
    $k[$j++] = $1.barcode.length; //#29572
    if ($1.validatecheck) { //#29572
        var _F = $k[--$j]; //#29572
        $k[$j++] = $f(_F - 1); //#29572
    } //#29572
    var _G = $k[--$j]; //#29572
    $1[$k[--$j]] = _G; //#29572
    $1.checksum = 41; //#29574
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#29578
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#29577
    } //#29577
    $1.checksum = $1.checksum % 43; //#29579
    if ($1.validatecheck) { //#29585
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#29583
            $k[$j++] = 'bwipp.hibccode39badCheckDigit'; //#29582
            $k[$j++] = "Incorrect HIBC Code 39 check digit provided"; //#29582
            bwipp_raiseerror(); //#29582
        } //#29582
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#29584
    } //#29584
    var _c = $s($f($1.barlen + 2)); //#29587
    $puti(_c, 1, $1.barcode); //#29587
    $1.barcode = _c; //#29587
    $put($1.barcode, 0, 43); //#29588
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#29589
    $1.text = $s($f($1.barlen + 4)); //#29591
    $put($1.text, 0, 42); //#29592
    $puti($1.text, 1, $1.barcode); //#29593
    var _t = $get($1.barcode, $f($1.barlen + 1)); //#29594
    $k[$j++] = $1.text; //#29594
    $k[$j++] = $f($1.barlen + 2); //#29594
    $k[$j++] = _t; //#29594
    if (_t == 32) { //#29594
        $j--; //#29594
        $k[$j++] = 95; //#29594
    } //#29594
    var _u = $k[--$j]; //#29594
    var _v = $k[--$j]; //#29594
    $put($k[--$j], _v, _u); //#29594
    $put($1.text, $f($1.barlen + 3), 42); //#29595
    $put($1.options, "dontdraw", true); //#29598
    $put($1.options, "includecheck", false); //#29599
    $put($1.options, "validatecheck", false); //#29600
    $k[$j++] = 'args'; //#29601
    $k[$j++] = $1.barcode; //#29601
    $k[$j++] = $1.options; //#29601
    bwipp_code39(); //#29601
    var _14 = $k[--$j]; //#29601
    $1[$k[--$j]] = _14; //#29601
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#29603
    $put($1.args, "textxalign", "center"); //#29604
    $put($1.args, "opt", $1.options); //#29605
    $k[$j++] = $1.args; //#29608
    if (!$1.dontdraw) { //#29608
        bwipp_renlinear(); //#29608
    } //#29608
}

function bwipp_hibccode128() {
    var $1 = {}; //#29643
    $1.ctx = null; //#29645
    $1.dontdraw = false; //#29646
    $1.textfont = "OCR-B"; //#29647
    $1.textsize = 10; //#29648
    $1.textyoffset = -8; //#29649
    $1.textxoffset = 0; //#29650
    $1.validatecheck = false; //#29651
    $k[$j++] = $1; //#29653
    bwipp_processoptions(); //#29653
    $1.options = $k[--$j]; //#29653
    $1.barcode = $k[--$j]; //#29654
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#29660
    $1.charvals = new Map; //#29661
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#29662
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#29662
    } //#29662
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#29670
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#29667
        if (!_C) { //#29669
            $k[$j++] = 'bwipp.hibccode128badCharacter'; //#29668
            $k[$j++] = "HIBC Code 128 must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#29668
            bwipp_raiseerror(); //#29668
        } //#29668
    } //#29668
    $k[$j++] = 'barlen'; //#29672
    $k[$j++] = $1.barcode.length; //#29672
    if ($1.validatecheck) { //#29672
        var _F = $k[--$j]; //#29672
        $k[$j++] = $f(_F - 1); //#29672
    } //#29672
    var _G = $k[--$j]; //#29672
    $1[$k[--$j]] = _G; //#29672
    $1.checksum = 41; //#29674
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#29678
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#29677
    } //#29677
    $1.checksum = $1.checksum % 43; //#29679
    if ($1.validatecheck) { //#29685
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#29683
            $k[$j++] = 'bwipp.hibccode128badCheckDigit'; //#29682
            $k[$j++] = "Incorrect HIBC Code 128 check digit provided"; //#29682
            bwipp_raiseerror(); //#29682
        } //#29682
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#29684
    } //#29684
    var _c = $s($f($1.barlen + 2)); //#29687
    $puti(_c, 1, $1.barcode); //#29687
    $1.barcode = _c; //#29687
    $put($1.barcode, 0, 43); //#29688
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#29689
    $1.text = $s($f($1.barlen + 4)); //#29691
    $put($1.text, 0, 42); //#29692
    $puti($1.text, 1, $1.barcode); //#29693
    var _t = $get($1.barcode, $f($1.barlen + 1)); //#29694
    $k[$j++] = $1.text; //#29694
    $k[$j++] = $f($1.barlen + 2); //#29694
    $k[$j++] = _t; //#29694
    if (_t == 32) { //#29694
        $j--; //#29694
        $k[$j++] = 95; //#29694
    } //#29694
    var _u = $k[--$j]; //#29694
    var _v = $k[--$j]; //#29694
    $put($k[--$j], _v, _u); //#29694
    $put($1.text, $f($1.barlen + 3), 42); //#29695
    $put($1.options, "dontdraw", true); //#29698
    $put($1.options, "validatecheck", false); //#29699
    $k[$j++] = 'args'; //#29700
    $k[$j++] = $1.barcode; //#29700
    $k[$j++] = $1.options; //#29700
    bwipp_code128(); //#29700
    var _13 = $k[--$j]; //#29700
    $1[$k[--$j]] = _13; //#29700
    $put($1.args, "txt", $a([$a([$1.text, $1.textxoffset, $1.textyoffset, $1.textfont, $1.textsize])])); //#29702
    $put($1.args, "textxalign", "center"); //#29703
    $put($1.args, "opt", $1.options); //#29704
    $k[$j++] = $1.args; //#29707
    if (!$1.dontdraw) { //#29707
        bwipp_renlinear(); //#29707
    } //#29707
}

function bwipp_hibcdatamatrix() {
    var $1 = {}; //#29742
    $1.ctx = null; //#29744
    $1.dontdraw = false; //#29745
    $1.validatecheck = false; //#29746
    $k[$j++] = $1; //#29748
    bwipp_processoptions(); //#29748
    $1.options = $k[--$j]; //#29748
    $1.barcode = $k[--$j]; //#29749
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#29755
    $1.charvals = new Map; //#29756
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#29757
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#29757
    } //#29757
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#29765
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#29762
        if (!_C) { //#29764
            $k[$j++] = 'bwipp.hibcdatamatrixBadCharacter'; //#29763
            $k[$j++] = "HIBC Data Matrix must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#29763
            bwipp_raiseerror(); //#29763
        } //#29763
    } //#29763
    $k[$j++] = 'barlen'; //#29767
    $k[$j++] = $1.barcode.length; //#29767
    if ($1.validatecheck) { //#29767
        var _F = $k[--$j]; //#29767
        $k[$j++] = $f(_F - 1); //#29767
    } //#29767
    var _G = $k[--$j]; //#29767
    $1[$k[--$j]] = _G; //#29767
    $1.checksum = 41; //#29769
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#29773
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#29772
    } //#29772
    $1.checksum = $1.checksum % 43; //#29774
    if ($1.validatecheck) { //#29780
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#29778
            $k[$j++] = 'bwipp.hibcdatamatrixBadCheckDigit'; //#29777
            $k[$j++] = "Incorrect HIBC Data Matrix check digit provided"; //#29777
            bwipp_raiseerror(); //#29777
        } //#29777
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#29779
    } //#29779
    var _c = $s($f($1.barlen + 2)); //#29782
    $puti(_c, 1, $1.barcode); //#29782
    $1.barcode = _c; //#29782
    $put($1.barcode, 0, 43); //#29783
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#29784
    $put($1.options, "dontdraw", true); //#29787
    $put($1.options, "validatecheck", false); //#29788
    $k[$j++] = 'args'; //#29789
    $k[$j++] = $1.barcode; //#29789
    $k[$j++] = $1.options; //#29789
    bwipp_datamatrix(); //#29789
    var _o = $k[--$j]; //#29789
    $1[$k[--$j]] = _o; //#29789
    var _r = $1.options; //#29791
    $put($1.args, "opt", _r); //#29791
    $k[$j++] = $1.args; //#29794
    if (!$1.dontdraw) { //#29794
        bwipp_renmatrix(); //#29794
    } //#29794
}

function bwipp_hibcdatamatrixrectangular() {
    var $1 = {}; //#29829
    $1.ctx = null; //#29831
    $1.dontdraw = false; //#29832
    $1.validatecheck = false; //#29833
    $k[$j++] = $1; //#29835
    bwipp_processoptions(); //#29835
    $1.options = $k[--$j]; //#29835
    $1.barcode = $k[--$j]; //#29836
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#29842
    $1.charvals = new Map; //#29843
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#29844
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#29844
    } //#29844
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#29852
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#29849
        if (!_C) { //#29851
            $k[$j++] = 'bwipp.hibcdatamatrixrectangularBadCharacter'; //#29850
            $k[$j++] = "HIBC Data Matrix Rectangular must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#29850
            bwipp_raiseerror(); //#29850
        } //#29850
    } //#29850
    $k[$j++] = 'barlen'; //#29854
    $k[$j++] = $1.barcode.length; //#29854
    if ($1.validatecheck) { //#29854
        var _F = $k[--$j]; //#29854
        $k[$j++] = $f(_F - 1); //#29854
    } //#29854
    var _G = $k[--$j]; //#29854
    $1[$k[--$j]] = _G; //#29854
    $1.checksum = 41; //#29856
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#29860
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#29859
    } //#29859
    $1.checksum = $1.checksum % 43; //#29861
    if ($1.validatecheck) { //#29867
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#29865
            $k[$j++] = 'bwipp.hibcdatamatrixrectangularBadCheckDigit'; //#29864
            $k[$j++] = "Incorrect HIBC Data Matrix Rectangular check digit provided"; //#29864
            bwipp_raiseerror(); //#29864
        } //#29864
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#29866
    } //#29866
    var _c = $s($f($1.barlen + 2)); //#29869
    $puti(_c, 1, $1.barcode); //#29869
    $1.barcode = _c; //#29869
    $put($1.barcode, 0, 43); //#29870
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#29871
    $put($1.options, "dontdraw", true); //#29874
    $put($1.options, "validatecheck", false); //#29875
    $put($1.options, "format", "rectangle"); //#29876
    $k[$j++] = 'args'; //#29877
    $k[$j++] = $1.barcode; //#29877
    $k[$j++] = $1.options; //#29877
    bwipp_datamatrix(); //#29877
    var _p = $k[--$j]; //#29877
    $1[$k[--$j]] = _p; //#29877
    var _r = $1.args; //#29879
    $put(_r, "opt", $1.options); //#29879
    $k[$j++] = $1.args; //#29882
    if (!$1.dontdraw) { //#29882
        bwipp_renmatrix(); //#29882
    } //#29882
}

function bwipp_hibcpdf417() {
    var $1 = {}; //#29917
    $1.ctx = null; //#29919
    $1.dontdraw = false; //#29920
    $1.columns = 2; //#29921
    $1.validatecheck = false; //#29922
    $k[$j++] = $1; //#29924
    bwipp_processoptions(); //#29924
    $1.options = $k[--$j]; //#29924
    $1.barcode = $k[--$j]; //#29925
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#29931
    $1.charvals = new Map; //#29932
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#29933
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#29933
    } //#29933
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#29941
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#29938
        if (!_C) { //#29940
            $k[$j++] = 'bwipp.hibcpdf417BadCharacter'; //#29939
            $k[$j++] = "HIBC PDF417 must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#29939
            bwipp_raiseerror(); //#29939
        } //#29939
    } //#29939
    $k[$j++] = 'barlen'; //#29943
    $k[$j++] = $1.barcode.length; //#29943
    if ($1.validatecheck) { //#29943
        var _F = $k[--$j]; //#29943
        $k[$j++] = $f(_F - 1); //#29943
    } //#29943
    var _G = $k[--$j]; //#29943
    $1[$k[--$j]] = _G; //#29943
    $1.checksum = 41; //#29945
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#29949
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#29948
    } //#29948
    $1.checksum = $1.checksum % 43; //#29950
    if ($1.validatecheck) { //#29956
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#29954
            $k[$j++] = 'bwipp.hibcpdf417BadCheckDigit'; //#29953
            $k[$j++] = "Incorrect HIBC PDF417 check digit provided"; //#29953
            bwipp_raiseerror(); //#29953
        } //#29953
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#29955
    } //#29955
    var _c = $s($f($1.barlen + 2)); //#29958
    $puti(_c, 1, $1.barcode); //#29958
    $1.barcode = _c; //#29958
    $put($1.barcode, 0, 43); //#29959
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#29960
    $put($1.options, "dontdraw", true); //#29963
    $put($1.options, "columns", $1.columns); //#29964
    $put($1.options, "validatecheck", false); //#29965
    var _p = $1.options; //#29966
    $k[$j++] = 'args'; //#29966
    $k[$j++] = $1.barcode; //#29966
    $k[$j++] = _p; //#29966
    bwipp_pdf417(); //#29966
    var _q = $k[--$j]; //#29966
    var _r = $k[--$j]; //#29966
    $1[_r] = _q; //#29966
    $put($1.args, "opt", $1.options); //#29968
    $k[$j++] = $1.args; //#29971
    if (!$1.dontdraw) { //#29971
        bwipp_renmatrix(); //#29971
    } //#29971
}

function bwipp_hibcmicropdf417() {
    var $1 = {}; //#30006
    $1.ctx = null; //#30008
    $1.dontdraw = false; //#30009
    $1.columns = 2; //#30010
    $1.validatecheck = false; //#30011
    $k[$j++] = $1; //#30013
    bwipp_processoptions(); //#30013
    $1.options = $k[--$j]; //#30013
    $1.barcode = $k[--$j]; //#30014
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#30020
    $1.charvals = new Map; //#30021
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#30022
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#30022
    } //#30022
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#30030
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#30027
        if (!_C) { //#30029
            $k[$j++] = 'bwipp.hibcmicropdf417BadCharacter'; //#30028
            $k[$j++] = "HIBC MicroPDF417 must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#30028
            bwipp_raiseerror(); //#30028
        } //#30028
    } //#30028
    $k[$j++] = 'barlen'; //#30032
    $k[$j++] = $1.barcode.length; //#30032
    if ($1.validatecheck) { //#30032
        var _F = $k[--$j]; //#30032
        $k[$j++] = $f(_F - 1); //#30032
    } //#30032
    var _G = $k[--$j]; //#30032
    $1[$k[--$j]] = _G; //#30032
    $1.checksum = 41; //#30034
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#30038
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#30037
    } //#30037
    $1.checksum = $1.checksum % 43; //#30039
    if ($1.validatecheck) { //#30045
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#30043
            $k[$j++] = 'bwipp.hibcmicropdf417BadCheckDigit'; //#30042
            $k[$j++] = "Incorrect HIBC MicroPDF417 check digit provided"; //#30042
            bwipp_raiseerror(); //#30042
        } //#30042
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#30044
    } //#30044
    var _c = $s($f($1.barlen + 2)); //#30047
    $puti(_c, 1, $1.barcode); //#30047
    $1.barcode = _c; //#30047
    $put($1.barcode, 0, 43); //#30048
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#30049
    $put($1.options, "dontdraw", true); //#30052
    var _m = $1.columns; //#30053
    $put($1.options, "columns", _m); //#30053
    $put($1.options, "validatecheck", false); //#30054
    $k[$j++] = 'args'; //#30055
    $k[$j++] = $1.barcode; //#30055
    $k[$j++] = $1.options; //#30055
    bwipp_micropdf417(); //#30055
    var _q = $k[--$j]; //#30055
    var _r = $k[--$j]; //#30055
    $1[_r] = _q; //#30055
    $put($1.args, "opt", $1.options); //#30057
    $k[$j++] = $1.args; //#30060
    if (!$1.dontdraw) { //#30060
        bwipp_renmatrix(); //#30060
    } //#30060
}

function bwipp_hibcqrcode() {
    var $1 = {}; //#30095
    $1.ctx = null; //#30097
    $1.dontdraw = false; //#30098
    $1.validatecheck = false; //#30099
    $k[$j++] = $1; //#30101
    bwipp_processoptions(); //#30101
    $1.options = $k[--$j]; //#30101
    $1.barcode = $k[--$j]; //#30102
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#30108
    $1.charvals = new Map; //#30109
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#30110
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#30110
    } //#30110
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#30118
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#30115
        if (!_C) { //#30117
            $k[$j++] = 'bwipp.hibcqrcodeBadCharacter'; //#30116
            $k[$j++] = "HIBC QR Code must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#30116
            bwipp_raiseerror(); //#30116
        } //#30116
    } //#30116
    $k[$j++] = 'barlen'; //#30120
    $k[$j++] = $1.barcode.length; //#30120
    if ($1.validatecheck) { //#30120
        var _F = $k[--$j]; //#30120
        $k[$j++] = $f(_F - 1); //#30120
    } //#30120
    var _G = $k[--$j]; //#30120
    $1[$k[--$j]] = _G; //#30120
    $1.checksum = 41; //#30122
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#30126
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#30125
    } //#30125
    $1.checksum = $1.checksum % 43; //#30127
    if ($1.validatecheck) { //#30133
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#30131
            $k[$j++] = 'bwipp.hibcqrcodeBadCheckDigit'; //#30130
            $k[$j++] = "Incorrect HIBC QR Code check digit provided"; //#30130
            bwipp_raiseerror(); //#30130
        } //#30130
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#30132
    } //#30132
    var _c = $s($f($1.barlen + 2)); //#30135
    $puti(_c, 1, $1.barcode); //#30135
    $1.barcode = _c; //#30135
    $put($1.barcode, 0, 43); //#30136
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#30137
    $put($1.options, "dontdraw", true); //#30140
    $put($1.options, "validatecheck", false); //#30141
    $k[$j++] = 'args'; //#30142
    $k[$j++] = $1.barcode; //#30142
    $k[$j++] = $1.options; //#30142
    bwipp_qrcode(); //#30142
    var _o = $k[--$j]; //#30142
    $1[$k[--$j]] = _o; //#30142
    var _r = $1.options; //#30144
    $put($1.args, "opt", _r); //#30144
    $k[$j++] = $1.args; //#30147
    if (!$1.dontdraw) { //#30147
        bwipp_renmatrix(); //#30147
    } //#30147
}

function bwipp_hibccodablockf() {
    var $1 = {}; //#30182
    $1.ctx = null; //#30184
    $1.dontdraw = false; //#30185
    $1.validatecheck = false; //#30186
    $k[$j++] = $1; //#30188
    bwipp_processoptions(); //#30188
    $1.options = $k[--$j]; //#30188
    $1.barcode = $k[--$j]; //#30189
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#30195
    $1.charvals = new Map; //#30196
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#30197
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#30197
    } //#30197
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#30205
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#30202
        if (!_C) { //#30204
            $k[$j++] = 'bwipp.codablockfBadCharacter'; //#30203
            $k[$j++] = "HIBC Codablock F must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#30203
            bwipp_raiseerror(); //#30203
        } //#30203
    } //#30203
    $k[$j++] = 'barlen'; //#30207
    $k[$j++] = $1.barcode.length; //#30207
    if ($1.validatecheck) { //#30207
        var _F = $k[--$j]; //#30207
        $k[$j++] = $f(_F - 1); //#30207
    } //#30207
    var _G = $k[--$j]; //#30207
    $1[$k[--$j]] = _G; //#30207
    $1.checksum = 41; //#30209
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#30213
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#30212
    } //#30212
    $1.checksum = $1.checksum % 43; //#30214
    if ($1.validatecheck) { //#30220
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#30218
            $k[$j++] = 'bwipp.hibccodablockfBadCheckDigit'; //#30217
            $k[$j++] = "Incorrect HIBC Codablock F check digit provided"; //#30217
            bwipp_raiseerror(); //#30217
        } //#30217
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#30219
    } //#30219
    var _c = $s($f($1.barlen + 2)); //#30222
    $puti(_c, 1, $1.barcode); //#30222
    $1.barcode = _c; //#30222
    $put($1.barcode, 0, 43); //#30223
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#30224
    $put($1.options, "dontdraw", true); //#30227
    $put($1.options, "validatecheck", false); //#30228
    $k[$j++] = 'args'; //#30229
    $k[$j++] = $1.barcode; //#30229
    $k[$j++] = $1.options; //#30229
    bwipp_codablockf(); //#30229
    var _o = $k[--$j]; //#30229
    $1[$k[--$j]] = _o; //#30229
    var _r = $1.options; //#30231
    $put($1.args, "opt", _r); //#30231
    $k[$j++] = $1.args; //#30234
    if (!$1.dontdraw) { //#30234
        bwipp_renmatrix(); //#30234
    } //#30234
}

function bwipp_hibcazteccode() {
    var $1 = {}; //#30269
    $1.ctx = null; //#30271
    $1.dontdraw = false; //#30272
    $1.validatecheck = false; //#30273
    $k[$j++] = $1; //#30275
    bwipp_processoptions(); //#30275
    $1.options = $k[--$j]; //#30275
    $1.barcode = $k[--$j]; //#30276
    $1.barchars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"; //#30282
    $1.charvals = new Map; //#30283
    for (var _2 = 0; _2 <= 42; _2 += 1) { //#30284
        $put($1.charvals, $geti($1.barchars, _2, 1), _2); //#30284
    } //#30284
    for (var _8 = 0, _7 = $1.barcode.length - 1; _8 <= _7; _8 += 1) { //#30292
        var _C = $get($1.charvals, $geti($1.barcode, _8, 1)) !== undefined; //#30289
        if (!_C) { //#30291
            $k[$j++] = 'bwipp.hibcazteccodeBadCharacter'; //#30290
            $k[$j++] = "HIBC Aztec Code must contain only digits, capital letters, spaces and the symbols -.$/+%"; //#30290
            bwipp_raiseerror(); //#30290
        } //#30290
    } //#30290
    $k[$j++] = 'barlen'; //#30294
    $k[$j++] = $1.barcode.length; //#30294
    if ($1.validatecheck) { //#30294
        var _F = $k[--$j]; //#30294
        $k[$j++] = $f(_F - 1); //#30294
    } //#30294
    var _G = $k[--$j]; //#30294
    $1[$k[--$j]] = _G; //#30294
    $1.checksum = 41; //#30296
    for (var _K = 0, _J = $f($1.barlen - 1); _K <= _J; _K += 1) { //#30300
        $1.checksum = $f($get($1.charvals, $geti($1.barcode, _K, 1)) + $1.checksum); //#30299
    } //#30299
    $1.checksum = $1.checksum % 43; //#30301
    if ($1.validatecheck) { //#30307
        if ($get($1.barcode, $1.barlen) != $get($1.barchars, $1.checksum)) { //#30305
            $k[$j++] = 'bwipp.hibcazteccodeBadCheckDigit'; //#30304
            $k[$j++] = "Incorrect HIBC Aztec Code check digit provided"; //#30304
            bwipp_raiseerror(); //#30304
        } //#30304
        $1.barcode = $geti($1.barcode, 0, $1.barlen); //#30306
    } //#30306
    var _c = $s($f($1.barlen + 2)); //#30309
    $puti(_c, 1, $1.barcode); //#30309
    $1.barcode = _c; //#30309
    $put($1.barcode, 0, 43); //#30310
    $put($1.barcode, $f($1.barlen + 1), $get($1.barchars, $1.checksum)); //#30311
    $put($1.options, "dontdraw", true); //#30314
    $put($1.options, "validatecheck", false); //#30315
    $k[$j++] = 'args'; //#30316
    $k[$j++] = $1.barcode; //#30316
    $k[$j++] = $1.options; //#30316
    bwipp_azteccode(); //#30316
    var _o = $k[--$j]; //#30316
    $1[$k[--$j]] = _o; //#30316
    var _r = $1.options; //#30318
    $put($1.args, "opt", _r); //#30318
    $k[$j++] = $1.args; //#30321
    if (!$1.dontdraw) { //#30321
        bwipp_renmatrix(); //#30321
    } //#30321
}

function bwipp_channelcode() {
    var $1 = {}; //#30353
    $1.options = $k[--$j]; //#30355
    $1.barcode = $k[--$j]; //#30356
    $1.dontdraw = false; //#30358
    $1.shortfinder = false; //#30359
    $1.includetext = false; //#30360
    $1.includecheck = false; //#30361
    $1.height = 1; //#30362
    $forall($1.options, function() { //#30373
        var _3 = $k[--$j]; //#30373
        $1[$k[--$j]] = _3; //#30373
    }); //#30373
    $1.height = +$1.height; //#30375
    if (($1.barcode.length < 2) || ($1.barcode.length > 7)) { //#30380
        $k[$j++] = 'bwipp.channelcodeBadLength'; //#30379
        $k[$j++] = "Channel Code must be 2 to 7 digits"; //#30379
        bwipp_raiseerror(); //#30379
    } //#30379
    $forall($1.barcode, function() { //#30385
        var _9 = $k[--$j]; //#30382
        if ((_9 < 48) || (_9 > 57)) { //#30384
            $k[$j++] = 'bwipp.channelcodeBadCharacter'; //#30383
            $k[$j++] = "Channel Code must contain only digits"; //#30383
            bwipp_raiseerror(); //#30383
        } //#30383
    }); //#30383
    if ($cvi($1.barcode) > $get($a([26, 292, 3493, 44072, 576688, 7742862]), $1.barcode.length - 2)) { //#30388
        $k[$j++] = 'bwipp.channelcodeTooBig'; //#30387
        $k[$j++] = "The Channel Code value is too big for the number of channels"; //#30387
        bwipp_raiseerror(); //#30387
    } //#30387
    $1.nextb = function() {
        var _E = $k[--$j]; //#30391
        var _N = (($f($get($1.s, _E) + ($f($get($1.b, $f(_E - 1)) + $f($get($1.b, $f(_E - 2)) + $get($1.s, $f(_E - 1))))))) > 4) ? 1 : 2; //#30396
        $k[$j++] = _E; //#30412
        $k[$j++] = _N; //#30412
        if (_E < $f($1.chan + 2)) { //#30410
            var _P = $k[--$j]; //#30398
            var _Q = $k[--$j]; //#30398
            var _R = $k[--$j]; //#30398
            $k[$j++] = _R; //#30401
            $k[$j++] = _Q; //#30401
            $k[$j++] = _P; //#30401
            for (var _T = _P, _S = _R; _T <= _S; _T += 1) { //#30401
                var _V = $k[--$j]; //#30399
                var _W = $k[--$j]; //#30399
                $put($1.b, _W, _T); //#30399
                var _X = $k[--$j]; //#30400
                var _Y = $k[--$j]; //#30400
                $k[$j++] = _Y; //#30400
                $k[$j++] = _X; //#30400
                $k[$j++] = _W; //#30400
                $k[$j++] = _V; //#30400
                $k[$j++] = $f($f(_X - _T) + 1); //#30400
                $k[$j++] = _Y; //#30400
                $k[$j++] = $f(_W + 1); //#30400
                $1.nexts(); //#30400
            } //#30400
        } else { //#30410
            var _Z = $k[--$j]; //#30403
            var _a = $k[--$j]; //#30403
            var _b = $k[--$j]; //#30403
            $k[$j++] = _b; //#30411
            $k[$j++] = _a; //#30411
            $k[$j++] = _Z; //#30411
            if ($le(_Z, _b)) { //#30411
                var _d = $k[--$j]; //#30404
                var _e = $k[--$j]; //#30404
                var _f = $k[--$j]; //#30404
                $put($1.b, _e, _f); //#30404
                $k[$j++] = _f; //#30409
                $k[$j++] = _e; //#30409
                $k[$j++] = _d; //#30409
                if ($1.value == $1.target) { //#30409
                    $k[$j++] = Infinity; //#30407
                    for (var _i = 3; _i <= 10; _i += 1) { //#30407
                        $k[$j++] = $get($1.s, _i); //#30407
                        $k[$j++] = $get($1.b, _i); //#30407
                    } //#30407
                    $1.out = $geti($a(), 0, $1.chan * 2); //#30408
                } //#30408
                $1.value = $1.value + 1; //#30410
            } //#30410
        } //#30410
        $j -= 4; //#30413
    }; //#30414
    $1.nexts = function() {
        var _r = $k[--$j]; //#30417
        $k[$j++] = _r; //#30417
        if (_r < $f($1.chan + 2)) { //#30417
            $k[$j++] = 1; //#30417
        } else { //#30417
            var _t = $k[--$j]; //#30417
            var _u = $k[--$j]; //#30417
            $k[$j++] = _u; //#30417
            $k[$j++] = _t; //#30417
            $k[$j++] = _u; //#30417
        } //#30417
        var _v = $k[--$j]; //#30417
        var _w = $k[--$j]; //#30417
        var _x = $k[--$j]; //#30417
        $k[$j++] = _x; //#30420
        $k[$j++] = _w; //#30420
        for (var _z = _v, _y = _x; _z <= _y; _z += 1) { //#30420
            var _11 = $k[--$j]; //#30418
            $put($1.s, _11, _z); //#30418
            var _12 = $k[--$j]; //#30419
            var _13 = $k[--$j]; //#30419
            $k[$j++] = _13; //#30419
            $k[$j++] = _12; //#30419
            $k[$j++] = _11; //#30419
            $k[$j++] = $f($f(_12 - _z) + 1); //#30419
            $k[$j++] = _13; //#30419
            $k[$j++] = _11; //#30419
            $1.nextb(); //#30419
        } //#30419
        $j -= 3; //#30421
    }; //#30422
    $1.encode = function() {
        $1.chan = $k[--$j]; //#30425
        $1.target = $k[--$j]; //#30426
        $1.value = 0; //#30427
        $1.out = -1; //#30428
        $1.b = $a([1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0]); //#30429
        $1.s = $a([0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0]); //#30430
        var _18 = $1.chan; //#30431
        $k[$j++] = _18; //#30431
        $k[$j++] = _18; //#30431
        $k[$j++] = 3; //#30431
        $1.nexts(); //#30431
        $k[$j++] = $1.out; //#30432
    }; //#30433
    $1.barlen = $1.barcode.length; //#30435
    $k[$j++] = 'finder'; //#30438
    if ($1.shortfinder) { //#30438
        $k[$j++] = $a([1, 1, 1, 1, 1]); //#30438
    } else { //#30438
        $k[$j++] = $a([1, 1, 1, 1, 1, 1, 1, 1, 1]); //#30438
    } //#30438
    var _1E = $k[--$j]; //#30438
    $1[$k[--$j]] = _1E; //#30438
    $k[$j++] = 'data'; //#30441
    $k[$j++] = $cvi($1.barcode); //#30441
    $k[$j++] = $1.barlen + 1; //#30441
    $1.encode(); //#30441
    var _1I = $k[--$j]; //#30441
    $1[$k[--$j]] = _1I; //#30441
    $1.check = $a([]); //#30444
    if ($1.includecheck) { //#30460
        $1.mod23 = $get($a([$a([]), $a([]), $a([13, 12, 4, 9, 3, 1]), $a([13, 2, 12, 3, 18, 16, 4, 1]), $a([11, 16, 17, 8, 20, 4, 10, 2, 5, 1]), $a([1, 4, 16, 18, 3, 12, 2, 8, 9, 13, 6, 1]), $a([20, 16, 22, 13, 15, 12, 5, 4, 8, 9, 21, 3, 7, 1]), $a([2, 6, 18, 8, 1, 3, 9, 4, 12, 13, 16, 2, 6, 18, 8, 1])]), $1.barlen); //#30454
        $k[$j++] = 0; //#30458
        for (var _1Z = 0, _1Y = $1.data.length - 1; _1Z <= _1Y; _1Z += 1) { //#30458
            var _1e = $k[--$j]; //#30457
            $k[$j++] = $f(_1e + ($f($get($1.data, _1Z) - 1) * $get($1.mod23, _1Z))); //#30457
        } //#30457
        var _1f = $k[--$j]; //#30459
        $k[$j++] = _1f % 23; //#30459
        $k[$j++] = 3; //#30459
        $1.encode(); //#30459
        $1.check = $k[--$j]; //#30459
    } //#30459
    $k[$j++] = Infinity; //#30466
    $aload($1.finder); //#30464
    $aload($1.data); //#30465
    $aload($1.check); //#30466
    $1.sbs = $a(); //#30466
    $1.txt = $a($1.barlen); //#30470
    for (var _1p = 0, _1o = $1.barlen - 1; _1p <= _1o; _1p += 1) { //#30474
        $1.i = _1p; //#30472
        $put($1.txt, $1.i, $a([$geti($1.barcode, $1.i, 1), 0, 0, "", 0])); //#30473
    } //#30473
    $k[$j++] = Infinity; //#30484
    var _1w = $1.sbs; //#30479
    $k[$j++] = Infinity; //#30480
    for (var _1y = 0, _1z = ~~(($1.sbs.length + 1) / 2); _1y < _1z; _1y++) { //#30480
        $k[$j++] = $1.height; //#30480
    } //#30480
    var _21 = $a(); //#30480
    $k[$j++] = Infinity; //#30481
    for (var _23 = 0, _24 = ~~(($1.sbs.length + 1) / 2); _23 < _24; _23++) { //#30481
        $k[$j++] = 0; //#30481
    } //#30481
    var _25 = $a(); //#30481
    $k[$j++] = 'ren'; //#30484
    $k[$j++] = bwipp_renlinear; //#30484
    $k[$j++] = 'sbs'; //#30484
    $k[$j++] = _1w; //#30484
    $k[$j++] = 'bhs'; //#30484
    $k[$j++] = _21; //#30484
    $k[$j++] = 'bbs'; //#30484
    $k[$j++] = _25; //#30484
    $k[$j++] = 'txt'; //#30484
    $k[$j++] = $1.txt; //#30484
    $k[$j++] = 'textxalign'; //#30484
    $k[$j++] = "center"; //#30484
    $k[$j++] = 'opt'; //#30484
    $k[$j++] = $1.options; //#30484
    var _28 = $d(); //#30484
    $k[$j++] = _28; //#30487
    if (!$1.dontdraw) { //#30487
        bwipp_renlinear(); //#30487
    } //#30487
}

function bwipp_renlinear() {
    if ($0.bwipjs_dontdraw) { //#30514
        return; //#30514
    } //#30514
    var $1 = {}; //#30515
    $1.args = $k[--$j]; //#30517
    $1.sbs = $a([]); //#30520
    $1.bhs = $a([]); //#30521
    $1.bbs = $a([]); //#30522
    $1.txt = $a([]); //#30523
    $1.barcolor = "unset"; //#30524
    $1.includetext = false; //#30525
    $1.textcolor = "unset"; //#30526
    $1.textxalign = "unset"; //#30527
    $1.textyalign = "unset"; //#30528
    $1.textfont = "OCR-B"; //#30529
    $1.textsize = 10; //#30530
    $1.textxoffset = 0; //#30531
    $1.textyoffset = 0; //#30532
    $1.textgaps = 0; //#30533
    $1.alttext = ""; //#30534
    $1.bordercolor = "unset"; //#30535
    $1.backgroundcolor = "unset"; //#30536
    $1.inkspread = 0; //#30537
    $1.width = 0; //#30538
    $1.barratio = 1; //#30539
    $1.spaceratio = 1; //#30540
    $1.showborder = false; //#30541
    $1.borderleft = 10; //#30542
    $1.borderright = 10; //#30543
    $1.bordertop = 1; //#30544
    $1.borderbottom = 1; //#30545
    $1.borderwidth = 0.5; //#30546
    $1.guardwhitespace = false; //#30547
    $1.guardleftpos = 0; //#30548
    $1.guardleftypos = 0; //#30549
    $1.guardrightpos = 0; //#30550
    $1.guardrightypos = 0; //#30551
    $1.guardwidth = 7; //#30552
    $1.guardheight = 7; //#30553
    $forall($1.args, function() { //#30556
        var _7 = $k[--$j]; //#30556
        $1[$k[--$j]] = _7; //#30556
    }); //#30556
    var _9 = $1.opt; //#30557
    for (var _E = _9.size, _D = _9.keys(), _C = 0; _C < _E; _C++) { //#30557
        var _A = _D.next().value; //#30557
        $1[_A] = _9.get(_A); //#30557
    } //#30557
    $1.barcolor = "" + $1.barcolor; //#30559
    $1.textcolor = "" + $1.textcolor; //#30560
    $1.textxalign = "" + $1.textxalign; //#30561
    $1.textyalign = "" + $1.textyalign; //#30562
    $1.textfont = "" + $1.textfont; //#30563
    $1.textsize = +$1.textsize; //#30564
    $1.textxoffset = +$1.textxoffset; //#30565
    $1.textyoffset = +$1.textyoffset; //#30566
    $1.textgaps = +$1.textgaps; //#30567
    $1.alttext = "" + $1.alttext; //#30568
    $1.bordercolor = "" + $1.bordercolor; //#30569
    $1.backgroundcolor = "" + $1.backgroundcolor; //#30570
    $1.inkspread = +$1.inkspread; //#30571
    $1.width = +$1.width; //#30572
    $1.barratio = +$1.barratio; //#30573
    $1.spaceratio = +$1.spaceratio; //#30574
    $1.borderleft = +$1.borderleft; //#30575
    $1.borderright = +$1.borderright; //#30576
    $1.bordertop = +$1.bordertop; //#30577
    $1.borderbottom = +$1.borderbottom; //#30578
    $1.borderwidth = +$1.borderwidth; //#30579
    $1.guardleftpos = +$1.guardleftpos; //#30580
    $1.guardleftypos = +$1.guardleftypos; //#30581
    $1.guardrightpos = +$1.guardrightpos; //#30582
    $1.guardrightypos = +$1.guardrightypos; //#30583
    $1.guardwidth = +$1.guardwidth; //#30584
    $1.guardheight = +$1.guardheight; //#30585
    $1.bars = $a(~~(($1.sbs.length + 1) / 2)); //#30588
    $1.x = 0; //#30589
    $1.maxh = 0; //#30589
    for (var _k = 0, _j = ((~~(($1.sbs.length + 1) / 2)) * 2) - 2; _k <= _j; _k += 1) { //#30608
        $1.i = _k; //#30591
        if (($1.i % 2) == 0) { //#30605
            $1.d = $f(($f(($get($1.sbs, $1.i) * $1.barratio) - $1.barratio)) + 1); //#30593
            if ($get($1.sbs, $1.i) != 0) { //#30602
                $1.h = $get($1.bhs, ~~($1.i / 2)) * 72; //#30595
                $1.c = $f(($1.d / 2) + $1.x); //#30596
                $1.y = $get($1.bbs, ~~($1.i / 2)) * 72; //#30597
                $1.w = $f($1.d - $1.inkspread); //#30598
                $put($1.bars, ~~($1.i / 2), $a([$1.h, $1.c, $1.y, $1.w])); //#30599
                if ($f($1.h + $1.y) > $1.maxh) { //#30600
                    $1.maxh = $f($1.h + $1.y); //#30600
                } //#30600
            } else { //#30602
                $put($1.bars, ~~($1.i / 2), -1); //#30602
            } //#30602
        } else { //#30605
            $1.d = $f(($f(($get($1.sbs, $1.i) * $1.spaceratio) - $1.spaceratio)) + 1); //#30605
        } //#30605
        $1.x = $f($1.x + $1.d); //#30607
    } //#30607
    $$.save(); //#30610
    var _1P = $$.currpos(); //#30612
    $$.translate(_1P.x, _1P.y); //#30612
    if ($1.width != 0) { //#30617
        $$.scale(($1.width * 72) / $1.x, 1); //#30616
    } //#30616
    $$.newpath(); //#30620
    $$.moveto(-$1.borderleft, -$1.borderbottom); //#30621
    $$.rlineto($f($f($1.x + $1.borderleft) + $1.borderright), 0); //#30622
    $$.rlineto(0, $f($f($1.maxh + $1.borderbottom) + $1.bordertop)); //#30623
    $$.rlineto(-($f($f($1.x + $1.borderleft) + $1.borderright)), 0); //#30624
    $$.rlineto(0, -($f($f($1.maxh + $1.borderbottom) + $1.bordertop))); //#30625
    $$.closepath(); //#30626
    if ($1.showborder) { //#30634
        $$.save(); //#30630
        if ($ne($1.bordercolor, "unset")) { //#30631
            $$.setcolor($1.bordercolor); //#30631
        } //#30631
        $$.setlinewidth($1.borderwidth); //#30632
        $$.stroke(); //#30632
        $$.restore(); //#30633
    } //#30633
    $$.save(); //#30637
    if ($ne($1.barcolor, "unset")) { //#30639
        $$.setcolor($1.barcolor); //#30639
    } //#30639
    var _1n = $1.bars; //#30640
    for (var _1o = 0, _1p = _1n.length; _1o < _1p; _1o++) { //#30646
        var _1q = $get(_1n, _1o); //#30646
        $k[$j++] = _1q; //#30645
        if (_1q != -1) { //#30644
            $aload($k[--$j]); //#30642
            $$.newpath(); //#30642
            $$.setlinewidth($k[--$j]); //#30642
            var _1t = $k[--$j]; //#30642
            $$.moveto($k[--$j], _1t); //#30642
            $$.rlineto(0, $k[--$j]); //#30642
            $$.stroke(); //#30642
        } else { //#30644
            $j--; //#30644
        } //#30644
    } //#30644
    $$.restore(); //#30647
    if ($ne($1.textcolor, "unset")) { //#30650
        $$.setcolor($1.textcolor); //#30650
    } //#30650
    if ($1.includetext) { //#30707
        if (($eq($1.textxalign, "unset") && $eq($1.textyalign, "unset")) && $eq($1.alttext, "")) { //#30705
            $1.s = 0; //#30653
            $1.fn = ""; //#30653
            var _22 = $1.txt; //#30654
            for (var _23 = 0, _24 = _22.length; _23 < _24; _23++) { //#30663
                $forall($get(_22, _23)); //#30655
                var _26 = $k[--$j]; //#30656
                var _27 = $k[--$j]; //#30656
                $k[$j++] = _27; //#30661
                $k[$j++] = _26; //#30661
                if ((_26 != $1.s) || $ne(_27, $1.fn)) { //#30660
                    var _2A = $k[--$j]; //#30657
                    var _2B = $k[--$j]; //#30657
                    $1.s = _2A; //#30657
                    $1.fn = _2B; //#30657
                    $$.selectfont(_2B, _2A); //#30658
                } else { //#30660
                    $j -= 2; //#30660
                } //#30660
                var _2C = $k[--$j]; //#30662
                $$.moveto($k[--$j], _2C); //#30662
                $$.show($k[--$j], 0, 0); //#30662
            } //#30662
        } else { //#30705
            $$.selectfont($1.textfont, $1.textsize); //#30665
            if ($eq($1.alttext, "")) { //#30671
                $k[$j++] = Infinity; //#30667
                var _2I = $1.txt; //#30667
                for (var _2J = 0, _2K = _2I.length; _2J < _2K; _2J++) { //#30667
                    $forall($get($get(_2I, _2J), 0)); //#30667
                } //#30667
                $1.txt = $a(); //#30667
                $1.tstr = $s($1.txt.length); //#30668
                for (var _2S = 0, _2R = $1.txt.length - 1; _2S <= _2R; _2S += 1) { //#30669
                    $put($1.tstr, _2S, $get($1.txt, _2S)); //#30669
                } //#30669
            } else { //#30671
                $1.tstr = $1.alttext; //#30671
            } //#30671
            if ($1.tstr.length == 0) { //#30681
                $k[$j++] = 0; //#30676
            } else { //#30681
                $$.save(); //#30678
                $$.newpath(); //#30679
                $$.moveto(0, 0); //#30679
                $$.charpath("0", false); //#30679
                var _2Y = $$.pathbbox(); //#30679
                $$.restore(); //#30681
                $k[$j++] = _2Y.ury; //#30681
            } //#30681
            $1.textascent = $k[--$j]; //#30690
            var _2b = $$.stringwidth($1.tstr); //#30691
            $1.textwidth = $f(_2b.w + (($1.tstr.length - 1) * $1.textgaps)); //#30691
            $1.textxpos = $f($1.textxoffset + ($f($1.x - $1.textwidth) / 2)); //#30693
            if ($eq($1.textxalign, "left")) { //#30694
                $1.textxpos = $1.textxoffset; //#30694
            } //#30694
            if ($eq($1.textxalign, "right")) { //#30695
                $1.textxpos = $f($f($1.x - $1.textxoffset) - $1.textwidth); //#30695
            } //#30695
            if ($eq($1.textxalign, "offleft")) { //#30696
                $1.textxpos = -$f($1.textwidth + $1.textxoffset); //#30696
            } //#30696
            if ($eq($1.textxalign, "offright")) { //#30697
                $1.textxpos = $f($1.x + $1.textxoffset); //#30697
            } //#30697
            if ($eq($1.textxalign, "justify") && ($1.textwidth < $1.x)) { //#30701
                $1.textxpos = 0; //#30699
                $1.textgaps = $f($1.x - $1.textwidth) / ($1.tstr.length - 1); //#30700
            } //#30700
            $1.textypos = -($f($f($1.textyoffset + $1.textascent) + 1)); //#30702
            if ($eq($1.textyalign, "above")) { //#30703
                $1.textypos = $f($f($1.textyoffset + $1.maxh) + 1); //#30703
            } //#30703
            if ($eq($1.textyalign, "center")) { //#30704
                $1.textypos = $f($1.textyoffset + ($f($1.maxh - $1.textascent) / 2)); //#30704
            } //#30704
            $$.moveto($1.textxpos, $1.textypos); //#30705
            $$.show($1.tstr, $1.textgaps, 0); //#30705
        } //#30705
    } //#30705
    if ($1.guardwhitespace) { //#30720
        $$.selectfont("OCR-B", $1.guardheight * 2); //#30711
        if ($1.guardleftpos != 0) { //#30715
            $$.moveto($f((-$1.guardleftpos) - 1), $f(($f($1.guardleftypos - ($1.guardheight / 2))) - 1.5)); //#30713
            $$.show("<", 0, 0); //#30714
        } //#30714
        if ($1.guardrightpos != 0) { //#30719
            $$.moveto($f(($f($f($1.guardrightpos + $1.x) - $1.guardwidth)) + 1), $f(($f($1.guardrightypos - ($1.guardheight / 2))) - 1.5)); //#30717
            $$.show(">", 0, 0); //#30718
        } //#30718
    } //#30718
    $$.restore(); //#30722
}

function bwipp_renmaximatrix() {
    if ($0.bwipjs_dontdraw) { //#30742
        return; //#30742
    } //#30742
    var $1 = {}; //#30744
    $1.args = $k[--$j]; //#30746
    $1.barcolor = "unset"; //#30749
    $1.backgroundcolor = "unset"; //#30750
    $forall($1.args, function() { //#30753
        var _3 = $k[--$j]; //#30753
        $1[$k[--$j]] = _3; //#30753
    }); //#30753
    var _5 = $1.opt; //#30754
    for (var _A = _5.size, _9 = _5.keys(), _8 = 0; _8 < _A; _8++) { //#30754
        var _6 = _9.next().value; //#30754
        $1[_6] = _5.get(_6); //#30754
    } //#30754
    $1.barcolor = "" + $1.barcolor; //#30756
    $1.backgroundcolor = "" + $1.backgroundcolor; //#30757
    $$.save(); //#30759
    if ($ne($1.barcolor, "unset")) { //#30761
        $$.setcolor($1.barcolor); //#30761
    } //#30761
    $$.maxicode($1.pixs); //#30762
    $$.restore(); //#30764
}
// bwip-js/barcode-ftr.js
//
// This code is injected below the cross-compiled barcode.js.

// `encoder` is one of the $0_* BWIPP functions
function bwipp_encode(bwipjs, encoder, text, opts, dontdraw) {
    if (typeof text !== 'string') {
        throw new Error('bwipp.typeError: barcode text not a string (' +
            text + ')');
    }
    opts = opts || {};
    if (typeof opts === 'string') {
        var tmp = opts.split(' ');
        opts = {};
        for (var i = 0; i < tmp.length; i++) {
            if (!tmp[i]) {
                continue;
            }
            var eq = tmp[i].indexOf('=');
            if (eq == -1) {
                opts[tmp[i]] = true;
            } else {
                opts[tmp[i].substr(0, eq)] = tmp[i].substr(eq + 1);
            }
        }
    } else if (typeof opts !== 'object' || opts.constructor !== Object) {
        throw new Error('bwipp.typeError: options not an object');
    }

    // Convert utf-16 to utf-8 but leave binary (8-bit) strings untouched.
    if (/[\u0100-\uffff]/.test(text)) {
        text = unescape(encodeURIComponent(text));
    }

    // Don't draw? (See file runtest)
    $0.bwipjs_dontdraw = opts.dontdraw || dontdraw || false;

    // Convert opts to a Map
    var map = new Map;
    for (var id in opts) {
        if (opts.hasOwnProperty(id)) {
            map.set(id, opts[id]);
        }
    }

    // Invoke the encoder
    $$ = bwipjs;
    $k = [text, map];
    $j = 2;
    encoder();

    // Return what is left on the stack.  This branch should only be taken
    // when running with the dontdraw option.
    if ($j) {
        return $k.splice(0, $j);
    }

    return true;
}

function bwipp_lookup(symbol) {
    if (!symbol) {
        throw new Error("bwipp.undefinedEncoder: bcid is not defined");
    }
    switch (symbol.replace(/-/g, "_")) {
        case "auspost":
            return bwipp_auspost;
        case "azteccode":
            return bwipp_azteccode;
        case "azteccodecompact":
            return bwipp_azteccodecompact;
        case "aztecrune":
            return bwipp_aztecrune;
        case "bc412":
            return bwipp_bc412;
        case "channelcode":
            return bwipp_channelcode;
        case "codablockf":
            return bwipp_codablockf;
        case "code11":
            return bwipp_code11;
        case "code128":
            return bwipp_code128;
        case "code16k":
            return bwipp_code16k;
        case "code2of5":
            return bwipp_code2of5;
        case "code32":
            return bwipp_code32;
        case "code39":
            return bwipp_code39;
        case "code39ext":
            return bwipp_code39ext;
        case "code49":
            return bwipp_code49;
        case "code93":
            return bwipp_code93;
        case "code93ext":
            return bwipp_code93ext;
        case "codeone":
            return bwipp_codeone;
        case "coop2of5":
            return bwipp_coop2of5;
        case "daft":
            return bwipp_daft;
        case "databarexpanded":
            return bwipp_databarexpanded;
        case "databarexpandedcomposite":
            return bwipp_databarexpandedcomposite;
        case "databarexpandedstacked":
            return bwipp_databarexpandedstacked;
        case "databarexpandedstackedcomposite":
            return bwipp_databarexpandedstackedcomposite;
        case "databarlimited":
            return bwipp_databarlimited;
        case "databarlimitedcomposite":
            return bwipp_databarlimitedcomposite;
        case "databaromni":
            return bwipp_databaromni;
        case "databaromnicomposite":
            return bwipp_databaromnicomposite;
        case "databarstacked":
            return bwipp_databarstacked;
        case "databarstackedcomposite":
            return bwipp_databarstackedcomposite;
        case "databarstackedomni":
            return bwipp_databarstackedomni;
        case "databarstackedomnicomposite":
            return bwipp_databarstackedomnicomposite;
        case "databartruncated":
            return bwipp_databartruncated;
        case "databartruncatedcomposite":
            return bwipp_databartruncatedcomposite;
        case "datalogic2of5":
            return bwipp_datalogic2of5;
        case "datamatrix":
            return bwipp_datamatrix;
        case "datamatrixrectangular":
            return bwipp_datamatrixrectangular;
        case "datamatrixrectangularextension":
            return bwipp_datamatrixrectangularextension;
        case "dotcode":
            return bwipp_dotcode;
        case "ean13":
            return bwipp_ean13;
        case "ean13composite":
            return bwipp_ean13composite;
        case "ean14":
            return bwipp_ean14;
        case "ean2":
            return bwipp_ean2;
        case "ean5":
            return bwipp_ean5;
        case "ean8":
            return bwipp_ean8;
        case "ean8composite":
            return bwipp_ean8composite;
        case "flattermarken":
            return bwipp_flattermarken;
        case "gs1_128":
            return bwipp_gs1_128;
        case "gs1_128composite":
            return bwipp_gs1_128composite;
        case "gs1_cc":
            return bwipp_gs1_cc;
        case "gs1datamatrix":
            return bwipp_gs1datamatrix;
        case "gs1datamatrixrectangular":
            return bwipp_gs1datamatrixrectangular;
        case "gs1dldatamatrix":
            return bwipp_gs1dldatamatrix;
        case "gs1dlqrcode":
            return bwipp_gs1dlqrcode;
        case "gs1dotcode":
            return bwipp_gs1dotcode;
        case "gs1northamericancoupon":
            return bwipp_gs1northamericancoupon;
        case "gs1qrcode":
            return bwipp_gs1qrcode;
        case "hanxin":
            return bwipp_hanxin;
        case "hibcazteccode":
            return bwipp_hibcazteccode;
        case "hibccodablockf":
            return bwipp_hibccodablockf;
        case "hibccode128":
            return bwipp_hibccode128;
        case "hibccode39":
            return bwipp_hibccode39;
        case "hibcdatamatrix":
            return bwipp_hibcdatamatrix;
        case "hibcdatamatrixrectangular":
            return bwipp_hibcdatamatrixrectangular;
        case "hibcmicropdf417":
            return bwipp_hibcmicropdf417;
        case "hibcpdf417":
            return bwipp_hibcpdf417;
        case "hibcqrcode":
            return bwipp_hibcqrcode;
        case "iata2of5":
            return bwipp_iata2of5;
        case "identcode":
            return bwipp_identcode;
        case "industrial2of5":
            return bwipp_industrial2of5;
        case "interleaved2of5":
            return bwipp_interleaved2of5;
        case "isbn":
            return bwipp_isbn;
        case "ismn":
            return bwipp_ismn;
        case "issn":
            return bwipp_issn;
        case "itf14":
            return bwipp_itf14;
        case "jabcode":
            return bwipp_jabcode;
        case "japanpost":
            return bwipp_japanpost;
        case "kix":
            return bwipp_kix;
        case "leitcode":
            return bwipp_leitcode;
        case "mailmark":
            return bwipp_mailmark;
        case "mands":
            return bwipp_mands;
        case "matrix2of5":
            return bwipp_matrix2of5;
        case "maxicode":
            return bwipp_maxicode;
        case "micropdf417":
            return bwipp_micropdf417;
        case "microqrcode":
            return bwipp_microqrcode;
        case "msi":
            return bwipp_msi;
        case "onecode":
            return bwipp_onecode;
        case "pdf417":
            return bwipp_pdf417;
        case "pdf417compact":
            return bwipp_pdf417compact;
        case "pharmacode":
            return bwipp_pharmacode;
        case "pharmacode2":
            return bwipp_pharmacode2;
        case "planet":
            return bwipp_planet;
        case "plessey":
            return bwipp_plessey;
        case "posicode":
            return bwipp_posicode;
        case "postnet":
            return bwipp_postnet;
        case "pzn":
            return bwipp_pzn;
        case "qrcode":
            return bwipp_qrcode;
        case "rationalizedCodabar":
            return bwipp_rationalizedCodabar;
        case "raw":
            return bwipp_raw;
        case "rectangularmicroqrcode":
            return bwipp_rectangularmicroqrcode;
        case "royalmail":
            return bwipp_royalmail;
        case "sscc18":
            return bwipp_sscc18;
        case "swissqrcode":
            return bwipp_swissqrcode;
        case "symbol":
            return bwipp_symbol;
        case "telepen":
            return bwipp_telepen;
        case "telepennumeric":
            return bwipp_telepennumeric;
        case "ultracode":
            return bwipp_ultracode;
        case "upca":
            return bwipp_upca;
        case "upcacomposite":
            return bwipp_upcacomposite;
        case "upce":
            return bwipp_upce;
        case "upcecomposite":
            return bwipp_upcecomposite;
    }
    throw new Error("bwipp.unknownEncoder: unknown encoder name: " + symbol);
}
var BWIPP_VERSION = '2022-10-19';
export { bwipp_auspost,bwipp_azteccode,bwipp_azteccodecompact,bwipp_aztecrune,bwipp_bc412,bwipp_channelcode,bwipp_codablockf,bwipp_code11,bwipp_code128,bwipp_code16k,bwipp_code2of5,bwipp_code32,bwipp_code39,bwipp_code39ext,bwipp_code49,bwipp_code93,bwipp_code93ext,bwipp_codeone,bwipp_coop2of5,bwipp_daft,bwipp_databarexpanded,bwipp_databarexpandedcomposite,bwipp_databarexpandedstacked,bwipp_databarexpandedstackedcomposite,bwipp_databarlimited,bwipp_databarlimitedcomposite,bwipp_databaromni,bwipp_databaromnicomposite,bwipp_databarstacked,bwipp_databarstackedcomposite,bwipp_databarstackedomni,bwipp_databarstackedomnicomposite,bwipp_databartruncated,bwipp_databartruncatedcomposite,bwipp_datalogic2of5,bwipp_datamatrix,bwipp_datamatrixrectangular,bwipp_datamatrixrectangularextension,bwipp_dotcode,bwipp_ean13,bwipp_ean13composite,bwipp_ean14,bwipp_ean2,bwipp_ean5,bwipp_ean8,bwipp_ean8composite,bwipp_flattermarken,bwipp_gs1_128,bwipp_gs1_128composite,bwipp_gs1_cc,bwipp_gs1datamatrix,bwipp_gs1datamatrixrectangular,bwipp_gs1dldatamatrix,bwipp_gs1dlqrcode,bwipp_gs1dotcode,bwipp_gs1northamericancoupon,bwipp_gs1qrcode,bwipp_hanxin,bwipp_hibcazteccode,bwipp_hibccodablockf,bwipp_hibccode128,bwipp_hibccode39,bwipp_hibcdatamatrix,bwipp_hibcdatamatrixrectangular,bwipp_hibcmicropdf417,bwipp_hibcpdf417,bwipp_hibcqrcode,bwipp_iata2of5,bwipp_identcode,bwipp_industrial2of5,bwipp_interleaved2of5,bwipp_isbn,bwipp_ismn,bwipp_issn,bwipp_itf14,bwipp_jabcode,bwipp_japanpost,bwipp_kix,bwipp_leitcode,bwipp_mailmark,bwipp_mands,bwipp_matrix2of5,bwipp_maxicode,bwipp_micropdf417,bwipp_microqrcode,bwipp_msi,bwipp_onecode,bwipp_pdf417,bwipp_pdf417compact,bwipp_pharmacode,bwipp_pharmacode2,bwipp_planet,bwipp_plessey,bwipp_posicode,bwipp_postnet,bwipp_pzn,bwipp_qrcode,bwipp_rationalizedCodabar,bwipp_raw,bwipp_rectangularmicroqrcode,bwipp_royalmail,bwipp_sscc18,bwipp_swissqrcode,bwipp_symbol,bwipp_telepen,bwipp_telepennumeric,bwipp_ultracode,bwipp_upca,bwipp_upcacomposite,bwipp_upce,bwipp_upcecomposite,bwipp_lookup,bwipp_encode,BWIPP_VERSION };
